--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Enclosed_Ideographic_Sup is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Square_Hiragana_Hoka                    :
      constant Unicode_Char := 16#1F200#;
   Squared_Katakana_Koko                   :
      constant Unicode_Char := 16#1F201#;
   Squared_Katakana_Sa                     :
      constant Unicode_Char := 16#1F202#;
   Squared_Cjk_Unified_Ideograph_624b      :
      constant Unicode_Char := 16#1F210#;
   Squared_Cjk_Unified_Ideograph_5b57      :
      constant Unicode_Char := 16#1F211#;
   Squared_Cjk_Unified_Ideograph_53cc      :
      constant Unicode_Char := 16#1F212#;
   Squared_Katakana_De                     :
      constant Unicode_Char := 16#1F213#;
   Squared_Cjk_Unified_Ideograph_4e8c      :
      constant Unicode_Char := 16#1F214#;
   Squared_Cjk_Unified_Ideograph_591a      :
      constant Unicode_Char := 16#1F215#;
   Squared_Cjk_Unified_Ideograph_89e3      :
      constant Unicode_Char := 16#1F216#;
   Squared_Cjk_Unified_Ideograph_5929      :
      constant Unicode_Char := 16#1F217#;
   Squared_Cjk_Unified_Ideograph_4ea4      :
      constant Unicode_Char := 16#1F218#;
   Squared_Cjk_Unified_Ideograph_6620      :
      constant Unicode_Char := 16#1F219#;
   Squared_Cjk_Unified_Ideograph_7121      :
      constant Unicode_Char := 16#1F21A#;
   Squared_Cjk_Unified_Ideograph_6599      :
      constant Unicode_Char := 16#1F21B#;
   Squared_Cjk_Unified_Ideograph_524d      :
      constant Unicode_Char := 16#1F21C#;
   Squared_Cjk_Unified_Ideograph_5f8c      :
      constant Unicode_Char := 16#1F21D#;
   Squared_Cjk_Unified_Ideograph_518d      :
      constant Unicode_Char := 16#1F21E#;
   Squared_Cjk_Unified_Ideograph_65b0      :
      constant Unicode_Char := 16#1F21F#;
   Squared_Cjk_Unified_Ideograph_521d      :
      constant Unicode_Char := 16#1F220#;
   Squared_Cjk_Unified_Ideograph_7d42      :
      constant Unicode_Char := 16#1F221#;
   Squared_Cjk_Unified_Ideograph_751f      :
      constant Unicode_Char := 16#1F222#;
   Squared_Cjk_Unified_Ideograph_8ca9      :
      constant Unicode_Char := 16#1F223#;
   Squared_Cjk_Unified_Ideograph_58f0      :
      constant Unicode_Char := 16#1F224#;
   Squared_Cjk_Unified_Ideograph_5439      :
      constant Unicode_Char := 16#1F225#;
   Squared_Cjk_Unified_Ideograph_6f14      :
      constant Unicode_Char := 16#1F226#;
   Squared_Cjk_Unified_Ideograph_6295      :
      constant Unicode_Char := 16#1F227#;
   Squared_Cjk_Unified_Ideograph_6355      :
      constant Unicode_Char := 16#1F228#;
   Squared_Cjk_Unified_Ideograph_4e00      :
      constant Unicode_Char := 16#1F229#;
   Squared_Cjk_Unified_Ideograph_4e09      :
      constant Unicode_Char := 16#1F22A#;
   Squared_Cjk_Unified_Ideograph_904a      :
      constant Unicode_Char := 16#1F22B#;
   Squared_Cjk_Unified_Ideograph_5de6      :
      constant Unicode_Char := 16#1F22C#;
   Squared_Cjk_Unified_Ideograph_4e2d      :
      constant Unicode_Char := 16#1F22D#;
   Squared_Cjk_Unified_Ideograph_53f3      :
      constant Unicode_Char := 16#1F22E#;
   Squared_Cjk_Unified_Ideograph_6307      :
      constant Unicode_Char := 16#1F22F#;
   Squared_Cjk_Unified_Ideograph_8d70      :
      constant Unicode_Char := 16#1F230#;
   Squared_Cjk_Unified_Ideograph_6253      :
      constant Unicode_Char := 16#1F231#;
   Squared_Cjk_Unified_Ideograph_7981      :
      constant Unicode_Char := 16#1F232#;
   Squared_Cjk_Unified_Ideograph_7a7a      :
      constant Unicode_Char := 16#1F233#;
   Squared_Cjk_Unified_Ideograph_5408      :
      constant Unicode_Char := 16#1F234#;
   Squared_Cjk_Unified_Ideograph_6e80      :
      constant Unicode_Char := 16#1F235#;
   Squared_Cjk_Unified_Ideograph_6709      :
      constant Unicode_Char := 16#1F236#;
   Squared_Cjk_Unified_Ideograph_6708      :
      constant Unicode_Char := 16#1F237#;
   Squared_Cjk_Unified_Ideograph_7533      :
      constant Unicode_Char := 16#1F238#;
   Squared_Cjk_Unified_Ideograph_5272      :
      constant Unicode_Char := 16#1F239#;
   Squared_Cjk_Unified_Ideograph_55b6      :
      constant Unicode_Char := 16#1F23A#;
   Tortoise_Shell_Bracketed_Cjk_Unified_Ideograph_672c :
      constant Unicode_Char := 16#1F240#;
   Tortoise_Shell_Bracketed_Cjk_Unified_Ideograph_4e09 :
      constant Unicode_Char := 16#1F241#;
   Tortoise_Shell_Bracketed_Cjk_Unified_Ideograph_4e8c :
      constant Unicode_Char := 16#1F242#;
   Tortoise_Shell_Bracketed_Cjk_Unified_Ideograph_5b89 :
      constant Unicode_Char := 16#1F243#;
   Tortoise_Shell_Bracketed_Cjk_Unified_Ideograph_70b9 :
      constant Unicode_Char := 16#1F244#;
   Tortoise_Shell_Bracketed_Cjk_Unified_Ideograph_6253 :
      constant Unicode_Char := 16#1F245#;
   Tortoise_Shell_Bracketed_Cjk_Unified_Ideograph_76d7 :
      constant Unicode_Char := 16#1F246#;
   Tortoise_Shell_Bracketed_Cjk_Unified_Ideograph_52dd :
      constant Unicode_Char := 16#1F247#;
   Tortoise_Shell_Bracketed_Cjk_Unified_Ideograph_6557 :
      constant Unicode_Char := 16#1F248#;
   Circled_Ideograph_Advantage             :
      constant Unicode_Char := 16#1F250#;
   Circled_Ideograph_Accept                :
      constant Unicode_Char := 16#1F251#;
end Unicode.Names.Enclosed_Ideographic_Sup;
