--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Supplemental_Arrows_C is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Leftwards_Arrow_With_Small_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F800#;
   Upwards_Arrow_With_Small_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F801#;
   Rightwards_Arrow_With_Small_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F802#;
   Downwards_Arrow_With_Small_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F803#;
   Leftwards_Arrow_With_Medium_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F804#;
   Upwards_Arrow_With_Medium_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F805#;
   Rightwards_Arrow_With_Medium_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F806#;
   Downwards_Arrow_With_Medium_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F807#;
   Leftwards_Arrow_With_Large_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F808#;
   Upwards_Arrow_With_Large_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F809#;
   Rightwards_Arrow_With_Large_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F80A#;
   Downwards_Arrow_With_Large_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F80B#;
   Leftwards_Arrow_With_Small_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F810#;
   Upwards_Arrow_With_Small_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F811#;
   Rightwards_Arrow_With_Small_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F812#;
   Downwards_Arrow_With_Small_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F813#;
   Leftwards_Arrow_With_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F814#;
   Upwards_Arrow_With_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F815#;
   Rightwards_Arrow_With_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F816#;
   Downwards_Arrow_With_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F817#;
   Heavy_Leftwards_Arrow_With_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F818#;
   Heavy_Upwards_Arrow_With_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F819#;
   Heavy_Rightwards_Arrow_With_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F81A#;
   Heavy_Downwards_Arrow_With_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F81B#;
   Heavy_Leftwards_Arrow_With_Large_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F81C#;
   Heavy_Upwards_Arrow_With_Large_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F81D#;
   Heavy_Rightwards_Arrow_With_Large_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F81E#;
   Heavy_Downwards_Arrow_With_Large_Equilateral_Arrowhead :
      constant Unicode_Char := 16#1F81F#;
   Leftwards_Triangle_Headed_Arrow_With_Narrow_Shaft :
      constant Unicode_Char := 16#1F820#;
   Upwards_Triangle_Headed_Arrow_With_Narrow_Shaft :
      constant Unicode_Char := 16#1F821#;
   Rightwards_Triangle_Headed_Arrow_With_Narrow_Shaft :
      constant Unicode_Char := 16#1F822#;
   Downwards_Triangle_Headed_Arrow_With_Narrow_Shaft :
      constant Unicode_Char := 16#1F823#;
   Leftwards_Triangle_Headed_Arrow_With_Medium_Shaft :
      constant Unicode_Char := 16#1F824#;
   Upwards_Triangle_Headed_Arrow_With_Medium_Shaft :
      constant Unicode_Char := 16#1F825#;
   Rightwards_Triangle_Headed_Arrow_With_Medium_Shaft :
      constant Unicode_Char := 16#1F826#;
   Downwards_Triangle_Headed_Arrow_With_Medium_Shaft :
      constant Unicode_Char := 16#1F827#;
   Leftwards_Triangle_Headed_Arrow_With_Bold_Shaft :
      constant Unicode_Char := 16#1F828#;
   Upwards_Triangle_Headed_Arrow_With_Bold_Shaft :
      constant Unicode_Char := 16#1F829#;
   Rightwards_Triangle_Headed_Arrow_With_Bold_Shaft :
      constant Unicode_Char := 16#1F82A#;
   Downwards_Triangle_Headed_Arrow_With_Bold_Shaft :
      constant Unicode_Char := 16#1F82B#;
   Leftwards_Triangle_Headed_Arrow_With_Heavy_Shaft :
      constant Unicode_Char := 16#1F82C#;
   Upwards_Triangle_Headed_Arrow_With_Heavy_Shaft :
      constant Unicode_Char := 16#1F82D#;
   Rightwards_Triangle_Headed_Arrow_With_Heavy_Shaft :
      constant Unicode_Char := 16#1F82E#;
   Downwards_Triangle_Headed_Arrow_With_Heavy_Shaft :
      constant Unicode_Char := 16#1F82F#;
   Leftwards_Triangle_Headed_Arrow_With_Very_Heavy_Shaft :
      constant Unicode_Char := 16#1F830#;
   Upwards_Triangle_Headed_Arrow_With_Very_Heavy_Shaft :
      constant Unicode_Char := 16#1F831#;
   Rightwards_Triangle_Headed_Arrow_With_Very_Heavy_Shaft :
      constant Unicode_Char := 16#1F832#;
   Downwards_Triangle_Headed_Arrow_With_Very_Heavy_Shaft :
      constant Unicode_Char := 16#1F833#;
   Leftwards_Finger_Post_Arrow             :
      constant Unicode_Char := 16#1F834#;
   Upwards_Finger_Post_Arrow               :
      constant Unicode_Char := 16#1F835#;
   Rightwards_Finger_Post_Arrow            :
      constant Unicode_Char := 16#1F836#;
   Downwards_Finger_Post_Arrow             :
      constant Unicode_Char := 16#1F837#;
   Leftwards_Squared_Arrow                 :
      constant Unicode_Char := 16#1F838#;
   Upwards_Squared_Arrow                   :
      constant Unicode_Char := 16#1F839#;
   Rightwards_Squared_Arrow                :
      constant Unicode_Char := 16#1F83A#;
   Downwards_Squared_Arrow                 :
      constant Unicode_Char := 16#1F83B#;
   Leftwards_Compressed_Arrow              :
      constant Unicode_Char := 16#1F83C#;
   Upwards_Compressed_Arrow                :
      constant Unicode_Char := 16#1F83D#;
   Rightwards_Compressed_Arrow             :
      constant Unicode_Char := 16#1F83E#;
   Downwards_Compressed_Arrow              :
      constant Unicode_Char := 16#1F83F#;
   Leftwards_Heavy_Compressed_Arrow        :
      constant Unicode_Char := 16#1F840#;
   Upwards_Heavy_Compressed_Arrow          :
      constant Unicode_Char := 16#1F841#;
   Rightwards_Heavy_Compressed_Arrow       :
      constant Unicode_Char := 16#1F842#;
   Downwards_Heavy_Compressed_Arrow        :
      constant Unicode_Char := 16#1F843#;
   Leftwards_Heavy_Arrow                   :
      constant Unicode_Char := 16#1F844#;
   Upwards_Heavy_Arrow                     :
      constant Unicode_Char := 16#1F845#;
   Rightwards_Heavy_Arrow                  :
      constant Unicode_Char := 16#1F846#;
   Downwards_Heavy_Arrow                   :
      constant Unicode_Char := 16#1F847#;
   Leftwards_Sans_Serif_Arrow              :
      constant Unicode_Char := 16#1F850#;
   Upwards_Sans_Serif_Arrow                :
      constant Unicode_Char := 16#1F851#;
   Rightwards_Sans_Serif_Arrow             :
      constant Unicode_Char := 16#1F852#;
   Downwards_Sans_Serif_Arrow              :
      constant Unicode_Char := 16#1F853#;
   North_West_Sans_Serif_Arrow             :
      constant Unicode_Char := 16#1F854#;
   North_East_Sans_Serif_Arrow             :
      constant Unicode_Char := 16#1F855#;
   South_East_Sans_Serif_Arrow             :
      constant Unicode_Char := 16#1F856#;
   South_West_Sans_Serif_Arrow             :
      constant Unicode_Char := 16#1F857#;
   Left_Right_Sans_Serif_Arrow             :
      constant Unicode_Char := 16#1F858#;
   Up_Down_Sans_Serif_Arrow                :
      constant Unicode_Char := 16#1F859#;
   Wide_Headed_Leftwards_Light_Barb_Arrow  :
      constant Unicode_Char := 16#1F860#;
   Wide_Headed_Upwards_Light_Barb_Arrow    :
      constant Unicode_Char := 16#1F861#;
   Wide_Headed_Rightwards_Light_Barb_Arrow :
      constant Unicode_Char := 16#1F862#;
   Wide_Headed_Downwards_Light_Barb_Arrow  :
      constant Unicode_Char := 16#1F863#;
   Wide_Headed_North_West_Light_Barb_Arrow :
      constant Unicode_Char := 16#1F864#;
   Wide_Headed_North_East_Light_Barb_Arrow :
      constant Unicode_Char := 16#1F865#;
   Wide_Headed_South_East_Light_Barb_Arrow :
      constant Unicode_Char := 16#1F866#;
   Wide_Headed_South_West_Light_Barb_Arrow :
      constant Unicode_Char := 16#1F867#;
   Wide_Headed_Leftwards_Barb_Arrow        :
      constant Unicode_Char := 16#1F868#;
   Wide_Headed_Upwards_Barb_Arrow          :
      constant Unicode_Char := 16#1F869#;
   Wide_Headed_Rightwards_Barb_Arrow       :
      constant Unicode_Char := 16#1F86A#;
   Wide_Headed_Downwards_Barb_Arrow        :
      constant Unicode_Char := 16#1F86B#;
   Wide_Headed_North_West_Barb_Arrow       :
      constant Unicode_Char := 16#1F86C#;
   Wide_Headed_North_East_Barb_Arrow       :
      constant Unicode_Char := 16#1F86D#;
   Wide_Headed_South_East_Barb_Arrow       :
      constant Unicode_Char := 16#1F86E#;
   Wide_Headed_South_West_Barb_Arrow       :
      constant Unicode_Char := 16#1F86F#;
   Wide_Headed_Leftwards_Medium_Barb_Arrow :
      constant Unicode_Char := 16#1F870#;
   Wide_Headed_Upwards_Medium_Barb_Arrow   :
      constant Unicode_Char := 16#1F871#;
   Wide_Headed_Rightwards_Medium_Barb_Arrow :
      constant Unicode_Char := 16#1F872#;
   Wide_Headed_Downwards_Medium_Barb_Arrow :
      constant Unicode_Char := 16#1F873#;
   Wide_Headed_North_West_Medium_Barb_Arrow :
      constant Unicode_Char := 16#1F874#;
   Wide_Headed_North_East_Medium_Barb_Arrow :
      constant Unicode_Char := 16#1F875#;
   Wide_Headed_South_East_Medium_Barb_Arrow :
      constant Unicode_Char := 16#1F876#;
   Wide_Headed_South_West_Medium_Barb_Arrow :
      constant Unicode_Char := 16#1F877#;
   Wide_Headed_Leftwards_Heavy_Barb_Arrow  :
      constant Unicode_Char := 16#1F878#;
   Wide_Headed_Upwards_Heavy_Barb_Arrow    :
      constant Unicode_Char := 16#1F879#;
   Wide_Headed_Rightwards_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F87A#;
   Wide_Headed_Downwards_Heavy_Barb_Arrow  :
      constant Unicode_Char := 16#1F87B#;
   Wide_Headed_North_West_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F87C#;
   Wide_Headed_North_East_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F87D#;
   Wide_Headed_South_East_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F87E#;
   Wide_Headed_South_West_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F87F#;
   Wide_Headed_Leftwards_Very_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F880#;
   Wide_Headed_Upwards_Very_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F881#;
   Wide_Headed_Rightwards_Very_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F882#;
   Wide_Headed_Downwards_Very_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F883#;
   Wide_Headed_North_West_Very_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F884#;
   Wide_Headed_North_East_Very_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F885#;
   Wide_Headed_South_East_Very_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F886#;
   Wide_Headed_South_West_Very_Heavy_Barb_Arrow :
      constant Unicode_Char := 16#1F887#;
   Leftwards_Triangle_Arrowhead            :
      constant Unicode_Char := 16#1F890#;
   Upwards_Triangle_Arrowhead              :
      constant Unicode_Char := 16#1F891#;
   Rightwards_Triangle_Arrowhead           :
      constant Unicode_Char := 16#1F892#;
   Downwards_Triangle_Arrowhead            :
      constant Unicode_Char := 16#1F893#;
   Leftwards_White_Arrow_Within_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F894#;
   Upwards_White_Arrow_Within_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F895#;
   Rightwards_White_Arrow_Within_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F896#;
   Downwards_White_Arrow_Within_Triangle_Arrowhead :
      constant Unicode_Char := 16#1F897#;
   Leftwards_Arrow_With_Notched_Tail       :
      constant Unicode_Char := 16#1F898#;
   Upwards_Arrow_With_Notched_Tail         :
      constant Unicode_Char := 16#1F899#;
   Rightwards_Arrow_With_Notched_Tail      :
      constant Unicode_Char := 16#1F89A#;
   Downwards_Arrow_With_Notched_Tail       :
      constant Unicode_Char := 16#1F89B#;
   Heavy_Arrow_Shaft_Width_One             :
      constant Unicode_Char := 16#1F89C#;
   Heavy_Arrow_Shaft_Width_Two_Thirds      :
      constant Unicode_Char := 16#1F89D#;
   Heavy_Arrow_Shaft_Width_One_Half        :
      constant Unicode_Char := 16#1F89E#;
   Heavy_Arrow_Shaft_Width_One_Third       :
      constant Unicode_Char := 16#1F89F#;
   Leftwards_Bottom_Shaded_White_Arrow     :
      constant Unicode_Char := 16#1F8A0#;
   Rightwards_Bottom_Shaded_White_Arrow    :
      constant Unicode_Char := 16#1F8A1#;
   Leftwards_Top_Shaded_White_Arrow        :
      constant Unicode_Char := 16#1F8A2#;
   Rightwards_Top_Shaded_White_Arrow       :
      constant Unicode_Char := 16#1F8A3#;
   Leftwards_Left_Shaded_White_Arrow       :
      constant Unicode_Char := 16#1F8A4#;
   Rightwards_Right_Shaded_White_Arrow     :
      constant Unicode_Char := 16#1F8A5#;
   Leftwards_Right_Shaded_White_Arrow      :
      constant Unicode_Char := 16#1F8A6#;
   Rightwards_Left_Shaded_White_Arrow      :
      constant Unicode_Char := 16#1F8A7#;
   Leftwards_Back_Tilted_Shadowed_White_Arrow :
      constant Unicode_Char := 16#1F8A8#;
   Rightwards_Back_Tilted_Shadowed_White_Arrow :
      constant Unicode_Char := 16#1F8A9#;
   Leftwards_Front_Tilted_Shadowed_White_Arrow :
      constant Unicode_Char := 16#1F8AA#;
   Rightwards_Front_Tilted_Shadowed_White_Arrow :
      constant Unicode_Char := 16#1F8AB#;
   White_Arrow_Shaft_Width_One             :
      constant Unicode_Char := 16#1F8AC#;
   White_Arrow_Shaft_Width_Two_Thirds      :
      constant Unicode_Char := 16#1F8AD#;
end Unicode.Names.Supplemental_Arrows_C;
