--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Latin_Extended_B is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Latin_Small_Letter_B_With_Stroke        : constant Unicode_Char := 16#0180#;
   Latin_Capital_Letter_B_With_Hook        : constant Unicode_Char := 16#0181#;
   Latin_Capital_Letter_B_With_Topbar      : constant Unicode_Char := 16#0182#;
   Latin_Small_Letter_B_With_Topbar        : constant Unicode_Char := 16#0183#;
   Latin_Capital_Letter_Tone_Six           : constant Unicode_Char := 16#0184#;
   Latin_Small_Letter_Tone_Six             : constant Unicode_Char := 16#0185#;
   Latin_Capital_Letter_Open_O             : constant Unicode_Char := 16#0186#;
   Latin_Capital_Letter_C_With_Hook        : constant Unicode_Char := 16#0187#;
   Latin_Small_Letter_C_With_Hook          : constant Unicode_Char := 16#0188#;
   Latin_Capital_Letter_African_D          : constant Unicode_Char := 16#0189#;
   Latin_Capital_Letter_D_With_Hook        : constant Unicode_Char := 16#018A#;
   Latin_Capital_Letter_D_With_Topbar      : constant Unicode_Char := 16#018B#;
   Latin_Small_Letter_D_With_Topbar        : constant Unicode_Char := 16#018C#;
   Latin_Small_Letter_Turned_Delta         : constant Unicode_Char := 16#018D#;
   Latin_Capital_Letter_Reversed_E         : constant Unicode_Char := 16#018E#;
   Latin_Capital_Letter_Schwa              : constant Unicode_Char := 16#018F#;
   Latin_Capital_Letter_Open_E             : constant Unicode_Char := 16#0190#;
   Latin_Capital_Letter_F_With_Hook        : constant Unicode_Char := 16#0191#;
   Latin_Small_Letter_F_With_Hook          : constant Unicode_Char := 16#0192#;
   Latin_Capital_Letter_G_With_Hook        : constant Unicode_Char := 16#0193#;
   Latin_Capital_Letter_Gamma              : constant Unicode_Char := 16#0194#;
   Latin_Small_Letter_Hv                   : constant Unicode_Char := 16#0195#;
   Latin_Capital_Letter_Iota               : constant Unicode_Char := 16#0196#;
   Latin_Capital_Letter_I_With_Stroke      : constant Unicode_Char := 16#0197#;
   Latin_Capital_Letter_K_With_Hook        : constant Unicode_Char := 16#0198#;
   Latin_Small_Letter_K_With_Hook          : constant Unicode_Char := 16#0199#;
   Latin_Small_Letter_L_With_Bar           : constant Unicode_Char := 16#019A#;
   Latin_Small_Letter_Lambda_With_Stroke   : constant Unicode_Char := 16#019B#;
   Latin_Capital_Letter_Turned_M           : constant Unicode_Char := 16#019C#;
   Latin_Capital_Letter_N_With_Left_Hook   : constant Unicode_Char := 16#019D#;
   Latin_Small_Letter_N_With_Long_Right_Leg :
      constant Unicode_Char := 16#019E#;
   Latin_Capital_Letter_O_With_Middle_Tilde :
      constant Unicode_Char := 16#019F#;
   Latin_Capital_Letter_O_With_Horn        : constant Unicode_Char := 16#01A0#;
   Latin_Small_Letter_O_With_Horn          : constant Unicode_Char := 16#01A1#;
   Latin_Capital_Letter_Oi                 : constant Unicode_Char := 16#01A2#;
   Latin_Capital_Letter_Gha                :
      Unicode_Char renames Latin_Capital_Letter_Oi;
   Latin_Small_Letter_Oi                   : constant Unicode_Char := 16#01A3#;
   Latin_Small_Letter_Gha                  :
      Unicode_Char renames Latin_Small_Letter_Oi;
   Latin_Capital_Letter_P_With_Hook        : constant Unicode_Char := 16#01A4#;
   Latin_Small_Letter_P_With_Hook          : constant Unicode_Char := 16#01A5#;
   Latin_Letter_Yr                         : constant Unicode_Char := 16#01A6#;
   Latin_Capital_Letter_Tone_Two           : constant Unicode_Char := 16#01A7#;
   Latin_Small_Letter_Tone_Two             : constant Unicode_Char := 16#01A8#;
   Latin_Capital_Letter_Esh                : constant Unicode_Char := 16#01A9#;
   Latin_Letter_Reversed_Esh_Loop          : constant Unicode_Char := 16#01AA#;
   Latin_Small_Letter_T_With_Palatal_Hook  : constant Unicode_Char := 16#01AB#;
   Latin_Capital_Letter_T_With_Hook        : constant Unicode_Char := 16#01AC#;
   Latin_Small_Letter_T_With_Hook          : constant Unicode_Char := 16#01AD#;
   Latin_Capital_Letter_T_With_Retroflex_Hook :
      constant Unicode_Char := 16#01AE#;
   Latin_Capital_Letter_U_With_Horn        : constant Unicode_Char := 16#01AF#;
   Latin_Small_Letter_U_With_Horn          : constant Unicode_Char := 16#01B0#;
   Latin_Capital_Letter_Upsilon            : constant Unicode_Char := 16#01B1#;
   Latin_Capital_Letter_V_With_Hook        : constant Unicode_Char := 16#01B2#;
   Latin_Capital_Letter_Y_With_Hook        : constant Unicode_Char := 16#01B3#;
   Latin_Small_Letter_Y_With_Hook          : constant Unicode_Char := 16#01B4#;
   Latin_Capital_Letter_Z_With_Stroke      : constant Unicode_Char := 16#01B5#;
   Latin_Small_Letter_Z_With_Stroke        : constant Unicode_Char := 16#01B6#;
   Latin_Capital_Letter_Ezh                : constant Unicode_Char := 16#01B7#;
   Latin_Capital_Letter_Ezh_Reversed       : constant Unicode_Char := 16#01B8#;
   Latin_Small_Letter_Ezh_Reversed         : constant Unicode_Char := 16#01B9#;
   Latin_Small_Letter_Ezh_With_Tail        : constant Unicode_Char := 16#01BA#;
   Latin_Letter_Two_With_Stroke            : constant Unicode_Char := 16#01BB#;
   Latin_Capital_Letter_Tone_Five          : constant Unicode_Char := 16#01BC#;
   Latin_Small_Letter_Tone_Five            : constant Unicode_Char := 16#01BD#;
   Latin_Letter_Inverted_Glottal_Stop_With_Stroke :
      constant Unicode_Char := 16#01BE#;
   Latin_Letter_Wynn                       : constant Unicode_Char := 16#01BF#;
   Latin_Letter_Dental_Click               : constant Unicode_Char := 16#01C0#;
   Latin_Letter_Lateral_Click              : constant Unicode_Char := 16#01C1#;
   Latin_Letter_Alveolar_Click             : constant Unicode_Char := 16#01C2#;
   Latin_Letter_Retroflex_Click            : constant Unicode_Char := 16#01C3#;
   Latin_Capital_Letter_Dz_With_Caron      : constant Unicode_Char := 16#01C4#;
   Latin_Capital_Letter_D_With_Small_Letter_Z_With_Caron :
      constant Unicode_Char := 16#01C5#;
   Latin_Small_Letter_Dz_With_Caron        : constant Unicode_Char := 16#01C6#;
   Latin_Capital_Letter_Lj                 : constant Unicode_Char := 16#01C7#;
   Latin_Capital_Letter_L_With_Small_Letter_J :
      constant Unicode_Char := 16#01C8#;
   Latin_Small_Letter_Lj                   : constant Unicode_Char := 16#01C9#;
   Latin_Capital_Letter_Nj                 : constant Unicode_Char := 16#01CA#;
   Latin_Capital_Letter_N_With_Small_Letter_J :
      constant Unicode_Char := 16#01CB#;
   Latin_Small_Letter_Nj                   : constant Unicode_Char := 16#01CC#;
   Latin_Capital_Letter_A_With_Caron       : constant Unicode_Char := 16#01CD#;
   Latin_Small_Letter_A_With_Caron         : constant Unicode_Char := 16#01CE#;
   Latin_Capital_Letter_I_With_Caron       : constant Unicode_Char := 16#01CF#;
   Latin_Small_Letter_I_With_Caron         : constant Unicode_Char := 16#01D0#;
   Latin_Capital_Letter_O_With_Caron       : constant Unicode_Char := 16#01D1#;
   Latin_Small_Letter_O_With_Caron         : constant Unicode_Char := 16#01D2#;
   Latin_Capital_Letter_U_With_Caron       : constant Unicode_Char := 16#01D3#;
   Latin_Small_Letter_U_With_Caron         : constant Unicode_Char := 16#01D4#;
   Latin_Capital_Letter_U_With_Diaeresis_And_Macron :
      constant Unicode_Char := 16#01D5#;
   Latin_Small_Letter_U_With_Diaeresis_And_Macron :
      constant Unicode_Char := 16#01D6#;
   Latin_Capital_Letter_U_With_Diaeresis_And_Acute :
      constant Unicode_Char := 16#01D7#;
   Latin_Small_Letter_U_With_Diaeresis_And_Acute :
      constant Unicode_Char := 16#01D8#;
   Latin_Capital_Letter_U_With_Diaeresis_And_Caron :
      constant Unicode_Char := 16#01D9#;
   Latin_Small_Letter_U_With_Diaeresis_And_Caron :
      constant Unicode_Char := 16#01DA#;
   Latin_Capital_Letter_U_With_Diaeresis_And_Grave :
      constant Unicode_Char := 16#01DB#;
   Latin_Small_Letter_U_With_Diaeresis_And_Grave :
      constant Unicode_Char := 16#01DC#;
   Latin_Small_Letter_Turned_E             : constant Unicode_Char := 16#01DD#;
   Latin_Capital_Letter_A_With_Diaeresis_And_Macron :
      constant Unicode_Char := 16#01DE#;
   Latin_Small_Letter_A_With_Diaeresis_And_Macron :
      constant Unicode_Char := 16#01DF#;
   Latin_Capital_Letter_A_With_Dot_Above_And_Macron :
      constant Unicode_Char := 16#01E0#;
   Latin_Small_Letter_A_With_Dot_Above_And_Macron :
      constant Unicode_Char := 16#01E1#;
   Latin_Capital_Letter_Ae_With_Macron     : constant Unicode_Char := 16#01E2#;
   Latin_Small_Letter_Ae_With_Macron       : constant Unicode_Char := 16#01E3#;
   Latin_Capital_Letter_G_With_Stroke      : constant Unicode_Char := 16#01E4#;
   Latin_Small_Letter_G_With_Stroke        : constant Unicode_Char := 16#01E5#;
   Latin_Capital_Letter_G_With_Caron       : constant Unicode_Char := 16#01E6#;
   Latin_Small_Letter_G_With_Caron         : constant Unicode_Char := 16#01E7#;
   Latin_Capital_Letter_K_With_Caron       : constant Unicode_Char := 16#01E8#;
   Latin_Small_Letter_K_With_Caron         : constant Unicode_Char := 16#01E9#;
   Latin_Capital_Letter_O_With_Ogonek      : constant Unicode_Char := 16#01EA#;
   Latin_Small_Letter_O_With_Ogonek        : constant Unicode_Char := 16#01EB#;
   Latin_Capital_Letter_O_With_Ogonek_And_Macron :
      constant Unicode_Char := 16#01EC#;
   Latin_Small_Letter_O_With_Ogonek_And_Macron :
      constant Unicode_Char := 16#01ED#;
   Latin_Capital_Letter_Ezh_With_Caron     : constant Unicode_Char := 16#01EE#;
   Latin_Small_Letter_Ezh_With_Caron       : constant Unicode_Char := 16#01EF#;
   Latin_Small_Letter_J_With_Caron         : constant Unicode_Char := 16#01F0#;
   Latin_Capital_Letter_Dz                 : constant Unicode_Char := 16#01F1#;
   Latin_Capital_Letter_D_With_Small_Letter_Z :
      constant Unicode_Char := 16#01F2#;
   Latin_Small_Letter_Dz                   : constant Unicode_Char := 16#01F3#;
   Latin_Capital_Letter_G_With_Acute       : constant Unicode_Char := 16#01F4#;
   Latin_Small_Letter_G_With_Acute         : constant Unicode_Char := 16#01F5#;
   Latin_Capital_Letter_Hwair              : constant Unicode_Char := 16#01F6#;
   Latin_Capital_Letter_Wynn               : constant Unicode_Char := 16#01F7#;
   Latin_Capital_Letter_N_With_Grave       : constant Unicode_Char := 16#01F8#;
   Latin_Small_Letter_N_With_Grave         : constant Unicode_Char := 16#01F9#;
   Latin_Capital_Letter_A_With_Ring_Above_And_Acute :
      constant Unicode_Char := 16#01FA#;
   Latin_Small_Letter_A_With_Ring_Above_And_Acute :
      constant Unicode_Char := 16#01FB#;
   Latin_Capital_Letter_Ae_With_Acute      : constant Unicode_Char := 16#01FC#;
   Latin_Small_Letter_Ae_With_Acute        : constant Unicode_Char := 16#01FD#;
   Latin_Capital_Letter_O_With_Stroke_And_Acute :
      constant Unicode_Char := 16#01FE#;
   Latin_Small_Letter_O_With_Stroke_And_Acute :
      constant Unicode_Char := 16#01FF#;
   Latin_Capital_Letter_A_With_Double_Grave :
      constant Unicode_Char := 16#0200#;
   Latin_Small_Letter_A_With_Double_Grave  : constant Unicode_Char := 16#0201#;
   Latin_Capital_Letter_A_With_Inverted_Breve :
      constant Unicode_Char := 16#0202#;
   Latin_Small_Letter_A_With_Inverted_Breve :
      constant Unicode_Char := 16#0203#;
   Latin_Capital_Letter_E_With_Double_Grave :
      constant Unicode_Char := 16#0204#;
   Latin_Small_Letter_E_With_Double_Grave  : constant Unicode_Char := 16#0205#;
   Latin_Capital_Letter_E_With_Inverted_Breve :
      constant Unicode_Char := 16#0206#;
   Latin_Small_Letter_E_With_Inverted_Breve :
      constant Unicode_Char := 16#0207#;
   Latin_Capital_Letter_I_With_Double_Grave :
      constant Unicode_Char := 16#0208#;
   Latin_Small_Letter_I_With_Double_Grave  : constant Unicode_Char := 16#0209#;
   Latin_Capital_Letter_I_With_Inverted_Breve :
      constant Unicode_Char := 16#020A#;
   Latin_Small_Letter_I_With_Inverted_Breve :
      constant Unicode_Char := 16#020B#;
   Latin_Capital_Letter_O_With_Double_Grave :
      constant Unicode_Char := 16#020C#;
   Latin_Small_Letter_O_With_Double_Grave  : constant Unicode_Char := 16#020D#;
   Latin_Capital_Letter_O_With_Inverted_Breve :
      constant Unicode_Char := 16#020E#;
   Latin_Small_Letter_O_With_Inverted_Breve :
      constant Unicode_Char := 16#020F#;
   Latin_Capital_Letter_R_With_Double_Grave :
      constant Unicode_Char := 16#0210#;
   Latin_Small_Letter_R_With_Double_Grave  : constant Unicode_Char := 16#0211#;
   Latin_Capital_Letter_R_With_Inverted_Breve :
      constant Unicode_Char := 16#0212#;
   Latin_Small_Letter_R_With_Inverted_Breve :
      constant Unicode_Char := 16#0213#;
   Latin_Capital_Letter_U_With_Double_Grave :
      constant Unicode_Char := 16#0214#;
   Latin_Small_Letter_U_With_Double_Grave  : constant Unicode_Char := 16#0215#;
   Latin_Capital_Letter_U_With_Inverted_Breve :
      constant Unicode_Char := 16#0216#;
   Latin_Small_Letter_U_With_Inverted_Breve :
      constant Unicode_Char := 16#0217#;
   Latin_Capital_Letter_S_With_Comma_Below : constant Unicode_Char := 16#0218#;
   Latin_Small_Letter_S_With_Comma_Below   : constant Unicode_Char := 16#0219#;
   Latin_Capital_Letter_T_With_Comma_Below : constant Unicode_Char := 16#021A#;
   Latin_Small_Letter_T_With_Comma_Below   : constant Unicode_Char := 16#021B#;
   Latin_Capital_Letter_Yogh               : constant Unicode_Char := 16#021C#;
   Latin_Small_Letter_Yogh                 : constant Unicode_Char := 16#021D#;
   Latin_Capital_Letter_H_With_Caron       : constant Unicode_Char := 16#021E#;
   Latin_Small_Letter_H_With_Caron         : constant Unicode_Char := 16#021F#;
   Latin_Capital_Letter_N_With_Long_Right_Leg :
      constant Unicode_Char := 16#0220#;
   Latin_Small_Letter_D_With_Curl          : constant Unicode_Char := 16#0221#;
   Latin_Capital_Letter_Ou                 : constant Unicode_Char := 16#0222#;
   Latin_Small_Letter_Ou                   : constant Unicode_Char := 16#0223#;
   Latin_Capital_Letter_Z_With_Hook        : constant Unicode_Char := 16#0224#;
   Latin_Small_Letter_Z_With_Hook          : constant Unicode_Char := 16#0225#;
   Latin_Capital_Letter_A_With_Dot_Above   : constant Unicode_Char := 16#0226#;
   Latin_Small_Letter_A_With_Dot_Above     : constant Unicode_Char := 16#0227#;
   Latin_Capital_Letter_E_With_Cedilla     : constant Unicode_Char := 16#0228#;
   Latin_Small_Letter_E_With_Cedilla       : constant Unicode_Char := 16#0229#;
   Latin_Capital_Letter_O_With_Diaeresis_And_Macron :
      constant Unicode_Char := 16#022A#;
   Latin_Small_Letter_O_With_Diaeresis_And_Macron :
      constant Unicode_Char := 16#022B#;
   Latin_Capital_Letter_O_With_Tilde_And_Macron :
      constant Unicode_Char := 16#022C#;
   Latin_Small_Letter_O_With_Tilde_And_Macron :
      constant Unicode_Char := 16#022D#;
   Latin_Capital_Letter_O_With_Dot_Above   : constant Unicode_Char := 16#022E#;
   Latin_Small_Letter_O_With_Dot_Above     : constant Unicode_Char := 16#022F#;
   Latin_Capital_Letter_O_With_Dot_Above_And_Macron :
      constant Unicode_Char := 16#0230#;
   Latin_Small_Letter_O_With_Dot_Above_And_Macron :
      constant Unicode_Char := 16#0231#;
   Latin_Capital_Letter_Y_With_Macron      : constant Unicode_Char := 16#0232#;
   Latin_Small_Letter_Y_With_Macron        : constant Unicode_Char := 16#0233#;
   Latin_Small_Letter_L_With_Curl          : constant Unicode_Char := 16#0234#;
   Latin_Small_Letter_N_With_Curl          : constant Unicode_Char := 16#0235#;
   Latin_Small_Letter_T_With_Curl          : constant Unicode_Char := 16#0236#;
   Latin_Small_Letter_Dotless_J            : constant Unicode_Char := 16#0237#;
   Latin_Small_Letter_Db_Digraph           : constant Unicode_Char := 16#0238#;
   Latin_Small_Letter_Qp_Digraph           : constant Unicode_Char := 16#0239#;
   Latin_Capital_Letter_A_With_Stroke      : constant Unicode_Char := 16#023A#;
   Latin_Capital_Letter_C_With_Stroke      : constant Unicode_Char := 16#023B#;
   Latin_Small_Letter_C_With_Stroke        : constant Unicode_Char := 16#023C#;
   Latin_Capital_Letter_L_With_Bar         : constant Unicode_Char := 16#023D#;
   Latin_Capital_Letter_T_With_Diagonal_Stroke :
      constant Unicode_Char := 16#023E#;
   Latin_Small_Letter_S_With_Swash_Tail    : constant Unicode_Char := 16#023F#;
   Latin_Small_Letter_Z_With_Swash_Tail    : constant Unicode_Char := 16#0240#;
   Latin_Capital_Letter_Glottal_Stop       : constant Unicode_Char := 16#0241#;
   Latin_Small_Letter_Glottal_Stop         : constant Unicode_Char := 16#0242#;
   Latin_Capital_Letter_B_With_Stroke      : constant Unicode_Char := 16#0243#;
   Latin_Capital_Letter_U_Bar              : constant Unicode_Char := 16#0244#;
   Latin_Capital_Letter_Turned_V           : constant Unicode_Char := 16#0245#;
   Latin_Capital_Letter_E_With_Stroke      : constant Unicode_Char := 16#0246#;
   Latin_Small_Letter_E_With_Stroke        : constant Unicode_Char := 16#0247#;
   Latin_Capital_Letter_J_With_Stroke      : constant Unicode_Char := 16#0248#;
   Latin_Small_Letter_J_With_Stroke        : constant Unicode_Char := 16#0249#;
   Latin_Capital_Letter_Small_Q_With_Hook_Tail :
      constant Unicode_Char := 16#024A#;
   Latin_Small_Letter_Q_With_Hook_Tail     : constant Unicode_Char := 16#024B#;
   Latin_Capital_Letter_R_With_Stroke      : constant Unicode_Char := 16#024C#;
   Latin_Small_Letter_R_With_Stroke        : constant Unicode_Char := 16#024D#;
   Latin_Capital_Letter_Y_With_Stroke      : constant Unicode_Char := 16#024E#;
   Latin_Small_Letter_Y_With_Stroke        : constant Unicode_Char := 16#024F#;
end Unicode.Names.Latin_Extended_B;
