--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Supplemental_Arrows_B is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Rightwards_Two_Headed_Arrow_With_Vertical_Stroke :
      constant Unicode_Char := 16#2900#;
   Rightwards_Two_Headed_Arrow_With_Double_Vertical_Stroke :
      constant Unicode_Char := 16#2901#;
   Leftwards_Double_Arrow_With_Vertical_Stroke :
      constant Unicode_Char := 16#2902#;
   Rightwards_Double_Arrow_With_Vertical_Stroke :
      constant Unicode_Char := 16#2903#;
   Left_Right_Double_Arrow_With_Vertical_Stroke :
      constant Unicode_Char := 16#2904#;
   Rightwards_Two_Headed_Arrow_From_Bar    : constant Unicode_Char := 16#2905#;
   Leftwards_Double_Arrow_From_Bar         : constant Unicode_Char := 16#2906#;
   Rightwards_Double_Arrow_From_Bar        : constant Unicode_Char := 16#2907#;
   Downwards_Arrow_With_Horizontal_Stroke  : constant Unicode_Char := 16#2908#;
   Upwards_Arrow_With_Horizontal_Stroke    : constant Unicode_Char := 16#2909#;
   Upwards_Triple_Arrow                    : constant Unicode_Char := 16#290A#;
   Downwards_Triple_Arrow                  : constant Unicode_Char := 16#290B#;
   Leftwards_Double_Dash_Arrow             : constant Unicode_Char := 16#290C#;
   Rightwards_Double_Dash_Arrow            : constant Unicode_Char := 16#290D#;
   Leftwards_Triple_Dash_Arrow             : constant Unicode_Char := 16#290E#;
   Rightwards_Triple_Dash_Arrow            : constant Unicode_Char := 16#290F#;
   Rightwards_Two_Headed_Triple_Dash_Arrow : constant Unicode_Char := 16#2910#;
   Rightwards_Arrow_With_Dotted_Stem       : constant Unicode_Char := 16#2911#;
   Upwards_Arrow_To_Bar                    : constant Unicode_Char := 16#2912#;
   Downwards_Arrow_To_Bar                  : constant Unicode_Char := 16#2913#;
   Rightwards_Arrow_With_Tail_With_Vertical_Stroke :
      constant Unicode_Char := 16#2914#;
   Rightwards_Arrow_With_Tail_With_Double_Vertical_Stroke :
      constant Unicode_Char := 16#2915#;
   Rightwards_Two_Headed_Arrow_With_Tail   : constant Unicode_Char := 16#2916#;
   Rightwards_Two_Headed_Arrow_With_Tail_With_Vertical_Stroke :
      constant Unicode_Char := 16#2917#;
   Rightwards_Two_Headed_Arrow_With_Tail_With_Double_Vertical_Stroke :
      constant Unicode_Char := 16#2918#;
   Leftwards_Arrow_Tail                    : constant Unicode_Char := 16#2919#;
   Rightwards_Arrow_Tail                   : constant Unicode_Char := 16#291A#;
   Leftwards_Double_Arrow_Tail             : constant Unicode_Char := 16#291B#;
   Rightwards_Double_Arrow_Tail            : constant Unicode_Char := 16#291C#;
   Leftwards_Arrow_To_Black_Diamond        : constant Unicode_Char := 16#291D#;
   Rightwards_Arrow_To_Black_Diamond       : constant Unicode_Char := 16#291E#;
   Leftwards_Arrow_From_Bar_To_Black_Diamond :
      constant Unicode_Char := 16#291F#;
   Rightwards_Arrow_From_Bar_To_Black_Diamond :
      constant Unicode_Char := 16#2920#;
   North_West_And_South_East_Arrow         : constant Unicode_Char := 16#2921#;
   North_East_And_South_West_Arrow         : constant Unicode_Char := 16#2922#;
   North_West_Arrow_With_Hook              : constant Unicode_Char := 16#2923#;
   North_East_Arrow_With_Hook              : constant Unicode_Char := 16#2924#;
   South_East_Arrow_With_Hook              : constant Unicode_Char := 16#2925#;
   South_West_Arrow_With_Hook              : constant Unicode_Char := 16#2926#;
   North_West_Arrow_And_North_East_Arrow   : constant Unicode_Char := 16#2927#;
   North_East_Arrow_And_South_East_Arrow   : constant Unicode_Char := 16#2928#;
   South_East_Arrow_And_South_West_Arrow   : constant Unicode_Char := 16#2929#;
   South_West_Arrow_And_North_West_Arrow   : constant Unicode_Char := 16#292A#;
   Rising_Diagonal_Crossing_Falling_Diagonal :
      constant Unicode_Char := 16#292B#;
   Falling_Diagonal_Crossing_Rising_Diagonal :
      constant Unicode_Char := 16#292C#;
   South_East_Arrow_Crossing_North_East_Arrow :
      constant Unicode_Char := 16#292D#;
   North_East_Arrow_Crossing_South_East_Arrow :
      constant Unicode_Char := 16#292E#;
   Falling_Diagonal_Crossing_North_East_Arrow :
      constant Unicode_Char := 16#292F#;
   Rising_Diagonal_Crossing_South_East_Arrow :
      constant Unicode_Char := 16#2930#;
   North_East_Arrow_Crossing_North_West_Arrow :
      constant Unicode_Char := 16#2931#;
   North_West_Arrow_Crossing_North_East_Arrow :
      constant Unicode_Char := 16#2932#;
   Wave_Arrow_Pointing_Directly_Right      : constant Unicode_Char := 16#2933#;
   Arrow_Pointing_Rightwards_Then_Curving_Upwards :
      constant Unicode_Char := 16#2934#;
   Arrow_Pointing_Rightwards_Then_Curving_Downwards :
      constant Unicode_Char := 16#2935#;
   Arrow_Pointing_Downwards_Then_Curving_Leftwards :
      constant Unicode_Char := 16#2936#;
   Arrow_Pointing_Downwards_Then_Curving_Rightwards :
      constant Unicode_Char := 16#2937#;
   Right_Side_Arc_Clockwise_Arrow          : constant Unicode_Char := 16#2938#;
   Left_Side_Arc_Anticlockwise_Arrow       : constant Unicode_Char := 16#2939#;
   Top_Arc_Anticlockwise_Arrow             : constant Unicode_Char := 16#293A#;
   Bottom_Arc_Anticlockwise_Arrow          : constant Unicode_Char := 16#293B#;
   Top_Arc_Clockwise_Arrow_With_Minus      : constant Unicode_Char := 16#293C#;
   Top_Arc_Anticlockwise_Arrow_With_Plus   : constant Unicode_Char := 16#293D#;
   Lower_Right_Semicircular_Clockwise_Arrow :
      constant Unicode_Char := 16#293E#;
   Lower_Left_Semicircular_Anticlockwise_Arrow :
      constant Unicode_Char := 16#293F#;
   Anticlockwise_Closed_Circle_Arrow       : constant Unicode_Char := 16#2940#;
   Clockwise_Closed_Circle_Arrow           : constant Unicode_Char := 16#2941#;
   Rightwards_Arrow_Above_Short_Leftwards_Arrow :
      constant Unicode_Char := 16#2942#;
   Leftwards_Arrow_Above_Short_Rightwards_Arrow :
      constant Unicode_Char := 16#2943#;
   Short_Rightwards_Arrow_Above_Leftwards_Arrow :
      constant Unicode_Char := 16#2944#;
   Rightwards_Arrow_With_Plus_Below        : constant Unicode_Char := 16#2945#;
   Leftwards_Arrow_With_Plus_Below         : constant Unicode_Char := 16#2946#;
   Rightwards_Arrow_Through_X              : constant Unicode_Char := 16#2947#;
   Left_Right_Arrow_Through_Small_Circle   : constant Unicode_Char := 16#2948#;
   Upwards_Two_Headed_Arrow_From_Small_Circle :
      constant Unicode_Char := 16#2949#;
   Left_Barb_Up_Right_Barb_Down_Harpoon    : constant Unicode_Char := 16#294A#;
   Left_Barb_Down_Right_Barb_Up_Harpoon    : constant Unicode_Char := 16#294B#;
   Up_Barb_Right_Down_Barb_Left_Harpoon    : constant Unicode_Char := 16#294C#;
   Up_Barb_Left_Down_Barb_Right_Harpoon    : constant Unicode_Char := 16#294D#;
   Left_Barb_Up_Right_Barb_Up_Harpoon      : constant Unicode_Char := 16#294E#;
   Up_Barb_Right_Down_Barb_Right_Harpoon   : constant Unicode_Char := 16#294F#;
   Left_Barb_Down_Right_Barb_Down_Harpoon  : constant Unicode_Char := 16#2950#;
   Up_Barb_Left_Down_Barb_Left_Harpoon     : constant Unicode_Char := 16#2951#;
   Leftwards_Harpoon_With_Barb_Up_To_Bar   : constant Unicode_Char := 16#2952#;
   Rightwards_Harpoon_With_Barb_Up_To_Bar  : constant Unicode_Char := 16#2953#;
   Upwards_Harpoon_With_Barb_Right_To_Bar  : constant Unicode_Char := 16#2954#;
   Downwards_Harpoon_With_Barb_Right_To_Bar :
      constant Unicode_Char := 16#2955#;
   Leftwards_Harpoon_With_Barb_Down_To_Bar : constant Unicode_Char := 16#2956#;
   Rightwards_Harpoon_With_Barb_Down_To_Bar :
      constant Unicode_Char := 16#2957#;
   Upwards_Harpoon_With_Barb_Left_To_Bar   : constant Unicode_Char := 16#2958#;
   Downwards_Harpoon_With_Barb_Left_To_Bar : constant Unicode_Char := 16#2959#;
   Leftwards_Harpoon_With_Barb_Up_From_Bar : constant Unicode_Char := 16#295A#;
   Rightwards_Harpoon_With_Barb_Up_From_Bar :
      constant Unicode_Char := 16#295B#;
   Upwards_Harpoon_With_Barb_Right_From_Bar :
      constant Unicode_Char := 16#295C#;
   Downwards_Harpoon_With_Barb_Right_From_Bar :
      constant Unicode_Char := 16#295D#;
   Leftwards_Harpoon_With_Barb_Down_From_Bar :
      constant Unicode_Char := 16#295E#;
   Rightwards_Harpoon_With_Barb_Down_From_Bar :
      constant Unicode_Char := 16#295F#;
   Upwards_Harpoon_With_Barb_Left_From_Bar : constant Unicode_Char := 16#2960#;
   Downwards_Harpoon_With_Barb_Left_From_Bar :
      constant Unicode_Char := 16#2961#;
   Leftwards_Harpoon_With_Barb_Up_Above_Leftwards_Harpoon_With_Barb_Down :
      constant Unicode_Char := 16#2962#;
   Upwards_Harpoon_With_Barb_Left_Beside_Upwards_Harpoon_With_Barb_Right :
      constant Unicode_Char := 16#2963#;
   Rightwards_Harpoon_With_Barb_Up_Above_Rightwards_Harpoon_With_Barb_Down :
      constant Unicode_Char := 16#2964#;
   Downwards_Harpoon_With_Barb_Left_Beside_Downwards_Harpoon_With_Barb_Right :
      constant Unicode_Char := 16#2965#;
   Leftwards_Harpoon_With_Barb_Up_Above_Rightwards_Harpoon_With_Barb_Up :
      constant Unicode_Char := 16#2966#;
   Leftwards_Harpoon_With_Barb_Down_Above_Rightwards_Harpoon_With_Barb_Down :
      constant Unicode_Char := 16#2967#;
   Rightwards_Harpoon_With_Barb_Up_Above_Leftwards_Harpoon_With_Barb_Up :
      constant Unicode_Char := 16#2968#;
   Rightwards_Harpoon_With_Barb_Down_Above_Leftwards_Harpoon_With_Barb_Down :
      constant Unicode_Char := 16#2969#;
   Leftwards_Harpoon_With_Barb_Up_Above_Long_Dash :
      constant Unicode_Char := 16#296A#;
   Leftwards_Harpoon_With_Barb_Down_Below_Long_Dash :
      constant Unicode_Char := 16#296B#;
   Rightwards_Harpoon_With_Barb_Up_Above_Long_Dash :
      constant Unicode_Char := 16#296C#;
   Rightwards_Harpoon_With_Barb_Down_Below_Long_Dash :
      constant Unicode_Char := 16#296D#;
   Upwards_Harpoon_With_Barb_Left_Beside_Downwards_Harpoon_With_Barb_Right :
      constant Unicode_Char := 16#296E#;
   Downwards_Harpoon_With_Barb_Left_Beside_Upwards_Harpoon_With_Barb_Right :
      constant Unicode_Char := 16#296F#;
   Right_Double_Arrow_With_Rounded_Head    : constant Unicode_Char := 16#2970#;
   Equals_Sign_Above_Rightwards_Arrow      : constant Unicode_Char := 16#2971#;
   Tilde_Operator_Above_Rightwards_Arrow   : constant Unicode_Char := 16#2972#;
   Leftwards_Arrow_Above_Tilde_Operator    : constant Unicode_Char := 16#2973#;
   Rightwards_Arrow_Above_Tilde_Operator   : constant Unicode_Char := 16#2974#;
   Rightwards_Arrow_Above_Almost_Equal_To  : constant Unicode_Char := 16#2975#;
   Less_Than_Above_Leftwards_Arrow         : constant Unicode_Char := 16#2976#;
   Leftwards_Arrow_Through_Less_Than       : constant Unicode_Char := 16#2977#;
   Greater_Than_Above_Rightwards_Arrow     : constant Unicode_Char := 16#2978#;
   Subset_Above_Rightwards_Arrow           : constant Unicode_Char := 16#2979#;
   Leftwards_Arrow_Through_Subset          : constant Unicode_Char := 16#297A#;
   Superset_Above_Leftwards_Arrow          : constant Unicode_Char := 16#297B#;
   Left_Fish_Tail                          : constant Unicode_Char := 16#297C#;
   Right_Fish_Tail                         : constant Unicode_Char := 16#297D#;
   Up_Fish_Tail                            : constant Unicode_Char := 16#297E#;
   Down_Fish_Tail                          : constant Unicode_Char := 16#297F#;
end Unicode.Names.Supplemental_Arrows_B;
