--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Variation_Selectors is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Variation_Selector_1                    : constant Unicode_Char := 16#FE00#;
   Vs1                                     :
      Unicode_Char renames Variation_Selector_1;
   Variation_Selector_2                    : constant Unicode_Char := 16#FE01#;
   Vs2                                     :
      Unicode_Char renames Variation_Selector_2;
   Variation_Selector_3                    : constant Unicode_Char := 16#FE02#;
   Vs3                                     :
      Unicode_Char renames Variation_Selector_3;
   Variation_Selector_4                    : constant Unicode_Char := 16#FE03#;
   Vs4                                     :
      Unicode_Char renames Variation_Selector_4;
   Variation_Selector_5                    : constant Unicode_Char := 16#FE04#;
   Vs5                                     :
      Unicode_Char renames Variation_Selector_5;
   Variation_Selector_6                    : constant Unicode_Char := 16#FE05#;
   Vs6                                     :
      Unicode_Char renames Variation_Selector_6;
   Variation_Selector_7                    : constant Unicode_Char := 16#FE06#;
   Vs7                                     :
      Unicode_Char renames Variation_Selector_7;
   Variation_Selector_8                    : constant Unicode_Char := 16#FE07#;
   Vs8                                     :
      Unicode_Char renames Variation_Selector_8;
   Variation_Selector_9                    : constant Unicode_Char := 16#FE08#;
   Vs9                                     :
      Unicode_Char renames Variation_Selector_9;
   Variation_Selector_10                   : constant Unicode_Char := 16#FE09#;
   Vs10                                    :
      Unicode_Char renames Variation_Selector_10;
   Variation_Selector_11                   : constant Unicode_Char := 16#FE0A#;
   Vs11                                    :
      Unicode_Char renames Variation_Selector_11;
   Variation_Selector_12                   : constant Unicode_Char := 16#FE0B#;
   Vs12                                    :
      Unicode_Char renames Variation_Selector_12;
   Variation_Selector_13                   : constant Unicode_Char := 16#FE0C#;
   Vs13                                    :
      Unicode_Char renames Variation_Selector_13;
   Variation_Selector_14                   : constant Unicode_Char := 16#FE0D#;
   Vs14                                    :
      Unicode_Char renames Variation_Selector_14;
   Variation_Selector_15                   : constant Unicode_Char := 16#FE0E#;
   Vs15                                    :
      Unicode_Char renames Variation_Selector_15;
   Variation_Selector_16                   : constant Unicode_Char := 16#FE0F#;
   Vs16                                    :
      Unicode_Char renames Variation_Selector_16;
end Unicode.Names.Variation_Selectors;
