--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cuneiform_Num_Punctuation is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cuneiform_Numeric_Sign_Two_Ash          :
      constant Unicode_Char := 16#12400#;
   Cuneiform_Numeric_Sign_Three_Ash        :
      constant Unicode_Char := 16#12401#;
   Cuneiform_Numeric_Sign_Four_Ash         :
      constant Unicode_Char := 16#12402#;
   Cuneiform_Numeric_Sign_Five_Ash         :
      constant Unicode_Char := 16#12403#;
   Cuneiform_Numeric_Sign_Six_Ash          :
      constant Unicode_Char := 16#12404#;
   Cuneiform_Numeric_Sign_Seven_Ash        :
      constant Unicode_Char := 16#12405#;
   Cuneiform_Numeric_Sign_Eight_Ash        :
      constant Unicode_Char := 16#12406#;
   Cuneiform_Numeric_Sign_Nine_Ash         :
      constant Unicode_Char := 16#12407#;
   Cuneiform_Numeric_Sign_Three_Dish       :
      constant Unicode_Char := 16#12408#;
   Cuneiform_Numeric_Sign_Four_Dish        :
      constant Unicode_Char := 16#12409#;
   Cuneiform_Numeric_Sign_Five_Dish        :
      constant Unicode_Char := 16#1240A#;
   Cuneiform_Numeric_Sign_Six_Dish         :
      constant Unicode_Char := 16#1240B#;
   Cuneiform_Numeric_Sign_Seven_Dish       :
      constant Unicode_Char := 16#1240C#;
   Cuneiform_Numeric_Sign_Eight_Dish       :
      constant Unicode_Char := 16#1240D#;
   Cuneiform_Numeric_Sign_Nine_Dish        :
      constant Unicode_Char := 16#1240E#;
   Cuneiform_Numeric_Sign_Four_U           :
      constant Unicode_Char := 16#1240F#;
   Cuneiform_Numeric_Sign_Five_U           :
      constant Unicode_Char := 16#12410#;
   Cuneiform_Numeric_Sign_Six_U            :
      constant Unicode_Char := 16#12411#;
   Cuneiform_Numeric_Sign_Seven_U          :
      constant Unicode_Char := 16#12412#;
   Cuneiform_Numeric_Sign_Eight_U          :
      constant Unicode_Char := 16#12413#;
   Cuneiform_Numeric_Sign_Nine_U           :
      constant Unicode_Char := 16#12414#;
   Cuneiform_Numeric_Sign_One_Gesh2        :
      constant Unicode_Char := 16#12415#;
   Cuneiform_Numeric_Sign_Two_Gesh2        :
      constant Unicode_Char := 16#12416#;
   Cuneiform_Numeric_Sign_Three_Gesh2      :
      constant Unicode_Char := 16#12417#;
   Cuneiform_Numeric_Sign_Four_Gesh2       :
      constant Unicode_Char := 16#12418#;
   Cuneiform_Numeric_Sign_Five_Gesh2       :
      constant Unicode_Char := 16#12419#;
   Cuneiform_Numeric_Sign_Six_Gesh2        :
      constant Unicode_Char := 16#1241A#;
   Cuneiform_Numeric_Sign_Seven_Gesh2      :
      constant Unicode_Char := 16#1241B#;
   Cuneiform_Numeric_Sign_Eight_Gesh2      :
      constant Unicode_Char := 16#1241C#;
   Cuneiform_Numeric_Sign_Nine_Gesh2       :
      constant Unicode_Char := 16#1241D#;
   Cuneiform_Numeric_Sign_One_Geshu        :
      constant Unicode_Char := 16#1241E#;
   Cuneiform_Numeric_Sign_Two_Geshu        :
      constant Unicode_Char := 16#1241F#;
   Cuneiform_Numeric_Sign_Three_Geshu      :
      constant Unicode_Char := 16#12420#;
   Cuneiform_Numeric_Sign_Four_Geshu       :
      constant Unicode_Char := 16#12421#;
   Cuneiform_Numeric_Sign_Five_Geshu       :
      constant Unicode_Char := 16#12422#;
   Cuneiform_Numeric_Sign_Two_Shar2        :
      constant Unicode_Char := 16#12423#;
   Cuneiform_Numeric_Sign_Three_Shar2      :
      constant Unicode_Char := 16#12424#;
   Cuneiform_Numeric_Sign_Three_Shar2_Variant_Form :
      constant Unicode_Char := 16#12425#;
   Cuneiform_Numeric_Sign_Four_Shar2       :
      constant Unicode_Char := 16#12426#;
   Cuneiform_Numeric_Sign_Five_Shar2       :
      constant Unicode_Char := 16#12427#;
   Cuneiform_Numeric_Sign_Six_Shar2        :
      constant Unicode_Char := 16#12428#;
   Cuneiform_Numeric_Sign_Seven_Shar2      :
      constant Unicode_Char := 16#12429#;
   Cuneiform_Numeric_Sign_Eight_Shar2      :
      constant Unicode_Char := 16#1242A#;
   Cuneiform_Numeric_Sign_Nine_Shar2       :
      constant Unicode_Char := 16#1242B#;
   Cuneiform_Numeric_Sign_One_Sharu        :
      constant Unicode_Char := 16#1242C#;
   Cuneiform_Numeric_Sign_Two_Sharu        :
      constant Unicode_Char := 16#1242D#;
   Cuneiform_Numeric_Sign_Three_Sharu      :
      constant Unicode_Char := 16#1242E#;
   Cuneiform_Numeric_Sign_Three_Sharu_Variant_Form :
      constant Unicode_Char := 16#1242F#;
   Cuneiform_Numeric_Sign_Four_Sharu       :
      constant Unicode_Char := 16#12430#;
   Cuneiform_Numeric_Sign_Five_Sharu       :
      constant Unicode_Char := 16#12431#;
   Cuneiform_Numeric_Sign_Shar2_Times_Gal_Plus_Dish :
      constant Unicode_Char := 16#12432#;
   Cuneiform_Numeric_Sign_Shar2_Times_Gal_Plus_Min :
      constant Unicode_Char := 16#12433#;
   Cuneiform_Numeric_Sign_One_Buru         :
      constant Unicode_Char := 16#12434#;
   Cuneiform_Numeric_Sign_Two_Buru         :
      constant Unicode_Char := 16#12435#;
   Cuneiform_Numeric_Sign_Three_Buru       :
      constant Unicode_Char := 16#12436#;
   Cuneiform_Numeric_Sign_Three_Buru_Variant_Form :
      constant Unicode_Char := 16#12437#;
   Cuneiform_Numeric_Sign_Four_Buru        :
      constant Unicode_Char := 16#12438#;
   Cuneiform_Numeric_Sign_Five_Buru        :
      constant Unicode_Char := 16#12439#;
   Cuneiform_Numeric_Sign_Three_Variant_Form_Esh16 :
      constant Unicode_Char := 16#1243A#;
   Cuneiform_Numeric_Sign_Three_Variant_Form_Esh21 :
      constant Unicode_Char := 16#1243B#;
   Cuneiform_Numeric_Sign_Four_Variant_Form_Limmu :
      constant Unicode_Char := 16#1243C#;
   Cuneiform_Numeric_Sign_Four_Variant_Form_Limmu4 :
      constant Unicode_Char := 16#1243D#;
   Cuneiform_Numeric_Sign_Four_Variant_Form_Limmu_A :
      constant Unicode_Char := 16#1243E#;
   Cuneiform_Numeric_Sign_Four_Variant_Form_Limmu_B :
      constant Unicode_Char := 16#1243F#;
   Cuneiform_Numeric_Sign_Six_Variant_Form_Ash9 :
      constant Unicode_Char := 16#12440#;
   Cuneiform_Numeric_Sign_Seven_Variant_Form_Imin3 :
      constant Unicode_Char := 16#12441#;
   Cuneiform_Numeric_Sign_Seven_Variant_Form_Imin_A :
      constant Unicode_Char := 16#12442#;
   Cuneiform_Numeric_Sign_Seven_Variant_Form_Imin_B :
      constant Unicode_Char := 16#12443#;
   Cuneiform_Numeric_Sign_Eight_Variant_Form_Ussu :
      constant Unicode_Char := 16#12444#;
   Cuneiform_Numeric_Sign_Eight_Variant_Form_Ussu3 :
      constant Unicode_Char := 16#12445#;
   Cuneiform_Numeric_Sign_Nine_Variant_Form_Ilimmu :
      constant Unicode_Char := 16#12446#;
   Cuneiform_Numeric_Sign_Nine_Variant_Form_Ilimmu3 :
      constant Unicode_Char := 16#12447#;
   Cuneiform_Numeric_Sign_Nine_Variant_Form_Ilimmu4 :
      constant Unicode_Char := 16#12448#;
   Cuneiform_Numeric_Sign_Nine_Variant_Form_Ilimmu_A :
      constant Unicode_Char := 16#12449#;
   Cuneiform_Numeric_Sign_Two_Ash_Tenu     :
      constant Unicode_Char := 16#1244A#;
   Cuneiform_Numeric_Sign_Three_Ash_Tenu   :
      constant Unicode_Char := 16#1244B#;
   Cuneiform_Numeric_Sign_Four_Ash_Tenu    :
      constant Unicode_Char := 16#1244C#;
   Cuneiform_Numeric_Sign_Five_Ash_Tenu    :
      constant Unicode_Char := 16#1244D#;
   Cuneiform_Numeric_Sign_Six_Ash_Tenu     :
      constant Unicode_Char := 16#1244E#;
   Cuneiform_Numeric_Sign_One_Ban2         :
      constant Unicode_Char := 16#1244F#;
   Cuneiform_Numeric_Sign_Two_Ban2         :
      constant Unicode_Char := 16#12450#;
   Cuneiform_Numeric_Sign_Three_Ban2       :
      constant Unicode_Char := 16#12451#;
   Cuneiform_Numeric_Sign_Four_Ban2        :
      constant Unicode_Char := 16#12452#;
   Cuneiform_Numeric_Sign_Four_Ban2_Variant_Form :
      constant Unicode_Char := 16#12453#;
   Cuneiform_Numeric_Sign_Five_Ban2        :
      constant Unicode_Char := 16#12454#;
   Cuneiform_Numeric_Sign_Five_Ban2_Variant_Form :
      constant Unicode_Char := 16#12455#;
   Cuneiform_Numeric_Sign_Nigidamin        :
      constant Unicode_Char := 16#12456#;
   Cuneiform_Numeric_Sign_Nigidaesh        :
      constant Unicode_Char := 16#12457#;
   Cuneiform_Numeric_Sign_One_Eshe3        :
      constant Unicode_Char := 16#12458#;
   Cuneiform_Numeric_Sign_Two_Eshe3        :
      constant Unicode_Char := 16#12459#;
   Cuneiform_Numeric_Sign_One_Third_Dish   :
      constant Unicode_Char := 16#1245A#;
   Cuneiform_Numeric_Sign_Two_Thirds_Dish  :
      constant Unicode_Char := 16#1245B#;
   Cuneiform_Numeric_Sign_Five_Sixths_Dish :
      constant Unicode_Char := 16#1245C#;
   Cuneiform_Numeric_Sign_One_Third_Variant_Form_A :
      constant Unicode_Char := 16#1245D#;
   Cuneiform_Numeric_Sign_Two_Thirds_Variant_Form_A :
      constant Unicode_Char := 16#1245E#;
   Cuneiform_Numeric_Sign_One_Eighth_Ash   :
      constant Unicode_Char := 16#1245F#;
   Cuneiform_Numeric_Sign_One_Quarter_Ash  :
      constant Unicode_Char := 16#12460#;
   Cuneiform_Numeric_Sign_Old_Assyrian_One_Sixth :
      constant Unicode_Char := 16#12461#;
   Cuneiform_Numeric_Sign_Old_Assyrian_One_Quarter :
      constant Unicode_Char := 16#12462#;
   Cuneiform_Numeric_Sign_One_Quarter_Gur  :
      constant Unicode_Char := 16#12463#;
   Cuneiform_Numeric_Sign_One_Half_Gur     :
      constant Unicode_Char := 16#12464#;
   Cuneiform_Numeric_Sign_Elamite_One_Third :
      constant Unicode_Char := 16#12465#;
   Cuneiform_Numeric_Sign_Elamite_Two_Thirds :
      constant Unicode_Char := 16#12466#;
   Cuneiform_Numeric_Sign_Elamite_Forty    :
      constant Unicode_Char := 16#12467#;
   Cuneiform_Numeric_Sign_Elamite_Fifty    :
      constant Unicode_Char := 16#12468#;
   Cuneiform_Numeric_Sign_Four_U_Variant_Form :
      constant Unicode_Char := 16#12469#;
   Cuneiform_Numeric_Sign_Five_U_Variant_Form :
      constant Unicode_Char := 16#1246A#;
   Cuneiform_Numeric_Sign_Six_U_Variant_Form :
      constant Unicode_Char := 16#1246B#;
   Cuneiform_Numeric_Sign_Seven_U_Variant_Form :
      constant Unicode_Char := 16#1246C#;
   Cuneiform_Numeric_Sign_Eight_U_Variant_Form :
      constant Unicode_Char := 16#1246D#;
   Cuneiform_Numeric_Sign_Nine_U_Variant_Form :
      constant Unicode_Char := 16#1246E#;
   Cuneiform_Punctuation_Sign_Old_Assyrian_Word_Divider :
      constant Unicode_Char := 16#12470#;
   Cuneiform_Punctuation_Sign_Vertical_Colon :
      constant Unicode_Char := 16#12471#;
   Cuneiform_Punctuation_Sign_Diagonal_Colon :
      constant Unicode_Char := 16#12472#;
   Cuneiform_Punctuation_Sign_Diagonal_Tricolon :
      constant Unicode_Char := 16#12473#;
   Cuneiform_Punctuation_Sign_Diagonal_Quadcolon :
      constant Unicode_Char := 16#12474#;
end Unicode.Names.Cuneiform_Num_Punctuation;
