--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Combining_Diacritical_Sup is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Combining_Dotted_Grave_Accent           : constant Unicode_Char := 16#1DC0#;
   Combining_Dotted_Acute_Accent           : constant Unicode_Char := 16#1DC1#;
   Combining_Snake_Below                   : constant Unicode_Char := 16#1DC2#;
   Combining_Suspension_Mark               : constant Unicode_Char := 16#1DC3#;
   Combining_Macron_Acute                  : constant Unicode_Char := 16#1DC4#;
   Combining_Grave_Macron                  : constant Unicode_Char := 16#1DC5#;
   Combining_Macron_Grave                  : constant Unicode_Char := 16#1DC6#;
   Combining_Acute_Macron                  : constant Unicode_Char := 16#1DC7#;
   Combining_Grave_Acute_Grave             : constant Unicode_Char := 16#1DC8#;
   Combining_Acute_Grave_Acute             : constant Unicode_Char := 16#1DC9#;
   Combining_Latin_Small_Letter_R_Below    : constant Unicode_Char := 16#1DCA#;
   Combining_Breve_Macron                  : constant Unicode_Char := 16#1DCB#;
   Combining_Macron_Breve                  : constant Unicode_Char := 16#1DCC#;
   Combining_Double_Circumflex_Above       : constant Unicode_Char := 16#1DCD#;
   Combining_Ogonek_Above                  : constant Unicode_Char := 16#1DCE#;
   Combining_Zigzag_Below                  : constant Unicode_Char := 16#1DCF#;
   Combining_Is_Below                      : constant Unicode_Char := 16#1DD0#;
   Combining_Ur_Above                      : constant Unicode_Char := 16#1DD1#;
   Combining_Us_Above                      : constant Unicode_Char := 16#1DD2#;
   Combining_Latin_Small_Letter_Flattened_Open_A_Above :
      constant Unicode_Char := 16#1DD3#;
   Combining_Latin_Small_Letter_Ae         : constant Unicode_Char := 16#1DD4#;
   Combining_Latin_Small_Letter_Ao         : constant Unicode_Char := 16#1DD5#;
   Combining_Latin_Small_Letter_Av         : constant Unicode_Char := 16#1DD6#;
   Combining_Latin_Small_Letter_C_Cedilla  : constant Unicode_Char := 16#1DD7#;
   Combining_Latin_Small_Letter_Insular_D  : constant Unicode_Char := 16#1DD8#;
   Combining_Latin_Small_Letter_Eth        : constant Unicode_Char := 16#1DD9#;
   Combining_Latin_Small_Letter_G          : constant Unicode_Char := 16#1DDA#;
   Combining_Latin_Letter_Small_Capital_G  : constant Unicode_Char := 16#1DDB#;
   Combining_Latin_Small_Letter_K          : constant Unicode_Char := 16#1DDC#;
   Combining_Latin_Small_Letter_L          : constant Unicode_Char := 16#1DDD#;
   Combining_Latin_Letter_Small_Capital_L  : constant Unicode_Char := 16#1DDE#;
   Combining_Latin_Letter_Small_Capital_M  : constant Unicode_Char := 16#1DDF#;
   Combining_Latin_Small_Letter_N          : constant Unicode_Char := 16#1DE0#;
   Combining_Latin_Letter_Small_Capital_N  : constant Unicode_Char := 16#1DE1#;
   Combining_Latin_Letter_Small_Capital_R  : constant Unicode_Char := 16#1DE2#;
   Combining_Latin_Small_Letter_R_Rotunda  : constant Unicode_Char := 16#1DE3#;
   Combining_Latin_Small_Letter_S          : constant Unicode_Char := 16#1DE4#;
   Combining_Latin_Small_Letter_Long_S     : constant Unicode_Char := 16#1DE5#;
   Combining_Latin_Small_Letter_Z          : constant Unicode_Char := 16#1DE6#;
   Combining_Latin_Small_Letter_Alpha      : constant Unicode_Char := 16#1DE7#;
   Combining_Latin_Small_Letter_B          : constant Unicode_Char := 16#1DE8#;
   Combining_Latin_Small_Letter_Beta       : constant Unicode_Char := 16#1DE9#;
   Combining_Latin_Small_Letter_Schwa      : constant Unicode_Char := 16#1DEA#;
   Combining_Latin_Small_Letter_F          : constant Unicode_Char := 16#1DEB#;
   Combining_Latin_Small_Letter_L_With_Double_Middle_Tilde :
      constant Unicode_Char := 16#1DEC#;
   Combining_Latin_Small_Letter_O_With_Light_Centralization_Stroke :
      constant Unicode_Char := 16#1DED#;
   Combining_Latin_Small_Letter_P          : constant Unicode_Char := 16#1DEE#;
   Combining_Latin_Small_Letter_Esh        : constant Unicode_Char := 16#1DEF#;
   Combining_Latin_Small_Letter_U_With_Light_Centralization_Stroke :
      constant Unicode_Char := 16#1DF0#;
   Combining_Latin_Small_Letter_W          : constant Unicode_Char := 16#1DF1#;
   Combining_Latin_Small_Letter_A_With_Diaeresis :
      constant Unicode_Char := 16#1DF2#;
   Combining_Latin_Small_Letter_O_With_Diaeresis :
      constant Unicode_Char := 16#1DF3#;
   Combining_Latin_Small_Letter_U_With_Diaeresis :
      constant Unicode_Char := 16#1DF4#;
   Combining_Up_Tack_Above                 : constant Unicode_Char := 16#1DF5#;
   Combining_Double_Inverted_Breve_Below   : constant Unicode_Char := 16#1DFC#;
   Combining_Almost_Equal_To_Below         : constant Unicode_Char := 16#1DFD#;
   Combining_Left_Arrowhead_Above          : constant Unicode_Char := 16#1DFE#;
   Combining_Right_Arrowhead_And_Down_Arrowhead_Below :
      constant Unicode_Char := 16#1DFF#;
end Unicode.Names.Combining_Diacritical_Sup;
