--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Aegean_Numbers is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Aegean_Word_Separator_Line              :
      constant Unicode_Char := 16#10100#;
   Aegean_Word_Separator_Dot               :
      constant Unicode_Char := 16#10101#;
   Aegean_Check_Mark                       :
      constant Unicode_Char := 16#10102#;
   Aegean_Number_One                       :
      constant Unicode_Char := 16#10107#;
   Aegean_Number_Two                       :
      constant Unicode_Char := 16#10108#;
   Aegean_Number_Three                     :
      constant Unicode_Char := 16#10109#;
   Aegean_Number_Four                      :
      constant Unicode_Char := 16#1010A#;
   Aegean_Number_Five                      :
      constant Unicode_Char := 16#1010B#;
   Aegean_Number_Six                       :
      constant Unicode_Char := 16#1010C#;
   Aegean_Number_Seven                     :
      constant Unicode_Char := 16#1010D#;
   Aegean_Number_Eight                     :
      constant Unicode_Char := 16#1010E#;
   Aegean_Number_Nine                      :
      constant Unicode_Char := 16#1010F#;
   Aegean_Number_Ten                       :
      constant Unicode_Char := 16#10110#;
   Aegean_Number_Twenty                    :
      constant Unicode_Char := 16#10111#;
   Aegean_Number_Thirty                    :
      constant Unicode_Char := 16#10112#;
   Aegean_Number_Forty                     :
      constant Unicode_Char := 16#10113#;
   Aegean_Number_Fifty                     :
      constant Unicode_Char := 16#10114#;
   Aegean_Number_Sixty                     :
      constant Unicode_Char := 16#10115#;
   Aegean_Number_Seventy                   :
      constant Unicode_Char := 16#10116#;
   Aegean_Number_Eighty                    :
      constant Unicode_Char := 16#10117#;
   Aegean_Number_Ninety                    :
      constant Unicode_Char := 16#10118#;
   Aegean_Number_One_Hundred               :
      constant Unicode_Char := 16#10119#;
   Aegean_Number_Two_Hundred               :
      constant Unicode_Char := 16#1011A#;
   Aegean_Number_Three_Hundred             :
      constant Unicode_Char := 16#1011B#;
   Aegean_Number_Four_Hundred              :
      constant Unicode_Char := 16#1011C#;
   Aegean_Number_Five_Hundred              :
      constant Unicode_Char := 16#1011D#;
   Aegean_Number_Six_Hundred               :
      constant Unicode_Char := 16#1011E#;
   Aegean_Number_Seven_Hundred             :
      constant Unicode_Char := 16#1011F#;
   Aegean_Number_Eight_Hundred             :
      constant Unicode_Char := 16#10120#;
   Aegean_Number_Nine_Hundred              :
      constant Unicode_Char := 16#10121#;
   Aegean_Number_One_Thousand              :
      constant Unicode_Char := 16#10122#;
   Aegean_Number_Two_Thousand              :
      constant Unicode_Char := 16#10123#;
   Aegean_Number_Three_Thousand            :
      constant Unicode_Char := 16#10124#;
   Aegean_Number_Four_Thousand             :
      constant Unicode_Char := 16#10125#;
   Aegean_Number_Five_Thousand             :
      constant Unicode_Char := 16#10126#;
   Aegean_Number_Six_Thousand              :
      constant Unicode_Char := 16#10127#;
   Aegean_Number_Seven_Thousand            :
      constant Unicode_Char := 16#10128#;
   Aegean_Number_Eight_Thousand            :
      constant Unicode_Char := 16#10129#;
   Aegean_Number_Nine_Thousand             :
      constant Unicode_Char := 16#1012A#;
   Aegean_Number_Ten_Thousand              :
      constant Unicode_Char := 16#1012B#;
   Aegean_Number_Twenty_Thousand           :
      constant Unicode_Char := 16#1012C#;
   Aegean_Number_Thirty_Thousand           :
      constant Unicode_Char := 16#1012D#;
   Aegean_Number_Forty_Thousand            :
      constant Unicode_Char := 16#1012E#;
   Aegean_Number_Fifty_Thousand            :
      constant Unicode_Char := 16#1012F#;
   Aegean_Number_Sixty_Thousand            :
      constant Unicode_Char := 16#10130#;
   Aegean_Number_Seventy_Thousand          :
      constant Unicode_Char := 16#10131#;
   Aegean_Number_Eighty_Thousand           :
      constant Unicode_Char := 16#10132#;
   Aegean_Number_Ninety_Thousand           :
      constant Unicode_Char := 16#10133#;
   Aegean_Weight_Base_Unit                 :
      constant Unicode_Char := 16#10137#;
   Aegean_Weight_First_Subunit             :
      constant Unicode_Char := 16#10138#;
   Aegean_Weight_Second_Subunit            :
      constant Unicode_Char := 16#10139#;
   Aegean_Weight_Third_Subunit             :
      constant Unicode_Char := 16#1013A#;
   Aegean_Weight_Fourth_Subunit            :
      constant Unicode_Char := 16#1013B#;
   Aegean_Dry_Measure_First_Subunit        :
      constant Unicode_Char := 16#1013C#;
   Aegean_Liquid_Measure_First_Subunit     :
      constant Unicode_Char := 16#1013D#;
   Aegean_Measure_Second_Subunit           :
      constant Unicode_Char := 16#1013E#;
   Aegean_Measure_Third_Subunit            :
      constant Unicode_Char := 16#1013F#;
end Unicode.Names.Aegean_Numbers;
