--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Thaana is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Thaana_Letter_Haa                       : constant Unicode_Char := 16#0780#;
   Thaana_Letter_Shaviyani                 : constant Unicode_Char := 16#0781#;
   Thaana_Letter_Noonu                     : constant Unicode_Char := 16#0782#;
   Thaana_Letter_Raa                       : constant Unicode_Char := 16#0783#;
   Thaana_Letter_Baa                       : constant Unicode_Char := 16#0784#;
   Thaana_Letter_Lhaviyani                 : constant Unicode_Char := 16#0785#;
   Thaana_Letter_Kaafu                     : constant Unicode_Char := 16#0786#;
   Thaana_Letter_Alifu                     : constant Unicode_Char := 16#0787#;
   Thaana_Letter_Vaavu                     : constant Unicode_Char := 16#0788#;
   Thaana_Letter_Meemu                     : constant Unicode_Char := 16#0789#;
   Thaana_Letter_Faafu                     : constant Unicode_Char := 16#078A#;
   Thaana_Letter_Dhaalu                    : constant Unicode_Char := 16#078B#;
   Thaana_Letter_Thaa                      : constant Unicode_Char := 16#078C#;
   Thaana_Letter_Laamu                     : constant Unicode_Char := 16#078D#;
   Thaana_Letter_Gaafu                     : constant Unicode_Char := 16#078E#;
   Thaana_Letter_Gnaviyani                 : constant Unicode_Char := 16#078F#;
   Thaana_Letter_Seenu                     : constant Unicode_Char := 16#0790#;
   Thaana_Letter_Daviyani                  : constant Unicode_Char := 16#0791#;
   Thaana_Letter_Zaviyani                  : constant Unicode_Char := 16#0792#;
   Thaana_Letter_Taviyani                  : constant Unicode_Char := 16#0793#;
   Thaana_Letter_Yaa                       : constant Unicode_Char := 16#0794#;
   Thaana_Letter_Paviyani                  : constant Unicode_Char := 16#0795#;
   Thaana_Letter_Javiyani                  : constant Unicode_Char := 16#0796#;
   Thaana_Letter_Chaviyani                 : constant Unicode_Char := 16#0797#;
   Thaana_Letter_Ttaa                      : constant Unicode_Char := 16#0798#;
   Thaana_Letter_Hhaa                      : constant Unicode_Char := 16#0799#;
   Thaana_Letter_Khaa                      : constant Unicode_Char := 16#079A#;
   Thaana_Letter_Thaalu                    : constant Unicode_Char := 16#079B#;
   Thaana_Letter_Zaa                       : constant Unicode_Char := 16#079C#;
   Thaana_Letter_Sheenu                    : constant Unicode_Char := 16#079D#;
   Thaana_Letter_Saadhu                    : constant Unicode_Char := 16#079E#;
   Thaana_Letter_Daadhu                    : constant Unicode_Char := 16#079F#;
   Thaana_Letter_To                        : constant Unicode_Char := 16#07A0#;
   Thaana_Letter_Zo                        : constant Unicode_Char := 16#07A1#;
   Thaana_Letter_Ainu                      : constant Unicode_Char := 16#07A2#;
   Thaana_Letter_Ghainu                    : constant Unicode_Char := 16#07A3#;
   Thaana_Letter_Qaafu                     : constant Unicode_Char := 16#07A4#;
   Thaana_Letter_Waavu                     : constant Unicode_Char := 16#07A5#;
   Thaana_Abafili                          : constant Unicode_Char := 16#07A6#;
   Thaana_Aabaafili                        : constant Unicode_Char := 16#07A7#;
   Thaana_Ibifili                          : constant Unicode_Char := 16#07A8#;
   Thaana_Eebeefili                        : constant Unicode_Char := 16#07A9#;
   Thaana_Ubufili                          : constant Unicode_Char := 16#07AA#;
   Thaana_Ooboofili                        : constant Unicode_Char := 16#07AB#;
   Thaana_Ebefili                          : constant Unicode_Char := 16#07AC#;
   Thaana_Eybeyfili                        : constant Unicode_Char := 16#07AD#;
   Thaana_Obofili                          : constant Unicode_Char := 16#07AE#;
   Thaana_Oaboafili                        : constant Unicode_Char := 16#07AF#;
   Thaana_Sukun                            : constant Unicode_Char := 16#07B0#;
   Thaana_Letter_Naa                       : constant Unicode_Char := 16#07B1#;
end Unicode.Names.Thaana;
