--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Georgian_Supplement is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Georgian_Small_Letter_An                : constant Unicode_Char := 16#2D00#;
   Georgian_Small_Letter_Ban               : constant Unicode_Char := 16#2D01#;
   Georgian_Small_Letter_Gan               : constant Unicode_Char := 16#2D02#;
   Georgian_Small_Letter_Don               : constant Unicode_Char := 16#2D03#;
   Georgian_Small_Letter_En                : constant Unicode_Char := 16#2D04#;
   Georgian_Small_Letter_Vin               : constant Unicode_Char := 16#2D05#;
   Georgian_Small_Letter_Zen               : constant Unicode_Char := 16#2D06#;
   Georgian_Small_Letter_Tan               : constant Unicode_Char := 16#2D07#;
   Georgian_Small_Letter_In                : constant Unicode_Char := 16#2D08#;
   Georgian_Small_Letter_Kan               : constant Unicode_Char := 16#2D09#;
   Georgian_Small_Letter_Las               : constant Unicode_Char := 16#2D0A#;
   Georgian_Small_Letter_Man               : constant Unicode_Char := 16#2D0B#;
   Georgian_Small_Letter_Nar               : constant Unicode_Char := 16#2D0C#;
   Georgian_Small_Letter_On                : constant Unicode_Char := 16#2D0D#;
   Georgian_Small_Letter_Par               : constant Unicode_Char := 16#2D0E#;
   Georgian_Small_Letter_Zhar              : constant Unicode_Char := 16#2D0F#;
   Georgian_Small_Letter_Rae               : constant Unicode_Char := 16#2D10#;
   Georgian_Small_Letter_San               : constant Unicode_Char := 16#2D11#;
   Georgian_Small_Letter_Tar               : constant Unicode_Char := 16#2D12#;
   Georgian_Small_Letter_Un                : constant Unicode_Char := 16#2D13#;
   Georgian_Small_Letter_Phar              : constant Unicode_Char := 16#2D14#;
   Georgian_Small_Letter_Khar              : constant Unicode_Char := 16#2D15#;
   Georgian_Small_Letter_Ghan              : constant Unicode_Char := 16#2D16#;
   Georgian_Small_Letter_Qar               : constant Unicode_Char := 16#2D17#;
   Georgian_Small_Letter_Shin              : constant Unicode_Char := 16#2D18#;
   Georgian_Small_Letter_Chin              : constant Unicode_Char := 16#2D19#;
   Georgian_Small_Letter_Can               : constant Unicode_Char := 16#2D1A#;
   Georgian_Small_Letter_Jil               : constant Unicode_Char := 16#2D1B#;
   Georgian_Small_Letter_Cil               : constant Unicode_Char := 16#2D1C#;
   Georgian_Small_Letter_Char              : constant Unicode_Char := 16#2D1D#;
   Georgian_Small_Letter_Xan               : constant Unicode_Char := 16#2D1E#;
   Georgian_Small_Letter_Jhan              : constant Unicode_Char := 16#2D1F#;
   Georgian_Small_Letter_Hae               : constant Unicode_Char := 16#2D20#;
   Georgian_Small_Letter_He                : constant Unicode_Char := 16#2D21#;
   Georgian_Small_Letter_Hie               : constant Unicode_Char := 16#2D22#;
   Georgian_Small_Letter_We                : constant Unicode_Char := 16#2D23#;
   Georgian_Small_Letter_Har               : constant Unicode_Char := 16#2D24#;
   Georgian_Small_Letter_Hoe               : constant Unicode_Char := 16#2D25#;
   Georgian_Small_Letter_Yn                : constant Unicode_Char := 16#2D27#;
   Georgian_Small_Letter_Aen               : constant Unicode_Char := 16#2D2D#;
end Unicode.Names.Georgian_Supplement;
