--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Glagolitic is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Glagolitic_Capital_Letter_Azu           : constant Unicode_Char := 16#2C00#;
   Glagolitic_Capital_Letter_Buky          : constant Unicode_Char := 16#2C01#;
   Glagolitic_Capital_Letter_Vede          : constant Unicode_Char := 16#2C02#;
   Glagolitic_Capital_Letter_Glagoli       : constant Unicode_Char := 16#2C03#;
   Glagolitic_Capital_Letter_Dobro         : constant Unicode_Char := 16#2C04#;
   Glagolitic_Capital_Letter_Yestu         : constant Unicode_Char := 16#2C05#;
   Glagolitic_Capital_Letter_Zhivete       : constant Unicode_Char := 16#2C06#;
   Glagolitic_Capital_Letter_Dzelo         : constant Unicode_Char := 16#2C07#;
   Glagolitic_Capital_Letter_Zemlja        : constant Unicode_Char := 16#2C08#;
   Glagolitic_Capital_Letter_Izhe          : constant Unicode_Char := 16#2C09#;
   Glagolitic_Capital_Letter_Initial_Izhe  : constant Unicode_Char := 16#2C0A#;
   Glagolitic_Capital_Letter_I             : constant Unicode_Char := 16#2C0B#;
   Glagolitic_Capital_Letter_Djervi        : constant Unicode_Char := 16#2C0C#;
   Glagolitic_Capital_Letter_Kako          : constant Unicode_Char := 16#2C0D#;
   Glagolitic_Capital_Letter_Ljudije       : constant Unicode_Char := 16#2C0E#;
   Glagolitic_Capital_Letter_Myslite       : constant Unicode_Char := 16#2C0F#;
   Glagolitic_Capital_Letter_Nashi         : constant Unicode_Char := 16#2C10#;
   Glagolitic_Capital_Letter_Onu           : constant Unicode_Char := 16#2C11#;
   Glagolitic_Capital_Letter_Pokoji        : constant Unicode_Char := 16#2C12#;
   Glagolitic_Capital_Letter_Ritsi         : constant Unicode_Char := 16#2C13#;
   Glagolitic_Capital_Letter_Slovo         : constant Unicode_Char := 16#2C14#;
   Glagolitic_Capital_Letter_Tvrido        : constant Unicode_Char := 16#2C15#;
   Glagolitic_Capital_Letter_Uku           : constant Unicode_Char := 16#2C16#;
   Glagolitic_Capital_Letter_Fritu         : constant Unicode_Char := 16#2C17#;
   Glagolitic_Capital_Letter_Heru          : constant Unicode_Char := 16#2C18#;
   Glagolitic_Capital_Letter_Otu           : constant Unicode_Char := 16#2C19#;
   Glagolitic_Capital_Letter_Pe            : constant Unicode_Char := 16#2C1A#;
   Glagolitic_Capital_Letter_Shta          : constant Unicode_Char := 16#2C1B#;
   Glagolitic_Capital_Letter_Tsi           : constant Unicode_Char := 16#2C1C#;
   Glagolitic_Capital_Letter_Chrivi        : constant Unicode_Char := 16#2C1D#;
   Glagolitic_Capital_Letter_Sha           : constant Unicode_Char := 16#2C1E#;
   Glagolitic_Capital_Letter_Yeru          : constant Unicode_Char := 16#2C1F#;
   Glagolitic_Capital_Letter_Yeri          : constant Unicode_Char := 16#2C20#;
   Glagolitic_Capital_Letter_Yati          : constant Unicode_Char := 16#2C21#;
   Glagolitic_Capital_Letter_Spidery_Ha    : constant Unicode_Char := 16#2C22#;
   Glagolitic_Capital_Letter_Yu            : constant Unicode_Char := 16#2C23#;
   Glagolitic_Capital_Letter_Small_Yus     : constant Unicode_Char := 16#2C24#;
   Glagolitic_Capital_Letter_Small_Yus_With_Tail :
      constant Unicode_Char := 16#2C25#;
   Glagolitic_Capital_Letter_Yo            : constant Unicode_Char := 16#2C26#;
   Glagolitic_Capital_Letter_Iotated_Small_Yus :
      constant Unicode_Char := 16#2C27#;
   Glagolitic_Capital_Letter_Big_Yus       : constant Unicode_Char := 16#2C28#;
   Glagolitic_Capital_Letter_Iotated_Big_Yus :
      constant Unicode_Char := 16#2C29#;
   Glagolitic_Capital_Letter_Fita          : constant Unicode_Char := 16#2C2A#;
   Glagolitic_Capital_Letter_Izhitsa       : constant Unicode_Char := 16#2C2B#;
   Glagolitic_Capital_Letter_Shtapic       : constant Unicode_Char := 16#2C2C#;
   Glagolitic_Capital_Letter_Trokutasti_A  : constant Unicode_Char := 16#2C2D#;
   Glagolitic_Capital_Letter_Latinate_Myslite :
      constant Unicode_Char := 16#2C2E#;
   Glagolitic_Small_Letter_Azu             : constant Unicode_Char := 16#2C30#;
   Glagolitic_Small_Letter_Buky            : constant Unicode_Char := 16#2C31#;
   Glagolitic_Small_Letter_Vede            : constant Unicode_Char := 16#2C32#;
   Glagolitic_Small_Letter_Glagoli         : constant Unicode_Char := 16#2C33#;
   Glagolitic_Small_Letter_Dobro           : constant Unicode_Char := 16#2C34#;
   Glagolitic_Small_Letter_Yestu           : constant Unicode_Char := 16#2C35#;
   Glagolitic_Small_Letter_Zhivete         : constant Unicode_Char := 16#2C36#;
   Glagolitic_Small_Letter_Dzelo           : constant Unicode_Char := 16#2C37#;
   Glagolitic_Small_Letter_Zemlja          : constant Unicode_Char := 16#2C38#;
   Glagolitic_Small_Letter_Izhe            : constant Unicode_Char := 16#2C39#;
   Glagolitic_Small_Letter_Initial_Izhe    : constant Unicode_Char := 16#2C3A#;
   Glagolitic_Small_Letter_I               : constant Unicode_Char := 16#2C3B#;
   Glagolitic_Small_Letter_Djervi          : constant Unicode_Char := 16#2C3C#;
   Glagolitic_Small_Letter_Kako            : constant Unicode_Char := 16#2C3D#;
   Glagolitic_Small_Letter_Ljudije         : constant Unicode_Char := 16#2C3E#;
   Glagolitic_Small_Letter_Myslite         : constant Unicode_Char := 16#2C3F#;
   Glagolitic_Small_Letter_Nashi           : constant Unicode_Char := 16#2C40#;
   Glagolitic_Small_Letter_Onu             : constant Unicode_Char := 16#2C41#;
   Glagolitic_Small_Letter_Pokoji          : constant Unicode_Char := 16#2C42#;
   Glagolitic_Small_Letter_Ritsi           : constant Unicode_Char := 16#2C43#;
   Glagolitic_Small_Letter_Slovo           : constant Unicode_Char := 16#2C44#;
   Glagolitic_Small_Letter_Tvrido          : constant Unicode_Char := 16#2C45#;
   Glagolitic_Small_Letter_Uku             : constant Unicode_Char := 16#2C46#;
   Glagolitic_Small_Letter_Fritu           : constant Unicode_Char := 16#2C47#;
   Glagolitic_Small_Letter_Heru            : constant Unicode_Char := 16#2C48#;
   Glagolitic_Small_Letter_Otu             : constant Unicode_Char := 16#2C49#;
   Glagolitic_Small_Letter_Pe              : constant Unicode_Char := 16#2C4A#;
   Glagolitic_Small_Letter_Shta            : constant Unicode_Char := 16#2C4B#;
   Glagolitic_Small_Letter_Tsi             : constant Unicode_Char := 16#2C4C#;
   Glagolitic_Small_Letter_Chrivi          : constant Unicode_Char := 16#2C4D#;
   Glagolitic_Small_Letter_Sha             : constant Unicode_Char := 16#2C4E#;
   Glagolitic_Small_Letter_Yeru            : constant Unicode_Char := 16#2C4F#;
   Glagolitic_Small_Letter_Yeri            : constant Unicode_Char := 16#2C50#;
   Glagolitic_Small_Letter_Yati            : constant Unicode_Char := 16#2C51#;
   Glagolitic_Small_Letter_Spidery_Ha      : constant Unicode_Char := 16#2C52#;
   Glagolitic_Small_Letter_Yu              : constant Unicode_Char := 16#2C53#;
   Glagolitic_Small_Letter_Small_Yus       : constant Unicode_Char := 16#2C54#;
   Glagolitic_Small_Letter_Small_Yus_With_Tail :
      constant Unicode_Char := 16#2C55#;
   Glagolitic_Small_Letter_Yo              : constant Unicode_Char := 16#2C56#;
   Glagolitic_Small_Letter_Iotated_Small_Yus :
      constant Unicode_Char := 16#2C57#;
   Glagolitic_Small_Letter_Big_Yus         : constant Unicode_Char := 16#2C58#;
   Glagolitic_Small_Letter_Iotated_Big_Yus : constant Unicode_Char := 16#2C59#;
   Glagolitic_Small_Letter_Fita            : constant Unicode_Char := 16#2C5A#;
   Glagolitic_Small_Letter_Izhitsa         : constant Unicode_Char := 16#2C5B#;
   Glagolitic_Small_Letter_Shtapic         : constant Unicode_Char := 16#2C5C#;
   Glagolitic_Small_Letter_Trokutasti_A    : constant Unicode_Char := 16#2C5D#;
   Glagolitic_Small_Letter_Latinate_Myslite :
      constant Unicode_Char := 16#2C5E#;
end Unicode.Names.Glagolitic;
