--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Kharoshthi is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Kharoshthi_Letter_A                     :
      constant Unicode_Char := 16#10A00#;
   Kharoshthi_Vowel_Sign_I                 :
      constant Unicode_Char := 16#10A01#;
   Kharoshthi_Vowel_Sign_U                 :
      constant Unicode_Char := 16#10A02#;
   Kharoshthi_Vowel_Sign_Vocalic_R         :
      constant Unicode_Char := 16#10A03#;
   Kharoshthi_Vowel_Sign_E                 :
      constant Unicode_Char := 16#10A05#;
   Kharoshthi_Vowel_Sign_O                 :
      constant Unicode_Char := 16#10A06#;
   Kharoshthi_Vowel_Length_Mark            :
      constant Unicode_Char := 16#10A0C#;
   Kharoshthi_Sign_Double_Ring_Below       :
      constant Unicode_Char := 16#10A0D#;
   Kharoshthi_Sign_Anusvara                :
      constant Unicode_Char := 16#10A0E#;
   Kharoshthi_Sign_Visarga                 :
      constant Unicode_Char := 16#10A0F#;
   Kharoshthi_Letter_Ka                    :
      constant Unicode_Char := 16#10A10#;
   Kharoshthi_Letter_Kha                   :
      constant Unicode_Char := 16#10A11#;
   Kharoshthi_Letter_Ga                    :
      constant Unicode_Char := 16#10A12#;
   Kharoshthi_Letter_Gha                   :
      constant Unicode_Char := 16#10A13#;
   Kharoshthi_Letter_Ca                    :
      constant Unicode_Char := 16#10A15#;
   Kharoshthi_Letter_Cha                   :
      constant Unicode_Char := 16#10A16#;
   Kharoshthi_Letter_Ja                    :
      constant Unicode_Char := 16#10A17#;
   Kharoshthi_Letter_Nya                   :
      constant Unicode_Char := 16#10A19#;
   Kharoshthi_Letter_Tta                   :
      constant Unicode_Char := 16#10A1A#;
   Kharoshthi_Letter_Ttha                  :
      constant Unicode_Char := 16#10A1B#;
   Kharoshthi_Letter_Dda                   :
      constant Unicode_Char := 16#10A1C#;
   Kharoshthi_Letter_Ddha                  :
      constant Unicode_Char := 16#10A1D#;
   Kharoshthi_Letter_Nna                   :
      constant Unicode_Char := 16#10A1E#;
   Kharoshthi_Letter_Ta                    :
      constant Unicode_Char := 16#10A1F#;
   Kharoshthi_Letter_Tha                   :
      constant Unicode_Char := 16#10A20#;
   Kharoshthi_Letter_Da                    :
      constant Unicode_Char := 16#10A21#;
   Kharoshthi_Letter_Dha                   :
      constant Unicode_Char := 16#10A22#;
   Kharoshthi_Letter_Na                    :
      constant Unicode_Char := 16#10A23#;
   Kharoshthi_Letter_Pa                    :
      constant Unicode_Char := 16#10A24#;
   Kharoshthi_Letter_Pha                   :
      constant Unicode_Char := 16#10A25#;
   Kharoshthi_Letter_Ba                    :
      constant Unicode_Char := 16#10A26#;
   Kharoshthi_Letter_Bha                   :
      constant Unicode_Char := 16#10A27#;
   Kharoshthi_Letter_Ma                    :
      constant Unicode_Char := 16#10A28#;
   Kharoshthi_Letter_Ya                    :
      constant Unicode_Char := 16#10A29#;
   Kharoshthi_Letter_Ra                    :
      constant Unicode_Char := 16#10A2A#;
   Kharoshthi_Letter_La                    :
      constant Unicode_Char := 16#10A2B#;
   Kharoshthi_Letter_Va                    :
      constant Unicode_Char := 16#10A2C#;
   Kharoshthi_Letter_Sha                   :
      constant Unicode_Char := 16#10A2D#;
   Kharoshthi_Letter_Ssa                   :
      constant Unicode_Char := 16#10A2E#;
   Kharoshthi_Letter_Sa                    :
      constant Unicode_Char := 16#10A2F#;
   Kharoshthi_Letter_Za                    :
      constant Unicode_Char := 16#10A30#;
   Kharoshthi_Letter_Ha                    :
      constant Unicode_Char := 16#10A31#;
   Kharoshthi_Letter_Kka                   :
      constant Unicode_Char := 16#10A32#;
   Kharoshthi_Letter_Tttha                 :
      constant Unicode_Char := 16#10A33#;
   Kharoshthi_Sign_Bar_Above               :
      constant Unicode_Char := 16#10A38#;
   Kharoshthi_Sign_Cauda                   :
      constant Unicode_Char := 16#10A39#;
   Kharoshthi_Sign_Dot_Below               :
      constant Unicode_Char := 16#10A3A#;
   Kharoshthi_Virama                       :
      constant Unicode_Char := 16#10A3F#;
   Kharoshthi_Digit_One                    :
      constant Unicode_Char := 16#10A40#;
   Kharoshthi_Digit_Two                    :
      constant Unicode_Char := 16#10A41#;
   Kharoshthi_Digit_Three                  :
      constant Unicode_Char := 16#10A42#;
   Kharoshthi_Digit_Four                   :
      constant Unicode_Char := 16#10A43#;
   Kharoshthi_Number_Ten                   :
      constant Unicode_Char := 16#10A44#;
   Kharoshthi_Number_Twenty                :
      constant Unicode_Char := 16#10A45#;
   Kharoshthi_Number_One_Hundred           :
      constant Unicode_Char := 16#10A46#;
   Kharoshthi_Number_One_Thousand          :
      constant Unicode_Char := 16#10A47#;
   Kharoshthi_Punctuation_Dot              :
      constant Unicode_Char := 16#10A50#;
   Kharoshthi_Punctuation_Small_Circle     :
      constant Unicode_Char := 16#10A51#;
   Kharoshthi_Punctuation_Circle           :
      constant Unicode_Char := 16#10A52#;
   Kharoshthi_Punctuation_Crescent_Bar     :
      constant Unicode_Char := 16#10A53#;
   Kharoshthi_Punctuation_Mangalam         :
      constant Unicode_Char := 16#10A54#;
   Kharoshthi_Punctuation_Lotus            :
      constant Unicode_Char := 16#10A55#;
   Kharoshthi_Punctuation_Danda            :
      constant Unicode_Char := 16#10A56#;
   Kharoshthi_Punctuation_Double_Danda     :
      constant Unicode_Char := 16#10A57#;
   Kharoshthi_Punctuation_Lines            :
      constant Unicode_Char := 16#10A58#;
end Unicode.Names.Kharoshthi;
