--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Lao is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Lao_Letter_Ko                           : constant Unicode_Char := 16#0E81#;
   Lao_Letter_Kho_Sung                     : constant Unicode_Char := 16#0E82#;
   Lao_Letter_Kho_Tam                      : constant Unicode_Char := 16#0E84#;
   Lao_Letter_Ngo                          : constant Unicode_Char := 16#0E87#;
   Lao_Letter_Co                           : constant Unicode_Char := 16#0E88#;
   Lao_Letter_So_Tam                       : constant Unicode_Char := 16#0E8A#;
   Lao_Letter_Nyo                          : constant Unicode_Char := 16#0E8D#;
   Lao_Letter_Do                           : constant Unicode_Char := 16#0E94#;
   Lao_Letter_To                           : constant Unicode_Char := 16#0E95#;
   Lao_Letter_Tho_Sung                     : constant Unicode_Char := 16#0E96#;
   Lao_Letter_Tho_Tam                      : constant Unicode_Char := 16#0E97#;
   Lao_Letter_No                           : constant Unicode_Char := 16#0E99#;
   Lao_Letter_Bo                           : constant Unicode_Char := 16#0E9A#;
   Lao_Letter_Po                           : constant Unicode_Char := 16#0E9B#;
   Lao_Letter_Pho_Sung                     : constant Unicode_Char := 16#0E9C#;
   Lao_Letter_Fo_Tam                       : constant Unicode_Char := 16#0E9D#;
   Lao_Letter_Fo_Fon                       :
      Unicode_Char renames Lao_Letter_Fo_Tam;
   Lao_Letter_Pho_Tam                      : constant Unicode_Char := 16#0E9E#;
   Lao_Letter_Fo_Sung                      : constant Unicode_Char := 16#0E9F#;
   Lao_Letter_Fo_Fay                       :
      Unicode_Char renames Lao_Letter_Fo_Sung;
   Lao_Letter_Mo                           : constant Unicode_Char := 16#0EA1#;
   Lao_Letter_Yo                           : constant Unicode_Char := 16#0EA2#;
   Lao_Letter_Lo_Ling                      : constant Unicode_Char := 16#0EA3#;
   Lao_Letter_Ro                           :
      Unicode_Char renames Lao_Letter_Lo_Ling;
   Lao_Letter_Lo_Loot                      : constant Unicode_Char := 16#0EA5#;
   Lao_Letter_Lo                           :
      Unicode_Char renames Lao_Letter_Lo_Loot;
   Lao_Letter_Wo                           : constant Unicode_Char := 16#0EA7#;
   Lao_Letter_So_Sung                      : constant Unicode_Char := 16#0EAA#;
   Lao_Letter_Ho_Sung                      : constant Unicode_Char := 16#0EAB#;
   Lao_Letter_O                            : constant Unicode_Char := 16#0EAD#;
   Lao_Letter_Ho_Tam                       : constant Unicode_Char := 16#0EAE#;
   Lao_Ellipsis                            : constant Unicode_Char := 16#0EAF#;
   Lao_Vowel_Sign_A                        : constant Unicode_Char := 16#0EB0#;
   Lao_Vowel_Sign_Mai_Kan                  : constant Unicode_Char := 16#0EB1#;
   Lao_Vowel_Sign_Aa                       : constant Unicode_Char := 16#0EB2#;
   Lao_Vowel_Sign_Am                       : constant Unicode_Char := 16#0EB3#;
   Lao_Vowel_Sign_I                        : constant Unicode_Char := 16#0EB4#;
   Lao_Vowel_Sign_Ii                       : constant Unicode_Char := 16#0EB5#;
   Lao_Vowel_Sign_Y                        : constant Unicode_Char := 16#0EB6#;
   Lao_Vowel_Sign_Yy                       : constant Unicode_Char := 16#0EB7#;
   Lao_Vowel_Sign_U                        : constant Unicode_Char := 16#0EB8#;
   Lao_Vowel_Sign_Uu                       : constant Unicode_Char := 16#0EB9#;
   Lao_Vowel_Sign_Mai_Kon                  : constant Unicode_Char := 16#0EBB#;
   Lao_Semivowel_Sign_Lo                   : constant Unicode_Char := 16#0EBC#;
   Lao_Semivowel_Sign_Nyo                  : constant Unicode_Char := 16#0EBD#;
   Lao_Vowel_Sign_E                        : constant Unicode_Char := 16#0EC0#;
   Lao_Vowel_Sign_Ei                       : constant Unicode_Char := 16#0EC1#;
   Lao_Vowel_Sign_O                        : constant Unicode_Char := 16#0EC2#;
   Lao_Vowel_Sign_Ay                       : constant Unicode_Char := 16#0EC3#;
   Lao_Vowel_Sign_Ai                       : constant Unicode_Char := 16#0EC4#;
   Lao_Ko_La                               : constant Unicode_Char := 16#0EC6#;
   Lao_Tone_Mai_Ek                         : constant Unicode_Char := 16#0EC8#;
   Lao_Tone_Mai_Tho                        : constant Unicode_Char := 16#0EC9#;
   Lao_Tone_Mai_Ti                         : constant Unicode_Char := 16#0ECA#;
   Lao_Tone_Mai_Catawa                     : constant Unicode_Char := 16#0ECB#;
   Lao_Cancellation_Mark                   : constant Unicode_Char := 16#0ECC#;
   Lao_Niggahita                           : constant Unicode_Char := 16#0ECD#;
   Lao_Digit_Zero                          : constant Unicode_Char := 16#0ED0#;
   Lao_Digit_One                           : constant Unicode_Char := 16#0ED1#;
   Lao_Digit_Two                           : constant Unicode_Char := 16#0ED2#;
   Lao_Digit_Three                         : constant Unicode_Char := 16#0ED3#;
   Lao_Digit_Four                          : constant Unicode_Char := 16#0ED4#;
   Lao_Digit_Five                          : constant Unicode_Char := 16#0ED5#;
   Lao_Digit_Six                           : constant Unicode_Char := 16#0ED6#;
   Lao_Digit_Seven                         : constant Unicode_Char := 16#0ED7#;
   Lao_Digit_Eight                         : constant Unicode_Char := 16#0ED8#;
   Lao_Digit_Nine                          : constant Unicode_Char := 16#0ED9#;
   Lao_Ho_No                               : constant Unicode_Char := 16#0EDC#;
   Lao_Ho_Mo                               : constant Unicode_Char := 16#0EDD#;
   Lao_Letter_Khmu_Go                      : constant Unicode_Char := 16#0EDE#;
   Lao_Letter_Khmu_Nyo                     : constant Unicode_Char := 16#0EDF#;
end Unicode.Names.Lao;
