--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Ornamental_Dingbats is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   North_West_Pointing_Leaf                :
      constant Unicode_Char := 16#1F650#;
   South_West_Pointing_Leaf                :
      constant Unicode_Char := 16#1F651#;
   North_East_Pointing_Leaf                :
      constant Unicode_Char := 16#1F652#;
   South_East_Pointing_Leaf                :
      constant Unicode_Char := 16#1F653#;
   Turned_North_West_Pointing_Leaf         :
      constant Unicode_Char := 16#1F654#;
   Turned_South_West_Pointing_Leaf         :
      constant Unicode_Char := 16#1F655#;
   Turned_North_East_Pointing_Leaf         :
      constant Unicode_Char := 16#1F656#;
   Turned_South_East_Pointing_Leaf         :
      constant Unicode_Char := 16#1F657#;
   North_West_Pointing_Vine_Leaf           :
      constant Unicode_Char := 16#1F658#;
   South_West_Pointing_Vine_Leaf           :
      constant Unicode_Char := 16#1F659#;
   North_East_Pointing_Vine_Leaf           :
      constant Unicode_Char := 16#1F65A#;
   South_East_Pointing_Vine_Leaf           :
      constant Unicode_Char := 16#1F65B#;
   Heavy_North_West_Pointing_Vine_Leaf     :
      constant Unicode_Char := 16#1F65C#;
   Heavy_South_West_Pointing_Vine_Leaf     :
      constant Unicode_Char := 16#1F65D#;
   Heavy_North_East_Pointing_Vine_Leaf     :
      constant Unicode_Char := 16#1F65E#;
   Heavy_South_East_Pointing_Vine_Leaf     :
      constant Unicode_Char := 16#1F65F#;
   North_West_Pointing_Bud                 :
      constant Unicode_Char := 16#1F660#;
   South_West_Pointing_Bud                 :
      constant Unicode_Char := 16#1F661#;
   North_East_Pointing_Bud                 :
      constant Unicode_Char := 16#1F662#;
   South_East_Pointing_Bud                 :
      constant Unicode_Char := 16#1F663#;
   Heavy_North_West_Pointing_Bud           :
      constant Unicode_Char := 16#1F664#;
   Heavy_South_West_Pointing_Bud           :
      constant Unicode_Char := 16#1F665#;
   Heavy_North_East_Pointing_Bud           :
      constant Unicode_Char := 16#1F666#;
   Heavy_South_East_Pointing_Bud           :
      constant Unicode_Char := 16#1F667#;
   Hollow_Quilt_Square_Ornament            :
      constant Unicode_Char := 16#1F668#;
   Hollow_Quilt_Square_Ornament_In_Black_Square :
      constant Unicode_Char := 16#1F669#;
   Solid_Quilt_Square_Ornament             :
      constant Unicode_Char := 16#1F66A#;
   Solid_Quilt_Square_Ornament_In_Black_Square :
      constant Unicode_Char := 16#1F66B#;
   Leftwards_Rocket                        :
      constant Unicode_Char := 16#1F66C#;
   Upwards_Rocket                          :
      constant Unicode_Char := 16#1F66D#;
   Rightwards_Rocket                       :
      constant Unicode_Char := 16#1F66E#;
   Downwards_Rocket                        :
      constant Unicode_Char := 16#1F66F#;
   Script_Ligature_Et_Ornament             :
      constant Unicode_Char := 16#1F670#;
   Heavy_Script_Ligature_Et_Ornament       :
      constant Unicode_Char := 16#1F671#;
   Ligature_Open_Et_Ornament               :
      constant Unicode_Char := 16#1F672#;
   Heavy_Ligature_Open_Et_Ornament         :
      constant Unicode_Char := 16#1F673#;
   Heavy_Ampersand_Ornament                :
      constant Unicode_Char := 16#1F674#;
   Swash_Ampersand_Ornament                :
      constant Unicode_Char := 16#1F675#;
   Sans_Serif_Heavy_Double_Turned_Comma_Quotation_Mark_Ornament :
      constant Unicode_Char := 16#1F676#;
   Sans_Serif_Heavy_Double_Comma_Quotation_Mark_Ornament :
      constant Unicode_Char := 16#1F677#;
   Sans_Serif_Heavy_Low_Double_Comma_Quotation_Mark_Ornament :
      constant Unicode_Char := 16#1F678#;
   Heavy_Interrobang_Ornament              :
      constant Unicode_Char := 16#1F679#;
   Sans_Serif_Interrobang_Ornament         :
      constant Unicode_Char := 16#1F67A#;
   Heavy_Sans_Serif_Interrobang_Ornament   :
      constant Unicode_Char := 16#1F67B#;
   Very_Heavy_Solidus                      :
      constant Unicode_Char := 16#1F67C#;
   Very_Heavy_Reverse_Solidus              :
      constant Unicode_Char := 16#1F67D#;
   Checker_Board                           :
      constant Unicode_Char := 16#1F67E#;
   Reverse_Checker_Board                   :
      constant Unicode_Char := 16#1F67F#;
end Unicode.Names.Ornamental_Dingbats;
