--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Bamum is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Bamum_Letter_A                          : constant Unicode_Char := 16#A6A0#;
   Bamum_Letter_Ka                         : constant Unicode_Char := 16#A6A1#;
   Bamum_Letter_U                          : constant Unicode_Char := 16#A6A2#;
   Bamum_Letter_Ku                         : constant Unicode_Char := 16#A6A3#;
   Bamum_Letter_Ee                         : constant Unicode_Char := 16#A6A4#;
   Bamum_Letter_Ree                        : constant Unicode_Char := 16#A6A5#;
   Bamum_Letter_Tae                        : constant Unicode_Char := 16#A6A6#;
   Bamum_Letter_O                          : constant Unicode_Char := 16#A6A7#;
   Bamum_Letter_Nyi                        : constant Unicode_Char := 16#A6A8#;
   Bamum_Letter_I                          : constant Unicode_Char := 16#A6A9#;
   Bamum_Letter_La                         : constant Unicode_Char := 16#A6AA#;
   Bamum_Letter_Pa                         : constant Unicode_Char := 16#A6AB#;
   Bamum_Letter_Rii                        : constant Unicode_Char := 16#A6AC#;
   Bamum_Letter_Riee                       : constant Unicode_Char := 16#A6AD#;
   Bamum_Letter_Leeee                      : constant Unicode_Char := 16#A6AE#;
   Bamum_Letter_Meeee                      : constant Unicode_Char := 16#A6AF#;
   Bamum_Letter_Taa                        : constant Unicode_Char := 16#A6B0#;
   Bamum_Letter_Ndaa                       : constant Unicode_Char := 16#A6B1#;
   Bamum_Letter_Njaem                      : constant Unicode_Char := 16#A6B2#;
   Bamum_Letter_M                          : constant Unicode_Char := 16#A6B3#;
   Bamum_Letter_Suu                        : constant Unicode_Char := 16#A6B4#;
   Bamum_Letter_Mu                         : constant Unicode_Char := 16#A6B5#;
   Bamum_Letter_Shii                       : constant Unicode_Char := 16#A6B6#;
   Bamum_Letter_Si                         : constant Unicode_Char := 16#A6B7#;
   Bamum_Letter_Sheux                      : constant Unicode_Char := 16#A6B8#;
   Bamum_Letter_Seux                       : constant Unicode_Char := 16#A6B9#;
   Bamum_Letter_Kyee                       : constant Unicode_Char := 16#A6BA#;
   Bamum_Letter_Ket                        : constant Unicode_Char := 16#A6BB#;
   Bamum_Letter_Nuae                       : constant Unicode_Char := 16#A6BC#;
   Bamum_Letter_Nu                         : constant Unicode_Char := 16#A6BD#;
   Bamum_Letter_Njuae                      : constant Unicode_Char := 16#A6BE#;
   Bamum_Letter_Yoq                        : constant Unicode_Char := 16#A6BF#;
   Bamum_Letter_Shu                        : constant Unicode_Char := 16#A6C0#;
   Bamum_Letter_Yuq                        : constant Unicode_Char := 16#A6C1#;
   Bamum_Letter_Ya                         : constant Unicode_Char := 16#A6C2#;
   Bamum_Letter_Nsha                       : constant Unicode_Char := 16#A6C3#;
   Bamum_Letter_Keux                       : constant Unicode_Char := 16#A6C4#;
   Bamum_Letter_Peux                       : constant Unicode_Char := 16#A6C5#;
   Bamum_Letter_Njee                       : constant Unicode_Char := 16#A6C6#;
   Bamum_Letter_Ntee                       : constant Unicode_Char := 16#A6C7#;
   Bamum_Letter_Pue                        : constant Unicode_Char := 16#A6C8#;
   Bamum_Letter_Wue                        : constant Unicode_Char := 16#A6C9#;
   Bamum_Letter_Pee                        : constant Unicode_Char := 16#A6CA#;
   Bamum_Letter_Fee                        : constant Unicode_Char := 16#A6CB#;
   Bamum_Letter_Ru                         : constant Unicode_Char := 16#A6CC#;
   Bamum_Letter_Lu                         : constant Unicode_Char := 16#A6CD#;
   Bamum_Letter_Mi                         : constant Unicode_Char := 16#A6CE#;
   Bamum_Letter_Ni                         : constant Unicode_Char := 16#A6CF#;
   Bamum_Letter_Reux                       : constant Unicode_Char := 16#A6D0#;
   Bamum_Letter_Rae                        : constant Unicode_Char := 16#A6D1#;
   Bamum_Letter_Ken                        : constant Unicode_Char := 16#A6D2#;
   Bamum_Letter_Ngkwaen                    : constant Unicode_Char := 16#A6D3#;
   Bamum_Letter_Ngga                       : constant Unicode_Char := 16#A6D4#;
   Bamum_Letter_Nga                        : constant Unicode_Char := 16#A6D5#;
   Bamum_Letter_Sho                        : constant Unicode_Char := 16#A6D6#;
   Bamum_Letter_Puae                       : constant Unicode_Char := 16#A6D7#;
   Bamum_Letter_Fu                         : constant Unicode_Char := 16#A6D8#;
   Bamum_Letter_Fom                        : constant Unicode_Char := 16#A6D9#;
   Bamum_Letter_Wa                         : constant Unicode_Char := 16#A6DA#;
   Bamum_Letter_Na                         : constant Unicode_Char := 16#A6DB#;
   Bamum_Letter_Li                         : constant Unicode_Char := 16#A6DC#;
   Bamum_Letter_Pi                         : constant Unicode_Char := 16#A6DD#;
   Bamum_Letter_Loq                        : constant Unicode_Char := 16#A6DE#;
   Bamum_Letter_Ko                         : constant Unicode_Char := 16#A6DF#;
   Bamum_Letter_Mben                       : constant Unicode_Char := 16#A6E0#;
   Bamum_Letter_Ren                        : constant Unicode_Char := 16#A6E1#;
   Bamum_Letter_Men                        : constant Unicode_Char := 16#A6E2#;
   Bamum_Letter_Ma                         : constant Unicode_Char := 16#A6E3#;
   Bamum_Letter_Ti                         : constant Unicode_Char := 16#A6E4#;
   Bamum_Letter_Ki                         : constant Unicode_Char := 16#A6E5#;
   Bamum_Letter_Mo                         : constant Unicode_Char := 16#A6E6#;
   Bamum_Letter_Mbaa                       : constant Unicode_Char := 16#A6E7#;
   Bamum_Letter_Tet                        : constant Unicode_Char := 16#A6E8#;
   Bamum_Letter_Kpa                        : constant Unicode_Char := 16#A6E9#;
   Bamum_Letter_Ten                        : constant Unicode_Char := 16#A6EA#;
   Bamum_Letter_Ntuu                       : constant Unicode_Char := 16#A6EB#;
   Bamum_Letter_Samba                      : constant Unicode_Char := 16#A6EC#;
   Bamum_Letter_Faamae                     : constant Unicode_Char := 16#A6ED#;
   Bamum_Letter_Kovuu                      : constant Unicode_Char := 16#A6EE#;
   Bamum_Letter_Koghom                     : constant Unicode_Char := 16#A6EF#;
   Bamum_Combining_Mark_Koqndon            : constant Unicode_Char := 16#A6F0#;
   Bamum_Combining_Mark_Tukwentis          : constant Unicode_Char := 16#A6F1#;
   Bamum_Njaemli                           : constant Unicode_Char := 16#A6F2#;
   Bamum_Full_Stop                         : constant Unicode_Char := 16#A6F3#;
   Bamum_Colon                             : constant Unicode_Char := 16#A6F4#;
   Bamum_Comma                             : constant Unicode_Char := 16#A6F5#;
   Bamum_Semicolon                         : constant Unicode_Char := 16#A6F6#;
   Bamum_Question_Mark                     : constant Unicode_Char := 16#A6F7#;
end Unicode.Names.Bamum;
