--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Arabic_Present_FormsB is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Arabic_Fathatan_Isolated_Form           : constant Unicode_Char := 16#FE70#;
   Arabic_Tatweel_With_Fathatan_Above      : constant Unicode_Char := 16#FE71#;
   Arabic_Dammatan_Isolated_Form           : constant Unicode_Char := 16#FE72#;
   Arabic_Tail_Fragment                    : constant Unicode_Char := 16#FE73#;
   Arabic_Kasratan_Isolated_Form           : constant Unicode_Char := 16#FE74#;
   Arabic_Fatha_Isolated_Form              : constant Unicode_Char := 16#FE76#;
   Arabic_Fatha_Medial_Form                : constant Unicode_Char := 16#FE77#;
   Arabic_Damma_Isolated_Form              : constant Unicode_Char := 16#FE78#;
   Arabic_Damma_Medial_Form                : constant Unicode_Char := 16#FE79#;
   Arabic_Kasra_Isolated_Form              : constant Unicode_Char := 16#FE7A#;
   Arabic_Kasra_Medial_Form                : constant Unicode_Char := 16#FE7B#;
   Arabic_Shadda_Isolated_Form             : constant Unicode_Char := 16#FE7C#;
   Arabic_Shadda_Medial_Form               : constant Unicode_Char := 16#FE7D#;
   Arabic_Sukun_Isolated_Form              : constant Unicode_Char := 16#FE7E#;
   Arabic_Sukun_Medial_Form                : constant Unicode_Char := 16#FE7F#;
   Arabic_Letter_Hamza_Isolated_Form       : constant Unicode_Char := 16#FE80#;
   Arabic_Letter_Alef_With_Madda_Above_Isolated_Form :
      constant Unicode_Char := 16#FE81#;
   Arabic_Letter_Alef_With_Madda_Above_Final_Form :
      constant Unicode_Char := 16#FE82#;
   Arabic_Letter_Alef_With_Hamza_Above_Isolated_Form :
      constant Unicode_Char := 16#FE83#;
   Arabic_Letter_Alef_With_Hamza_Above_Final_Form :
      constant Unicode_Char := 16#FE84#;
   Arabic_Letter_Waw_With_Hamza_Above_Isolated_Form :
      constant Unicode_Char := 16#FE85#;
   Arabic_Letter_Waw_With_Hamza_Above_Final_Form :
      constant Unicode_Char := 16#FE86#;
   Arabic_Letter_Alef_With_Hamza_Below_Isolated_Form :
      constant Unicode_Char := 16#FE87#;
   Arabic_Letter_Alef_With_Hamza_Below_Final_Form :
      constant Unicode_Char := 16#FE88#;
   Arabic_Letter_Yeh_With_Hamza_Above_Isolated_Form :
      constant Unicode_Char := 16#FE89#;
   Arabic_Letter_Yeh_With_Hamza_Above_Final_Form :
      constant Unicode_Char := 16#FE8A#;
   Arabic_Letter_Yeh_With_Hamza_Above_Initial_Form :
      constant Unicode_Char := 16#FE8B#;
   Arabic_Letter_Yeh_With_Hamza_Above_Medial_Form :
      constant Unicode_Char := 16#FE8C#;
   Arabic_Letter_Alef_Isolated_Form        : constant Unicode_Char := 16#FE8D#;
   Arabic_Letter_Alef_Final_Form           : constant Unicode_Char := 16#FE8E#;
   Arabic_Letter_Beh_Isolated_Form         : constant Unicode_Char := 16#FE8F#;
   Arabic_Letter_Beh_Final_Form            : constant Unicode_Char := 16#FE90#;
   Arabic_Letter_Beh_Initial_Form          : constant Unicode_Char := 16#FE91#;
   Arabic_Letter_Beh_Medial_Form           : constant Unicode_Char := 16#FE92#;
   Arabic_Letter_Teh_Marbuta_Isolated_Form : constant Unicode_Char := 16#FE93#;
   Arabic_Letter_Teh_Marbuta_Final_Form    : constant Unicode_Char := 16#FE94#;
   Arabic_Letter_Teh_Isolated_Form         : constant Unicode_Char := 16#FE95#;
   Arabic_Letter_Teh_Final_Form            : constant Unicode_Char := 16#FE96#;
   Arabic_Letter_Teh_Initial_Form          : constant Unicode_Char := 16#FE97#;
   Arabic_Letter_Teh_Medial_Form           : constant Unicode_Char := 16#FE98#;
   Arabic_Letter_Theh_Isolated_Form        : constant Unicode_Char := 16#FE99#;
   Arabic_Letter_Theh_Final_Form           : constant Unicode_Char := 16#FE9A#;
   Arabic_Letter_Theh_Initial_Form         : constant Unicode_Char := 16#FE9B#;
   Arabic_Letter_Theh_Medial_Form          : constant Unicode_Char := 16#FE9C#;
   Arabic_Letter_Jeem_Isolated_Form        : constant Unicode_Char := 16#FE9D#;
   Arabic_Letter_Jeem_Final_Form           : constant Unicode_Char := 16#FE9E#;
   Arabic_Letter_Jeem_Initial_Form         : constant Unicode_Char := 16#FE9F#;
   Arabic_Letter_Jeem_Medial_Form          : constant Unicode_Char := 16#FEA0#;
   Arabic_Letter_Hah_Isolated_Form         : constant Unicode_Char := 16#FEA1#;
   Arabic_Letter_Hah_Final_Form            : constant Unicode_Char := 16#FEA2#;
   Arabic_Letter_Hah_Initial_Form          : constant Unicode_Char := 16#FEA3#;
   Arabic_Letter_Hah_Medial_Form           : constant Unicode_Char := 16#FEA4#;
   Arabic_Letter_Khah_Isolated_Form        : constant Unicode_Char := 16#FEA5#;
   Arabic_Letter_Khah_Final_Form           : constant Unicode_Char := 16#FEA6#;
   Arabic_Letter_Khah_Initial_Form         : constant Unicode_Char := 16#FEA7#;
   Arabic_Letter_Khah_Medial_Form          : constant Unicode_Char := 16#FEA8#;
   Arabic_Letter_Dal_Isolated_Form         : constant Unicode_Char := 16#FEA9#;
   Arabic_Letter_Dal_Final_Form            : constant Unicode_Char := 16#FEAA#;
   Arabic_Letter_Thal_Isolated_Form        : constant Unicode_Char := 16#FEAB#;
   Arabic_Letter_Thal_Final_Form           : constant Unicode_Char := 16#FEAC#;
   Arabic_Letter_Reh_Isolated_Form         : constant Unicode_Char := 16#FEAD#;
   Arabic_Letter_Reh_Final_Form            : constant Unicode_Char := 16#FEAE#;
   Arabic_Letter_Zain_Isolated_Form        : constant Unicode_Char := 16#FEAF#;
   Arabic_Letter_Zain_Final_Form           : constant Unicode_Char := 16#FEB0#;
   Arabic_Letter_Seen_Isolated_Form        : constant Unicode_Char := 16#FEB1#;
   Arabic_Letter_Seen_Final_Form           : constant Unicode_Char := 16#FEB2#;
   Arabic_Letter_Seen_Initial_Form         : constant Unicode_Char := 16#FEB3#;
   Arabic_Letter_Seen_Medial_Form          : constant Unicode_Char := 16#FEB4#;
   Arabic_Letter_Sheen_Isolated_Form       : constant Unicode_Char := 16#FEB5#;
   Arabic_Letter_Sheen_Final_Form          : constant Unicode_Char := 16#FEB6#;
   Arabic_Letter_Sheen_Initial_Form        : constant Unicode_Char := 16#FEB7#;
   Arabic_Letter_Sheen_Medial_Form         : constant Unicode_Char := 16#FEB8#;
   Arabic_Letter_Sad_Isolated_Form         : constant Unicode_Char := 16#FEB9#;
   Arabic_Letter_Sad_Final_Form            : constant Unicode_Char := 16#FEBA#;
   Arabic_Letter_Sad_Initial_Form          : constant Unicode_Char := 16#FEBB#;
   Arabic_Letter_Sad_Medial_Form           : constant Unicode_Char := 16#FEBC#;
   Arabic_Letter_Dad_Isolated_Form         : constant Unicode_Char := 16#FEBD#;
   Arabic_Letter_Dad_Final_Form            : constant Unicode_Char := 16#FEBE#;
   Arabic_Letter_Dad_Initial_Form          : constant Unicode_Char := 16#FEBF#;
   Arabic_Letter_Dad_Medial_Form           : constant Unicode_Char := 16#FEC0#;
   Arabic_Letter_Tah_Isolated_Form         : constant Unicode_Char := 16#FEC1#;
   Arabic_Letter_Tah_Final_Form            : constant Unicode_Char := 16#FEC2#;
   Arabic_Letter_Tah_Initial_Form          : constant Unicode_Char := 16#FEC3#;
   Arabic_Letter_Tah_Medial_Form           : constant Unicode_Char := 16#FEC4#;
   Arabic_Letter_Zah_Isolated_Form         : constant Unicode_Char := 16#FEC5#;
   Arabic_Letter_Zah_Final_Form            : constant Unicode_Char := 16#FEC6#;
   Arabic_Letter_Zah_Initial_Form          : constant Unicode_Char := 16#FEC7#;
   Arabic_Letter_Zah_Medial_Form           : constant Unicode_Char := 16#FEC8#;
   Arabic_Letter_Ain_Isolated_Form         : constant Unicode_Char := 16#FEC9#;
   Arabic_Letter_Ain_Final_Form            : constant Unicode_Char := 16#FECA#;
   Arabic_Letter_Ain_Initial_Form          : constant Unicode_Char := 16#FECB#;
   Arabic_Letter_Ain_Medial_Form           : constant Unicode_Char := 16#FECC#;
   Arabic_Letter_Ghain_Isolated_Form       : constant Unicode_Char := 16#FECD#;
   Arabic_Letter_Ghain_Final_Form          : constant Unicode_Char := 16#FECE#;
   Arabic_Letter_Ghain_Initial_Form        : constant Unicode_Char := 16#FECF#;
   Arabic_Letter_Ghain_Medial_Form         : constant Unicode_Char := 16#FED0#;
   Arabic_Letter_Feh_Isolated_Form         : constant Unicode_Char := 16#FED1#;
   Arabic_Letter_Feh_Final_Form            : constant Unicode_Char := 16#FED2#;
   Arabic_Letter_Feh_Initial_Form          : constant Unicode_Char := 16#FED3#;
   Arabic_Letter_Feh_Medial_Form           : constant Unicode_Char := 16#FED4#;
   Arabic_Letter_Qaf_Isolated_Form         : constant Unicode_Char := 16#FED5#;
   Arabic_Letter_Qaf_Final_Form            : constant Unicode_Char := 16#FED6#;
   Arabic_Letter_Qaf_Initial_Form          : constant Unicode_Char := 16#FED7#;
   Arabic_Letter_Qaf_Medial_Form           : constant Unicode_Char := 16#FED8#;
   Arabic_Letter_Kaf_Isolated_Form         : constant Unicode_Char := 16#FED9#;
   Arabic_Letter_Kaf_Final_Form            : constant Unicode_Char := 16#FEDA#;
   Arabic_Letter_Kaf_Initial_Form          : constant Unicode_Char := 16#FEDB#;
   Arabic_Letter_Kaf_Medial_Form           : constant Unicode_Char := 16#FEDC#;
   Arabic_Letter_Lam_Isolated_Form         : constant Unicode_Char := 16#FEDD#;
   Arabic_Letter_Lam_Final_Form            : constant Unicode_Char := 16#FEDE#;
   Arabic_Letter_Lam_Initial_Form          : constant Unicode_Char := 16#FEDF#;
   Arabic_Letter_Lam_Medial_Form           : constant Unicode_Char := 16#FEE0#;
   Arabic_Letter_Meem_Isolated_Form        : constant Unicode_Char := 16#FEE1#;
   Arabic_Letter_Meem_Final_Form           : constant Unicode_Char := 16#FEE2#;
   Arabic_Letter_Meem_Initial_Form         : constant Unicode_Char := 16#FEE3#;
   Arabic_Letter_Meem_Medial_Form          : constant Unicode_Char := 16#FEE4#;
   Arabic_Letter_Noon_Isolated_Form        : constant Unicode_Char := 16#FEE5#;
   Arabic_Letter_Noon_Final_Form           : constant Unicode_Char := 16#FEE6#;
   Arabic_Letter_Noon_Initial_Form         : constant Unicode_Char := 16#FEE7#;
   Arabic_Letter_Noon_Medial_Form          : constant Unicode_Char := 16#FEE8#;
   Arabic_Letter_Heh_Isolated_Form         : constant Unicode_Char := 16#FEE9#;
   Arabic_Letter_Heh_Final_Form            : constant Unicode_Char := 16#FEEA#;
   Arabic_Letter_Heh_Initial_Form          : constant Unicode_Char := 16#FEEB#;
   Arabic_Letter_Heh_Medial_Form           : constant Unicode_Char := 16#FEEC#;
   Arabic_Letter_Waw_Isolated_Form         : constant Unicode_Char := 16#FEED#;
   Arabic_Letter_Waw_Final_Form            : constant Unicode_Char := 16#FEEE#;
   Arabic_Letter_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FEEF#;
   Arabic_Letter_Alef_Maksura_Final_Form   : constant Unicode_Char := 16#FEF0#;
   Arabic_Letter_Yeh_Isolated_Form         : constant Unicode_Char := 16#FEF1#;
   Arabic_Letter_Yeh_Final_Form            : constant Unicode_Char := 16#FEF2#;
   Arabic_Letter_Yeh_Initial_Form          : constant Unicode_Char := 16#FEF3#;
   Arabic_Letter_Yeh_Medial_Form           : constant Unicode_Char := 16#FEF4#;
   Arabic_Ligature_Lam_With_Alef_With_Madda_Above_Isolated_Form :
      constant Unicode_Char := 16#FEF5#;
   Arabic_Ligature_Lam_With_Alef_With_Madda_Above_Final_Form :
      constant Unicode_Char := 16#FEF6#;
   Arabic_Ligature_Lam_With_Alef_With_Hamza_Above_Isolated_Form :
      constant Unicode_Char := 16#FEF7#;
   Arabic_Ligature_Lam_With_Alef_With_Hamza_Above_Final_Form :
      constant Unicode_Char := 16#FEF8#;
   Arabic_Ligature_Lam_With_Alef_With_Hamza_Below_Isolated_Form :
      constant Unicode_Char := 16#FEF9#;
   Arabic_Ligature_Lam_With_Alef_With_Hamza_Below_Final_Form :
      constant Unicode_Char := 16#FEFA#;
   Arabic_Ligature_Lam_With_Alef_Isolated_Form :
      constant Unicode_Char := 16#FEFB#;
   Arabic_Ligature_Lam_With_Alef_Final_Form :
      constant Unicode_Char := 16#FEFC#;
   Zero_Width_No_Break_Space               : constant Unicode_Char := 16#FEFF#;
   Byte_Order_Mark                         :
      Unicode_Char renames Zero_Width_No_Break_Space;
   Bom                                     :
      Unicode_Char renames Zero_Width_No_Break_Space;
   Zwnbsp                                  :
      Unicode_Char renames Zero_Width_No_Break_Space;
end Unicode.Names.Arabic_Present_FormsB;
