--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Tai_Xuan_Jing_Symbols is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Monogram_For_Earth                      :
      constant Unicode_Char := 16#1D300#;
   Digram_For_Heavenly_Earth               :
      constant Unicode_Char := 16#1D301#;
   Digram_For_Human_Earth                  :
      constant Unicode_Char := 16#1D302#;
   Digram_For_Earthly_Heaven               :
      constant Unicode_Char := 16#1D303#;
   Digram_For_Earthly_Human                :
      constant Unicode_Char := 16#1D304#;
   Digram_For_Earth                        :
      constant Unicode_Char := 16#1D305#;
   Tetragram_For_Centre                    :
      constant Unicode_Char := 16#1D306#;
   Tetragram_For_Full_Circle               :
      constant Unicode_Char := 16#1D307#;
   Tetragram_For_Mired                     :
      constant Unicode_Char := 16#1D308#;
   Tetragram_For_Barrier                   :
      constant Unicode_Char := 16#1D309#;
   Tetragram_For_Keeping_Small             :
      constant Unicode_Char := 16#1D30A#;
   Tetragram_For_Contrariety               :
      constant Unicode_Char := 16#1D30B#;
   Tetragram_For_Ascent                    :
      constant Unicode_Char := 16#1D30C#;
   Tetragram_For_Opposition                :
      constant Unicode_Char := 16#1D30D#;
   Tetragram_For_Branching_Out             :
      constant Unicode_Char := 16#1D30E#;
   Tetragram_For_Defectiveness_Or_Distortion :
      constant Unicode_Char := 16#1D30F#;
   Tetragram_For_Divergence                :
      constant Unicode_Char := 16#1D310#;
   Tetragram_For_Youthfulness              :
      constant Unicode_Char := 16#1D311#;
   Tetragram_For_Increase                  :
      constant Unicode_Char := 16#1D312#;
   Tetragram_For_Penetration               :
      constant Unicode_Char := 16#1D313#;
   Tetragram_For_Reach                     :
      constant Unicode_Char := 16#1D314#;
   Tetragram_For_Contact                   :
      constant Unicode_Char := 16#1D315#;
   Tetragram_For_Holding_Back              :
      constant Unicode_Char := 16#1D316#;
   Tetragram_For_Waiting                   :
      constant Unicode_Char := 16#1D317#;
   Tetragram_For_Following                 :
      constant Unicode_Char := 16#1D318#;
   Tetragram_For_Advance                   :
      constant Unicode_Char := 16#1D319#;
   Tetragram_For_Release                   :
      constant Unicode_Char := 16#1D31A#;
   Tetragram_For_Resistance                :
      constant Unicode_Char := 16#1D31B#;
   Tetragram_For_Ease                      :
      constant Unicode_Char := 16#1D31C#;
   Tetragram_For_Joy                       :
      constant Unicode_Char := 16#1D31D#;
   Tetragram_For_Contention                :
      constant Unicode_Char := 16#1D31E#;
   Tetragram_For_Endeavour                 :
      constant Unicode_Char := 16#1D31F#;
   Tetragram_For_Duties                    :
      constant Unicode_Char := 16#1D320#;
   Tetragram_For_Change                    :
      constant Unicode_Char := 16#1D321#;
   Tetragram_For_Decisiveness              :
      constant Unicode_Char := 16#1D322#;
   Tetragram_For_Bold_Resolution           :
      constant Unicode_Char := 16#1D323#;
   Tetragram_For_Packing                   :
      constant Unicode_Char := 16#1D324#;
   Tetragram_For_Legion                    :
      constant Unicode_Char := 16#1D325#;
   Tetragram_For_Closeness                 :
      constant Unicode_Char := 16#1D326#;
   Tetragram_For_Kinship                   :
      constant Unicode_Char := 16#1D327#;
   Tetragram_For_Gathering                 :
      constant Unicode_Char := 16#1D328#;
   Tetragram_For_Strength                  :
      constant Unicode_Char := 16#1D329#;
   Tetragram_For_Purity                    :
      constant Unicode_Char := 16#1D32A#;
   Tetragram_For_Fullness                  :
      constant Unicode_Char := 16#1D32B#;
   Tetragram_For_Residence                 :
      constant Unicode_Char := 16#1D32C#;
   Tetragram_For_Law_Or_Model              :
      constant Unicode_Char := 16#1D32D#;
   Tetragram_For_Response                  :
      constant Unicode_Char := 16#1D32E#;
   Tetragram_For_Going_To_Meet             :
      constant Unicode_Char := 16#1D32F#;
   Tetragram_For_Encounters                :
      constant Unicode_Char := 16#1D330#;
   Tetragram_For_Stove                     :
      constant Unicode_Char := 16#1D331#;
   Tetragram_For_Greatness                 :
      constant Unicode_Char := 16#1D332#;
   Tetragram_For_Enlargement               :
      constant Unicode_Char := 16#1D333#;
   Tetragram_For_Pattern                   :
      constant Unicode_Char := 16#1D334#;
   Tetragram_For_Ritual                    :
      constant Unicode_Char := 16#1D335#;
   Tetragram_For_Flight                    :
      constant Unicode_Char := 16#1D336#;
   Tetragram_For_Vastness_Or_Wasting       :
      constant Unicode_Char := 16#1D337#;
   Tetragram_For_Constancy                 :
      constant Unicode_Char := 16#1D338#;
   Tetragram_For_Measure                   :
      constant Unicode_Char := 16#1D339#;
   Tetragram_For_Eternity                  :
      constant Unicode_Char := 16#1D33A#;
   Tetragram_For_Unity                     :
      constant Unicode_Char := 16#1D33B#;
   Tetragram_For_Diminishment              :
      constant Unicode_Char := 16#1D33C#;
   Tetragram_For_Closed_Mouth              :
      constant Unicode_Char := 16#1D33D#;
   Tetragram_For_Guardedness               :
      constant Unicode_Char := 16#1D33E#;
   Tetragram_For_Gathering_In              :
      constant Unicode_Char := 16#1D33F#;
   Tetragram_For_Massing                   :
      constant Unicode_Char := 16#1D340#;
   Tetragram_For_Accumulation              :
      constant Unicode_Char := 16#1D341#;
   Tetragram_For_Embellishment             :
      constant Unicode_Char := 16#1D342#;
   Tetragram_For_Doubt                     :
      constant Unicode_Char := 16#1D343#;
   Tetragram_For_Watch                     :
      constant Unicode_Char := 16#1D344#;
   Tetragram_For_Sinking                   :
      constant Unicode_Char := 16#1D345#;
   Tetragram_For_Inner                     :
      constant Unicode_Char := 16#1D346#;
   Tetragram_For_Departure                 :
      constant Unicode_Char := 16#1D347#;
   Tetragram_For_Darkening                 :
      constant Unicode_Char := 16#1D348#;
   Tetragram_For_Dimming                   :
      constant Unicode_Char := 16#1D349#;
   Tetragram_For_Exhaustion                :
      constant Unicode_Char := 16#1D34A#;
   Tetragram_For_Severance                 :
      constant Unicode_Char := 16#1D34B#;
   Tetragram_For_Stoppage                  :
      constant Unicode_Char := 16#1D34C#;
   Tetragram_For_Hardness                  :
      constant Unicode_Char := 16#1D34D#;
   Tetragram_For_Completion                :
      constant Unicode_Char := 16#1D34E#;
   Tetragram_For_Closure                   :
      constant Unicode_Char := 16#1D34F#;
   Tetragram_For_Failure                   :
      constant Unicode_Char := 16#1D350#;
   Tetragram_For_Aggravation               :
      constant Unicode_Char := 16#1D351#;
   Tetragram_For_Compliance                :
      constant Unicode_Char := 16#1D352#;
   Tetragram_For_On_The_Verge              :
      constant Unicode_Char := 16#1D353#;
   Tetragram_For_Difficulties              :
      constant Unicode_Char := 16#1D354#;
   Tetragram_For_Labouring                 :
      constant Unicode_Char := 16#1D355#;
   Tetragram_For_Fostering                 :
      constant Unicode_Char := 16#1D356#;
end Unicode.Names.Tai_Xuan_Jing_Symbols;
