--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Carian is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Carian_Letter_A                         :
      constant Unicode_Char := 16#102A0#;
   Carian_Letter_P2                        :
      constant Unicode_Char := 16#102A1#;
   Carian_Letter_D                         :
      constant Unicode_Char := 16#102A2#;
   Carian_Letter_L                         :
      constant Unicode_Char := 16#102A3#;
   Carian_Letter_Uuu                       :
      constant Unicode_Char := 16#102A4#;
   Carian_Letter_R                         :
      constant Unicode_Char := 16#102A5#;
   Carian_Letter_Ld                        :
      constant Unicode_Char := 16#102A6#;
   Carian_Letter_A2                        :
      constant Unicode_Char := 16#102A7#;
   Carian_Letter_Q                         :
      constant Unicode_Char := 16#102A8#;
   Carian_Letter_B                         :
      constant Unicode_Char := 16#102A9#;
   Carian_Letter_M                         :
      constant Unicode_Char := 16#102AA#;
   Carian_Letter_O                         :
      constant Unicode_Char := 16#102AB#;
   Carian_Letter_D2                        :
      constant Unicode_Char := 16#102AC#;
   Carian_Letter_T                         :
      constant Unicode_Char := 16#102AD#;
   Carian_Letter_Sh                        :
      constant Unicode_Char := 16#102AE#;
   Carian_Letter_Sh2                       :
      constant Unicode_Char := 16#102AF#;
   Carian_Letter_S                         :
      constant Unicode_Char := 16#102B0#;
   Carian_Letter_C_18                      :
      constant Unicode_Char := 16#102B1#;
   Carian_Letter_U                         :
      constant Unicode_Char := 16#102B2#;
   Carian_Letter_Nn                        :
      constant Unicode_Char := 16#102B3#;
   Carian_Letter_X                         :
      constant Unicode_Char := 16#102B4#;
   Carian_Letter_N                         :
      constant Unicode_Char := 16#102B5#;
   Carian_Letter_Tt2                       :
      constant Unicode_Char := 16#102B6#;
   Carian_Letter_P                         :
      constant Unicode_Char := 16#102B7#;
   Carian_Letter_Ss                        :
      constant Unicode_Char := 16#102B8#;
   Carian_Letter_I                         :
      constant Unicode_Char := 16#102B9#;
   Carian_Letter_E                         :
      constant Unicode_Char := 16#102BA#;
   Carian_Letter_Uuuu                      :
      constant Unicode_Char := 16#102BB#;
   Carian_Letter_K                         :
      constant Unicode_Char := 16#102BC#;
   Carian_Letter_K2                        :
      constant Unicode_Char := 16#102BD#;
   Carian_Letter_Nd                        :
      constant Unicode_Char := 16#102BE#;
   Carian_Letter_Uu                        :
      constant Unicode_Char := 16#102BF#;
   Carian_Letter_G                         :
      constant Unicode_Char := 16#102C0#;
   Carian_Letter_G2                        :
      constant Unicode_Char := 16#102C1#;
   Carian_Letter_St                        :
      constant Unicode_Char := 16#102C2#;
   Carian_Letter_St2                       :
      constant Unicode_Char := 16#102C3#;
   Carian_Letter_Ng                        :
      constant Unicode_Char := 16#102C4#;
   Carian_Letter_Ii                        :
      constant Unicode_Char := 16#102C5#;
   Carian_Letter_C_39                      :
      constant Unicode_Char := 16#102C6#;
   Carian_Letter_Tt                        :
      constant Unicode_Char := 16#102C7#;
   Carian_Letter_Uuu2                      :
      constant Unicode_Char := 16#102C8#;
   Carian_Letter_Rr                        :
      constant Unicode_Char := 16#102C9#;
   Carian_Letter_Mb                        :
      constant Unicode_Char := 16#102CA#;
   Carian_Letter_Mb2                       :
      constant Unicode_Char := 16#102CB#;
   Carian_Letter_Mb3                       :
      constant Unicode_Char := 16#102CC#;
   Carian_Letter_Mb4                       :
      constant Unicode_Char := 16#102CD#;
   Carian_Letter_Ld2                       :
      constant Unicode_Char := 16#102CE#;
   Carian_Letter_E2                        :
      constant Unicode_Char := 16#102CF#;
   Carian_Letter_Uuu3                      :
      constant Unicode_Char := 16#102D0#;
end Unicode.Names.Carian;
