--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Ahom is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Ahom_Letter_Ka                          :
      constant Unicode_Char := 16#11700#;
   Ahom_Letter_Kha                         :
      constant Unicode_Char := 16#11701#;
   Ahom_Letter_Nga                         :
      constant Unicode_Char := 16#11702#;
   Ahom_Letter_Na                          :
      constant Unicode_Char := 16#11703#;
   Ahom_Letter_Ta                          :
      constant Unicode_Char := 16#11704#;
   Ahom_Letter_Alternate_Ta                :
      constant Unicode_Char := 16#11705#;
   Ahom_Letter_Pa                          :
      constant Unicode_Char := 16#11706#;
   Ahom_Letter_Pha                         :
      constant Unicode_Char := 16#11707#;
   Ahom_Letter_Ba                          :
      constant Unicode_Char := 16#11708#;
   Ahom_Letter_Ma                          :
      constant Unicode_Char := 16#11709#;
   Ahom_Letter_Ja                          :
      constant Unicode_Char := 16#1170A#;
   Ahom_Letter_Cha                         :
      constant Unicode_Char := 16#1170B#;
   Ahom_Letter_Tha                         :
      constant Unicode_Char := 16#1170C#;
   Ahom_Letter_Ra                          :
      constant Unicode_Char := 16#1170D#;
   Ahom_Letter_La                          :
      constant Unicode_Char := 16#1170E#;
   Ahom_Letter_Sa                          :
      constant Unicode_Char := 16#1170F#;
   Ahom_Letter_Nya                         :
      constant Unicode_Char := 16#11710#;
   Ahom_Letter_Ha                          :
      constant Unicode_Char := 16#11711#;
   Ahom_Letter_A                           :
      constant Unicode_Char := 16#11712#;
   Ahom_Letter_Da                          :
      constant Unicode_Char := 16#11713#;
   Ahom_Letter_Dha                         :
      constant Unicode_Char := 16#11714#;
   Ahom_Letter_Ga                          :
      constant Unicode_Char := 16#11715#;
   Ahom_Letter_Alternate_Ga                :
      constant Unicode_Char := 16#11716#;
   Ahom_Letter_Gha                         :
      constant Unicode_Char := 16#11717#;
   Ahom_Letter_Bha                         :
      constant Unicode_Char := 16#11718#;
   Ahom_Letter_Jha                         :
      constant Unicode_Char := 16#11719#;
   Ahom_Consonant_Sign_Medial_La           :
      constant Unicode_Char := 16#1171D#;
   Ahom_Consonant_Sign_Medial_Ra           :
      constant Unicode_Char := 16#1171E#;
   Ahom_Consonant_Sign_Medial_Ligating_Ra  :
      constant Unicode_Char := 16#1171F#;
   Ahom_Vowel_Sign_A                       :
      constant Unicode_Char := 16#11720#;
   Ahom_Vowel_Sign_Aa                      :
      constant Unicode_Char := 16#11721#;
   Ahom_Vowel_Sign_I                       :
      constant Unicode_Char := 16#11722#;
   Ahom_Vowel_Sign_Ii                      :
      constant Unicode_Char := 16#11723#;
   Ahom_Vowel_Sign_U                       :
      constant Unicode_Char := 16#11724#;
   Ahom_Vowel_Sign_Uu                      :
      constant Unicode_Char := 16#11725#;
   Ahom_Vowel_Sign_E                       :
      constant Unicode_Char := 16#11726#;
   Ahom_Vowel_Sign_Aw                      :
      constant Unicode_Char := 16#11727#;
   Ahom_Vowel_Sign_O                       :
      constant Unicode_Char := 16#11728#;
   Ahom_Vowel_Sign_Ai                      :
      constant Unicode_Char := 16#11729#;
   Ahom_Vowel_Sign_Am                      :
      constant Unicode_Char := 16#1172A#;
   Ahom_Sign_Killer                        :
      constant Unicode_Char := 16#1172B#;
   Ahom_Digit_Zero                         :
      constant Unicode_Char := 16#11730#;
   Ahom_Digit_One                          :
      constant Unicode_Char := 16#11731#;
   Ahom_Digit_Two                          :
      constant Unicode_Char := 16#11732#;
   Ahom_Digit_Three                        :
      constant Unicode_Char := 16#11733#;
   Ahom_Digit_Four                         :
      constant Unicode_Char := 16#11734#;
   Ahom_Digit_Five                         :
      constant Unicode_Char := 16#11735#;
   Ahom_Digit_Six                          :
      constant Unicode_Char := 16#11736#;
   Ahom_Digit_Seven                        :
      constant Unicode_Char := 16#11737#;
   Ahom_Digit_Eight                        :
      constant Unicode_Char := 16#11738#;
   Ahom_Digit_Nine                         :
      constant Unicode_Char := 16#11739#;
   Ahom_Number_Ten                         :
      constant Unicode_Char := 16#1173A#;
   Ahom_Number_Twenty                      :
      constant Unicode_Char := 16#1173B#;
   Ahom_Sign_Small_Section                 :
      constant Unicode_Char := 16#1173C#;
   Ahom_Sign_Section                       :
      constant Unicode_Char := 16#1173D#;
   Ahom_Sign_Rulai                         :
      constant Unicode_Char := 16#1173E#;
   Ahom_Symbol_Vi                          :
      constant Unicode_Char := 16#1173F#;
end Unicode.Names.Ahom;
