--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Kangxi_Radicals is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Kangxi_Radical_One                      : constant Unicode_Char := 16#2F00#;
   Kangxi_Radical_Line                     : constant Unicode_Char := 16#2F01#;
   Kangxi_Radical_Dot                      : constant Unicode_Char := 16#2F02#;
   Kangxi_Radical_Slash                    : constant Unicode_Char := 16#2F03#;
   Kangxi_Radical_Second                   : constant Unicode_Char := 16#2F04#;
   Kangxi_Radical_Hook                     : constant Unicode_Char := 16#2F05#;
   Kangxi_Radical_Two                      : constant Unicode_Char := 16#2F06#;
   Kangxi_Radical_Lid                      : constant Unicode_Char := 16#2F07#;
   Kangxi_Radical_Man                      : constant Unicode_Char := 16#2F08#;
   Kangxi_Radical_Legs                     : constant Unicode_Char := 16#2F09#;
   Kangxi_Radical_Enter                    : constant Unicode_Char := 16#2F0A#;
   Kangxi_Radical_Eight                    : constant Unicode_Char := 16#2F0B#;
   Kangxi_Radical_Down_Box                 : constant Unicode_Char := 16#2F0C#;
   Kangxi_Radical_Cover                    : constant Unicode_Char := 16#2F0D#;
   Kangxi_Radical_Ice                      : constant Unicode_Char := 16#2F0E#;
   Kangxi_Radical_Table                    : constant Unicode_Char := 16#2F0F#;
   Kangxi_Radical_Open_Box                 : constant Unicode_Char := 16#2F10#;
   Kangxi_Radical_Knife                    : constant Unicode_Char := 16#2F11#;
   Kangxi_Radical_Power                    : constant Unicode_Char := 16#2F12#;
   Kangxi_Radical_Wrap                     : constant Unicode_Char := 16#2F13#;
   Kangxi_Radical_Spoon                    : constant Unicode_Char := 16#2F14#;
   Kangxi_Radical_Right_Open_Box           : constant Unicode_Char := 16#2F15#;
   Kangxi_Radical_Hiding_Enclosure         : constant Unicode_Char := 16#2F16#;
   Kangxi_Radical_Ten                      : constant Unicode_Char := 16#2F17#;
   Kangxi_Radical_Divination               : constant Unicode_Char := 16#2F18#;
   Kangxi_Radical_Seal                     : constant Unicode_Char := 16#2F19#;
   Kangxi_Radical_Cliff                    : constant Unicode_Char := 16#2F1A#;
   Kangxi_Radical_Private                  : constant Unicode_Char := 16#2F1B#;
   Kangxi_Radical_Again                    : constant Unicode_Char := 16#2F1C#;
   Kangxi_Radical_Mouth                    : constant Unicode_Char := 16#2F1D#;
   Kangxi_Radical_Enclosure                : constant Unicode_Char := 16#2F1E#;
   Kangxi_Radical_Earth                    : constant Unicode_Char := 16#2F1F#;
   Kangxi_Radical_Scholar                  : constant Unicode_Char := 16#2F20#;
   Kangxi_Radical_Go                       : constant Unicode_Char := 16#2F21#;
   Kangxi_Radical_Go_Slowly                : constant Unicode_Char := 16#2F22#;
   Kangxi_Radical_Evening                  : constant Unicode_Char := 16#2F23#;
   Kangxi_Radical_Big                      : constant Unicode_Char := 16#2F24#;
   Kangxi_Radical_Woman                    : constant Unicode_Char := 16#2F25#;
   Kangxi_Radical_Child                    : constant Unicode_Char := 16#2F26#;
   Kangxi_Radical_Roof                     : constant Unicode_Char := 16#2F27#;
   Kangxi_Radical_Inch                     : constant Unicode_Char := 16#2F28#;
   Kangxi_Radical_Small                    : constant Unicode_Char := 16#2F29#;
   Kangxi_Radical_Lame                     : constant Unicode_Char := 16#2F2A#;
   Kangxi_Radical_Corpse                   : constant Unicode_Char := 16#2F2B#;
   Kangxi_Radical_Sprout                   : constant Unicode_Char := 16#2F2C#;
   Kangxi_Radical_Mountain                 : constant Unicode_Char := 16#2F2D#;
   Kangxi_Radical_River                    : constant Unicode_Char := 16#2F2E#;
   Kangxi_Radical_Work                     : constant Unicode_Char := 16#2F2F#;
   Kangxi_Radical_Oneself                  : constant Unicode_Char := 16#2F30#;
   Kangxi_Radical_Turban                   : constant Unicode_Char := 16#2F31#;
   Kangxi_Radical_Dry                      : constant Unicode_Char := 16#2F32#;
   Kangxi_Radical_Short_Thread             : constant Unicode_Char := 16#2F33#;
   Kangxi_Radical_Dotted_Cliff             : constant Unicode_Char := 16#2F34#;
   Kangxi_Radical_Long_Stride              : constant Unicode_Char := 16#2F35#;
   Kangxi_Radical_Two_Hands                : constant Unicode_Char := 16#2F36#;
   Kangxi_Radical_Shoot                    : constant Unicode_Char := 16#2F37#;
   Kangxi_Radical_Bow                      : constant Unicode_Char := 16#2F38#;
   Kangxi_Radical_Snout                    : constant Unicode_Char := 16#2F39#;
   Kangxi_Radical_Bristle                  : constant Unicode_Char := 16#2F3A#;
   Kangxi_Radical_Step                     : constant Unicode_Char := 16#2F3B#;
   Kangxi_Radical_Heart                    : constant Unicode_Char := 16#2F3C#;
   Kangxi_Radical_Halberd                  : constant Unicode_Char := 16#2F3D#;
   Kangxi_Radical_Door                     : constant Unicode_Char := 16#2F3E#;
   Kangxi_Radical_Hand                     : constant Unicode_Char := 16#2F3F#;
   Kangxi_Radical_Branch                   : constant Unicode_Char := 16#2F40#;
   Kangxi_Radical_Rap                      : constant Unicode_Char := 16#2F41#;
   Kangxi_Radical_Script                   : constant Unicode_Char := 16#2F42#;
   Kangxi_Radical_Dipper                   : constant Unicode_Char := 16#2F43#;
   Kangxi_Radical_Axe                      : constant Unicode_Char := 16#2F44#;
   Kangxi_Radical_Square                   : constant Unicode_Char := 16#2F45#;
   Kangxi_Radical_Not                      : constant Unicode_Char := 16#2F46#;
   Kangxi_Radical_Sun                      : constant Unicode_Char := 16#2F47#;
   Kangxi_Radical_Say                      : constant Unicode_Char := 16#2F48#;
   Kangxi_Radical_Moon                     : constant Unicode_Char := 16#2F49#;
   Kangxi_Radical_Tree                     : constant Unicode_Char := 16#2F4A#;
   Kangxi_Radical_Lack                     : constant Unicode_Char := 16#2F4B#;
   Kangxi_Radical_Stop                     : constant Unicode_Char := 16#2F4C#;
   Kangxi_Radical_Death                    : constant Unicode_Char := 16#2F4D#;
   Kangxi_Radical_Weapon                   : constant Unicode_Char := 16#2F4E#;
   Kangxi_Radical_Do_Not                   : constant Unicode_Char := 16#2F4F#;
   Kangxi_Radical_Compare                  : constant Unicode_Char := 16#2F50#;
   Kangxi_Radical_Fur                      : constant Unicode_Char := 16#2F51#;
   Kangxi_Radical_Clan                     : constant Unicode_Char := 16#2F52#;
   Kangxi_Radical_Steam                    : constant Unicode_Char := 16#2F53#;
   Kangxi_Radical_Water                    : constant Unicode_Char := 16#2F54#;
   Kangxi_Radical_Fire                     : constant Unicode_Char := 16#2F55#;
   Kangxi_Radical_Claw                     : constant Unicode_Char := 16#2F56#;
   Kangxi_Radical_Father                   : constant Unicode_Char := 16#2F57#;
   Kangxi_Radical_Double_X                 : constant Unicode_Char := 16#2F58#;
   Kangxi_Radical_Half_Tree_Trunk          : constant Unicode_Char := 16#2F59#;
   Kangxi_Radical_Slice                    : constant Unicode_Char := 16#2F5A#;
   Kangxi_Radical_Fang                     : constant Unicode_Char := 16#2F5B#;
   Kangxi_Radical_Cow                      : constant Unicode_Char := 16#2F5C#;
   Kangxi_Radical_Dog                      : constant Unicode_Char := 16#2F5D#;
   Kangxi_Radical_Profound                 : constant Unicode_Char := 16#2F5E#;
   Kangxi_Radical_Jade                     : constant Unicode_Char := 16#2F5F#;
   Kangxi_Radical_Melon                    : constant Unicode_Char := 16#2F60#;
   Kangxi_Radical_Tile                     : constant Unicode_Char := 16#2F61#;
   Kangxi_Radical_Sweet                    : constant Unicode_Char := 16#2F62#;
   Kangxi_Radical_Life                     : constant Unicode_Char := 16#2F63#;
   Kangxi_Radical_Use                      : constant Unicode_Char := 16#2F64#;
   Kangxi_Radical_Field                    : constant Unicode_Char := 16#2F65#;
   Kangxi_Radical_Bolt_Of_Cloth            : constant Unicode_Char := 16#2F66#;
   Kangxi_Radical_Sickness                 : constant Unicode_Char := 16#2F67#;
   Kangxi_Radical_Dotted_Tent              : constant Unicode_Char := 16#2F68#;
   Kangxi_Radical_White                    : constant Unicode_Char := 16#2F69#;
   Kangxi_Radical_Skin                     : constant Unicode_Char := 16#2F6A#;
   Kangxi_Radical_Dish                     : constant Unicode_Char := 16#2F6B#;
   Kangxi_Radical_Eye                      : constant Unicode_Char := 16#2F6C#;
   Kangxi_Radical_Spear                    : constant Unicode_Char := 16#2F6D#;
   Kangxi_Radical_Arrow                    : constant Unicode_Char := 16#2F6E#;
   Kangxi_Radical_Stone                    : constant Unicode_Char := 16#2F6F#;
   Kangxi_Radical_Spirit                   : constant Unicode_Char := 16#2F70#;
   Kangxi_Radical_Track                    : constant Unicode_Char := 16#2F71#;
   Kangxi_Radical_Grain                    : constant Unicode_Char := 16#2F72#;
   Kangxi_Radical_Cave                     : constant Unicode_Char := 16#2F73#;
   Kangxi_Radical_Stand                    : constant Unicode_Char := 16#2F74#;
   Kangxi_Radical_Bamboo                   : constant Unicode_Char := 16#2F75#;
   Kangxi_Radical_Rice                     : constant Unicode_Char := 16#2F76#;
   Kangxi_Radical_Silk                     : constant Unicode_Char := 16#2F77#;
   Kangxi_Radical_Jar                      : constant Unicode_Char := 16#2F78#;
   Kangxi_Radical_Net                      : constant Unicode_Char := 16#2F79#;
   Kangxi_Radical_Sheep                    : constant Unicode_Char := 16#2F7A#;
   Kangxi_Radical_Feather                  : constant Unicode_Char := 16#2F7B#;
   Kangxi_Radical_Old                      : constant Unicode_Char := 16#2F7C#;
   Kangxi_Radical_And                      : constant Unicode_Char := 16#2F7D#;
   Kangxi_Radical_Plow                     : constant Unicode_Char := 16#2F7E#;
   Kangxi_Radical_Ear                      : constant Unicode_Char := 16#2F7F#;
   Kangxi_Radical_Brush                    : constant Unicode_Char := 16#2F80#;
   Kangxi_Radical_Meat                     : constant Unicode_Char := 16#2F81#;
   Kangxi_Radical_Minister                 : constant Unicode_Char := 16#2F82#;
   Kangxi_Radical_Self                     : constant Unicode_Char := 16#2F83#;
   Kangxi_Radical_Arrive                   : constant Unicode_Char := 16#2F84#;
   Kangxi_Radical_Mortar                   : constant Unicode_Char := 16#2F85#;
   Kangxi_Radical_Tongue                   : constant Unicode_Char := 16#2F86#;
   Kangxi_Radical_Oppose                   : constant Unicode_Char := 16#2F87#;
   Kangxi_Radical_Boat                     : constant Unicode_Char := 16#2F88#;
   Kangxi_Radical_Stopping                 : constant Unicode_Char := 16#2F89#;
   Kangxi_Radical_Color                    : constant Unicode_Char := 16#2F8A#;
   Kangxi_Radical_Grass                    : constant Unicode_Char := 16#2F8B#;
   Kangxi_Radical_Tiger                    : constant Unicode_Char := 16#2F8C#;
   Kangxi_Radical_Insect                   : constant Unicode_Char := 16#2F8D#;
   Kangxi_Radical_Blood                    : constant Unicode_Char := 16#2F8E#;
   Kangxi_Radical_Walk_Enclosure           : constant Unicode_Char := 16#2F8F#;
   Kangxi_Radical_Clothes                  : constant Unicode_Char := 16#2F90#;
   Kangxi_Radical_West                     : constant Unicode_Char := 16#2F91#;
   Kangxi_Radical_See                      : constant Unicode_Char := 16#2F92#;
   Kangxi_Radical_Horn                     : constant Unicode_Char := 16#2F93#;
   Kangxi_Radical_Speech                   : constant Unicode_Char := 16#2F94#;
   Kangxi_Radical_Valley                   : constant Unicode_Char := 16#2F95#;
   Kangxi_Radical_Bean                     : constant Unicode_Char := 16#2F96#;
   Kangxi_Radical_Pig                      : constant Unicode_Char := 16#2F97#;
   Kangxi_Radical_Badger                   : constant Unicode_Char := 16#2F98#;
   Kangxi_Radical_Shell                    : constant Unicode_Char := 16#2F99#;
   Kangxi_Radical_Red                      : constant Unicode_Char := 16#2F9A#;
   Kangxi_Radical_Run                      : constant Unicode_Char := 16#2F9B#;
   Kangxi_Radical_Foot                     : constant Unicode_Char := 16#2F9C#;
   Kangxi_Radical_Body                     : constant Unicode_Char := 16#2F9D#;
   Kangxi_Radical_Cart                     : constant Unicode_Char := 16#2F9E#;
   Kangxi_Radical_Bitter                   : constant Unicode_Char := 16#2F9F#;
   Kangxi_Radical_Morning                  : constant Unicode_Char := 16#2FA0#;
   Kangxi_Radical_Walk                     : constant Unicode_Char := 16#2FA1#;
   Kangxi_Radical_City                     : constant Unicode_Char := 16#2FA2#;
   Kangxi_Radical_Wine                     : constant Unicode_Char := 16#2FA3#;
   Kangxi_Radical_Distinguish              : constant Unicode_Char := 16#2FA4#;
   Kangxi_Radical_Village                  : constant Unicode_Char := 16#2FA5#;
   Kangxi_Radical_Gold                     : constant Unicode_Char := 16#2FA6#;
   Kangxi_Radical_Long                     : constant Unicode_Char := 16#2FA7#;
   Kangxi_Radical_Gate                     : constant Unicode_Char := 16#2FA8#;
   Kangxi_Radical_Mound                    : constant Unicode_Char := 16#2FA9#;
   Kangxi_Radical_Slave                    : constant Unicode_Char := 16#2FAA#;
   Kangxi_Radical_Short_Tailed_Bird        : constant Unicode_Char := 16#2FAB#;
   Kangxi_Radical_Rain                     : constant Unicode_Char := 16#2FAC#;
   Kangxi_Radical_Blue                     : constant Unicode_Char := 16#2FAD#;
   Kangxi_Radical_Wrong                    : constant Unicode_Char := 16#2FAE#;
   Kangxi_Radical_Face                     : constant Unicode_Char := 16#2FAF#;
   Kangxi_Radical_Leather                  : constant Unicode_Char := 16#2FB0#;
   Kangxi_Radical_Tanned_Leather           : constant Unicode_Char := 16#2FB1#;
   Kangxi_Radical_Leek                     : constant Unicode_Char := 16#2FB2#;
   Kangxi_Radical_Sound                    : constant Unicode_Char := 16#2FB3#;
   Kangxi_Radical_Leaf                     : constant Unicode_Char := 16#2FB4#;
   Kangxi_Radical_Wind                     : constant Unicode_Char := 16#2FB5#;
   Kangxi_Radical_Fly                      : constant Unicode_Char := 16#2FB6#;
   Kangxi_Radical_Eat                      : constant Unicode_Char := 16#2FB7#;
   Kangxi_Radical_Head                     : constant Unicode_Char := 16#2FB8#;
   Kangxi_Radical_Fragrant                 : constant Unicode_Char := 16#2FB9#;
   Kangxi_Radical_Horse                    : constant Unicode_Char := 16#2FBA#;
   Kangxi_Radical_Bone                     : constant Unicode_Char := 16#2FBB#;
   Kangxi_Radical_Tall                     : constant Unicode_Char := 16#2FBC#;
   Kangxi_Radical_Hair                     : constant Unicode_Char := 16#2FBD#;
   Kangxi_Radical_Fight                    : constant Unicode_Char := 16#2FBE#;
   Kangxi_Radical_Sacrificial_Wine         : constant Unicode_Char := 16#2FBF#;
   Kangxi_Radical_Cauldron                 : constant Unicode_Char := 16#2FC0#;
   Kangxi_Radical_Ghost                    : constant Unicode_Char := 16#2FC1#;
   Kangxi_Radical_Fish                     : constant Unicode_Char := 16#2FC2#;
   Kangxi_Radical_Bird                     : constant Unicode_Char := 16#2FC3#;
   Kangxi_Radical_Salt                     : constant Unicode_Char := 16#2FC4#;
   Kangxi_Radical_Deer                     : constant Unicode_Char := 16#2FC5#;
   Kangxi_Radical_Wheat                    : constant Unicode_Char := 16#2FC6#;
   Kangxi_Radical_Hemp                     : constant Unicode_Char := 16#2FC7#;
   Kangxi_Radical_Yellow                   : constant Unicode_Char := 16#2FC8#;
   Kangxi_Radical_Millet                   : constant Unicode_Char := 16#2FC9#;
   Kangxi_Radical_Black                    : constant Unicode_Char := 16#2FCA#;
   Kangxi_Radical_Embroidery               : constant Unicode_Char := 16#2FCB#;
   Kangxi_Radical_Frog                     : constant Unicode_Char := 16#2FCC#;
   Kangxi_Radical_Tripod                   : constant Unicode_Char := 16#2FCD#;
   Kangxi_Radical_Drum                     : constant Unicode_Char := 16#2FCE#;
   Kangxi_Radical_Rat                      : constant Unicode_Char := 16#2FCF#;
   Kangxi_Radical_Nose                     : constant Unicode_Char := 16#2FD0#;
   Kangxi_Radical_Even                     : constant Unicode_Char := 16#2FD1#;
   Kangxi_Radical_Tooth                    : constant Unicode_Char := 16#2FD2#;
   Kangxi_Radical_Dragon                   : constant Unicode_Char := 16#2FD3#;
   Kangxi_Radical_Turtle                   : constant Unicode_Char := 16#2FD4#;
   Kangxi_Radical_Flute                    : constant Unicode_Char := 16#2FD5#;
end Unicode.Names.Kangxi_Radicals;
