--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Ethiopic is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Ethiopic_Syllable_Ha                    : constant Unicode_Char := 16#1200#;
   Ethiopic_Syllable_Hu                    : constant Unicode_Char := 16#1201#;
   Ethiopic_Syllable_Hi                    : constant Unicode_Char := 16#1202#;
   Ethiopic_Syllable_Haa                   : constant Unicode_Char := 16#1203#;
   Ethiopic_Syllable_Hee                   : constant Unicode_Char := 16#1204#;
   Ethiopic_Syllable_He                    : constant Unicode_Char := 16#1205#;
   Ethiopic_Syllable_Ho                    : constant Unicode_Char := 16#1206#;
   Ethiopic_Syllable_Hoa                   : constant Unicode_Char := 16#1207#;
   Ethiopic_Syllable_La                    : constant Unicode_Char := 16#1208#;
   Ethiopic_Syllable_Lu                    : constant Unicode_Char := 16#1209#;
   Ethiopic_Syllable_Li                    : constant Unicode_Char := 16#120A#;
   Ethiopic_Syllable_Laa                   : constant Unicode_Char := 16#120B#;
   Ethiopic_Syllable_Lee                   : constant Unicode_Char := 16#120C#;
   Ethiopic_Syllable_Le                    : constant Unicode_Char := 16#120D#;
   Ethiopic_Syllable_Lo                    : constant Unicode_Char := 16#120E#;
   Ethiopic_Syllable_Lwa                   : constant Unicode_Char := 16#120F#;
   Ethiopic_Syllable_Hha                   : constant Unicode_Char := 16#1210#;
   Ethiopic_Syllable_Hhu                   : constant Unicode_Char := 16#1211#;
   Ethiopic_Syllable_Hhi                   : constant Unicode_Char := 16#1212#;
   Ethiopic_Syllable_Hhaa                  : constant Unicode_Char := 16#1213#;
   Ethiopic_Syllable_Hhee                  : constant Unicode_Char := 16#1214#;
   Ethiopic_Syllable_Hhe                   : constant Unicode_Char := 16#1215#;
   Ethiopic_Syllable_Hho                   : constant Unicode_Char := 16#1216#;
   Ethiopic_Syllable_Hhwa                  : constant Unicode_Char := 16#1217#;
   Ethiopic_Syllable_Ma                    : constant Unicode_Char := 16#1218#;
   Ethiopic_Syllable_Mu                    : constant Unicode_Char := 16#1219#;
   Ethiopic_Syllable_Mi                    : constant Unicode_Char := 16#121A#;
   Ethiopic_Syllable_Maa                   : constant Unicode_Char := 16#121B#;
   Ethiopic_Syllable_Mee                   : constant Unicode_Char := 16#121C#;
   Ethiopic_Syllable_Me                    : constant Unicode_Char := 16#121D#;
   Ethiopic_Syllable_Mo                    : constant Unicode_Char := 16#121E#;
   Ethiopic_Syllable_Mwa                   : constant Unicode_Char := 16#121F#;
   Ethiopic_Syllable_Sza                   : constant Unicode_Char := 16#1220#;
   Ethiopic_Syllable_Szu                   : constant Unicode_Char := 16#1221#;
   Ethiopic_Syllable_Szi                   : constant Unicode_Char := 16#1222#;
   Ethiopic_Syllable_Szaa                  : constant Unicode_Char := 16#1223#;
   Ethiopic_Syllable_Szee                  : constant Unicode_Char := 16#1224#;
   Ethiopic_Syllable_Sze                   : constant Unicode_Char := 16#1225#;
   Ethiopic_Syllable_Szo                   : constant Unicode_Char := 16#1226#;
   Ethiopic_Syllable_Szwa                  : constant Unicode_Char := 16#1227#;
   Ethiopic_Syllable_Ra                    : constant Unicode_Char := 16#1228#;
   Ethiopic_Syllable_Ru                    : constant Unicode_Char := 16#1229#;
   Ethiopic_Syllable_Ri                    : constant Unicode_Char := 16#122A#;
   Ethiopic_Syllable_Raa                   : constant Unicode_Char := 16#122B#;
   Ethiopic_Syllable_Ree                   : constant Unicode_Char := 16#122C#;
   Ethiopic_Syllable_Re                    : constant Unicode_Char := 16#122D#;
   Ethiopic_Syllable_Ro                    : constant Unicode_Char := 16#122E#;
   Ethiopic_Syllable_Rwa                   : constant Unicode_Char := 16#122F#;
   Ethiopic_Syllable_Sa                    : constant Unicode_Char := 16#1230#;
   Ethiopic_Syllable_Su                    : constant Unicode_Char := 16#1231#;
   Ethiopic_Syllable_Si                    : constant Unicode_Char := 16#1232#;
   Ethiopic_Syllable_Saa                   : constant Unicode_Char := 16#1233#;
   Ethiopic_Syllable_See                   : constant Unicode_Char := 16#1234#;
   Ethiopic_Syllable_Se                    : constant Unicode_Char := 16#1235#;
   Ethiopic_Syllable_So                    : constant Unicode_Char := 16#1236#;
   Ethiopic_Syllable_Swa                   : constant Unicode_Char := 16#1237#;
   Ethiopic_Syllable_Sha                   : constant Unicode_Char := 16#1238#;
   Ethiopic_Syllable_Shu                   : constant Unicode_Char := 16#1239#;
   Ethiopic_Syllable_Shi                   : constant Unicode_Char := 16#123A#;
   Ethiopic_Syllable_Shaa                  : constant Unicode_Char := 16#123B#;
   Ethiopic_Syllable_Shee                  : constant Unicode_Char := 16#123C#;
   Ethiopic_Syllable_She                   : constant Unicode_Char := 16#123D#;
   Ethiopic_Syllable_Sho                   : constant Unicode_Char := 16#123E#;
   Ethiopic_Syllable_Shwa                  : constant Unicode_Char := 16#123F#;
   Ethiopic_Syllable_Qa                    : constant Unicode_Char := 16#1240#;
   Ethiopic_Syllable_Qu                    : constant Unicode_Char := 16#1241#;
   Ethiopic_Syllable_Qi                    : constant Unicode_Char := 16#1242#;
   Ethiopic_Syllable_Qaa                   : constant Unicode_Char := 16#1243#;
   Ethiopic_Syllable_Qee                   : constant Unicode_Char := 16#1244#;
   Ethiopic_Syllable_Qe                    : constant Unicode_Char := 16#1245#;
   Ethiopic_Syllable_Qo                    : constant Unicode_Char := 16#1246#;
   Ethiopic_Syllable_Qoa                   : constant Unicode_Char := 16#1247#;
   Ethiopic_Syllable_Qwa                   : constant Unicode_Char := 16#1248#;
   Ethiopic_Syllable_Qwi                   : constant Unicode_Char := 16#124A#;
   Ethiopic_Syllable_Qwaa                  : constant Unicode_Char := 16#124B#;
   Ethiopic_Syllable_Qwee                  : constant Unicode_Char := 16#124C#;
   Ethiopic_Syllable_Qwe                   : constant Unicode_Char := 16#124D#;
   Ethiopic_Syllable_Qha                   : constant Unicode_Char := 16#1250#;
   Ethiopic_Syllable_Qhu                   : constant Unicode_Char := 16#1251#;
   Ethiopic_Syllable_Qhi                   : constant Unicode_Char := 16#1252#;
   Ethiopic_Syllable_Qhaa                  : constant Unicode_Char := 16#1253#;
   Ethiopic_Syllable_Qhee                  : constant Unicode_Char := 16#1254#;
   Ethiopic_Syllable_Qhe                   : constant Unicode_Char := 16#1255#;
   Ethiopic_Syllable_Qho                   : constant Unicode_Char := 16#1256#;
   Ethiopic_Syllable_Qhwa                  : constant Unicode_Char := 16#1258#;
   Ethiopic_Syllable_Qhwi                  : constant Unicode_Char := 16#125A#;
   Ethiopic_Syllable_Qhwaa                 : constant Unicode_Char := 16#125B#;
   Ethiopic_Syllable_Qhwee                 : constant Unicode_Char := 16#125C#;
   Ethiopic_Syllable_Qhwe                  : constant Unicode_Char := 16#125D#;
   Ethiopic_Syllable_Ba                    : constant Unicode_Char := 16#1260#;
   Ethiopic_Syllable_Bu                    : constant Unicode_Char := 16#1261#;
   Ethiopic_Syllable_Bi                    : constant Unicode_Char := 16#1262#;
   Ethiopic_Syllable_Baa                   : constant Unicode_Char := 16#1263#;
   Ethiopic_Syllable_Bee                   : constant Unicode_Char := 16#1264#;
   Ethiopic_Syllable_Be                    : constant Unicode_Char := 16#1265#;
   Ethiopic_Syllable_Bo                    : constant Unicode_Char := 16#1266#;
   Ethiopic_Syllable_Bwa                   : constant Unicode_Char := 16#1267#;
   Ethiopic_Syllable_Va                    : constant Unicode_Char := 16#1268#;
   Ethiopic_Syllable_Vu                    : constant Unicode_Char := 16#1269#;
   Ethiopic_Syllable_Vi                    : constant Unicode_Char := 16#126A#;
   Ethiopic_Syllable_Vaa                   : constant Unicode_Char := 16#126B#;
   Ethiopic_Syllable_Vee                   : constant Unicode_Char := 16#126C#;
   Ethiopic_Syllable_Ve                    : constant Unicode_Char := 16#126D#;
   Ethiopic_Syllable_Vo                    : constant Unicode_Char := 16#126E#;
   Ethiopic_Syllable_Vwa                   : constant Unicode_Char := 16#126F#;
   Ethiopic_Syllable_Ta                    : constant Unicode_Char := 16#1270#;
   Ethiopic_Syllable_Tu                    : constant Unicode_Char := 16#1271#;
   Ethiopic_Syllable_Ti                    : constant Unicode_Char := 16#1272#;
   Ethiopic_Syllable_Taa                   : constant Unicode_Char := 16#1273#;
   Ethiopic_Syllable_Tee                   : constant Unicode_Char := 16#1274#;
   Ethiopic_Syllable_Te                    : constant Unicode_Char := 16#1275#;
   Ethiopic_Syllable_To                    : constant Unicode_Char := 16#1276#;
   Ethiopic_Syllable_Twa                   : constant Unicode_Char := 16#1277#;
   Ethiopic_Syllable_Ca                    : constant Unicode_Char := 16#1278#;
   Ethiopic_Syllable_Cu                    : constant Unicode_Char := 16#1279#;
   Ethiopic_Syllable_Ci                    : constant Unicode_Char := 16#127A#;
   Ethiopic_Syllable_Caa                   : constant Unicode_Char := 16#127B#;
   Ethiopic_Syllable_Cee                   : constant Unicode_Char := 16#127C#;
   Ethiopic_Syllable_Ce                    : constant Unicode_Char := 16#127D#;
   Ethiopic_Syllable_Co                    : constant Unicode_Char := 16#127E#;
   Ethiopic_Syllable_Cwa                   : constant Unicode_Char := 16#127F#;
   Ethiopic_Syllable_Xa                    : constant Unicode_Char := 16#1280#;
   Ethiopic_Syllable_Xu                    : constant Unicode_Char := 16#1281#;
   Ethiopic_Syllable_Xi                    : constant Unicode_Char := 16#1282#;
   Ethiopic_Syllable_Xaa                   : constant Unicode_Char := 16#1283#;
   Ethiopic_Syllable_Xee                   : constant Unicode_Char := 16#1284#;
   Ethiopic_Syllable_Xe                    : constant Unicode_Char := 16#1285#;
   Ethiopic_Syllable_Xo                    : constant Unicode_Char := 16#1286#;
   Ethiopic_Syllable_Xoa                   : constant Unicode_Char := 16#1287#;
   Ethiopic_Syllable_Xwa                   : constant Unicode_Char := 16#1288#;
   Ethiopic_Syllable_Xwi                   : constant Unicode_Char := 16#128A#;
   Ethiopic_Syllable_Xwaa                  : constant Unicode_Char := 16#128B#;
   Ethiopic_Syllable_Xwee                  : constant Unicode_Char := 16#128C#;
   Ethiopic_Syllable_Xwe                   : constant Unicode_Char := 16#128D#;
   Ethiopic_Syllable_Na                    : constant Unicode_Char := 16#1290#;
   Ethiopic_Syllable_Nu                    : constant Unicode_Char := 16#1291#;
   Ethiopic_Syllable_Ni                    : constant Unicode_Char := 16#1292#;
   Ethiopic_Syllable_Naa                   : constant Unicode_Char := 16#1293#;
   Ethiopic_Syllable_Nee                   : constant Unicode_Char := 16#1294#;
   Ethiopic_Syllable_Ne                    : constant Unicode_Char := 16#1295#;
   Ethiopic_Syllable_No                    : constant Unicode_Char := 16#1296#;
   Ethiopic_Syllable_Nwa                   : constant Unicode_Char := 16#1297#;
   Ethiopic_Syllable_Nya                   : constant Unicode_Char := 16#1298#;
   Ethiopic_Syllable_Nyu                   : constant Unicode_Char := 16#1299#;
   Ethiopic_Syllable_Nyi                   : constant Unicode_Char := 16#129A#;
   Ethiopic_Syllable_Nyaa                  : constant Unicode_Char := 16#129B#;
   Ethiopic_Syllable_Nyee                  : constant Unicode_Char := 16#129C#;
   Ethiopic_Syllable_Nye                   : constant Unicode_Char := 16#129D#;
   Ethiopic_Syllable_Nyo                   : constant Unicode_Char := 16#129E#;
   Ethiopic_Syllable_Nywa                  : constant Unicode_Char := 16#129F#;
   Ethiopic_Syllable_Glottal_A             : constant Unicode_Char := 16#12A0#;
   Ethiopic_Syllable_Glottal_U             : constant Unicode_Char := 16#12A1#;
   Ethiopic_Syllable_Glottal_I             : constant Unicode_Char := 16#12A2#;
   Ethiopic_Syllable_Glottal_Aa            : constant Unicode_Char := 16#12A3#;
   Ethiopic_Syllable_Glottal_Ee            : constant Unicode_Char := 16#12A4#;
   Ethiopic_Syllable_Glottal_E             : constant Unicode_Char := 16#12A5#;
   Ethiopic_Syllable_Glottal_O             : constant Unicode_Char := 16#12A6#;
   Ethiopic_Syllable_Glottal_Wa            : constant Unicode_Char := 16#12A7#;
   Ethiopic_Syllable_Ka                    : constant Unicode_Char := 16#12A8#;
   Ethiopic_Syllable_Ku                    : constant Unicode_Char := 16#12A9#;
   Ethiopic_Syllable_Ki                    : constant Unicode_Char := 16#12AA#;
   Ethiopic_Syllable_Kaa                   : constant Unicode_Char := 16#12AB#;
   Ethiopic_Syllable_Kee                   : constant Unicode_Char := 16#12AC#;
   Ethiopic_Syllable_Ke                    : constant Unicode_Char := 16#12AD#;
   Ethiopic_Syllable_Ko                    : constant Unicode_Char := 16#12AE#;
   Ethiopic_Syllable_Koa                   : constant Unicode_Char := 16#12AF#;
   Ethiopic_Syllable_Kwa                   : constant Unicode_Char := 16#12B0#;
   Ethiopic_Syllable_Kwi                   : constant Unicode_Char := 16#12B2#;
   Ethiopic_Syllable_Kwaa                  : constant Unicode_Char := 16#12B3#;
   Ethiopic_Syllable_Kwee                  : constant Unicode_Char := 16#12B4#;
   Ethiopic_Syllable_Kwe                   : constant Unicode_Char := 16#12B5#;
   Ethiopic_Syllable_Kxa                   : constant Unicode_Char := 16#12B8#;
   Ethiopic_Syllable_Kxu                   : constant Unicode_Char := 16#12B9#;
   Ethiopic_Syllable_Kxi                   : constant Unicode_Char := 16#12BA#;
   Ethiopic_Syllable_Kxaa                  : constant Unicode_Char := 16#12BB#;
   Ethiopic_Syllable_Kxee                  : constant Unicode_Char := 16#12BC#;
   Ethiopic_Syllable_Kxe                   : constant Unicode_Char := 16#12BD#;
   Ethiopic_Syllable_Kxo                   : constant Unicode_Char := 16#12BE#;
   Ethiopic_Syllable_Kxwa                  : constant Unicode_Char := 16#12C0#;
   Ethiopic_Syllable_Kxwi                  : constant Unicode_Char := 16#12C2#;
   Ethiopic_Syllable_Kxwaa                 : constant Unicode_Char := 16#12C3#;
   Ethiopic_Syllable_Kxwee                 : constant Unicode_Char := 16#12C4#;
   Ethiopic_Syllable_Kxwe                  : constant Unicode_Char := 16#12C5#;
   Ethiopic_Syllable_Wa                    : constant Unicode_Char := 16#12C8#;
   Ethiopic_Syllable_Wu                    : constant Unicode_Char := 16#12C9#;
   Ethiopic_Syllable_Wi                    : constant Unicode_Char := 16#12CA#;
   Ethiopic_Syllable_Waa                   : constant Unicode_Char := 16#12CB#;
   Ethiopic_Syllable_Wee                   : constant Unicode_Char := 16#12CC#;
   Ethiopic_Syllable_We                    : constant Unicode_Char := 16#12CD#;
   Ethiopic_Syllable_Wo                    : constant Unicode_Char := 16#12CE#;
   Ethiopic_Syllable_Woa                   : constant Unicode_Char := 16#12CF#;
   Ethiopic_Syllable_Pharyngeal_A          : constant Unicode_Char := 16#12D0#;
   Ethiopic_Syllable_Pharyngeal_U          : constant Unicode_Char := 16#12D1#;
   Ethiopic_Syllable_Pharyngeal_I          : constant Unicode_Char := 16#12D2#;
   Ethiopic_Syllable_Pharyngeal_Aa         : constant Unicode_Char := 16#12D3#;
   Ethiopic_Syllable_Pharyngeal_Ee         : constant Unicode_Char := 16#12D4#;
   Ethiopic_Syllable_Pharyngeal_E          : constant Unicode_Char := 16#12D5#;
   Ethiopic_Syllable_Pharyngeal_O          : constant Unicode_Char := 16#12D6#;
   Ethiopic_Syllable_Za                    : constant Unicode_Char := 16#12D8#;
   Ethiopic_Syllable_Zu                    : constant Unicode_Char := 16#12D9#;
   Ethiopic_Syllable_Zi                    : constant Unicode_Char := 16#12DA#;
   Ethiopic_Syllable_Zaa                   : constant Unicode_Char := 16#12DB#;
   Ethiopic_Syllable_Zee                   : constant Unicode_Char := 16#12DC#;
   Ethiopic_Syllable_Ze                    : constant Unicode_Char := 16#12DD#;
   Ethiopic_Syllable_Zo                    : constant Unicode_Char := 16#12DE#;
   Ethiopic_Syllable_Zwa                   : constant Unicode_Char := 16#12DF#;
   Ethiopic_Syllable_Zha                   : constant Unicode_Char := 16#12E0#;
   Ethiopic_Syllable_Zhu                   : constant Unicode_Char := 16#12E1#;
   Ethiopic_Syllable_Zhi                   : constant Unicode_Char := 16#12E2#;
   Ethiopic_Syllable_Zhaa                  : constant Unicode_Char := 16#12E3#;
   Ethiopic_Syllable_Zhee                  : constant Unicode_Char := 16#12E4#;
   Ethiopic_Syllable_Zhe                   : constant Unicode_Char := 16#12E5#;
   Ethiopic_Syllable_Zho                   : constant Unicode_Char := 16#12E6#;
   Ethiopic_Syllable_Zhwa                  : constant Unicode_Char := 16#12E7#;
   Ethiopic_Syllable_Ya                    : constant Unicode_Char := 16#12E8#;
   Ethiopic_Syllable_Yu                    : constant Unicode_Char := 16#12E9#;
   Ethiopic_Syllable_Yi                    : constant Unicode_Char := 16#12EA#;
   Ethiopic_Syllable_Yaa                   : constant Unicode_Char := 16#12EB#;
   Ethiopic_Syllable_Yee                   : constant Unicode_Char := 16#12EC#;
   Ethiopic_Syllable_Ye                    : constant Unicode_Char := 16#12ED#;
   Ethiopic_Syllable_Yo                    : constant Unicode_Char := 16#12EE#;
   Ethiopic_Syllable_Yoa                   : constant Unicode_Char := 16#12EF#;
   Ethiopic_Syllable_Da                    : constant Unicode_Char := 16#12F0#;
   Ethiopic_Syllable_Du                    : constant Unicode_Char := 16#12F1#;
   Ethiopic_Syllable_Di                    : constant Unicode_Char := 16#12F2#;
   Ethiopic_Syllable_Daa                   : constant Unicode_Char := 16#12F3#;
   Ethiopic_Syllable_Dee                   : constant Unicode_Char := 16#12F4#;
   Ethiopic_Syllable_De                    : constant Unicode_Char := 16#12F5#;
   Ethiopic_Syllable_Do                    : constant Unicode_Char := 16#12F6#;
   Ethiopic_Syllable_Dwa                   : constant Unicode_Char := 16#12F7#;
   Ethiopic_Syllable_Dda                   : constant Unicode_Char := 16#12F8#;
   Ethiopic_Syllable_Ddu                   : constant Unicode_Char := 16#12F9#;
   Ethiopic_Syllable_Ddi                   : constant Unicode_Char := 16#12FA#;
   Ethiopic_Syllable_Ddaa                  : constant Unicode_Char := 16#12FB#;
   Ethiopic_Syllable_Ddee                  : constant Unicode_Char := 16#12FC#;
   Ethiopic_Syllable_Dde                   : constant Unicode_Char := 16#12FD#;
   Ethiopic_Syllable_Ddo                   : constant Unicode_Char := 16#12FE#;
   Ethiopic_Syllable_Ddwa                  : constant Unicode_Char := 16#12FF#;
   Ethiopic_Syllable_Ja                    : constant Unicode_Char := 16#1300#;
   Ethiopic_Syllable_Ju                    : constant Unicode_Char := 16#1301#;
   Ethiopic_Syllable_Ji                    : constant Unicode_Char := 16#1302#;
   Ethiopic_Syllable_Jaa                   : constant Unicode_Char := 16#1303#;
   Ethiopic_Syllable_Jee                   : constant Unicode_Char := 16#1304#;
   Ethiopic_Syllable_Je                    : constant Unicode_Char := 16#1305#;
   Ethiopic_Syllable_Jo                    : constant Unicode_Char := 16#1306#;
   Ethiopic_Syllable_Jwa                   : constant Unicode_Char := 16#1307#;
   Ethiopic_Syllable_Ga                    : constant Unicode_Char := 16#1308#;
   Ethiopic_Syllable_Gu                    : constant Unicode_Char := 16#1309#;
   Ethiopic_Syllable_Gi                    : constant Unicode_Char := 16#130A#;
   Ethiopic_Syllable_Gaa                   : constant Unicode_Char := 16#130B#;
   Ethiopic_Syllable_Gee                   : constant Unicode_Char := 16#130C#;
   Ethiopic_Syllable_Ge                    : constant Unicode_Char := 16#130D#;
   Ethiopic_Syllable_Go                    : constant Unicode_Char := 16#130E#;
   Ethiopic_Syllable_Goa                   : constant Unicode_Char := 16#130F#;
   Ethiopic_Syllable_Gwa                   : constant Unicode_Char := 16#1310#;
   Ethiopic_Syllable_Gwi                   : constant Unicode_Char := 16#1312#;
   Ethiopic_Syllable_Gwaa                  : constant Unicode_Char := 16#1313#;
   Ethiopic_Syllable_Gwee                  : constant Unicode_Char := 16#1314#;
   Ethiopic_Syllable_Gwe                   : constant Unicode_Char := 16#1315#;
   Ethiopic_Syllable_Gga                   : constant Unicode_Char := 16#1318#;
   Ethiopic_Syllable_Ggu                   : constant Unicode_Char := 16#1319#;
   Ethiopic_Syllable_Ggi                   : constant Unicode_Char := 16#131A#;
   Ethiopic_Syllable_Ggaa                  : constant Unicode_Char := 16#131B#;
   Ethiopic_Syllable_Ggee                  : constant Unicode_Char := 16#131C#;
   Ethiopic_Syllable_Gge                   : constant Unicode_Char := 16#131D#;
   Ethiopic_Syllable_Ggo                   : constant Unicode_Char := 16#131E#;
   Ethiopic_Syllable_Ggwaa                 : constant Unicode_Char := 16#131F#;
   Ethiopic_Syllable_Tha                   : constant Unicode_Char := 16#1320#;
   Ethiopic_Syllable_Thu                   : constant Unicode_Char := 16#1321#;
   Ethiopic_Syllable_Thi                   : constant Unicode_Char := 16#1322#;
   Ethiopic_Syllable_Thaa                  : constant Unicode_Char := 16#1323#;
   Ethiopic_Syllable_Thee                  : constant Unicode_Char := 16#1324#;
   Ethiopic_Syllable_The                   : constant Unicode_Char := 16#1325#;
   Ethiopic_Syllable_Tho                   : constant Unicode_Char := 16#1326#;
   Ethiopic_Syllable_Thwa                  : constant Unicode_Char := 16#1327#;
   Ethiopic_Syllable_Cha                   : constant Unicode_Char := 16#1328#;
   Ethiopic_Syllable_Chu                   : constant Unicode_Char := 16#1329#;
   Ethiopic_Syllable_Chi                   : constant Unicode_Char := 16#132A#;
   Ethiopic_Syllable_Chaa                  : constant Unicode_Char := 16#132B#;
   Ethiopic_Syllable_Chee                  : constant Unicode_Char := 16#132C#;
   Ethiopic_Syllable_Che                   : constant Unicode_Char := 16#132D#;
   Ethiopic_Syllable_Cho                   : constant Unicode_Char := 16#132E#;
   Ethiopic_Syllable_Chwa                  : constant Unicode_Char := 16#132F#;
   Ethiopic_Syllable_Pha                   : constant Unicode_Char := 16#1330#;
   Ethiopic_Syllable_Phu                   : constant Unicode_Char := 16#1331#;
   Ethiopic_Syllable_Phi                   : constant Unicode_Char := 16#1332#;
   Ethiopic_Syllable_Phaa                  : constant Unicode_Char := 16#1333#;
   Ethiopic_Syllable_Phee                  : constant Unicode_Char := 16#1334#;
   Ethiopic_Syllable_Phe                   : constant Unicode_Char := 16#1335#;
   Ethiopic_Syllable_Pho                   : constant Unicode_Char := 16#1336#;
   Ethiopic_Syllable_Phwa                  : constant Unicode_Char := 16#1337#;
   Ethiopic_Syllable_Tsa                   : constant Unicode_Char := 16#1338#;
   Ethiopic_Syllable_Tsu                   : constant Unicode_Char := 16#1339#;
   Ethiopic_Syllable_Tsi                   : constant Unicode_Char := 16#133A#;
   Ethiopic_Syllable_Tsaa                  : constant Unicode_Char := 16#133B#;
   Ethiopic_Syllable_Tsee                  : constant Unicode_Char := 16#133C#;
   Ethiopic_Syllable_Tse                   : constant Unicode_Char := 16#133D#;
   Ethiopic_Syllable_Tso                   : constant Unicode_Char := 16#133E#;
   Ethiopic_Syllable_Tswa                  : constant Unicode_Char := 16#133F#;
   Ethiopic_Syllable_Tza                   : constant Unicode_Char := 16#1340#;
   Ethiopic_Syllable_Tzu                   : constant Unicode_Char := 16#1341#;
   Ethiopic_Syllable_Tzi                   : constant Unicode_Char := 16#1342#;
   Ethiopic_Syllable_Tzaa                  : constant Unicode_Char := 16#1343#;
   Ethiopic_Syllable_Tzee                  : constant Unicode_Char := 16#1344#;
   Ethiopic_Syllable_Tze                   : constant Unicode_Char := 16#1345#;
   Ethiopic_Syllable_Tzo                   : constant Unicode_Char := 16#1346#;
   Ethiopic_Syllable_Tzoa                  : constant Unicode_Char := 16#1347#;
   Ethiopic_Syllable_Fa                    : constant Unicode_Char := 16#1348#;
   Ethiopic_Syllable_Fu                    : constant Unicode_Char := 16#1349#;
   Ethiopic_Syllable_Fi                    : constant Unicode_Char := 16#134A#;
   Ethiopic_Syllable_Faa                   : constant Unicode_Char := 16#134B#;
   Ethiopic_Syllable_Fee                   : constant Unicode_Char := 16#134C#;
   Ethiopic_Syllable_Fe                    : constant Unicode_Char := 16#134D#;
   Ethiopic_Syllable_Fo                    : constant Unicode_Char := 16#134E#;
   Ethiopic_Syllable_Fwa                   : constant Unicode_Char := 16#134F#;
   Ethiopic_Syllable_Pa                    : constant Unicode_Char := 16#1350#;
   Ethiopic_Syllable_Pu                    : constant Unicode_Char := 16#1351#;
   Ethiopic_Syllable_Pi                    : constant Unicode_Char := 16#1352#;
   Ethiopic_Syllable_Paa                   : constant Unicode_Char := 16#1353#;
   Ethiopic_Syllable_Pee                   : constant Unicode_Char := 16#1354#;
   Ethiopic_Syllable_Pe                    : constant Unicode_Char := 16#1355#;
   Ethiopic_Syllable_Po                    : constant Unicode_Char := 16#1356#;
   Ethiopic_Syllable_Pwa                   : constant Unicode_Char := 16#1357#;
   Ethiopic_Syllable_Rya                   : constant Unicode_Char := 16#1358#;
   Ethiopic_Syllable_Mya                   : constant Unicode_Char := 16#1359#;
   Ethiopic_Syllable_Fya                   : constant Unicode_Char := 16#135A#;
   Ethiopic_Combining_Gemination_And_Vowel_Length_Mark :
      constant Unicode_Char := 16#135D#;
   Ethiopic_Combining_Vowel_Length_Mark    : constant Unicode_Char := 16#135E#;
   Ethiopic_Combining_Gemination_Mark      : constant Unicode_Char := 16#135F#;
   Ethiopic_Section_Mark                   : constant Unicode_Char := 16#1360#;
   Ethiopic_Wordspace                      : constant Unicode_Char := 16#1361#;
   Ethiopic_Full_Stop                      : constant Unicode_Char := 16#1362#;
   Ethiopic_Comma                          : constant Unicode_Char := 16#1363#;
   Ethiopic_Semicolon                      : constant Unicode_Char := 16#1364#;
   Ethiopic_Colon                          : constant Unicode_Char := 16#1365#;
   Ethiopic_Preface_Colon                  : constant Unicode_Char := 16#1366#;
   Ethiopic_Question_Mark                  : constant Unicode_Char := 16#1367#;
   Ethiopic_Paragraph_Separator            : constant Unicode_Char := 16#1368#;
   Ethiopic_Digit_One                      : constant Unicode_Char := 16#1369#;
   Ethiopic_Digit_Two                      : constant Unicode_Char := 16#136A#;
   Ethiopic_Digit_Three                    : constant Unicode_Char := 16#136B#;
   Ethiopic_Digit_Four                     : constant Unicode_Char := 16#136C#;
   Ethiopic_Digit_Five                     : constant Unicode_Char := 16#136D#;
   Ethiopic_Digit_Six                      : constant Unicode_Char := 16#136E#;
   Ethiopic_Digit_Seven                    : constant Unicode_Char := 16#136F#;
   Ethiopic_Digit_Eight                    : constant Unicode_Char := 16#1370#;
   Ethiopic_Digit_Nine                     : constant Unicode_Char := 16#1371#;
   Ethiopic_Number_Ten                     : constant Unicode_Char := 16#1372#;
   Ethiopic_Number_Twenty                  : constant Unicode_Char := 16#1373#;
   Ethiopic_Number_Thirty                  : constant Unicode_Char := 16#1374#;
   Ethiopic_Number_Forty                   : constant Unicode_Char := 16#1375#;
   Ethiopic_Number_Fifty                   : constant Unicode_Char := 16#1376#;
   Ethiopic_Number_Sixty                   : constant Unicode_Char := 16#1377#;
   Ethiopic_Number_Seventy                 : constant Unicode_Char := 16#1378#;
   Ethiopic_Number_Eighty                  : constant Unicode_Char := 16#1379#;
   Ethiopic_Number_Ninety                  : constant Unicode_Char := 16#137A#;
   Ethiopic_Number_Hundred                 : constant Unicode_Char := 16#137B#;
   Ethiopic_Number_Ten_Thousand            : constant Unicode_Char := 16#137C#;
end Unicode.Names.Ethiopic;
