--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cherokee is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cherokee_Letter_A                       : constant Unicode_Char := 16#13A0#;
   Cherokee_Letter_E                       : constant Unicode_Char := 16#13A1#;
   Cherokee_Letter_I                       : constant Unicode_Char := 16#13A2#;
   Cherokee_Letter_O                       : constant Unicode_Char := 16#13A3#;
   Cherokee_Letter_U                       : constant Unicode_Char := 16#13A4#;
   Cherokee_Letter_V                       : constant Unicode_Char := 16#13A5#;
   Cherokee_Letter_Ga                      : constant Unicode_Char := 16#13A6#;
   Cherokee_Letter_Ka                      : constant Unicode_Char := 16#13A7#;
   Cherokee_Letter_Ge                      : constant Unicode_Char := 16#13A8#;
   Cherokee_Letter_Gi                      : constant Unicode_Char := 16#13A9#;
   Cherokee_Letter_Go                      : constant Unicode_Char := 16#13AA#;
   Cherokee_Letter_Gu                      : constant Unicode_Char := 16#13AB#;
   Cherokee_Letter_Gv                      : constant Unicode_Char := 16#13AC#;
   Cherokee_Letter_Ha                      : constant Unicode_Char := 16#13AD#;
   Cherokee_Letter_He                      : constant Unicode_Char := 16#13AE#;
   Cherokee_Letter_Hi                      : constant Unicode_Char := 16#13AF#;
   Cherokee_Letter_Ho                      : constant Unicode_Char := 16#13B0#;
   Cherokee_Letter_Hu                      : constant Unicode_Char := 16#13B1#;
   Cherokee_Letter_Hv                      : constant Unicode_Char := 16#13B2#;
   Cherokee_Letter_La                      : constant Unicode_Char := 16#13B3#;
   Cherokee_Letter_Le                      : constant Unicode_Char := 16#13B4#;
   Cherokee_Letter_Li                      : constant Unicode_Char := 16#13B5#;
   Cherokee_Letter_Lo                      : constant Unicode_Char := 16#13B6#;
   Cherokee_Letter_Lu                      : constant Unicode_Char := 16#13B7#;
   Cherokee_Letter_Lv                      : constant Unicode_Char := 16#13B8#;
   Cherokee_Letter_Ma                      : constant Unicode_Char := 16#13B9#;
   Cherokee_Letter_Me                      : constant Unicode_Char := 16#13BA#;
   Cherokee_Letter_Mi                      : constant Unicode_Char := 16#13BB#;
   Cherokee_Letter_Mo                      : constant Unicode_Char := 16#13BC#;
   Cherokee_Letter_Mu                      : constant Unicode_Char := 16#13BD#;
   Cherokee_Letter_Na                      : constant Unicode_Char := 16#13BE#;
   Cherokee_Letter_Hna                     : constant Unicode_Char := 16#13BF#;
   Cherokee_Letter_Nah                     : constant Unicode_Char := 16#13C0#;
   Cherokee_Letter_Ne                      : constant Unicode_Char := 16#13C1#;
   Cherokee_Letter_Ni                      : constant Unicode_Char := 16#13C2#;
   Cherokee_Letter_No                      : constant Unicode_Char := 16#13C3#;
   Cherokee_Letter_Nu                      : constant Unicode_Char := 16#13C4#;
   Cherokee_Letter_Nv                      : constant Unicode_Char := 16#13C5#;
   Cherokee_Letter_Qua                     : constant Unicode_Char := 16#13C6#;
   Cherokee_Letter_Que                     : constant Unicode_Char := 16#13C7#;
   Cherokee_Letter_Qui                     : constant Unicode_Char := 16#13C8#;
   Cherokee_Letter_Quo                     : constant Unicode_Char := 16#13C9#;
   Cherokee_Letter_Quu                     : constant Unicode_Char := 16#13CA#;
   Cherokee_Letter_Quv                     : constant Unicode_Char := 16#13CB#;
   Cherokee_Letter_Sa                      : constant Unicode_Char := 16#13CC#;
   Cherokee_Letter_S                       : constant Unicode_Char := 16#13CD#;
   Cherokee_Letter_Se                      : constant Unicode_Char := 16#13CE#;
   Cherokee_Letter_Si                      : constant Unicode_Char := 16#13CF#;
   Cherokee_Letter_So                      : constant Unicode_Char := 16#13D0#;
   Cherokee_Letter_Su                      : constant Unicode_Char := 16#13D1#;
   Cherokee_Letter_Sv                      : constant Unicode_Char := 16#13D2#;
   Cherokee_Letter_Da                      : constant Unicode_Char := 16#13D3#;
   Cherokee_Letter_Ta                      : constant Unicode_Char := 16#13D4#;
   Cherokee_Letter_De                      : constant Unicode_Char := 16#13D5#;
   Cherokee_Letter_Te                      : constant Unicode_Char := 16#13D6#;
   Cherokee_Letter_Di                      : constant Unicode_Char := 16#13D7#;
   Cherokee_Letter_Ti                      : constant Unicode_Char := 16#13D8#;
   Cherokee_Letter_Do                      : constant Unicode_Char := 16#13D9#;
   Cherokee_Letter_Du                      : constant Unicode_Char := 16#13DA#;
   Cherokee_Letter_Dv                      : constant Unicode_Char := 16#13DB#;
   Cherokee_Letter_Dla                     : constant Unicode_Char := 16#13DC#;
   Cherokee_Letter_Tla                     : constant Unicode_Char := 16#13DD#;
   Cherokee_Letter_Tle                     : constant Unicode_Char := 16#13DE#;
   Cherokee_Letter_Tli                     : constant Unicode_Char := 16#13DF#;
   Cherokee_Letter_Tlo                     : constant Unicode_Char := 16#13E0#;
   Cherokee_Letter_Tlu                     : constant Unicode_Char := 16#13E1#;
   Cherokee_Letter_Tlv                     : constant Unicode_Char := 16#13E2#;
   Cherokee_Letter_Tsa                     : constant Unicode_Char := 16#13E3#;
   Cherokee_Letter_Tse                     : constant Unicode_Char := 16#13E4#;
   Cherokee_Letter_Tsi                     : constant Unicode_Char := 16#13E5#;
   Cherokee_Letter_Tso                     : constant Unicode_Char := 16#13E6#;
   Cherokee_Letter_Tsu                     : constant Unicode_Char := 16#13E7#;
   Cherokee_Letter_Tsv                     : constant Unicode_Char := 16#13E8#;
   Cherokee_Letter_Wa                      : constant Unicode_Char := 16#13E9#;
   Cherokee_Letter_We                      : constant Unicode_Char := 16#13EA#;
   Cherokee_Letter_Wi                      : constant Unicode_Char := 16#13EB#;
   Cherokee_Letter_Wo                      : constant Unicode_Char := 16#13EC#;
   Cherokee_Letter_Wu                      : constant Unicode_Char := 16#13ED#;
   Cherokee_Letter_Wv                      : constant Unicode_Char := 16#13EE#;
   Cherokee_Letter_Ya                      : constant Unicode_Char := 16#13EF#;
   Cherokee_Letter_Ye                      : constant Unicode_Char := 16#13F0#;
   Cherokee_Letter_Yi                      : constant Unicode_Char := 16#13F1#;
   Cherokee_Letter_Yo                      : constant Unicode_Char := 16#13F2#;
   Cherokee_Letter_Yu                      : constant Unicode_Char := 16#13F3#;
   Cherokee_Letter_Yv                      : constant Unicode_Char := 16#13F4#;
   Cherokee_Letter_Mv                      : constant Unicode_Char := 16#13F5#;
   Cherokee_Small_Letter_Ye                : constant Unicode_Char := 16#13F8#;
   Cherokee_Small_Letter_Yi                : constant Unicode_Char := 16#13F9#;
   Cherokee_Small_Letter_Yo                : constant Unicode_Char := 16#13FA#;
   Cherokee_Small_Letter_Yu                : constant Unicode_Char := 16#13FB#;
   Cherokee_Small_Letter_Yv                : constant Unicode_Char := 16#13FC#;
   Cherokee_Small_Letter_Mv                : constant Unicode_Char := 16#13FD#;
end Unicode.Names.Cherokee;
