--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Sharada is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Sharada_Sign_Candrabindu                :
      constant Unicode_Char := 16#11180#;
   Sharada_Sign_Anusvara                   :
      constant Unicode_Char := 16#11181#;
   Sharada_Sign_Visarga                    :
      constant Unicode_Char := 16#11182#;
   Sharada_Letter_A                        :
      constant Unicode_Char := 16#11183#;
   Sharada_Letter_Aa                       :
      constant Unicode_Char := 16#11184#;
   Sharada_Letter_I                        :
      constant Unicode_Char := 16#11185#;
   Sharada_Letter_Ii                       :
      constant Unicode_Char := 16#11186#;
   Sharada_Letter_U                        :
      constant Unicode_Char := 16#11187#;
   Sharada_Letter_Uu                       :
      constant Unicode_Char := 16#11188#;
   Sharada_Letter_Vocalic_R                :
      constant Unicode_Char := 16#11189#;
   Sharada_Letter_Vocalic_Rr               :
      constant Unicode_Char := 16#1118A#;
   Sharada_Letter_Vocalic_L                :
      constant Unicode_Char := 16#1118B#;
   Sharada_Letter_Vocalic_Ll               :
      constant Unicode_Char := 16#1118C#;
   Sharada_Letter_E                        :
      constant Unicode_Char := 16#1118D#;
   Sharada_Letter_Ai                       :
      constant Unicode_Char := 16#1118E#;
   Sharada_Letter_O                        :
      constant Unicode_Char := 16#1118F#;
   Sharada_Letter_Au                       :
      constant Unicode_Char := 16#11190#;
   Sharada_Letter_Ka                       :
      constant Unicode_Char := 16#11191#;
   Sharada_Letter_Kha                      :
      constant Unicode_Char := 16#11192#;
   Sharada_Letter_Ga                       :
      constant Unicode_Char := 16#11193#;
   Sharada_Letter_Gha                      :
      constant Unicode_Char := 16#11194#;
   Sharada_Letter_Nga                      :
      constant Unicode_Char := 16#11195#;
   Sharada_Letter_Ca                       :
      constant Unicode_Char := 16#11196#;
   Sharada_Letter_Cha                      :
      constant Unicode_Char := 16#11197#;
   Sharada_Letter_Ja                       :
      constant Unicode_Char := 16#11198#;
   Sharada_Letter_Jha                      :
      constant Unicode_Char := 16#11199#;
   Sharada_Letter_Nya                      :
      constant Unicode_Char := 16#1119A#;
   Sharada_Letter_Tta                      :
      constant Unicode_Char := 16#1119B#;
   Sharada_Letter_Ttha                     :
      constant Unicode_Char := 16#1119C#;
   Sharada_Letter_Dda                      :
      constant Unicode_Char := 16#1119D#;
   Sharada_Letter_Ddha                     :
      constant Unicode_Char := 16#1119E#;
   Sharada_Letter_Nna                      :
      constant Unicode_Char := 16#1119F#;
   Sharada_Letter_Ta                       :
      constant Unicode_Char := 16#111A0#;
   Sharada_Letter_Tha                      :
      constant Unicode_Char := 16#111A1#;
   Sharada_Letter_Da                       :
      constant Unicode_Char := 16#111A2#;
   Sharada_Letter_Dha                      :
      constant Unicode_Char := 16#111A3#;
   Sharada_Letter_Na                       :
      constant Unicode_Char := 16#111A4#;
   Sharada_Letter_Pa                       :
      constant Unicode_Char := 16#111A5#;
   Sharada_Letter_Pha                      :
      constant Unicode_Char := 16#111A6#;
   Sharada_Letter_Ba                       :
      constant Unicode_Char := 16#111A7#;
   Sharada_Letter_Bha                      :
      constant Unicode_Char := 16#111A8#;
   Sharada_Letter_Ma                       :
      constant Unicode_Char := 16#111A9#;
   Sharada_Letter_Ya                       :
      constant Unicode_Char := 16#111AA#;
   Sharada_Letter_Ra                       :
      constant Unicode_Char := 16#111AB#;
   Sharada_Letter_La                       :
      constant Unicode_Char := 16#111AC#;
   Sharada_Letter_Lla                      :
      constant Unicode_Char := 16#111AD#;
   Sharada_Letter_Va                       :
      constant Unicode_Char := 16#111AE#;
   Sharada_Letter_Sha                      :
      constant Unicode_Char := 16#111AF#;
   Sharada_Letter_Ssa                      :
      constant Unicode_Char := 16#111B0#;
   Sharada_Letter_Sa                       :
      constant Unicode_Char := 16#111B1#;
   Sharada_Letter_Ha                       :
      constant Unicode_Char := 16#111B2#;
   Sharada_Vowel_Sign_Aa                   :
      constant Unicode_Char := 16#111B3#;
   Sharada_Vowel_Sign_I                    :
      constant Unicode_Char := 16#111B4#;
   Sharada_Vowel_Sign_Ii                   :
      constant Unicode_Char := 16#111B5#;
   Sharada_Vowel_Sign_U                    :
      constant Unicode_Char := 16#111B6#;
   Sharada_Vowel_Sign_Uu                   :
      constant Unicode_Char := 16#111B7#;
   Sharada_Vowel_Sign_Vocalic_R            :
      constant Unicode_Char := 16#111B8#;
   Sharada_Vowel_Sign_Vocalic_Rr           :
      constant Unicode_Char := 16#111B9#;
   Sharada_Vowel_Sign_Vocalic_L            :
      constant Unicode_Char := 16#111BA#;
   Sharada_Vowel_Sign_Vocalic_Ll           :
      constant Unicode_Char := 16#111BB#;
   Sharada_Vowel_Sign_E                    :
      constant Unicode_Char := 16#111BC#;
   Sharada_Vowel_Sign_Ai                   :
      constant Unicode_Char := 16#111BD#;
   Sharada_Vowel_Sign_O                    :
      constant Unicode_Char := 16#111BE#;
   Sharada_Vowel_Sign_Au                   :
      constant Unicode_Char := 16#111BF#;
   Sharada_Sign_Virama                     :
      constant Unicode_Char := 16#111C0#;
   Sharada_Sign_Avagraha                   :
      constant Unicode_Char := 16#111C1#;
   Sharada_Sign_Jihvamuliya                :
      constant Unicode_Char := 16#111C2#;
   Sharada_Sign_Upadhmaniya                :
      constant Unicode_Char := 16#111C3#;
   Sharada_Om                              :
      constant Unicode_Char := 16#111C4#;
   Sharada_Danda                           :
      constant Unicode_Char := 16#111C5#;
   Sharada_Double_Danda                    :
      constant Unicode_Char := 16#111C6#;
   Sharada_Abbreviation_Sign               :
      constant Unicode_Char := 16#111C7#;
   Sharada_Separator                       :
      constant Unicode_Char := 16#111C8#;
   Sharada_Sandhi_Mark                     :
      constant Unicode_Char := 16#111C9#;
   Sharada_Sign_Nukta                      :
      constant Unicode_Char := 16#111CA#;
   Sharada_Vowel_Modifier_Mark             :
      constant Unicode_Char := 16#111CB#;
   Sharada_Extra_Short_Vowel_Mark          :
      constant Unicode_Char := 16#111CC#;
   Sharada_Sutra_Mark                      :
      constant Unicode_Char := 16#111CD#;
   Sharada_Digit_Zero                      :
      constant Unicode_Char := 16#111D0#;
   Sharada_Digit_One                       :
      constant Unicode_Char := 16#111D1#;
   Sharada_Digit_Two                       :
      constant Unicode_Char := 16#111D2#;
   Sharada_Digit_Three                     :
      constant Unicode_Char := 16#111D3#;
   Sharada_Digit_Four                      :
      constant Unicode_Char := 16#111D4#;
   Sharada_Digit_Five                      :
      constant Unicode_Char := 16#111D5#;
   Sharada_Digit_Six                       :
      constant Unicode_Char := 16#111D6#;
   Sharada_Digit_Seven                     :
      constant Unicode_Char := 16#111D7#;
   Sharada_Digit_Eight                     :
      constant Unicode_Char := 16#111D8#;
   Sharada_Digit_Nine                      :
      constant Unicode_Char := 16#111D9#;
   Sharada_Ekam                            :
      constant Unicode_Char := 16#111DA#;
   Sharada_Sign_Siddham                    :
      constant Unicode_Char := 16#111DB#;
   Sharada_Headstroke                      :
      constant Unicode_Char := 16#111DC#;
   Sharada_Continuation_Sign               :
      constant Unicode_Char := 16#111DD#;
   Sharada_Section_Mark_1                  :
      constant Unicode_Char := 16#111DE#;
   Sharada_Section_Mark_2                  :
      constant Unicode_Char := 16#111DF#;
end Unicode.Names.Sharada;
