--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Arabic_Present_FormsA is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Arabic_Letter_Alef_Wasla_Isolated_Form  : constant Unicode_Char := 16#FB50#;
   Arabic_Letter_Alef_Wasla_Final_Form     : constant Unicode_Char := 16#FB51#;
   Arabic_Letter_Beeh_Isolated_Form        : constant Unicode_Char := 16#FB52#;
   Arabic_Letter_Beeh_Final_Form           : constant Unicode_Char := 16#FB53#;
   Arabic_Letter_Beeh_Initial_Form         : constant Unicode_Char := 16#FB54#;
   Arabic_Letter_Beeh_Medial_Form          : constant Unicode_Char := 16#FB55#;
   Arabic_Letter_Peh_Isolated_Form         : constant Unicode_Char := 16#FB56#;
   Arabic_Letter_Peh_Final_Form            : constant Unicode_Char := 16#FB57#;
   Arabic_Letter_Peh_Initial_Form          : constant Unicode_Char := 16#FB58#;
   Arabic_Letter_Peh_Medial_Form           : constant Unicode_Char := 16#FB59#;
   Arabic_Letter_Beheh_Isolated_Form       : constant Unicode_Char := 16#FB5A#;
   Arabic_Letter_Beheh_Final_Form          : constant Unicode_Char := 16#FB5B#;
   Arabic_Letter_Beheh_Initial_Form        : constant Unicode_Char := 16#FB5C#;
   Arabic_Letter_Beheh_Medial_Form         : constant Unicode_Char := 16#FB5D#;
   Arabic_Letter_Tteheh_Isolated_Form      : constant Unicode_Char := 16#FB5E#;
   Arabic_Letter_Tteheh_Final_Form         : constant Unicode_Char := 16#FB5F#;
   Arabic_Letter_Tteheh_Initial_Form       : constant Unicode_Char := 16#FB60#;
   Arabic_Letter_Tteheh_Medial_Form        : constant Unicode_Char := 16#FB61#;
   Arabic_Letter_Teheh_Isolated_Form       : constant Unicode_Char := 16#FB62#;
   Arabic_Letter_Teheh_Final_Form          : constant Unicode_Char := 16#FB63#;
   Arabic_Letter_Teheh_Initial_Form        : constant Unicode_Char := 16#FB64#;
   Arabic_Letter_Teheh_Medial_Form         : constant Unicode_Char := 16#FB65#;
   Arabic_Letter_Tteh_Isolated_Form        : constant Unicode_Char := 16#FB66#;
   Arabic_Letter_Tteh_Final_Form           : constant Unicode_Char := 16#FB67#;
   Arabic_Letter_Tteh_Initial_Form         : constant Unicode_Char := 16#FB68#;
   Arabic_Letter_Tteh_Medial_Form          : constant Unicode_Char := 16#FB69#;
   Arabic_Letter_Veh_Isolated_Form         : constant Unicode_Char := 16#FB6A#;
   Arabic_Letter_Veh_Final_Form            : constant Unicode_Char := 16#FB6B#;
   Arabic_Letter_Veh_Initial_Form          : constant Unicode_Char := 16#FB6C#;
   Arabic_Letter_Veh_Medial_Form           : constant Unicode_Char := 16#FB6D#;
   Arabic_Letter_Peheh_Isolated_Form       : constant Unicode_Char := 16#FB6E#;
   Arabic_Letter_Peheh_Final_Form          : constant Unicode_Char := 16#FB6F#;
   Arabic_Letter_Peheh_Initial_Form        : constant Unicode_Char := 16#FB70#;
   Arabic_Letter_Peheh_Medial_Form         : constant Unicode_Char := 16#FB71#;
   Arabic_Letter_Dyeh_Isolated_Form        : constant Unicode_Char := 16#FB72#;
   Arabic_Letter_Dyeh_Final_Form           : constant Unicode_Char := 16#FB73#;
   Arabic_Letter_Dyeh_Initial_Form         : constant Unicode_Char := 16#FB74#;
   Arabic_Letter_Dyeh_Medial_Form          : constant Unicode_Char := 16#FB75#;
   Arabic_Letter_Nyeh_Isolated_Form        : constant Unicode_Char := 16#FB76#;
   Arabic_Letter_Nyeh_Final_Form           : constant Unicode_Char := 16#FB77#;
   Arabic_Letter_Nyeh_Initial_Form         : constant Unicode_Char := 16#FB78#;
   Arabic_Letter_Nyeh_Medial_Form          : constant Unicode_Char := 16#FB79#;
   Arabic_Letter_Tcheh_Isolated_Form       : constant Unicode_Char := 16#FB7A#;
   Arabic_Letter_Tcheh_Final_Form          : constant Unicode_Char := 16#FB7B#;
   Arabic_Letter_Tcheh_Initial_Form        : constant Unicode_Char := 16#FB7C#;
   Arabic_Letter_Tcheh_Medial_Form         : constant Unicode_Char := 16#FB7D#;
   Arabic_Letter_Tcheheh_Isolated_Form     : constant Unicode_Char := 16#FB7E#;
   Arabic_Letter_Tcheheh_Final_Form        : constant Unicode_Char := 16#FB7F#;
   Arabic_Letter_Tcheheh_Initial_Form      : constant Unicode_Char := 16#FB80#;
   Arabic_Letter_Tcheheh_Medial_Form       : constant Unicode_Char := 16#FB81#;
   Arabic_Letter_Ddahal_Isolated_Form      : constant Unicode_Char := 16#FB82#;
   Arabic_Letter_Ddahal_Final_Form         : constant Unicode_Char := 16#FB83#;
   Arabic_Letter_Dahal_Isolated_Form       : constant Unicode_Char := 16#FB84#;
   Arabic_Letter_Dahal_Final_Form          : constant Unicode_Char := 16#FB85#;
   Arabic_Letter_Dul_Isolated_Form         : constant Unicode_Char := 16#FB86#;
   Arabic_Letter_Dul_Final_Form            : constant Unicode_Char := 16#FB87#;
   Arabic_Letter_Ddal_Isolated_Form        : constant Unicode_Char := 16#FB88#;
   Arabic_Letter_Ddal_Final_Form           : constant Unicode_Char := 16#FB89#;
   Arabic_Letter_Jeh_Isolated_Form         : constant Unicode_Char := 16#FB8A#;
   Arabic_Letter_Jeh_Final_Form            : constant Unicode_Char := 16#FB8B#;
   Arabic_Letter_Rreh_Isolated_Form        : constant Unicode_Char := 16#FB8C#;
   Arabic_Letter_Rreh_Final_Form           : constant Unicode_Char := 16#FB8D#;
   Arabic_Letter_Keheh_Isolated_Form       : constant Unicode_Char := 16#FB8E#;
   Arabic_Letter_Keheh_Final_Form          : constant Unicode_Char := 16#FB8F#;
   Arabic_Letter_Keheh_Initial_Form        : constant Unicode_Char := 16#FB90#;
   Arabic_Letter_Keheh_Medial_Form         : constant Unicode_Char := 16#FB91#;
   Arabic_Letter_Gaf_Isolated_Form         : constant Unicode_Char := 16#FB92#;
   Arabic_Letter_Gaf_Final_Form            : constant Unicode_Char := 16#FB93#;
   Arabic_Letter_Gaf_Initial_Form          : constant Unicode_Char := 16#FB94#;
   Arabic_Letter_Gaf_Medial_Form           : constant Unicode_Char := 16#FB95#;
   Arabic_Letter_Gueh_Isolated_Form        : constant Unicode_Char := 16#FB96#;
   Arabic_Letter_Gueh_Final_Form           : constant Unicode_Char := 16#FB97#;
   Arabic_Letter_Gueh_Initial_Form         : constant Unicode_Char := 16#FB98#;
   Arabic_Letter_Gueh_Medial_Form          : constant Unicode_Char := 16#FB99#;
   Arabic_Letter_Ngoeh_Isolated_Form       : constant Unicode_Char := 16#FB9A#;
   Arabic_Letter_Ngoeh_Final_Form          : constant Unicode_Char := 16#FB9B#;
   Arabic_Letter_Ngoeh_Initial_Form        : constant Unicode_Char := 16#FB9C#;
   Arabic_Letter_Ngoeh_Medial_Form         : constant Unicode_Char := 16#FB9D#;
   Arabic_Letter_Noon_Ghunna_Isolated_Form : constant Unicode_Char := 16#FB9E#;
   Arabic_Letter_Noon_Ghunna_Final_Form    : constant Unicode_Char := 16#FB9F#;
   Arabic_Letter_Rnoon_Isolated_Form       : constant Unicode_Char := 16#FBA0#;
   Arabic_Letter_Rnoon_Final_Form          : constant Unicode_Char := 16#FBA1#;
   Arabic_Letter_Rnoon_Initial_Form        : constant Unicode_Char := 16#FBA2#;
   Arabic_Letter_Rnoon_Medial_Form         : constant Unicode_Char := 16#FBA3#;
   Arabic_Letter_Heh_With_Yeh_Above_Isolated_Form :
      constant Unicode_Char := 16#FBA4#;
   Arabic_Letter_Heh_With_Yeh_Above_Final_Form :
      constant Unicode_Char := 16#FBA5#;
   Arabic_Letter_Heh_Goal_Isolated_Form    : constant Unicode_Char := 16#FBA6#;
   Arabic_Letter_Heh_Goal_Final_Form       : constant Unicode_Char := 16#FBA7#;
   Arabic_Letter_Heh_Goal_Initial_Form     : constant Unicode_Char := 16#FBA8#;
   Arabic_Letter_Heh_Goal_Medial_Form      : constant Unicode_Char := 16#FBA9#;
   Arabic_Letter_Heh_Doachashmee_Isolated_Form :
      constant Unicode_Char := 16#FBAA#;
   Arabic_Letter_Heh_Doachashmee_Final_Form :
      constant Unicode_Char := 16#FBAB#;
   Arabic_Letter_Heh_Doachashmee_Initial_Form :
      constant Unicode_Char := 16#FBAC#;
   Arabic_Letter_Heh_Doachashmee_Medial_Form :
      constant Unicode_Char := 16#FBAD#;
   Arabic_Letter_Yeh_Barree_Isolated_Form  : constant Unicode_Char := 16#FBAE#;
   Arabic_Letter_Yeh_Barree_Final_Form     : constant Unicode_Char := 16#FBAF#;
   Arabic_Letter_Yeh_Barree_With_Hamza_Above_Isolated_Form :
      constant Unicode_Char := 16#FBB0#;
   Arabic_Letter_Yeh_Barree_With_Hamza_Above_Final_Form :
      constant Unicode_Char := 16#FBB1#;
   Arabic_Symbol_Dot_Above                 : constant Unicode_Char := 16#FBB2#;
   Arabic_Symbol_Dot_Below                 : constant Unicode_Char := 16#FBB3#;
   Arabic_Symbol_Two_Dots_Above            : constant Unicode_Char := 16#FBB4#;
   Arabic_Symbol_Two_Dots_Below            : constant Unicode_Char := 16#FBB5#;
   Arabic_Symbol_Three_Dots_Above          : constant Unicode_Char := 16#FBB6#;
   Arabic_Symbol_Three_Dots_Below          : constant Unicode_Char := 16#FBB7#;
   Arabic_Symbol_Three_Dots_Pointing_Downwards_Above :
      constant Unicode_Char := 16#FBB8#;
   Arabic_Symbol_Three_Dots_Pointing_Downwards_Below :
      constant Unicode_Char := 16#FBB9#;
   Arabic_Symbol_Four_Dots_Above           : constant Unicode_Char := 16#FBBA#;
   Arabic_Symbol_Four_Dots_Below           : constant Unicode_Char := 16#FBBB#;
   Arabic_Symbol_Double_Vertical_Bar_Below : constant Unicode_Char := 16#FBBC#;
   Arabic_Symbol_Two_Dots_Vertically_Above : constant Unicode_Char := 16#FBBD#;
   Arabic_Symbol_Two_Dots_Vertically_Below : constant Unicode_Char := 16#FBBE#;
   Arabic_Symbol_Ring                      : constant Unicode_Char := 16#FBBF#;
   Arabic_Symbol_Small_Tah_Above           : constant Unicode_Char := 16#FBC0#;
   Arabic_Symbol_Small_Tah_Below           : constant Unicode_Char := 16#FBC1#;
   Arabic_Letter_Ng_Isolated_Form          : constant Unicode_Char := 16#FBD3#;
   Arabic_Letter_Ng_Final_Form             : constant Unicode_Char := 16#FBD4#;
   Arabic_Letter_Ng_Initial_Form           : constant Unicode_Char := 16#FBD5#;
   Arabic_Letter_Ng_Medial_Form            : constant Unicode_Char := 16#FBD6#;
   Arabic_Letter_U_Isolated_Form           : constant Unicode_Char := 16#FBD7#;
   Arabic_Letter_U_Final_Form              : constant Unicode_Char := 16#FBD8#;
   Arabic_Letter_Oe_Isolated_Form          : constant Unicode_Char := 16#FBD9#;
   Arabic_Letter_Oe_Final_Form             : constant Unicode_Char := 16#FBDA#;
   Arabic_Letter_Yu_Isolated_Form          : constant Unicode_Char := 16#FBDB#;
   Arabic_Letter_Yu_Final_Form             : constant Unicode_Char := 16#FBDC#;
   Arabic_Letter_U_With_Hamza_Above_Isolated_Form :
      constant Unicode_Char := 16#FBDD#;
   Arabic_Letter_Ve_Isolated_Form          : constant Unicode_Char := 16#FBDE#;
   Arabic_Letter_Ve_Final_Form             : constant Unicode_Char := 16#FBDF#;
   Arabic_Letter_Kirghiz_Oe_Isolated_Form  : constant Unicode_Char := 16#FBE0#;
   Arabic_Letter_Kirghiz_Oe_Final_Form     : constant Unicode_Char := 16#FBE1#;
   Arabic_Letter_Kirghiz_Yu_Isolated_Form  : constant Unicode_Char := 16#FBE2#;
   Arabic_Letter_Kirghiz_Yu_Final_Form     : constant Unicode_Char := 16#FBE3#;
   Arabic_Letter_E_Isolated_Form           : constant Unicode_Char := 16#FBE4#;
   Arabic_Letter_E_Final_Form              : constant Unicode_Char := 16#FBE5#;
   Arabic_Letter_E_Initial_Form            : constant Unicode_Char := 16#FBE6#;
   Arabic_Letter_E_Medial_Form             : constant Unicode_Char := 16#FBE7#;
   Arabic_Letter_Uighur_Kazakh_Kirghiz_Alef_Maksura_Initial_Form :
      constant Unicode_Char := 16#FBE8#;
   Arabic_Letter_Uighur_Kazakh_Kirghiz_Alef_Maksura_Medial_Form :
      constant Unicode_Char := 16#FBE9#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Alef_Isolated_Form :
      constant Unicode_Char := 16#FBEA#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Alef_Final_Form :
      constant Unicode_Char := 16#FBEB#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Ae_Isolated_Form :
      constant Unicode_Char := 16#FBEC#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Ae_Final_Form :
      constant Unicode_Char := 16#FBED#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Waw_Isolated_Form :
      constant Unicode_Char := 16#FBEE#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Waw_Final_Form :
      constant Unicode_Char := 16#FBEF#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_U_Isolated_Form :
      constant Unicode_Char := 16#FBF0#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_U_Final_Form :
      constant Unicode_Char := 16#FBF1#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Oe_Isolated_Form :
      constant Unicode_Char := 16#FBF2#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Oe_Final_Form :
      constant Unicode_Char := 16#FBF3#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Yu_Isolated_Form :
      constant Unicode_Char := 16#FBF4#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Yu_Final_Form :
      constant Unicode_Char := 16#FBF5#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_E_Isolated_Form :
      constant Unicode_Char := 16#FBF6#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_E_Final_Form :
      constant Unicode_Char := 16#FBF7#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_E_Initial_Form :
      constant Unicode_Char := 16#FBF8#;
   Arabic_Ligature_Uighur_Kirghiz_Yeh_With_Hamza_Above_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FBF9#;
   Arabic_Ligature_Uighur_Kirghiz_Yeh_With_Hamza_Above_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FBFA#;
   Arabic_Ligature_Uighur_Kirghiz_Yeh_With_Hamza_Above_With_Alef_Maksura_Initial_Form :
      constant Unicode_Char := 16#FBFB#;
   Arabic_Letter_Farsi_Yeh_Isolated_Form   : constant Unicode_Char := 16#FBFC#;
   Arabic_Letter_Farsi_Yeh_Final_Form      : constant Unicode_Char := 16#FBFD#;
   Arabic_Letter_Farsi_Yeh_Initial_Form    : constant Unicode_Char := 16#FBFE#;
   Arabic_Letter_Farsi_Yeh_Medial_Form     : constant Unicode_Char := 16#FBFF#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC00#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC01#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC02#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC03#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC04#;
   Arabic_Ligature_Beh_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC05#;
   Arabic_Ligature_Beh_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC06#;
   Arabic_Ligature_Beh_With_Khah_Isolated_Form :
      constant Unicode_Char := 16#FC07#;
   Arabic_Ligature_Beh_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC08#;
   Arabic_Ligature_Beh_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC09#;
   Arabic_Ligature_Beh_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC0A#;
   Arabic_Ligature_Teh_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC0B#;
   Arabic_Ligature_Teh_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC0C#;
   Arabic_Ligature_Teh_With_Khah_Isolated_Form :
      constant Unicode_Char := 16#FC0D#;
   Arabic_Ligature_Teh_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC0E#;
   Arabic_Ligature_Teh_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC0F#;
   Arabic_Ligature_Teh_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC10#;
   Arabic_Ligature_Theh_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC11#;
   Arabic_Ligature_Theh_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC12#;
   Arabic_Ligature_Theh_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC13#;
   Arabic_Ligature_Theh_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC14#;
   Arabic_Ligature_Jeem_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC15#;
   Arabic_Ligature_Jeem_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC16#;
   Arabic_Ligature_Hah_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC17#;
   Arabic_Ligature_Hah_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC18#;
   Arabic_Ligature_Khah_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC19#;
   Arabic_Ligature_Khah_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC1A#;
   Arabic_Ligature_Khah_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC1B#;
   Arabic_Ligature_Seen_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC1C#;
   Arabic_Ligature_Seen_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC1D#;
   Arabic_Ligature_Seen_With_Khah_Isolated_Form :
      constant Unicode_Char := 16#FC1E#;
   Arabic_Ligature_Seen_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC1F#;
   Arabic_Ligature_Sad_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC20#;
   Arabic_Ligature_Sad_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC21#;
   Arabic_Ligature_Dad_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC22#;
   Arabic_Ligature_Dad_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC23#;
   Arabic_Ligature_Dad_With_Khah_Isolated_Form :
      constant Unicode_Char := 16#FC24#;
   Arabic_Ligature_Dad_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC25#;
   Arabic_Ligature_Tah_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC26#;
   Arabic_Ligature_Tah_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC27#;
   Arabic_Ligature_Zah_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC28#;
   Arabic_Ligature_Ain_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC29#;
   Arabic_Ligature_Ain_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC2A#;
   Arabic_Ligature_Ghain_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC2B#;
   Arabic_Ligature_Ghain_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC2C#;
   Arabic_Ligature_Feh_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC2D#;
   Arabic_Ligature_Feh_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC2E#;
   Arabic_Ligature_Feh_With_Khah_Isolated_Form :
      constant Unicode_Char := 16#FC2F#;
   Arabic_Ligature_Feh_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC30#;
   Arabic_Ligature_Feh_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC31#;
   Arabic_Ligature_Feh_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC32#;
   Arabic_Ligature_Qaf_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC33#;
   Arabic_Ligature_Qaf_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC34#;
   Arabic_Ligature_Qaf_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC35#;
   Arabic_Ligature_Qaf_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC36#;
   Arabic_Ligature_Kaf_With_Alef_Isolated_Form :
      constant Unicode_Char := 16#FC37#;
   Arabic_Ligature_Kaf_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC38#;
   Arabic_Ligature_Kaf_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC39#;
   Arabic_Ligature_Kaf_With_Khah_Isolated_Form :
      constant Unicode_Char := 16#FC3A#;
   Arabic_Ligature_Kaf_With_Lam_Isolated_Form :
      constant Unicode_Char := 16#FC3B#;
   Arabic_Ligature_Kaf_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC3C#;
   Arabic_Ligature_Kaf_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC3D#;
   Arabic_Ligature_Kaf_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC3E#;
   Arabic_Ligature_Lam_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC3F#;
   Arabic_Ligature_Lam_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC40#;
   Arabic_Ligature_Lam_With_Khah_Isolated_Form :
      constant Unicode_Char := 16#FC41#;
   Arabic_Ligature_Lam_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC42#;
   Arabic_Ligature_Lam_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC43#;
   Arabic_Ligature_Lam_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC44#;
   Arabic_Ligature_Meem_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC45#;
   Arabic_Ligature_Meem_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC46#;
   Arabic_Ligature_Meem_With_Khah_Isolated_Form :
      constant Unicode_Char := 16#FC47#;
   Arabic_Ligature_Meem_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC48#;
   Arabic_Ligature_Meem_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC49#;
   Arabic_Ligature_Meem_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC4A#;
   Arabic_Ligature_Noon_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC4B#;
   Arabic_Ligature_Noon_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC4C#;
   Arabic_Ligature_Noon_With_Khah_Isolated_Form :
      constant Unicode_Char := 16#FC4D#;
   Arabic_Ligature_Noon_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC4E#;
   Arabic_Ligature_Noon_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC4F#;
   Arabic_Ligature_Noon_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC50#;
   Arabic_Ligature_Heh_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC51#;
   Arabic_Ligature_Heh_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC52#;
   Arabic_Ligature_Heh_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC53#;
   Arabic_Ligature_Heh_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC54#;
   Arabic_Ligature_Yeh_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FC55#;
   Arabic_Ligature_Yeh_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FC56#;
   Arabic_Ligature_Yeh_With_Khah_Isolated_Form :
      constant Unicode_Char := 16#FC57#;
   Arabic_Ligature_Yeh_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FC58#;
   Arabic_Ligature_Yeh_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FC59#;
   Arabic_Ligature_Yeh_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FC5A#;
   Arabic_Ligature_Thal_With_Superscript_Alef_Isolated_Form :
      constant Unicode_Char := 16#FC5B#;
   Arabic_Ligature_Reh_With_Superscript_Alef_Isolated_Form :
      constant Unicode_Char := 16#FC5C#;
   Arabic_Ligature_Alef_Maksura_With_Superscript_Alef_Isolated_Form :
      constant Unicode_Char := 16#FC5D#;
   Arabic_Ligature_Shadda_With_Dammatan_Isolated_Form :
      constant Unicode_Char := 16#FC5E#;
   Arabic_Ligature_Shadda_With_Kasratan_Isolated_Form :
      constant Unicode_Char := 16#FC5F#;
   Arabic_Ligature_Shadda_With_Fatha_Isolated_Form :
      constant Unicode_Char := 16#FC60#;
   Arabic_Ligature_Shadda_With_Damma_Isolated_Form :
      constant Unicode_Char := 16#FC61#;
   Arabic_Ligature_Shadda_With_Kasra_Isolated_Form :
      constant Unicode_Char := 16#FC62#;
   Arabic_Ligature_Shadda_With_Superscript_Alef_Isolated_Form :
      constant Unicode_Char := 16#FC63#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Reh_Final_Form :
      constant Unicode_Char := 16#FC64#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Zain_Final_Form :
      constant Unicode_Char := 16#FC65#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Meem_Final_Form :
      constant Unicode_Char := 16#FC66#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Noon_Final_Form :
      constant Unicode_Char := 16#FC67#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FC68#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FC69#;
   Arabic_Ligature_Beh_With_Reh_Final_Form : constant Unicode_Char := 16#FC6A#;
   Arabic_Ligature_Beh_With_Zain_Final_Form :
      constant Unicode_Char := 16#FC6B#;
   Arabic_Ligature_Beh_With_Meem_Final_Form :
      constant Unicode_Char := 16#FC6C#;
   Arabic_Ligature_Beh_With_Noon_Final_Form :
      constant Unicode_Char := 16#FC6D#;
   Arabic_Ligature_Beh_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FC6E#;
   Arabic_Ligature_Beh_With_Yeh_Final_Form : constant Unicode_Char := 16#FC6F#;
   Arabic_Ligature_Teh_With_Reh_Final_Form : constant Unicode_Char := 16#FC70#;
   Arabic_Ligature_Teh_With_Zain_Final_Form :
      constant Unicode_Char := 16#FC71#;
   Arabic_Ligature_Teh_With_Meem_Final_Form :
      constant Unicode_Char := 16#FC72#;
   Arabic_Ligature_Teh_With_Noon_Final_Form :
      constant Unicode_Char := 16#FC73#;
   Arabic_Ligature_Teh_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FC74#;
   Arabic_Ligature_Teh_With_Yeh_Final_Form : constant Unicode_Char := 16#FC75#;
   Arabic_Ligature_Theh_With_Reh_Final_Form :
      constant Unicode_Char := 16#FC76#;
   Arabic_Ligature_Theh_With_Zain_Final_Form :
      constant Unicode_Char := 16#FC77#;
   Arabic_Ligature_Theh_With_Meem_Final_Form :
      constant Unicode_Char := 16#FC78#;
   Arabic_Ligature_Theh_With_Noon_Final_Form :
      constant Unicode_Char := 16#FC79#;
   Arabic_Ligature_Theh_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FC7A#;
   Arabic_Ligature_Theh_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FC7B#;
   Arabic_Ligature_Feh_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FC7C#;
   Arabic_Ligature_Feh_With_Yeh_Final_Form : constant Unicode_Char := 16#FC7D#;
   Arabic_Ligature_Qaf_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FC7E#;
   Arabic_Ligature_Qaf_With_Yeh_Final_Form : constant Unicode_Char := 16#FC7F#;
   Arabic_Ligature_Kaf_With_Alef_Final_Form :
      constant Unicode_Char := 16#FC80#;
   Arabic_Ligature_Kaf_With_Lam_Final_Form : constant Unicode_Char := 16#FC81#;
   Arabic_Ligature_Kaf_With_Meem_Final_Form :
      constant Unicode_Char := 16#FC82#;
   Arabic_Ligature_Kaf_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FC83#;
   Arabic_Ligature_Kaf_With_Yeh_Final_Form : constant Unicode_Char := 16#FC84#;
   Arabic_Ligature_Lam_With_Meem_Final_Form :
      constant Unicode_Char := 16#FC85#;
   Arabic_Ligature_Lam_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FC86#;
   Arabic_Ligature_Lam_With_Yeh_Final_Form : constant Unicode_Char := 16#FC87#;
   Arabic_Ligature_Meem_With_Alef_Final_Form :
      constant Unicode_Char := 16#FC88#;
   Arabic_Ligature_Meem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FC89#;
   Arabic_Ligature_Noon_With_Reh_Final_Form :
      constant Unicode_Char := 16#FC8A#;
   Arabic_Ligature_Noon_With_Zain_Final_Form :
      constant Unicode_Char := 16#FC8B#;
   Arabic_Ligature_Noon_With_Meem_Final_Form :
      constant Unicode_Char := 16#FC8C#;
   Arabic_Ligature_Noon_With_Noon_Final_Form :
      constant Unicode_Char := 16#FC8D#;
   Arabic_Ligature_Noon_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FC8E#;
   Arabic_Ligature_Noon_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FC8F#;
   Arabic_Ligature_Alef_Maksura_With_Superscript_Alef_Final_Form :
      constant Unicode_Char := 16#FC90#;
   Arabic_Ligature_Yeh_With_Reh_Final_Form : constant Unicode_Char := 16#FC91#;
   Arabic_Ligature_Yeh_With_Zain_Final_Form :
      constant Unicode_Char := 16#FC92#;
   Arabic_Ligature_Yeh_With_Meem_Final_Form :
      constant Unicode_Char := 16#FC93#;
   Arabic_Ligature_Yeh_With_Noon_Final_Form :
      constant Unicode_Char := 16#FC94#;
   Arabic_Ligature_Yeh_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FC95#;
   Arabic_Ligature_Yeh_With_Yeh_Final_Form : constant Unicode_Char := 16#FC96#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FC97#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FC98#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FC99#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FC9A#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Heh_Initial_Form :
      constant Unicode_Char := 16#FC9B#;
   Arabic_Ligature_Beh_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FC9C#;
   Arabic_Ligature_Beh_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FC9D#;
   Arabic_Ligature_Beh_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FC9E#;
   Arabic_Ligature_Beh_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FC9F#;
   Arabic_Ligature_Beh_With_Heh_Initial_Form :
      constant Unicode_Char := 16#FCA0#;
   Arabic_Ligature_Teh_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCA1#;
   Arabic_Ligature_Teh_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCA2#;
   Arabic_Ligature_Teh_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FCA3#;
   Arabic_Ligature_Teh_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCA4#;
   Arabic_Ligature_Teh_With_Heh_Initial_Form :
      constant Unicode_Char := 16#FCA5#;
   Arabic_Ligature_Theh_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCA6#;
   Arabic_Ligature_Jeem_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCA7#;
   Arabic_Ligature_Jeem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCA8#;
   Arabic_Ligature_Hah_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCA9#;
   Arabic_Ligature_Hah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCAA#;
   Arabic_Ligature_Khah_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCAB#;
   Arabic_Ligature_Khah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCAC#;
   Arabic_Ligature_Seen_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCAD#;
   Arabic_Ligature_Seen_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCAE#;
   Arabic_Ligature_Seen_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FCAF#;
   Arabic_Ligature_Seen_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCB0#;
   Arabic_Ligature_Sad_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCB1#;
   Arabic_Ligature_Sad_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FCB2#;
   Arabic_Ligature_Sad_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCB3#;
   Arabic_Ligature_Dad_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCB4#;
   Arabic_Ligature_Dad_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCB5#;
   Arabic_Ligature_Dad_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FCB6#;
   Arabic_Ligature_Dad_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCB7#;
   Arabic_Ligature_Tah_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCB8#;
   Arabic_Ligature_Zah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCB9#;
   Arabic_Ligature_Ain_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCBA#;
   Arabic_Ligature_Ain_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCBB#;
   Arabic_Ligature_Ghain_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCBC#;
   Arabic_Ligature_Ghain_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCBD#;
   Arabic_Ligature_Feh_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCBE#;
   Arabic_Ligature_Feh_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCBF#;
   Arabic_Ligature_Feh_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FCC0#;
   Arabic_Ligature_Feh_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCC1#;
   Arabic_Ligature_Qaf_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCC2#;
   Arabic_Ligature_Qaf_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCC3#;
   Arabic_Ligature_Kaf_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCC4#;
   Arabic_Ligature_Kaf_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCC5#;
   Arabic_Ligature_Kaf_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FCC6#;
   Arabic_Ligature_Kaf_With_Lam_Initial_Form :
      constant Unicode_Char := 16#FCC7#;
   Arabic_Ligature_Kaf_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCC8#;
   Arabic_Ligature_Lam_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCC9#;
   Arabic_Ligature_Lam_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCCA#;
   Arabic_Ligature_Lam_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FCCB#;
   Arabic_Ligature_Lam_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCCC#;
   Arabic_Ligature_Lam_With_Heh_Initial_Form :
      constant Unicode_Char := 16#FCCD#;
   Arabic_Ligature_Meem_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCCE#;
   Arabic_Ligature_Meem_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCCF#;
   Arabic_Ligature_Meem_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FCD0#;
   Arabic_Ligature_Meem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCD1#;
   Arabic_Ligature_Noon_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCD2#;
   Arabic_Ligature_Noon_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCD3#;
   Arabic_Ligature_Noon_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FCD4#;
   Arabic_Ligature_Noon_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCD5#;
   Arabic_Ligature_Noon_With_Heh_Initial_Form :
      constant Unicode_Char := 16#FCD6#;
   Arabic_Ligature_Heh_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCD7#;
   Arabic_Ligature_Heh_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCD8#;
   Arabic_Ligature_Heh_With_Superscript_Alef_Initial_Form :
      constant Unicode_Char := 16#FCD9#;
   Arabic_Ligature_Yeh_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FCDA#;
   Arabic_Ligature_Yeh_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FCDB#;
   Arabic_Ligature_Yeh_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FCDC#;
   Arabic_Ligature_Yeh_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FCDD#;
   Arabic_Ligature_Yeh_With_Heh_Initial_Form :
      constant Unicode_Char := 16#FCDE#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FCDF#;
   Arabic_Ligature_Yeh_With_Hamza_Above_With_Heh_Medial_Form :
      constant Unicode_Char := 16#FCE0#;
   Arabic_Ligature_Beh_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FCE1#;
   Arabic_Ligature_Beh_With_Heh_Medial_Form :
      constant Unicode_Char := 16#FCE2#;
   Arabic_Ligature_Teh_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FCE3#;
   Arabic_Ligature_Teh_With_Heh_Medial_Form :
      constant Unicode_Char := 16#FCE4#;
   Arabic_Ligature_Theh_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FCE5#;
   Arabic_Ligature_Theh_With_Heh_Medial_Form :
      constant Unicode_Char := 16#FCE6#;
   Arabic_Ligature_Seen_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FCE7#;
   Arabic_Ligature_Seen_With_Heh_Medial_Form :
      constant Unicode_Char := 16#FCE8#;
   Arabic_Ligature_Sheen_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FCE9#;
   Arabic_Ligature_Sheen_With_Heh_Medial_Form :
      constant Unicode_Char := 16#FCEA#;
   Arabic_Ligature_Kaf_With_Lam_Medial_Form :
      constant Unicode_Char := 16#FCEB#;
   Arabic_Ligature_Kaf_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FCEC#;
   Arabic_Ligature_Lam_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FCED#;
   Arabic_Ligature_Noon_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FCEE#;
   Arabic_Ligature_Noon_With_Heh_Medial_Form :
      constant Unicode_Char := 16#FCEF#;
   Arabic_Ligature_Yeh_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FCF0#;
   Arabic_Ligature_Yeh_With_Heh_Medial_Form :
      constant Unicode_Char := 16#FCF1#;
   Arabic_Ligature_Shadda_With_Fatha_Medial_Form :
      constant Unicode_Char := 16#FCF2#;
   Arabic_Ligature_Shadda_With_Damma_Medial_Form :
      constant Unicode_Char := 16#FCF3#;
   Arabic_Ligature_Shadda_With_Kasra_Medial_Form :
      constant Unicode_Char := 16#FCF4#;
   Arabic_Ligature_Tah_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FCF5#;
   Arabic_Ligature_Tah_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FCF6#;
   Arabic_Ligature_Ain_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FCF7#;
   Arabic_Ligature_Ain_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FCF8#;
   Arabic_Ligature_Ghain_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FCF9#;
   Arabic_Ligature_Ghain_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FCFA#;
   Arabic_Ligature_Seen_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FCFB#;
   Arabic_Ligature_Seen_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FCFC#;
   Arabic_Ligature_Sheen_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FCFD#;
   Arabic_Ligature_Sheen_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FCFE#;
   Arabic_Ligature_Hah_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FCFF#;
   Arabic_Ligature_Hah_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FD00#;
   Arabic_Ligature_Jeem_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FD01#;
   Arabic_Ligature_Jeem_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FD02#;
   Arabic_Ligature_Khah_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FD03#;
   Arabic_Ligature_Khah_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FD04#;
   Arabic_Ligature_Sad_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FD05#;
   Arabic_Ligature_Sad_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FD06#;
   Arabic_Ligature_Dad_With_Alef_Maksura_Isolated_Form :
      constant Unicode_Char := 16#FD07#;
   Arabic_Ligature_Dad_With_Yeh_Isolated_Form :
      constant Unicode_Char := 16#FD08#;
   Arabic_Ligature_Sheen_With_Jeem_Isolated_Form :
      constant Unicode_Char := 16#FD09#;
   Arabic_Ligature_Sheen_With_Hah_Isolated_Form :
      constant Unicode_Char := 16#FD0A#;
   Arabic_Ligature_Sheen_With_Khah_Isolated_Form :
      constant Unicode_Char := 16#FD0B#;
   Arabic_Ligature_Sheen_With_Meem_Isolated_Form :
      constant Unicode_Char := 16#FD0C#;
   Arabic_Ligature_Sheen_With_Reh_Isolated_Form :
      constant Unicode_Char := 16#FD0D#;
   Arabic_Ligature_Seen_With_Reh_Isolated_Form :
      constant Unicode_Char := 16#FD0E#;
   Arabic_Ligature_Sad_With_Reh_Isolated_Form :
      constant Unicode_Char := 16#FD0F#;
   Arabic_Ligature_Dad_With_Reh_Isolated_Form :
      constant Unicode_Char := 16#FD10#;
   Arabic_Ligature_Tah_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD11#;
   Arabic_Ligature_Tah_With_Yeh_Final_Form : constant Unicode_Char := 16#FD12#;
   Arabic_Ligature_Ain_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD13#;
   Arabic_Ligature_Ain_With_Yeh_Final_Form : constant Unicode_Char := 16#FD14#;
   Arabic_Ligature_Ghain_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD15#;
   Arabic_Ligature_Ghain_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD16#;
   Arabic_Ligature_Seen_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD17#;
   Arabic_Ligature_Seen_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD18#;
   Arabic_Ligature_Sheen_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD19#;
   Arabic_Ligature_Sheen_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD1A#;
   Arabic_Ligature_Hah_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD1B#;
   Arabic_Ligature_Hah_With_Yeh_Final_Form : constant Unicode_Char := 16#FD1C#;
   Arabic_Ligature_Jeem_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD1D#;
   Arabic_Ligature_Jeem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD1E#;
   Arabic_Ligature_Khah_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD1F#;
   Arabic_Ligature_Khah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD20#;
   Arabic_Ligature_Sad_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD21#;
   Arabic_Ligature_Sad_With_Yeh_Final_Form : constant Unicode_Char := 16#FD22#;
   Arabic_Ligature_Dad_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD23#;
   Arabic_Ligature_Dad_With_Yeh_Final_Form : constant Unicode_Char := 16#FD24#;
   Arabic_Ligature_Sheen_With_Jeem_Final_Form :
      constant Unicode_Char := 16#FD25#;
   Arabic_Ligature_Sheen_With_Hah_Final_Form :
      constant Unicode_Char := 16#FD26#;
   Arabic_Ligature_Sheen_With_Khah_Final_Form :
      constant Unicode_Char := 16#FD27#;
   Arabic_Ligature_Sheen_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD28#;
   Arabic_Ligature_Sheen_With_Reh_Final_Form :
      constant Unicode_Char := 16#FD29#;
   Arabic_Ligature_Seen_With_Reh_Final_Form :
      constant Unicode_Char := 16#FD2A#;
   Arabic_Ligature_Sad_With_Reh_Final_Form : constant Unicode_Char := 16#FD2B#;
   Arabic_Ligature_Dad_With_Reh_Final_Form : constant Unicode_Char := 16#FD2C#;
   Arabic_Ligature_Sheen_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FD2D#;
   Arabic_Ligature_Sheen_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FD2E#;
   Arabic_Ligature_Sheen_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FD2F#;
   Arabic_Ligature_Sheen_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD30#;
   Arabic_Ligature_Seen_With_Heh_Initial_Form :
      constant Unicode_Char := 16#FD31#;
   Arabic_Ligature_Sheen_With_Heh_Initial_Form :
      constant Unicode_Char := 16#FD32#;
   Arabic_Ligature_Tah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD33#;
   Arabic_Ligature_Seen_With_Jeem_Medial_Form :
      constant Unicode_Char := 16#FD34#;
   Arabic_Ligature_Seen_With_Hah_Medial_Form :
      constant Unicode_Char := 16#FD35#;
   Arabic_Ligature_Seen_With_Khah_Medial_Form :
      constant Unicode_Char := 16#FD36#;
   Arabic_Ligature_Sheen_With_Jeem_Medial_Form :
      constant Unicode_Char := 16#FD37#;
   Arabic_Ligature_Sheen_With_Hah_Medial_Form :
      constant Unicode_Char := 16#FD38#;
   Arabic_Ligature_Sheen_With_Khah_Medial_Form :
      constant Unicode_Char := 16#FD39#;
   Arabic_Ligature_Tah_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FD3A#;
   Arabic_Ligature_Zah_With_Meem_Medial_Form :
      constant Unicode_Char := 16#FD3B#;
   Arabic_Ligature_Alef_With_Fathatan_Final_Form :
      constant Unicode_Char := 16#FD3C#;
   Arabic_Ligature_Alef_With_Fathatan_Isolated_Form :
      constant Unicode_Char := 16#FD3D#;
   Ornate_Left_Parenthesis                 : constant Unicode_Char := 16#FD3E#;
   Ornate_Right_Parenthesis                : constant Unicode_Char := 16#FD3F#;
   Arabic_Ligature_Teh_With_Jeem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD50#;
   Arabic_Ligature_Teh_With_Hah_With_Jeem_Final_Form :
      constant Unicode_Char := 16#FD51#;
   Arabic_Ligature_Teh_With_Hah_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FD52#;
   Arabic_Ligature_Teh_With_Hah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD53#;
   Arabic_Ligature_Teh_With_Khah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD54#;
   Arabic_Ligature_Teh_With_Meem_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FD55#;
   Arabic_Ligature_Teh_With_Meem_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FD56#;
   Arabic_Ligature_Teh_With_Meem_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FD57#;
   Arabic_Ligature_Jeem_With_Meem_With_Hah_Final_Form :
      constant Unicode_Char := 16#FD58#;
   Arabic_Ligature_Jeem_With_Meem_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FD59#;
   Arabic_Ligature_Hah_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD5A#;
   Arabic_Ligature_Hah_With_Meem_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD5B#;
   Arabic_Ligature_Seen_With_Hah_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FD5C#;
   Arabic_Ligature_Seen_With_Jeem_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FD5D#;
   Arabic_Ligature_Seen_With_Jeem_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD5E#;
   Arabic_Ligature_Seen_With_Meem_With_Hah_Final_Form :
      constant Unicode_Char := 16#FD5F#;
   Arabic_Ligature_Seen_With_Meem_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FD60#;
   Arabic_Ligature_Seen_With_Meem_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FD61#;
   Arabic_Ligature_Seen_With_Meem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD62#;
   Arabic_Ligature_Seen_With_Meem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD63#;
   Arabic_Ligature_Sad_With_Hah_With_Hah_Final_Form :
      constant Unicode_Char := 16#FD64#;
   Arabic_Ligature_Sad_With_Hah_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FD65#;
   Arabic_Ligature_Sad_With_Meem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD66#;
   Arabic_Ligature_Sheen_With_Hah_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD67#;
   Arabic_Ligature_Sheen_With_Hah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD68#;
   Arabic_Ligature_Sheen_With_Jeem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD69#;
   Arabic_Ligature_Sheen_With_Meem_With_Khah_Final_Form :
      constant Unicode_Char := 16#FD6A#;
   Arabic_Ligature_Sheen_With_Meem_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FD6B#;
   Arabic_Ligature_Sheen_With_Meem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD6C#;
   Arabic_Ligature_Sheen_With_Meem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD6D#;
   Arabic_Ligature_Dad_With_Hah_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD6E#;
   Arabic_Ligature_Dad_With_Khah_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD6F#;
   Arabic_Ligature_Dad_With_Khah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD70#;
   Arabic_Ligature_Tah_With_Meem_With_Hah_Final_Form :
      constant Unicode_Char := 16#FD71#;
   Arabic_Ligature_Tah_With_Meem_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FD72#;
   Arabic_Ligature_Tah_With_Meem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD73#;
   Arabic_Ligature_Tah_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD74#;
   Arabic_Ligature_Ain_With_Jeem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD75#;
   Arabic_Ligature_Ain_With_Meem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD76#;
   Arabic_Ligature_Ain_With_Meem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD77#;
   Arabic_Ligature_Ain_With_Meem_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD78#;
   Arabic_Ligature_Ghain_With_Meem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD79#;
   Arabic_Ligature_Ghain_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD7A#;
   Arabic_Ligature_Ghain_With_Meem_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD7B#;
   Arabic_Ligature_Feh_With_Khah_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD7C#;
   Arabic_Ligature_Feh_With_Khah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD7D#;
   Arabic_Ligature_Qaf_With_Meem_With_Hah_Final_Form :
      constant Unicode_Char := 16#FD7E#;
   Arabic_Ligature_Qaf_With_Meem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD7F#;
   Arabic_Ligature_Lam_With_Hah_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD80#;
   Arabic_Ligature_Lam_With_Hah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD81#;
   Arabic_Ligature_Lam_With_Hah_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD82#;
   Arabic_Ligature_Lam_With_Jeem_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FD83#;
   Arabic_Ligature_Lam_With_Jeem_With_Jeem_Final_Form :
      constant Unicode_Char := 16#FD84#;
   Arabic_Ligature_Lam_With_Khah_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD85#;
   Arabic_Ligature_Lam_With_Khah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD86#;
   Arabic_Ligature_Lam_With_Meem_With_Hah_Final_Form :
      constant Unicode_Char := 16#FD87#;
   Arabic_Ligature_Lam_With_Meem_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FD88#;
   Arabic_Ligature_Meem_With_Hah_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FD89#;
   Arabic_Ligature_Meem_With_Hah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD8A#;
   Arabic_Ligature_Meem_With_Hah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD8B#;
   Arabic_Ligature_Meem_With_Jeem_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FD8C#;
   Arabic_Ligature_Meem_With_Jeem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD8D#;
   Arabic_Ligature_Meem_With_Khah_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FD8E#;
   Arabic_Ligature_Meem_With_Khah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD8F#;
   Arabic_Ligature_Meem_With_Jeem_With_Khah_Initial_Form :
      constant Unicode_Char := 16#FD92#;
   Arabic_Ligature_Heh_With_Meem_With_Jeem_Initial_Form :
      constant Unicode_Char := 16#FD93#;
   Arabic_Ligature_Heh_With_Meem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD94#;
   Arabic_Ligature_Noon_With_Hah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD95#;
   Arabic_Ligature_Noon_With_Hah_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD96#;
   Arabic_Ligature_Noon_With_Jeem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD97#;
   Arabic_Ligature_Noon_With_Jeem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD98#;
   Arabic_Ligature_Noon_With_Jeem_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD99#;
   Arabic_Ligature_Noon_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD9A#;
   Arabic_Ligature_Noon_With_Meem_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FD9B#;
   Arabic_Ligature_Yeh_With_Meem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FD9C#;
   Arabic_Ligature_Yeh_With_Meem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FD9D#;
   Arabic_Ligature_Beh_With_Khah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD9E#;
   Arabic_Ligature_Teh_With_Jeem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FD9F#;
   Arabic_Ligature_Teh_With_Jeem_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FDA0#;
   Arabic_Ligature_Teh_With_Khah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDA1#;
   Arabic_Ligature_Teh_With_Khah_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FDA2#;
   Arabic_Ligature_Teh_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDA3#;
   Arabic_Ligature_Teh_With_Meem_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FDA4#;
   Arabic_Ligature_Jeem_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDA5#;
   Arabic_Ligature_Jeem_With_Hah_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FDA6#;
   Arabic_Ligature_Jeem_With_Meem_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FDA7#;
   Arabic_Ligature_Seen_With_Khah_With_Alef_Maksura_Final_Form :
      constant Unicode_Char := 16#FDA8#;
   Arabic_Ligature_Sad_With_Hah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDA9#;
   Arabic_Ligature_Sheen_With_Hah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDAA#;
   Arabic_Ligature_Dad_With_Hah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDAB#;
   Arabic_Ligature_Lam_With_Jeem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDAC#;
   Arabic_Ligature_Lam_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDAD#;
   Arabic_Ligature_Yeh_With_Hah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDAE#;
   Arabic_Ligature_Yeh_With_Jeem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDAF#;
   Arabic_Ligature_Yeh_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDB0#;
   Arabic_Ligature_Meem_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDB1#;
   Arabic_Ligature_Qaf_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDB2#;
   Arabic_Ligature_Noon_With_Hah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDB3#;
   Arabic_Ligature_Qaf_With_Meem_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FDB4#;
   Arabic_Ligature_Lam_With_Hah_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FDB5#;
   Arabic_Ligature_Ain_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDB6#;
   Arabic_Ligature_Kaf_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDB7#;
   Arabic_Ligature_Noon_With_Jeem_With_Hah_Initial_Form :
      constant Unicode_Char := 16#FDB8#;
   Arabic_Ligature_Meem_With_Khah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDB9#;
   Arabic_Ligature_Lam_With_Jeem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FDBA#;
   Arabic_Ligature_Kaf_With_Meem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FDBB#;
   Arabic_Ligature_Lam_With_Jeem_With_Meem_Final_Form :
      constant Unicode_Char := 16#FDBC#;
   Arabic_Ligature_Noon_With_Jeem_With_Hah_Final_Form :
      constant Unicode_Char := 16#FDBD#;
   Arabic_Ligature_Jeem_With_Hah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDBE#;
   Arabic_Ligature_Hah_With_Jeem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDBF#;
   Arabic_Ligature_Meem_With_Jeem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDC0#;
   Arabic_Ligature_Feh_With_Meem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDC1#;
   Arabic_Ligature_Beh_With_Hah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDC2#;
   Arabic_Ligature_Kaf_With_Meem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FDC3#;
   Arabic_Ligature_Ain_With_Jeem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FDC4#;
   Arabic_Ligature_Sad_With_Meem_With_Meem_Initial_Form :
      constant Unicode_Char := 16#FDC5#;
   Arabic_Ligature_Seen_With_Khah_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDC6#;
   Arabic_Ligature_Noon_With_Jeem_With_Yeh_Final_Form :
      constant Unicode_Char := 16#FDC7#;
   Arabic_Ligature_Salla_Used_As_Koranic_Stop_Sign_Isolated_Form :
      constant Unicode_Char := 16#FDF0#;
   Arabic_Ligature_Qala_Used_As_Koranic_Stop_Sign_Isolated_Form :
      constant Unicode_Char := 16#FDF1#;
   Arabic_Ligature_Allah_Isolated_Form     : constant Unicode_Char := 16#FDF2#;
   Arabic_Ligature_Akbar_Isolated_Form     : constant Unicode_Char := 16#FDF3#;
   Arabic_Ligature_Mohammad_Isolated_Form  : constant Unicode_Char := 16#FDF4#;
   Arabic_Ligature_Salam_Isolated_Form     : constant Unicode_Char := 16#FDF5#;
   Arabic_Ligature_Rasoul_Isolated_Form    : constant Unicode_Char := 16#FDF6#;
   Arabic_Ligature_Alayhe_Isolated_Form    : constant Unicode_Char := 16#FDF7#;
   Arabic_Ligature_Wasallam_Isolated_Form  : constant Unicode_Char := 16#FDF8#;
   Arabic_Ligature_Salla_Isolated_Form     : constant Unicode_Char := 16#FDF9#;
   Arabic_Ligature_Sallallahou_Alayhe_Wasallam :
      constant Unicode_Char := 16#FDFA#;
   Arabic_Ligature_Jallajalalouhou         : constant Unicode_Char := 16#FDFB#;
   Rial_Sign                               : constant Unicode_Char := 16#FDFC#;
   Arabic_Ligature_Bismillah_Ar_Rahman_Ar_Raheem :
      constant Unicode_Char := 16#FDFD#;
end Unicode.Names.Arabic_Present_FormsA;
