--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Sundanese is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Sundanese_Sign_Panyecek                 : constant Unicode_Char := 16#1B80#;
   Sundanese_Sign_Panglayar                : constant Unicode_Char := 16#1B81#;
   Sundanese_Sign_Pangwisad                : constant Unicode_Char := 16#1B82#;
   Sundanese_Letter_A                      : constant Unicode_Char := 16#1B83#;
   Sundanese_Letter_I                      : constant Unicode_Char := 16#1B84#;
   Sundanese_Letter_U                      : constant Unicode_Char := 16#1B85#;
   Sundanese_Letter_Ae                     : constant Unicode_Char := 16#1B86#;
   Sundanese_Letter_O                      : constant Unicode_Char := 16#1B87#;
   Sundanese_Letter_E                      : constant Unicode_Char := 16#1B88#;
   Sundanese_Letter_Eu                     : constant Unicode_Char := 16#1B89#;
   Sundanese_Letter_Ka                     : constant Unicode_Char := 16#1B8A#;
   Sundanese_Letter_Qa                     : constant Unicode_Char := 16#1B8B#;
   Sundanese_Letter_Ga                     : constant Unicode_Char := 16#1B8C#;
   Sundanese_Letter_Nga                    : constant Unicode_Char := 16#1B8D#;
   Sundanese_Letter_Ca                     : constant Unicode_Char := 16#1B8E#;
   Sundanese_Letter_Ja                     : constant Unicode_Char := 16#1B8F#;
   Sundanese_Letter_Za                     : constant Unicode_Char := 16#1B90#;
   Sundanese_Letter_Nya                    : constant Unicode_Char := 16#1B91#;
   Sundanese_Letter_Ta                     : constant Unicode_Char := 16#1B92#;
   Sundanese_Letter_Da                     : constant Unicode_Char := 16#1B93#;
   Sundanese_Letter_Na                     : constant Unicode_Char := 16#1B94#;
   Sundanese_Letter_Pa                     : constant Unicode_Char := 16#1B95#;
   Sundanese_Letter_Fa                     : constant Unicode_Char := 16#1B96#;
   Sundanese_Letter_Va                     : constant Unicode_Char := 16#1B97#;
   Sundanese_Letter_Ba                     : constant Unicode_Char := 16#1B98#;
   Sundanese_Letter_Ma                     : constant Unicode_Char := 16#1B99#;
   Sundanese_Letter_Ya                     : constant Unicode_Char := 16#1B9A#;
   Sundanese_Letter_Ra                     : constant Unicode_Char := 16#1B9B#;
   Sundanese_Letter_La                     : constant Unicode_Char := 16#1B9C#;
   Sundanese_Letter_Wa                     : constant Unicode_Char := 16#1B9D#;
   Sundanese_Letter_Sa                     : constant Unicode_Char := 16#1B9E#;
   Sundanese_Letter_Xa                     : constant Unicode_Char := 16#1B9F#;
   Sundanese_Letter_Ha                     : constant Unicode_Char := 16#1BA0#;
   Sundanese_Consonant_Sign_Pamingkal      : constant Unicode_Char := 16#1BA1#;
   Sundanese_Consonant_Sign_Panyakra       : constant Unicode_Char := 16#1BA2#;
   Sundanese_Consonant_Sign_Panyiku        : constant Unicode_Char := 16#1BA3#;
   Sundanese_Vowel_Sign_Panghulu           : constant Unicode_Char := 16#1BA4#;
   Sundanese_Vowel_Sign_Panyuku            : constant Unicode_Char := 16#1BA5#;
   Sundanese_Vowel_Sign_Panaelaeng         : constant Unicode_Char := 16#1BA6#;
   Sundanese_Vowel_Sign_Panolong           : constant Unicode_Char := 16#1BA7#;
   Sundanese_Vowel_Sign_Pamepet            : constant Unicode_Char := 16#1BA8#;
   Sundanese_Vowel_Sign_Paneuleung         : constant Unicode_Char := 16#1BA9#;
   Sundanese_Sign_Pamaaeh                  : constant Unicode_Char := 16#1BAA#;
   Sundanese_Sign_Virama                   : constant Unicode_Char := 16#1BAB#;
   Sundanese_Consonant_Sign_Pasangan_Ma    : constant Unicode_Char := 16#1BAC#;
   Sundanese_Consonant_Sign_Pasangan_Wa    : constant Unicode_Char := 16#1BAD#;
   Sundanese_Letter_Kha                    : constant Unicode_Char := 16#1BAE#;
   Sundanese_Letter_Sya                    : constant Unicode_Char := 16#1BAF#;
   Sundanese_Digit_Zero                    : constant Unicode_Char := 16#1BB0#;
   Sundanese_Digit_One                     : constant Unicode_Char := 16#1BB1#;
   Sundanese_Digit_Two                     : constant Unicode_Char := 16#1BB2#;
   Sundanese_Digit_Three                   : constant Unicode_Char := 16#1BB3#;
   Sundanese_Digit_Four                    : constant Unicode_Char := 16#1BB4#;
   Sundanese_Digit_Five                    : constant Unicode_Char := 16#1BB5#;
   Sundanese_Digit_Six                     : constant Unicode_Char := 16#1BB6#;
   Sundanese_Digit_Seven                   : constant Unicode_Char := 16#1BB7#;
   Sundanese_Digit_Eight                   : constant Unicode_Char := 16#1BB8#;
   Sundanese_Digit_Nine                    : constant Unicode_Char := 16#1BB9#;
   Sundanese_Avagraha                      : constant Unicode_Char := 16#1BBA#;
   Sundanese_Letter_Reu                    : constant Unicode_Char := 16#1BBB#;
   Sundanese_Letter_Leu                    : constant Unicode_Char := 16#1BBC#;
   Sundanese_Letter_Bha                    : constant Unicode_Char := 16#1BBD#;
   Sundanese_Letter_Final_K                : constant Unicode_Char := 16#1BBE#;
   Sundanese_Letter_Final_M                : constant Unicode_Char := 16#1BBF#;
end Unicode.Names.Sundanese;
