--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Vai is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Vai_Syllable_Ee                         : constant Unicode_Char := 16#A500#;
   Vai_Syllable_Een                        : constant Unicode_Char := 16#A501#;
   Vai_Syllable_Hee                        : constant Unicode_Char := 16#A502#;
   Vai_Syllable_Wee                        : constant Unicode_Char := 16#A503#;
   Vai_Syllable_Ween                       : constant Unicode_Char := 16#A504#;
   Vai_Syllable_Pee                        : constant Unicode_Char := 16#A505#;
   Vai_Syllable_Bhee                       : constant Unicode_Char := 16#A506#;
   Vai_Syllable_Bee                        : constant Unicode_Char := 16#A507#;
   Vai_Syllable_Mbee                       : constant Unicode_Char := 16#A508#;
   Vai_Syllable_Kpee                       : constant Unicode_Char := 16#A509#;
   Vai_Syllable_Mgbee                      : constant Unicode_Char := 16#A50A#;
   Vai_Syllable_Gbee                       : constant Unicode_Char := 16#A50B#;
   Vai_Syllable_Fee                        : constant Unicode_Char := 16#A50C#;
   Vai_Syllable_Vee                        : constant Unicode_Char := 16#A50D#;
   Vai_Syllable_Tee                        : constant Unicode_Char := 16#A50E#;
   Vai_Syllable_Thee                       : constant Unicode_Char := 16#A50F#;
   Vai_Syllable_Dhee                       : constant Unicode_Char := 16#A510#;
   Vai_Syllable_Dhhee                      : constant Unicode_Char := 16#A511#;
   Vai_Syllable_Lee                        : constant Unicode_Char := 16#A512#;
   Vai_Syllable_Ree                        : constant Unicode_Char := 16#A513#;
   Vai_Syllable_Dee                        : constant Unicode_Char := 16#A514#;
   Vai_Syllable_Ndee                       : constant Unicode_Char := 16#A515#;
   Vai_Syllable_See                        : constant Unicode_Char := 16#A516#;
   Vai_Syllable_Shee                       : constant Unicode_Char := 16#A517#;
   Vai_Syllable_Zee                        : constant Unicode_Char := 16#A518#;
   Vai_Syllable_Zhee                       : constant Unicode_Char := 16#A519#;
   Vai_Syllable_Cee                        : constant Unicode_Char := 16#A51A#;
   Vai_Syllable_Jee                        : constant Unicode_Char := 16#A51B#;
   Vai_Syllable_Njee                       : constant Unicode_Char := 16#A51C#;
   Vai_Syllable_Yee                        : constant Unicode_Char := 16#A51D#;
   Vai_Syllable_Kee                        : constant Unicode_Char := 16#A51E#;
   Vai_Syllable_Nggee                      : constant Unicode_Char := 16#A51F#;
   Vai_Syllable_Gee                        : constant Unicode_Char := 16#A520#;
   Vai_Syllable_Mee                        : constant Unicode_Char := 16#A521#;
   Vai_Syllable_Nee                        : constant Unicode_Char := 16#A522#;
   Vai_Syllable_Nyee                       : constant Unicode_Char := 16#A523#;
   Vai_Syllable_I                          : constant Unicode_Char := 16#A524#;
   Vai_Syllable_In                         : constant Unicode_Char := 16#A525#;
   Vai_Syllable_Hi                         : constant Unicode_Char := 16#A526#;
   Vai_Syllable_Hin                        : constant Unicode_Char := 16#A527#;
   Vai_Syllable_Wi                         : constant Unicode_Char := 16#A528#;
   Vai_Syllable_Win                        : constant Unicode_Char := 16#A529#;
   Vai_Syllable_Pi                         : constant Unicode_Char := 16#A52A#;
   Vai_Syllable_Bhi                        : constant Unicode_Char := 16#A52B#;
   Vai_Syllable_Bi                         : constant Unicode_Char := 16#A52C#;
   Vai_Syllable_Mbi                        : constant Unicode_Char := 16#A52D#;
   Vai_Syllable_Kpi                        : constant Unicode_Char := 16#A52E#;
   Vai_Syllable_Mgbi                       : constant Unicode_Char := 16#A52F#;
   Vai_Syllable_Gbi                        : constant Unicode_Char := 16#A530#;
   Vai_Syllable_Fi                         : constant Unicode_Char := 16#A531#;
   Vai_Syllable_Vi                         : constant Unicode_Char := 16#A532#;
   Vai_Syllable_Ti                         : constant Unicode_Char := 16#A533#;
   Vai_Syllable_Thi                        : constant Unicode_Char := 16#A534#;
   Vai_Syllable_Dhi                        : constant Unicode_Char := 16#A535#;
   Vai_Syllable_Dhhi                       : constant Unicode_Char := 16#A536#;
   Vai_Syllable_Li                         : constant Unicode_Char := 16#A537#;
   Vai_Syllable_Ri                         : constant Unicode_Char := 16#A538#;
   Vai_Syllable_Di                         : constant Unicode_Char := 16#A539#;
   Vai_Syllable_Ndi                        : constant Unicode_Char := 16#A53A#;
   Vai_Syllable_Si                         : constant Unicode_Char := 16#A53B#;
   Vai_Syllable_Shi                        : constant Unicode_Char := 16#A53C#;
   Vai_Syllable_Zi                         : constant Unicode_Char := 16#A53D#;
   Vai_Syllable_Zhi                        : constant Unicode_Char := 16#A53E#;
   Vai_Syllable_Ci                         : constant Unicode_Char := 16#A53F#;
   Vai_Syllable_Ji                         : constant Unicode_Char := 16#A540#;
   Vai_Syllable_Nji                        : constant Unicode_Char := 16#A541#;
   Vai_Syllable_Yi                         : constant Unicode_Char := 16#A542#;
   Vai_Syllable_Ki                         : constant Unicode_Char := 16#A543#;
   Vai_Syllable_Nggi                       : constant Unicode_Char := 16#A544#;
   Vai_Syllable_Gi                         : constant Unicode_Char := 16#A545#;
   Vai_Syllable_Mi                         : constant Unicode_Char := 16#A546#;
   Vai_Syllable_Ni                         : constant Unicode_Char := 16#A547#;
   Vai_Syllable_Nyi                        : constant Unicode_Char := 16#A548#;
   Vai_Syllable_A                          : constant Unicode_Char := 16#A549#;
   Vai_Syllable_An                         : constant Unicode_Char := 16#A54A#;
   Vai_Syllable_Ngan                       : constant Unicode_Char := 16#A54B#;
   Vai_Syllable_Ha                         : constant Unicode_Char := 16#A54C#;
   Vai_Syllable_Han                        : constant Unicode_Char := 16#A54D#;
   Vai_Syllable_Wa                         : constant Unicode_Char := 16#A54E#;
   Vai_Syllable_Wan                        : constant Unicode_Char := 16#A54F#;
   Vai_Syllable_Pa                         : constant Unicode_Char := 16#A550#;
   Vai_Syllable_Bha                        : constant Unicode_Char := 16#A551#;
   Vai_Syllable_Ba                         : constant Unicode_Char := 16#A552#;
   Vai_Syllable_Mba                        : constant Unicode_Char := 16#A553#;
   Vai_Syllable_Kpa                        : constant Unicode_Char := 16#A554#;
   Vai_Syllable_Kpan                       : constant Unicode_Char := 16#A555#;
   Vai_Syllable_Mgba                       : constant Unicode_Char := 16#A556#;
   Vai_Syllable_Gba                        : constant Unicode_Char := 16#A557#;
   Vai_Syllable_Fa                         : constant Unicode_Char := 16#A558#;
   Vai_Syllable_Va                         : constant Unicode_Char := 16#A559#;
   Vai_Syllable_Ta                         : constant Unicode_Char := 16#A55A#;
   Vai_Syllable_Tha                        : constant Unicode_Char := 16#A55B#;
   Vai_Syllable_Dha                        : constant Unicode_Char := 16#A55C#;
   Vai_Syllable_Dhha                       : constant Unicode_Char := 16#A55D#;
   Vai_Syllable_La                         : constant Unicode_Char := 16#A55E#;
   Vai_Syllable_Ra                         : constant Unicode_Char := 16#A55F#;
   Vai_Syllable_Da                         : constant Unicode_Char := 16#A560#;
   Vai_Syllable_Nda                        : constant Unicode_Char := 16#A561#;
   Vai_Syllable_Sa                         : constant Unicode_Char := 16#A562#;
   Vai_Syllable_Sha                        : constant Unicode_Char := 16#A563#;
   Vai_Syllable_Za                         : constant Unicode_Char := 16#A564#;
   Vai_Syllable_Zha                        : constant Unicode_Char := 16#A565#;
   Vai_Syllable_Ca                         : constant Unicode_Char := 16#A566#;
   Vai_Syllable_Ja                         : constant Unicode_Char := 16#A567#;
   Vai_Syllable_Nja                        : constant Unicode_Char := 16#A568#;
   Vai_Syllable_Ya                         : constant Unicode_Char := 16#A569#;
   Vai_Syllable_Ka                         : constant Unicode_Char := 16#A56A#;
   Vai_Syllable_Kan                        : constant Unicode_Char := 16#A56B#;
   Vai_Syllable_Ngga                       : constant Unicode_Char := 16#A56C#;
   Vai_Syllable_Ga                         : constant Unicode_Char := 16#A56D#;
   Vai_Syllable_Ma                         : constant Unicode_Char := 16#A56E#;
   Vai_Syllable_Na                         : constant Unicode_Char := 16#A56F#;
   Vai_Syllable_Nya                        : constant Unicode_Char := 16#A570#;
   Vai_Syllable_Oo                         : constant Unicode_Char := 16#A571#;
   Vai_Syllable_Oon                        : constant Unicode_Char := 16#A572#;
   Vai_Syllable_Hoo                        : constant Unicode_Char := 16#A573#;
   Vai_Syllable_Woo                        : constant Unicode_Char := 16#A574#;
   Vai_Syllable_Woon                       : constant Unicode_Char := 16#A575#;
   Vai_Syllable_Poo                        : constant Unicode_Char := 16#A576#;
   Vai_Syllable_Bhoo                       : constant Unicode_Char := 16#A577#;
   Vai_Syllable_Boo                        : constant Unicode_Char := 16#A578#;
   Vai_Syllable_Mboo                       : constant Unicode_Char := 16#A579#;
   Vai_Syllable_Kpoo                       : constant Unicode_Char := 16#A57A#;
   Vai_Syllable_Mgboo                      : constant Unicode_Char := 16#A57B#;
   Vai_Syllable_Gboo                       : constant Unicode_Char := 16#A57C#;
   Vai_Syllable_Foo                        : constant Unicode_Char := 16#A57D#;
   Vai_Syllable_Voo                        : constant Unicode_Char := 16#A57E#;
   Vai_Syllable_Too                        : constant Unicode_Char := 16#A57F#;
   Vai_Syllable_Thoo                       : constant Unicode_Char := 16#A580#;
   Vai_Syllable_Dhoo                       : constant Unicode_Char := 16#A581#;
   Vai_Syllable_Dhhoo                      : constant Unicode_Char := 16#A582#;
   Vai_Syllable_Loo                        : constant Unicode_Char := 16#A583#;
   Vai_Syllable_Roo                        : constant Unicode_Char := 16#A584#;
   Vai_Syllable_Doo                        : constant Unicode_Char := 16#A585#;
   Vai_Syllable_Ndoo                       : constant Unicode_Char := 16#A586#;
   Vai_Syllable_Soo                        : constant Unicode_Char := 16#A587#;
   Vai_Syllable_Shoo                       : constant Unicode_Char := 16#A588#;
   Vai_Syllable_Zoo                        : constant Unicode_Char := 16#A589#;
   Vai_Syllable_Zhoo                       : constant Unicode_Char := 16#A58A#;
   Vai_Syllable_Coo                        : constant Unicode_Char := 16#A58B#;
   Vai_Syllable_Joo                        : constant Unicode_Char := 16#A58C#;
   Vai_Syllable_Njoo                       : constant Unicode_Char := 16#A58D#;
   Vai_Syllable_Yoo                        : constant Unicode_Char := 16#A58E#;
   Vai_Syllable_Koo                        : constant Unicode_Char := 16#A58F#;
   Vai_Syllable_Nggoo                      : constant Unicode_Char := 16#A590#;
   Vai_Syllable_Goo                        : constant Unicode_Char := 16#A591#;
   Vai_Syllable_Moo                        : constant Unicode_Char := 16#A592#;
   Vai_Syllable_Noo                        : constant Unicode_Char := 16#A593#;
   Vai_Syllable_Nyoo                       : constant Unicode_Char := 16#A594#;
   Vai_Syllable_U                          : constant Unicode_Char := 16#A595#;
   Vai_Syllable_Un                         : constant Unicode_Char := 16#A596#;
   Vai_Syllable_Hu                         : constant Unicode_Char := 16#A597#;
   Vai_Syllable_Hun                        : constant Unicode_Char := 16#A598#;
   Vai_Syllable_Wu                         : constant Unicode_Char := 16#A599#;
   Vai_Syllable_Wun                        : constant Unicode_Char := 16#A59A#;
   Vai_Syllable_Pu                         : constant Unicode_Char := 16#A59B#;
   Vai_Syllable_Bhu                        : constant Unicode_Char := 16#A59C#;
   Vai_Syllable_Bu                         : constant Unicode_Char := 16#A59D#;
   Vai_Syllable_Mbu                        : constant Unicode_Char := 16#A59E#;
   Vai_Syllable_Kpu                        : constant Unicode_Char := 16#A59F#;
   Vai_Syllable_Mgbu                       : constant Unicode_Char := 16#A5A0#;
   Vai_Syllable_Gbu                        : constant Unicode_Char := 16#A5A1#;
   Vai_Syllable_Fu                         : constant Unicode_Char := 16#A5A2#;
   Vai_Syllable_Vu                         : constant Unicode_Char := 16#A5A3#;
   Vai_Syllable_Tu                         : constant Unicode_Char := 16#A5A4#;
   Vai_Syllable_Thu                        : constant Unicode_Char := 16#A5A5#;
   Vai_Syllable_Dhu                        : constant Unicode_Char := 16#A5A6#;
   Vai_Syllable_Dhhu                       : constant Unicode_Char := 16#A5A7#;
   Vai_Syllable_Lu                         : constant Unicode_Char := 16#A5A8#;
   Vai_Syllable_Ru                         : constant Unicode_Char := 16#A5A9#;
   Vai_Syllable_Du                         : constant Unicode_Char := 16#A5AA#;
   Vai_Syllable_Ndu                        : constant Unicode_Char := 16#A5AB#;
   Vai_Syllable_Su                         : constant Unicode_Char := 16#A5AC#;
   Vai_Syllable_Shu                        : constant Unicode_Char := 16#A5AD#;
   Vai_Syllable_Zu                         : constant Unicode_Char := 16#A5AE#;
   Vai_Syllable_Zhu                        : constant Unicode_Char := 16#A5AF#;
   Vai_Syllable_Cu                         : constant Unicode_Char := 16#A5B0#;
   Vai_Syllable_Ju                         : constant Unicode_Char := 16#A5B1#;
   Vai_Syllable_Nju                        : constant Unicode_Char := 16#A5B2#;
   Vai_Syllable_Yu                         : constant Unicode_Char := 16#A5B3#;
   Vai_Syllable_Ku                         : constant Unicode_Char := 16#A5B4#;
   Vai_Syllable_Nggu                       : constant Unicode_Char := 16#A5B5#;
   Vai_Syllable_Gu                         : constant Unicode_Char := 16#A5B6#;
   Vai_Syllable_Mu                         : constant Unicode_Char := 16#A5B7#;
   Vai_Syllable_Nu                         : constant Unicode_Char := 16#A5B8#;
   Vai_Syllable_Nyu                        : constant Unicode_Char := 16#A5B9#;
   Vai_Syllable_O                          : constant Unicode_Char := 16#A5BA#;
   Vai_Syllable_On                         : constant Unicode_Char := 16#A5BB#;
   Vai_Syllable_Ngon                       : constant Unicode_Char := 16#A5BC#;
   Vai_Syllable_Ho                         : constant Unicode_Char := 16#A5BD#;
   Vai_Syllable_Hon                        : constant Unicode_Char := 16#A5BE#;
   Vai_Syllable_Wo                         : constant Unicode_Char := 16#A5BF#;
   Vai_Syllable_Won                        : constant Unicode_Char := 16#A5C0#;
   Vai_Syllable_Po                         : constant Unicode_Char := 16#A5C1#;
   Vai_Syllable_Bho                        : constant Unicode_Char := 16#A5C2#;
   Vai_Syllable_Bo                         : constant Unicode_Char := 16#A5C3#;
   Vai_Syllable_Mbo                        : constant Unicode_Char := 16#A5C4#;
   Vai_Syllable_Kpo                        : constant Unicode_Char := 16#A5C5#;
   Vai_Syllable_Mgbo                       : constant Unicode_Char := 16#A5C6#;
   Vai_Syllable_Gbo                        : constant Unicode_Char := 16#A5C7#;
   Vai_Syllable_Gbon                       : constant Unicode_Char := 16#A5C8#;
   Vai_Syllable_Fo                         : constant Unicode_Char := 16#A5C9#;
   Vai_Syllable_Vo                         : constant Unicode_Char := 16#A5CA#;
   Vai_Syllable_To                         : constant Unicode_Char := 16#A5CB#;
   Vai_Syllable_Tho                        : constant Unicode_Char := 16#A5CC#;
   Vai_Syllable_Dho                        : constant Unicode_Char := 16#A5CD#;
   Vai_Syllable_Dhho                       : constant Unicode_Char := 16#A5CE#;
   Vai_Syllable_Lo                         : constant Unicode_Char := 16#A5CF#;
   Vai_Syllable_Ro                         : constant Unicode_Char := 16#A5D0#;
   Vai_Syllable_Do                         : constant Unicode_Char := 16#A5D1#;
   Vai_Syllable_Ndo                        : constant Unicode_Char := 16#A5D2#;
   Vai_Syllable_So                         : constant Unicode_Char := 16#A5D3#;
   Vai_Syllable_Sho                        : constant Unicode_Char := 16#A5D4#;
   Vai_Syllable_Zo                         : constant Unicode_Char := 16#A5D5#;
   Vai_Syllable_Zho                        : constant Unicode_Char := 16#A5D6#;
   Vai_Syllable_Co                         : constant Unicode_Char := 16#A5D7#;
   Vai_Syllable_Jo                         : constant Unicode_Char := 16#A5D8#;
   Vai_Syllable_Njo                        : constant Unicode_Char := 16#A5D9#;
   Vai_Syllable_Yo                         : constant Unicode_Char := 16#A5DA#;
   Vai_Syllable_Ko                         : constant Unicode_Char := 16#A5DB#;
   Vai_Syllable_Nggo                       : constant Unicode_Char := 16#A5DC#;
   Vai_Syllable_Go                         : constant Unicode_Char := 16#A5DD#;
   Vai_Syllable_Mo                         : constant Unicode_Char := 16#A5DE#;
   Vai_Syllable_No                         : constant Unicode_Char := 16#A5DF#;
   Vai_Syllable_Nyo                        : constant Unicode_Char := 16#A5E0#;
   Vai_Syllable_E                          : constant Unicode_Char := 16#A5E1#;
   Vai_Syllable_En                         : constant Unicode_Char := 16#A5E2#;
   Vai_Syllable_Ngen                       : constant Unicode_Char := 16#A5E3#;
   Vai_Syllable_He                         : constant Unicode_Char := 16#A5E4#;
   Vai_Syllable_Hen                        : constant Unicode_Char := 16#A5E5#;
   Vai_Syllable_We                         : constant Unicode_Char := 16#A5E6#;
   Vai_Syllable_Wen                        : constant Unicode_Char := 16#A5E7#;
   Vai_Syllable_Pe                         : constant Unicode_Char := 16#A5E8#;
   Vai_Syllable_Bhe                        : constant Unicode_Char := 16#A5E9#;
   Vai_Syllable_Be                         : constant Unicode_Char := 16#A5EA#;
   Vai_Syllable_Mbe                        : constant Unicode_Char := 16#A5EB#;
   Vai_Syllable_Kpe                        : constant Unicode_Char := 16#A5EC#;
   Vai_Syllable_Kpen                       : constant Unicode_Char := 16#A5ED#;
   Vai_Syllable_Mgbe                       : constant Unicode_Char := 16#A5EE#;
   Vai_Syllable_Gbe                        : constant Unicode_Char := 16#A5EF#;
   Vai_Syllable_Gben                       : constant Unicode_Char := 16#A5F0#;
   Vai_Syllable_Fe                         : constant Unicode_Char := 16#A5F1#;
   Vai_Syllable_Ve                         : constant Unicode_Char := 16#A5F2#;
   Vai_Syllable_Te                         : constant Unicode_Char := 16#A5F3#;
   Vai_Syllable_The                        : constant Unicode_Char := 16#A5F4#;
   Vai_Syllable_Dhe                        : constant Unicode_Char := 16#A5F5#;
   Vai_Syllable_Dhhe                       : constant Unicode_Char := 16#A5F6#;
   Vai_Syllable_Le                         : constant Unicode_Char := 16#A5F7#;
   Vai_Syllable_Re                         : constant Unicode_Char := 16#A5F8#;
   Vai_Syllable_De                         : constant Unicode_Char := 16#A5F9#;
   Vai_Syllable_Nde                        : constant Unicode_Char := 16#A5FA#;
   Vai_Syllable_Se                         : constant Unicode_Char := 16#A5FB#;
   Vai_Syllable_She                        : constant Unicode_Char := 16#A5FC#;
   Vai_Syllable_Ze                         : constant Unicode_Char := 16#A5FD#;
   Vai_Syllable_Zhe                        : constant Unicode_Char := 16#A5FE#;
   Vai_Syllable_Ce                         : constant Unicode_Char := 16#A5FF#;
   Vai_Syllable_Je                         : constant Unicode_Char := 16#A600#;
   Vai_Syllable_Nje                        : constant Unicode_Char := 16#A601#;
   Vai_Syllable_Ye                         : constant Unicode_Char := 16#A602#;
   Vai_Syllable_Ke                         : constant Unicode_Char := 16#A603#;
   Vai_Syllable_Ngge                       : constant Unicode_Char := 16#A604#;
   Vai_Syllable_Nggen                      : constant Unicode_Char := 16#A605#;
   Vai_Syllable_Ge                         : constant Unicode_Char := 16#A606#;
   Vai_Syllable_Gen                        : constant Unicode_Char := 16#A607#;
   Vai_Syllable_Me                         : constant Unicode_Char := 16#A608#;
   Vai_Syllable_Ne                         : constant Unicode_Char := 16#A609#;
   Vai_Syllable_Nye                        : constant Unicode_Char := 16#A60A#;
   Vai_Syllable_Ng                         : constant Unicode_Char := 16#A60B#;
   Vai_Syllable_Lengthener                 : constant Unicode_Char := 16#A60C#;
   Vai_Comma                               : constant Unicode_Char := 16#A60D#;
   Vai_Full_Stop                           : constant Unicode_Char := 16#A60E#;
   Vai_Question_Mark                       : constant Unicode_Char := 16#A60F#;
   Vai_Syllable_Ndole_Fa                   : constant Unicode_Char := 16#A610#;
   Vai_Syllable_Ndole_Ka                   : constant Unicode_Char := 16#A611#;
   Vai_Syllable_Ndole_Soo                  : constant Unicode_Char := 16#A612#;
   Vai_Symbol_Feeng                        : constant Unicode_Char := 16#A613#;
   Vai_Symbol_Keeng                        : constant Unicode_Char := 16#A614#;
   Vai_Symbol_Ting                         : constant Unicode_Char := 16#A615#;
   Vai_Symbol_Nii                          : constant Unicode_Char := 16#A616#;
   Vai_Symbol_Bang                         : constant Unicode_Char := 16#A617#;
   Vai_Symbol_Faa                          : constant Unicode_Char := 16#A618#;
   Vai_Symbol_Taa                          : constant Unicode_Char := 16#A619#;
   Vai_Symbol_Dang                         : constant Unicode_Char := 16#A61A#;
   Vai_Symbol_Doong                        : constant Unicode_Char := 16#A61B#;
   Vai_Symbol_Kung                         : constant Unicode_Char := 16#A61C#;
   Vai_Symbol_Tong                         : constant Unicode_Char := 16#A61D#;
   Vai_Symbol_Do_O                         : constant Unicode_Char := 16#A61E#;
   Vai_Symbol_Jong                         : constant Unicode_Char := 16#A61F#;
   Vai_Digit_Zero                          : constant Unicode_Char := 16#A620#;
   Vai_Digit_One                           : constant Unicode_Char := 16#A621#;
   Vai_Digit_Two                           : constant Unicode_Char := 16#A622#;
   Vai_Digit_Three                         : constant Unicode_Char := 16#A623#;
   Vai_Digit_Four                          : constant Unicode_Char := 16#A624#;
   Vai_Digit_Five                          : constant Unicode_Char := 16#A625#;
   Vai_Digit_Six                           : constant Unicode_Char := 16#A626#;
   Vai_Digit_Seven                         : constant Unicode_Char := 16#A627#;
   Vai_Digit_Eight                         : constant Unicode_Char := 16#A628#;
   Vai_Digit_Nine                          : constant Unicode_Char := 16#A629#;
   Vai_Syllable_Ndole_Ma                   : constant Unicode_Char := 16#A62A#;
   Vai_Syllable_Ndole_Do                   : constant Unicode_Char := 16#A62B#;
end Unicode.Names.Vai;
