--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Pahawh_Hmong is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Pahawh_Hmong_Vowel_Keeb                 :
      constant Unicode_Char := 16#16B00#;
   Pahawh_Hmong_Vowel_Keev                 :
      constant Unicode_Char := 16#16B01#;
   Pahawh_Hmong_Vowel_Kib                  :
      constant Unicode_Char := 16#16B02#;
   Pahawh_Hmong_Vowel_Kiv                  :
      constant Unicode_Char := 16#16B03#;
   Pahawh_Hmong_Vowel_Kaub                 :
      constant Unicode_Char := 16#16B04#;
   Pahawh_Hmong_Vowel_Kauv                 :
      constant Unicode_Char := 16#16B05#;
   Pahawh_Hmong_Vowel_Kub                  :
      constant Unicode_Char := 16#16B06#;
   Pahawh_Hmong_Vowel_Kuv                  :
      constant Unicode_Char := 16#16B07#;
   Pahawh_Hmong_Vowel_Keb                  :
      constant Unicode_Char := 16#16B08#;
   Pahawh_Hmong_Vowel_Kev                  :
      constant Unicode_Char := 16#16B09#;
   Pahawh_Hmong_Vowel_Kaib                 :
      constant Unicode_Char := 16#16B0A#;
   Pahawh_Hmong_Vowel_Kaiv                 :
      constant Unicode_Char := 16#16B0B#;
   Pahawh_Hmong_Vowel_Koob                 :
      constant Unicode_Char := 16#16B0C#;
   Pahawh_Hmong_Vowel_Koov                 :
      constant Unicode_Char := 16#16B0D#;
   Pahawh_Hmong_Vowel_Kawb                 :
      constant Unicode_Char := 16#16B0E#;
   Pahawh_Hmong_Vowel_Kawv                 :
      constant Unicode_Char := 16#16B0F#;
   Pahawh_Hmong_Vowel_Kuab                 :
      constant Unicode_Char := 16#16B10#;
   Pahawh_Hmong_Vowel_Kuav                 :
      constant Unicode_Char := 16#16B11#;
   Pahawh_Hmong_Vowel_Kob                  :
      constant Unicode_Char := 16#16B12#;
   Pahawh_Hmong_Vowel_Kov                  :
      constant Unicode_Char := 16#16B13#;
   Pahawh_Hmong_Vowel_Kiab                 :
      constant Unicode_Char := 16#16B14#;
   Pahawh_Hmong_Vowel_Kiav                 :
      constant Unicode_Char := 16#16B15#;
   Pahawh_Hmong_Vowel_Kab                  :
      constant Unicode_Char := 16#16B16#;
   Pahawh_Hmong_Vowel_Kav                  :
      constant Unicode_Char := 16#16B17#;
   Pahawh_Hmong_Vowel_Kwb                  :
      constant Unicode_Char := 16#16B18#;
   Pahawh_Hmong_Vowel_Kwv                  :
      constant Unicode_Char := 16#16B19#;
   Pahawh_Hmong_Vowel_Kaab                 :
      constant Unicode_Char := 16#16B1A#;
   Pahawh_Hmong_Vowel_Kaav                 :
      constant Unicode_Char := 16#16B1B#;
   Pahawh_Hmong_Consonant_Vau              :
      constant Unicode_Char := 16#16B1C#;
   Pahawh_Hmong_Consonant_Ntsau            :
      constant Unicode_Char := 16#16B1D#;
   Pahawh_Hmong_Consonant_Lau              :
      constant Unicode_Char := 16#16B1E#;
   Pahawh_Hmong_Consonant_Hau              :
      constant Unicode_Char := 16#16B1F#;
   Pahawh_Hmong_Consonant_Nlau             :
      constant Unicode_Char := 16#16B20#;
   Pahawh_Hmong_Consonant_Rau              :
      constant Unicode_Char := 16#16B21#;
   Pahawh_Hmong_Consonant_Nkau             :
      constant Unicode_Char := 16#16B22#;
   Pahawh_Hmong_Consonant_Qhau             :
      constant Unicode_Char := 16#16B23#;
   Pahawh_Hmong_Consonant_Yau              :
      constant Unicode_Char := 16#16B24#;
   Pahawh_Hmong_Consonant_Hlau             :
      constant Unicode_Char := 16#16B25#;
   Pahawh_Hmong_Consonant_Mau              :
      constant Unicode_Char := 16#16B26#;
   Pahawh_Hmong_Consonant_Chau             :
      constant Unicode_Char := 16#16B27#;
   Pahawh_Hmong_Consonant_Nchau            :
      constant Unicode_Char := 16#16B28#;
   Pahawh_Hmong_Consonant_Hnau             :
      constant Unicode_Char := 16#16B29#;
   Pahawh_Hmong_Consonant_Plhau            :
      constant Unicode_Char := 16#16B2A#;
   Pahawh_Hmong_Consonant_Nthau            :
      constant Unicode_Char := 16#16B2B#;
   Pahawh_Hmong_Consonant_Nau              :
      constant Unicode_Char := 16#16B2C#;
   Pahawh_Hmong_Consonant_Au               :
      constant Unicode_Char := 16#16B2D#;
   Pahawh_Hmong_Consonant_Xau              :
      constant Unicode_Char := 16#16B2E#;
   Pahawh_Hmong_Consonant_Cau              :
      constant Unicode_Char := 16#16B2F#;
   Pahawh_Hmong_Mark_Cim_Tub               :
      constant Unicode_Char := 16#16B30#;
   Pahawh_Hmong_Mark_Cim_So                :
      constant Unicode_Char := 16#16B31#;
   Pahawh_Hmong_Mark_Cim_Kes               :
      constant Unicode_Char := 16#16B32#;
   Pahawh_Hmong_Mark_Cim_Khav              :
      constant Unicode_Char := 16#16B33#;
   Pahawh_Hmong_Mark_Cim_Suam              :
      constant Unicode_Char := 16#16B34#;
   Pahawh_Hmong_Mark_Cim_Hom               :
      constant Unicode_Char := 16#16B35#;
   Pahawh_Hmong_Mark_Cim_Taum              :
      constant Unicode_Char := 16#16B36#;
   Pahawh_Hmong_Sign_Vos_Thom              :
      constant Unicode_Char := 16#16B37#;
   Pahawh_Hmong_Sign_Vos_Tshab_Ceeb        :
      constant Unicode_Char := 16#16B38#;
   Pahawh_Hmong_Sign_Cim_Cheem             :
      constant Unicode_Char := 16#16B39#;
   Pahawh_Hmong_Sign_Vos_Thiab             :
      constant Unicode_Char := 16#16B3A#;
   Pahawh_Hmong_Sign_Vos_Feem              :
      constant Unicode_Char := 16#16B3B#;
   Pahawh_Hmong_Sign_Xyeem_Ntxiv           :
      constant Unicode_Char := 16#16B3C#;
   Pahawh_Hmong_Sign_Xyeem_Rho             :
      constant Unicode_Char := 16#16B3D#;
   Pahawh_Hmong_Sign_Xyeem_Tov             :
      constant Unicode_Char := 16#16B3E#;
   Pahawh_Hmong_Sign_Xyeem_Faib            :
      constant Unicode_Char := 16#16B3F#;
   Pahawh_Hmong_Sign_Vos_Seev              :
      constant Unicode_Char := 16#16B40#;
   Pahawh_Hmong_Sign_Meej_Suab             :
      constant Unicode_Char := 16#16B41#;
   Pahawh_Hmong_Sign_Vos_Nrua              :
      constant Unicode_Char := 16#16B42#;
   Pahawh_Hmong_Sign_Ib_Yam                :
      constant Unicode_Char := 16#16B43#;
   Pahawh_Hmong_Sign_Xaus                  :
      constant Unicode_Char := 16#16B44#;
   Pahawh_Hmong_Sign_Cim_Tsov_Rog          :
      constant Unicode_Char := 16#16B45#;
   Pahawh_Hmong_Digit_Zero                 :
      constant Unicode_Char := 16#16B50#;
   Pahawh_Hmong_Digit_One                  :
      constant Unicode_Char := 16#16B51#;
   Pahawh_Hmong_Digit_Two                  :
      constant Unicode_Char := 16#16B52#;
   Pahawh_Hmong_Digit_Three                :
      constant Unicode_Char := 16#16B53#;
   Pahawh_Hmong_Digit_Four                 :
      constant Unicode_Char := 16#16B54#;
   Pahawh_Hmong_Digit_Five                 :
      constant Unicode_Char := 16#16B55#;
   Pahawh_Hmong_Digit_Six                  :
      constant Unicode_Char := 16#16B56#;
   Pahawh_Hmong_Digit_Seven                :
      constant Unicode_Char := 16#16B57#;
   Pahawh_Hmong_Digit_Eight                :
      constant Unicode_Char := 16#16B58#;
   Pahawh_Hmong_Digit_Nine                 :
      constant Unicode_Char := 16#16B59#;
   Pahawh_Hmong_Number_Tens                :
      constant Unicode_Char := 16#16B5B#;
   Pahawh_Hmong_Number_Hundreds            :
      constant Unicode_Char := 16#16B5C#;
   Pahawh_Hmong_Number_Ten_Thousands       :
      constant Unicode_Char := 16#16B5D#;
   Pahawh_Hmong_Number_Millions            :
      constant Unicode_Char := 16#16B5E#;
   Pahawh_Hmong_Number_Hundred_Millions    :
      constant Unicode_Char := 16#16B5F#;
   Pahawh_Hmong_Number_Ten_Billions        :
      constant Unicode_Char := 16#16B60#;
   Pahawh_Hmong_Number_Trillions           :
      constant Unicode_Char := 16#16B61#;
   Pahawh_Hmong_Sign_Vos_Lub               :
      constant Unicode_Char := 16#16B63#;
   Pahawh_Hmong_Sign_Xyoo                  :
      constant Unicode_Char := 16#16B64#;
   Pahawh_Hmong_Sign_Hli                   :
      constant Unicode_Char := 16#16B65#;
   Pahawh_Hmong_Sign_Third_Stage_Hli       :
      constant Unicode_Char := 16#16B66#;
   Pahawh_Hmong_Sign_Zwj_Thaj              :
      constant Unicode_Char := 16#16B67#;
   Pahawh_Hmong_Sign_Hnub                  :
      constant Unicode_Char := 16#16B68#;
   Pahawh_Hmong_Sign_Nqig                  :
      constant Unicode_Char := 16#16B69#;
   Pahawh_Hmong_Sign_Xiab                  :
      constant Unicode_Char := 16#16B6A#;
   Pahawh_Hmong_Sign_Ntuj                  :
      constant Unicode_Char := 16#16B6B#;
   Pahawh_Hmong_Sign_Av                    :
      constant Unicode_Char := 16#16B6C#;
   Pahawh_Hmong_Sign_Txheej_Ceev           :
      constant Unicode_Char := 16#16B6D#;
   Pahawh_Hmong_Sign_Meej_Tseeb            :
      constant Unicode_Char := 16#16B6E#;
   Pahawh_Hmong_Sign_Tau                   :
      constant Unicode_Char := 16#16B6F#;
   Pahawh_Hmong_Sign_Los                   :
      constant Unicode_Char := 16#16B70#;
   Pahawh_Hmong_Sign_Mus                   :
      constant Unicode_Char := 16#16B71#;
   Pahawh_Hmong_Sign_Cim_Hais_Lus_Ntog_Ntog :
      constant Unicode_Char := 16#16B72#;
   Pahawh_Hmong_Sign_Cim_Cuam_Tshooj       :
      constant Unicode_Char := 16#16B73#;
   Pahawh_Hmong_Sign_Cim_Txwv              :
      constant Unicode_Char := 16#16B74#;
   Pahawh_Hmong_Sign_Cim_Txwv_Chwv         :
      constant Unicode_Char := 16#16B75#;
   Pahawh_Hmong_Sign_Cim_Pub_Dawb          :
      constant Unicode_Char := 16#16B76#;
   Pahawh_Hmong_Sign_Cim_Nres_Tos          :
      constant Unicode_Char := 16#16B77#;
   Pahawh_Hmong_Clan_Sign_Tsheej           :
      constant Unicode_Char := 16#16B7D#;
   Pahawh_Hmong_Clan_Sign_Yeeg             :
      constant Unicode_Char := 16#16B7E#;
   Pahawh_Hmong_Clan_Sign_Lis              :
      constant Unicode_Char := 16#16B7F#;
   Pahawh_Hmong_Clan_Sign_Lauj             :
      constant Unicode_Char := 16#16B80#;
   Pahawh_Hmong_Clan_Sign_Xyooj            :
      constant Unicode_Char := 16#16B81#;
   Pahawh_Hmong_Clan_Sign_Koo              :
      constant Unicode_Char := 16#16B82#;
   Pahawh_Hmong_Clan_Sign_Hawj             :
      constant Unicode_Char := 16#16B83#;
   Pahawh_Hmong_Clan_Sign_Muas             :
      constant Unicode_Char := 16#16B84#;
   Pahawh_Hmong_Clan_Sign_Thoj             :
      constant Unicode_Char := 16#16B85#;
   Pahawh_Hmong_Clan_Sign_Tsab             :
      constant Unicode_Char := 16#16B86#;
   Pahawh_Hmong_Clan_Sign_Phab             :
      constant Unicode_Char := 16#16B87#;
   Pahawh_Hmong_Clan_Sign_Khab             :
      constant Unicode_Char := 16#16B88#;
   Pahawh_Hmong_Clan_Sign_Ham              :
      constant Unicode_Char := 16#16B89#;
   Pahawh_Hmong_Clan_Sign_Vaj              :
      constant Unicode_Char := 16#16B8A#;
   Pahawh_Hmong_Clan_Sign_Faj              :
      constant Unicode_Char := 16#16B8B#;
   Pahawh_Hmong_Clan_Sign_Yaj              :
      constant Unicode_Char := 16#16B8C#;
   Pahawh_Hmong_Clan_Sign_Tswb             :
      constant Unicode_Char := 16#16B8D#;
   Pahawh_Hmong_Clan_Sign_Kwm              :
      constant Unicode_Char := 16#16B8E#;
   Pahawh_Hmong_Clan_Sign_Vwj              :
      constant Unicode_Char := 16#16B8F#;
end Unicode.Names.Pahawh_Hmong;
