--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Emoticons is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Grinning_Face                           :
      constant Unicode_Char := 16#1F600#;
   Grinning_Face_With_Smiling_Eyes         :
      constant Unicode_Char := 16#1F601#;
   Face_With_Tears_Of_Joy                  :
      constant Unicode_Char := 16#1F602#;
   Smiling_Face_With_Open_Mouth            :
      constant Unicode_Char := 16#1F603#;
   Smiling_Face_With_Open_Mouth_And_Smiling_Eyes :
      constant Unicode_Char := 16#1F604#;
   Smiling_Face_With_Open_Mouth_And_Cold_Sweat :
      constant Unicode_Char := 16#1F605#;
   Smiling_Face_With_Open_Mouth_And_Tightly_Closed_Eyes :
      constant Unicode_Char := 16#1F606#;
   Smiling_Face_With_Halo                  :
      constant Unicode_Char := 16#1F607#;
   Smiling_Face_With_Horns                 :
      constant Unicode_Char := 16#1F608#;
   Winking_Face                            :
      constant Unicode_Char := 16#1F609#;
   Smiling_Face_With_Smiling_Eyes          :
      constant Unicode_Char := 16#1F60A#;
   Face_Savouring_Delicious_Food           :
      constant Unicode_Char := 16#1F60B#;
   Relieved_Face                           :
      constant Unicode_Char := 16#1F60C#;
   Smiling_Face_With_Heart_Shaped_Eyes     :
      constant Unicode_Char := 16#1F60D#;
   Smiling_Face_With_Sunglasses            :
      constant Unicode_Char := 16#1F60E#;
   Smirking_Face                           :
      constant Unicode_Char := 16#1F60F#;
   Neutral_Face                            :
      constant Unicode_Char := 16#1F610#;
   Expressionless_Face                     :
      constant Unicode_Char := 16#1F611#;
   Unamused_Face                           :
      constant Unicode_Char := 16#1F612#;
   Face_With_Cold_Sweat                    :
      constant Unicode_Char := 16#1F613#;
   Pensive_Face                            :
      constant Unicode_Char := 16#1F614#;
   Confused_Face                           :
      constant Unicode_Char := 16#1F615#;
   Confounded_Face                         :
      constant Unicode_Char := 16#1F616#;
   Kissing_Face                            :
      constant Unicode_Char := 16#1F617#;
   Face_Throwing_A_Kiss                    :
      constant Unicode_Char := 16#1F618#;
   Kissing_Face_With_Smiling_Eyes          :
      constant Unicode_Char := 16#1F619#;
   Kissing_Face_With_Closed_Eyes           :
      constant Unicode_Char := 16#1F61A#;
   Face_With_Stuck_Out_Tongue              :
      constant Unicode_Char := 16#1F61B#;
   Face_With_Stuck_Out_Tongue_And_Winking_Eye :
      constant Unicode_Char := 16#1F61C#;
   Face_With_Stuck_Out_Tongue_And_Tightly_Closed_Eyes :
      constant Unicode_Char := 16#1F61D#;
   Disappointed_Face                       :
      constant Unicode_Char := 16#1F61E#;
   Worried_Face                            :
      constant Unicode_Char := 16#1F61F#;
   Angry_Face                              :
      constant Unicode_Char := 16#1F620#;
   Pouting_Face                            :
      constant Unicode_Char := 16#1F621#;
   Crying_Face                             :
      constant Unicode_Char := 16#1F622#;
   Persevering_Face                        :
      constant Unicode_Char := 16#1F623#;
   Face_With_Look_Of_Triumph               :
      constant Unicode_Char := 16#1F624#;
   Disappointed_But_Relieved_Face          :
      constant Unicode_Char := 16#1F625#;
   Frowning_Face_With_Open_Mouth           :
      constant Unicode_Char := 16#1F626#;
   Anguished_Face                          :
      constant Unicode_Char := 16#1F627#;
   Fearful_Face                            :
      constant Unicode_Char := 16#1F628#;
   Weary_Face                              :
      constant Unicode_Char := 16#1F629#;
   Sleepy_Face                             :
      constant Unicode_Char := 16#1F62A#;
   Tired_Face                              :
      constant Unicode_Char := 16#1F62B#;
   Grimacing_Face                          :
      constant Unicode_Char := 16#1F62C#;
   Loudly_Crying_Face                      :
      constant Unicode_Char := 16#1F62D#;
   Face_With_Open_Mouth                    :
      constant Unicode_Char := 16#1F62E#;
   Hushed_Face                             :
      constant Unicode_Char := 16#1F62F#;
   Face_With_Open_Mouth_And_Cold_Sweat     :
      constant Unicode_Char := 16#1F630#;
   Face_Screaming_In_Fear                  :
      constant Unicode_Char := 16#1F631#;
   Astonished_Face                         :
      constant Unicode_Char := 16#1F632#;
   Flushed_Face                            :
      constant Unicode_Char := 16#1F633#;
   Sleeping_Face                           :
      constant Unicode_Char := 16#1F634#;
   Dizzy_Face                              :
      constant Unicode_Char := 16#1F635#;
   Face_Without_Mouth                      :
      constant Unicode_Char := 16#1F636#;
   Face_With_Medical_Mask                  :
      constant Unicode_Char := 16#1F637#;
   Grinning_Cat_Face_With_Smiling_Eyes     :
      constant Unicode_Char := 16#1F638#;
   Cat_Face_With_Tears_Of_Joy              :
      constant Unicode_Char := 16#1F639#;
   Smiling_Cat_Face_With_Open_Mouth        :
      constant Unicode_Char := 16#1F63A#;
   Smiling_Cat_Face_With_Heart_Shaped_Eyes :
      constant Unicode_Char := 16#1F63B#;
   Cat_Face_With_Wry_Smile                 :
      constant Unicode_Char := 16#1F63C#;
   Kissing_Cat_Face_With_Closed_Eyes       :
      constant Unicode_Char := 16#1F63D#;
   Pouting_Cat_Face                        :
      constant Unicode_Char := 16#1F63E#;
   Crying_Cat_Face                         :
      constant Unicode_Char := 16#1F63F#;
   Weary_Cat_Face                          :
      constant Unicode_Char := 16#1F640#;
   Slightly_Frowning_Face                  :
      constant Unicode_Char := 16#1F641#;
   Slightly_Smiling_Face                   :
      constant Unicode_Char := 16#1F642#;
   Upside_Down_Face                        :
      constant Unicode_Char := 16#1F643#;
   Face_With_Rolling_Eyes                  :
      constant Unicode_Char := 16#1F644#;
   Face_With_No_Good_Gesture               :
      constant Unicode_Char := 16#1F645#;
   Face_With_Ok_Gesture                    :
      constant Unicode_Char := 16#1F646#;
   Person_Bowing_Deeply                    :
      constant Unicode_Char := 16#1F647#;
   See_No_Evil_Monkey                      :
      constant Unicode_Char := 16#1F648#;
   Hear_No_Evil_Monkey                     :
      constant Unicode_Char := 16#1F649#;
   Speak_No_Evil_Monkey                    :
      constant Unicode_Char := 16#1F64A#;
   Happy_Person_Raising_One_Hand           :
      constant Unicode_Char := 16#1F64B#;
   Person_Raising_Both_Hands_In_Celebration :
      constant Unicode_Char := 16#1F64C#;
   Person_Frowning                         :
      constant Unicode_Char := 16#1F64D#;
   Person_With_Pouting_Face                :
      constant Unicode_Char := 16#1F64E#;
   Person_With_Folded_Hands                :
      constant Unicode_Char := 16#1F64F#;
end Unicode.Names.Emoticons;
