--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Tirhuta is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Tirhuta_Anji                            :
      constant Unicode_Char := 16#11480#;
   Tirhuta_Letter_A                        :
      constant Unicode_Char := 16#11481#;
   Tirhuta_Letter_Aa                       :
      constant Unicode_Char := 16#11482#;
   Tirhuta_Letter_I                        :
      constant Unicode_Char := 16#11483#;
   Tirhuta_Letter_Ii                       :
      constant Unicode_Char := 16#11484#;
   Tirhuta_Letter_U                        :
      constant Unicode_Char := 16#11485#;
   Tirhuta_Letter_Uu                       :
      constant Unicode_Char := 16#11486#;
   Tirhuta_Letter_Vocalic_R                :
      constant Unicode_Char := 16#11487#;
   Tirhuta_Letter_Vocalic_Rr               :
      constant Unicode_Char := 16#11488#;
   Tirhuta_Letter_Vocalic_L                :
      constant Unicode_Char := 16#11489#;
   Tirhuta_Letter_Vocalic_Ll               :
      constant Unicode_Char := 16#1148A#;
   Tirhuta_Letter_E                        :
      constant Unicode_Char := 16#1148B#;
   Tirhuta_Letter_Ai                       :
      constant Unicode_Char := 16#1148C#;
   Tirhuta_Letter_O                        :
      constant Unicode_Char := 16#1148D#;
   Tirhuta_Letter_Au                       :
      constant Unicode_Char := 16#1148E#;
   Tirhuta_Letter_Ka                       :
      constant Unicode_Char := 16#1148F#;
   Tirhuta_Letter_Kha                      :
      constant Unicode_Char := 16#11490#;
   Tirhuta_Letter_Ga                       :
      constant Unicode_Char := 16#11491#;
   Tirhuta_Letter_Gha                      :
      constant Unicode_Char := 16#11492#;
   Tirhuta_Letter_Nga                      :
      constant Unicode_Char := 16#11493#;
   Tirhuta_Letter_Ca                       :
      constant Unicode_Char := 16#11494#;
   Tirhuta_Letter_Cha                      :
      constant Unicode_Char := 16#11495#;
   Tirhuta_Letter_Ja                       :
      constant Unicode_Char := 16#11496#;
   Tirhuta_Letter_Jha                      :
      constant Unicode_Char := 16#11497#;
   Tirhuta_Letter_Nya                      :
      constant Unicode_Char := 16#11498#;
   Tirhuta_Letter_Tta                      :
      constant Unicode_Char := 16#11499#;
   Tirhuta_Letter_Ttha                     :
      constant Unicode_Char := 16#1149A#;
   Tirhuta_Letter_Dda                      :
      constant Unicode_Char := 16#1149B#;
   Tirhuta_Letter_Ddha                     :
      constant Unicode_Char := 16#1149C#;
   Tirhuta_Letter_Nna                      :
      constant Unicode_Char := 16#1149D#;
   Tirhuta_Letter_Ta                       :
      constant Unicode_Char := 16#1149E#;
   Tirhuta_Letter_Tha                      :
      constant Unicode_Char := 16#1149F#;
   Tirhuta_Letter_Da                       :
      constant Unicode_Char := 16#114A0#;
   Tirhuta_Letter_Dha                      :
      constant Unicode_Char := 16#114A1#;
   Tirhuta_Letter_Na                       :
      constant Unicode_Char := 16#114A2#;
   Tirhuta_Letter_Pa                       :
      constant Unicode_Char := 16#114A3#;
   Tirhuta_Letter_Pha                      :
      constant Unicode_Char := 16#114A4#;
   Tirhuta_Letter_Ba                       :
      constant Unicode_Char := 16#114A5#;
   Tirhuta_Letter_Bha                      :
      constant Unicode_Char := 16#114A6#;
   Tirhuta_Letter_Ma                       :
      constant Unicode_Char := 16#114A7#;
   Tirhuta_Letter_Ya                       :
      constant Unicode_Char := 16#114A8#;
   Tirhuta_Letter_Ra                       :
      constant Unicode_Char := 16#114A9#;
   Tirhuta_Letter_La                       :
      constant Unicode_Char := 16#114AA#;
   Tirhuta_Letter_Va                       :
      constant Unicode_Char := 16#114AB#;
   Tirhuta_Letter_Sha                      :
      constant Unicode_Char := 16#114AC#;
   Tirhuta_Letter_Ssa                      :
      constant Unicode_Char := 16#114AD#;
   Tirhuta_Letter_Sa                       :
      constant Unicode_Char := 16#114AE#;
   Tirhuta_Letter_Ha                       :
      constant Unicode_Char := 16#114AF#;
   Tirhuta_Vowel_Sign_Aa                   :
      constant Unicode_Char := 16#114B0#;
   Tirhuta_Vowel_Sign_I                    :
      constant Unicode_Char := 16#114B1#;
   Tirhuta_Vowel_Sign_Ii                   :
      constant Unicode_Char := 16#114B2#;
   Tirhuta_Vowel_Sign_U                    :
      constant Unicode_Char := 16#114B3#;
   Tirhuta_Vowel_Sign_Uu                   :
      constant Unicode_Char := 16#114B4#;
   Tirhuta_Vowel_Sign_Vocalic_R            :
      constant Unicode_Char := 16#114B5#;
   Tirhuta_Vowel_Sign_Vocalic_Rr           :
      constant Unicode_Char := 16#114B6#;
   Tirhuta_Vowel_Sign_Vocalic_L            :
      constant Unicode_Char := 16#114B7#;
   Tirhuta_Vowel_Sign_Vocalic_Ll           :
      constant Unicode_Char := 16#114B8#;
   Tirhuta_Vowel_Sign_E                    :
      constant Unicode_Char := 16#114B9#;
   Tirhuta_Vowel_Sign_Short_E              :
      constant Unicode_Char := 16#114BA#;
   Tirhuta_Vowel_Sign_Ai                   :
      constant Unicode_Char := 16#114BB#;
   Tirhuta_Vowel_Sign_O                    :
      constant Unicode_Char := 16#114BC#;
   Tirhuta_Vowel_Sign_Short_O              :
      constant Unicode_Char := 16#114BD#;
   Tirhuta_Vowel_Sign_Au                   :
      constant Unicode_Char := 16#114BE#;
   Tirhuta_Sign_Candrabindu                :
      constant Unicode_Char := 16#114BF#;
   Tirhuta_Sign_Anusvara                   :
      constant Unicode_Char := 16#114C0#;
   Tirhuta_Sign_Visarga                    :
      constant Unicode_Char := 16#114C1#;
   Tirhuta_Sign_Virama                     :
      constant Unicode_Char := 16#114C2#;
   Tirhuta_Sign_Nukta                      :
      constant Unicode_Char := 16#114C3#;
   Tirhuta_Sign_Avagraha                   :
      constant Unicode_Char := 16#114C4#;
   Tirhuta_Gvang                           :
      constant Unicode_Char := 16#114C5#;
   Tirhuta_Abbreviation_Sign               :
      constant Unicode_Char := 16#114C6#;
   Tirhuta_Om                              :
      constant Unicode_Char := 16#114C7#;
   Tirhuta_Digit_Zero                      :
      constant Unicode_Char := 16#114D0#;
   Tirhuta_Digit_One                       :
      constant Unicode_Char := 16#114D1#;
   Tirhuta_Digit_Two                       :
      constant Unicode_Char := 16#114D2#;
   Tirhuta_Digit_Three                     :
      constant Unicode_Char := 16#114D3#;
   Tirhuta_Digit_Four                      :
      constant Unicode_Char := 16#114D4#;
   Tirhuta_Digit_Five                      :
      constant Unicode_Char := 16#114D5#;
   Tirhuta_Digit_Six                       :
      constant Unicode_Char := 16#114D6#;
   Tirhuta_Digit_Seven                     :
      constant Unicode_Char := 16#114D7#;
   Tirhuta_Digit_Eight                     :
      constant Unicode_Char := 16#114D8#;
   Tirhuta_Digit_Nine                      :
      constant Unicode_Char := 16#114D9#;
end Unicode.Names.Tirhuta;
