--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Control_Pictures is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Symbol_For_Null                         : constant Unicode_Char := 16#2400#;
   Symbol_For_Start_Of_Heading             : constant Unicode_Char := 16#2401#;
   Symbol_For_Start_Of_Text                : constant Unicode_Char := 16#2402#;
   Symbol_For_End_Of_Text                  : constant Unicode_Char := 16#2403#;
   Symbol_For_End_Of_Transmission          : constant Unicode_Char := 16#2404#;
   Symbol_For_Enquiry                      : constant Unicode_Char := 16#2405#;
   Symbol_For_Acknowledge                  : constant Unicode_Char := 16#2406#;
   Symbol_For_Bell                         : constant Unicode_Char := 16#2407#;
   Symbol_For_Backspace                    : constant Unicode_Char := 16#2408#;
   Symbol_For_Horizontal_Tabulation        : constant Unicode_Char := 16#2409#;
   Symbol_For_Line_Feed                    : constant Unicode_Char := 16#240A#;
   Symbol_For_Vertical_Tabulation          : constant Unicode_Char := 16#240B#;
   Symbol_For_Form_Feed                    : constant Unicode_Char := 16#240C#;
   Symbol_For_Carriage_Return              : constant Unicode_Char := 16#240D#;
   Symbol_For_Shift_Out                    : constant Unicode_Char := 16#240E#;
   Symbol_For_Shift_In                     : constant Unicode_Char := 16#240F#;
   Symbol_For_Data_Link_Escape             : constant Unicode_Char := 16#2410#;
   Symbol_For_Device_Control_One           : constant Unicode_Char := 16#2411#;
   Symbol_For_Device_Control_Two           : constant Unicode_Char := 16#2412#;
   Symbol_For_Device_Control_Three         : constant Unicode_Char := 16#2413#;
   Symbol_For_Device_Control_Four          : constant Unicode_Char := 16#2414#;
   Symbol_For_Negative_Acknowledge         : constant Unicode_Char := 16#2415#;
   Symbol_For_Synchronous_Idle             : constant Unicode_Char := 16#2416#;
   Symbol_For_End_Of_Transmission_Block    : constant Unicode_Char := 16#2417#;
   Symbol_For_Cancel                       : constant Unicode_Char := 16#2418#;
   Symbol_For_End_Of_Medium                : constant Unicode_Char := 16#2419#;
   Symbol_For_Substitute                   : constant Unicode_Char := 16#241A#;
   Symbol_For_Escape                       : constant Unicode_Char := 16#241B#;
   Symbol_For_File_Separator               : constant Unicode_Char := 16#241C#;
   Symbol_For_Group_Separator              : constant Unicode_Char := 16#241D#;
   Symbol_For_Record_Separator             : constant Unicode_Char := 16#241E#;
   Symbol_For_Unit_Separator               : constant Unicode_Char := 16#241F#;
   Symbol_For_Space                        : constant Unicode_Char := 16#2420#;
   Symbol_For_Delete                       : constant Unicode_Char := 16#2421#;
   Blank_Symbol                            : constant Unicode_Char := 16#2422#;
   Open_Box                                : constant Unicode_Char := 16#2423#;
   Symbol_For_Newline                      : constant Unicode_Char := 16#2424#;
   Symbol_For_Delete_Form_Two              : constant Unicode_Char := 16#2425#;
   Symbol_For_Substitute_Form_Two          : constant Unicode_Char := 16#2426#;
end Unicode.Names.Control_Pictures;
