--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Limbu is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Limbu_Vowel_Carrier_Letter              : constant Unicode_Char := 16#1900#;
   Limbu_Letter_Ka                         : constant Unicode_Char := 16#1901#;
   Limbu_Letter_Kha                        : constant Unicode_Char := 16#1902#;
   Limbu_Letter_Ga                         : constant Unicode_Char := 16#1903#;
   Limbu_Letter_Gha                        : constant Unicode_Char := 16#1904#;
   Limbu_Letter_Nga                        : constant Unicode_Char := 16#1905#;
   Limbu_Letter_Ca                         : constant Unicode_Char := 16#1906#;
   Limbu_Letter_Cha                        : constant Unicode_Char := 16#1907#;
   Limbu_Letter_Ja                         : constant Unicode_Char := 16#1908#;
   Limbu_Letter_Jha                        : constant Unicode_Char := 16#1909#;
   Limbu_Letter_Yan                        : constant Unicode_Char := 16#190A#;
   Limbu_Letter_Ta                         : constant Unicode_Char := 16#190B#;
   Limbu_Letter_Tha                        : constant Unicode_Char := 16#190C#;
   Limbu_Letter_Da                         : constant Unicode_Char := 16#190D#;
   Limbu_Letter_Dha                        : constant Unicode_Char := 16#190E#;
   Limbu_Letter_Na                         : constant Unicode_Char := 16#190F#;
   Limbu_Letter_Pa                         : constant Unicode_Char := 16#1910#;
   Limbu_Letter_Pha                        : constant Unicode_Char := 16#1911#;
   Limbu_Letter_Ba                         : constant Unicode_Char := 16#1912#;
   Limbu_Letter_Bha                        : constant Unicode_Char := 16#1913#;
   Limbu_Letter_Ma                         : constant Unicode_Char := 16#1914#;
   Limbu_Letter_Ya                         : constant Unicode_Char := 16#1915#;
   Limbu_Letter_Ra                         : constant Unicode_Char := 16#1916#;
   Limbu_Letter_La                         : constant Unicode_Char := 16#1917#;
   Limbu_Letter_Wa                         : constant Unicode_Char := 16#1918#;
   Limbu_Letter_Sha                        : constant Unicode_Char := 16#1919#;
   Limbu_Letter_Ssa                        : constant Unicode_Char := 16#191A#;
   Limbu_Letter_Sa                         : constant Unicode_Char := 16#191B#;
   Limbu_Letter_Ha                         : constant Unicode_Char := 16#191C#;
   Limbu_Letter_Gyan                       : constant Unicode_Char := 16#191D#;
   Limbu_Letter_Tra                        : constant Unicode_Char := 16#191E#;
   Limbu_Vowel_Sign_A                      : constant Unicode_Char := 16#1920#;
   Limbu_Vowel_Sign_I                      : constant Unicode_Char := 16#1921#;
   Limbu_Vowel_Sign_U                      : constant Unicode_Char := 16#1922#;
   Limbu_Vowel_Sign_Ee                     : constant Unicode_Char := 16#1923#;
   Limbu_Vowel_Sign_Ai                     : constant Unicode_Char := 16#1924#;
   Limbu_Vowel_Sign_Oo                     : constant Unicode_Char := 16#1925#;
   Limbu_Vowel_Sign_Au                     : constant Unicode_Char := 16#1926#;
   Limbu_Vowel_Sign_E                      : constant Unicode_Char := 16#1927#;
   Limbu_Vowel_Sign_O                      : constant Unicode_Char := 16#1928#;
   Limbu_Subjoined_Letter_Ya               : constant Unicode_Char := 16#1929#;
   Limbu_Subjoined_Letter_Ra               : constant Unicode_Char := 16#192A#;
   Limbu_Subjoined_Letter_Wa               : constant Unicode_Char := 16#192B#;
   Limbu_Small_Letter_Ka                   : constant Unicode_Char := 16#1930#;
   Limbu_Small_Letter_Nga                  : constant Unicode_Char := 16#1931#;
   Limbu_Small_Letter_Anusvara             : constant Unicode_Char := 16#1932#;
   Limbu_Small_Letter_Ta                   : constant Unicode_Char := 16#1933#;
   Limbu_Small_Letter_Na                   : constant Unicode_Char := 16#1934#;
   Limbu_Small_Letter_Pa                   : constant Unicode_Char := 16#1935#;
   Limbu_Small_Letter_Ma                   : constant Unicode_Char := 16#1936#;
   Limbu_Small_Letter_Ra                   : constant Unicode_Char := 16#1937#;
   Limbu_Small_Letter_La                   : constant Unicode_Char := 16#1938#;
   Limbu_Sign_Mukphreng                    : constant Unicode_Char := 16#1939#;
   Limbu_Sign_Kemphreng                    : constant Unicode_Char := 16#193A#;
   Limbu_Sign_Sa_I                         : constant Unicode_Char := 16#193B#;
   Limbu_Sign_Loo                          : constant Unicode_Char := 16#1940#;
   Limbu_Exclamation_Mark                  : constant Unicode_Char := 16#1944#;
   Limbu_Question_Mark                     : constant Unicode_Char := 16#1945#;
   Limbu_Digit_Zero                        : constant Unicode_Char := 16#1946#;
   Limbu_Digit_One                         : constant Unicode_Char := 16#1947#;
   Limbu_Digit_Two                         : constant Unicode_Char := 16#1948#;
   Limbu_Digit_Three                       : constant Unicode_Char := 16#1949#;
   Limbu_Digit_Four                        : constant Unicode_Char := 16#194A#;
   Limbu_Digit_Five                        : constant Unicode_Char := 16#194B#;
   Limbu_Digit_Six                         : constant Unicode_Char := 16#194C#;
   Limbu_Digit_Seven                       : constant Unicode_Char := 16#194D#;
   Limbu_Digit_Eight                       : constant Unicode_Char := 16#194E#;
   Limbu_Digit_Nine                        : constant Unicode_Char := 16#194F#;
end Unicode.Names.Limbu;
