--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Greek_Extended is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Greek_Small_Letter_Alpha_With_Psili     : constant Unicode_Char := 16#1F00#;
   Greek_Small_Letter_Alpha_With_Dasia     : constant Unicode_Char := 16#1F01#;
   Greek_Small_Letter_Alpha_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F02#;
   Greek_Small_Letter_Alpha_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F03#;
   Greek_Small_Letter_Alpha_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F04#;
   Greek_Small_Letter_Alpha_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F05#;
   Greek_Small_Letter_Alpha_With_Psili_And_Perispomeni :
      constant Unicode_Char := 16#1F06#;
   Greek_Small_Letter_Alpha_With_Dasia_And_Perispomeni :
      constant Unicode_Char := 16#1F07#;
   Greek_Capital_Letter_Alpha_With_Psili   : constant Unicode_Char := 16#1F08#;
   Greek_Capital_Letter_Alpha_With_Dasia   : constant Unicode_Char := 16#1F09#;
   Greek_Capital_Letter_Alpha_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F0A#;
   Greek_Capital_Letter_Alpha_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F0B#;
   Greek_Capital_Letter_Alpha_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F0C#;
   Greek_Capital_Letter_Alpha_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F0D#;
   Greek_Capital_Letter_Alpha_With_Psili_And_Perispomeni :
      constant Unicode_Char := 16#1F0E#;
   Greek_Capital_Letter_Alpha_With_Dasia_And_Perispomeni :
      constant Unicode_Char := 16#1F0F#;
   Greek_Small_Letter_Epsilon_With_Psili   : constant Unicode_Char := 16#1F10#;
   Greek_Small_Letter_Epsilon_With_Dasia   : constant Unicode_Char := 16#1F11#;
   Greek_Small_Letter_Epsilon_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F12#;
   Greek_Small_Letter_Epsilon_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F13#;
   Greek_Small_Letter_Epsilon_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F14#;
   Greek_Small_Letter_Epsilon_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F15#;
   Greek_Capital_Letter_Epsilon_With_Psili : constant Unicode_Char := 16#1F18#;
   Greek_Capital_Letter_Epsilon_With_Dasia : constant Unicode_Char := 16#1F19#;
   Greek_Capital_Letter_Epsilon_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F1A#;
   Greek_Capital_Letter_Epsilon_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F1B#;
   Greek_Capital_Letter_Epsilon_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F1C#;
   Greek_Capital_Letter_Epsilon_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F1D#;
   Greek_Small_Letter_Eta_With_Psili       : constant Unicode_Char := 16#1F20#;
   Greek_Small_Letter_Eta_With_Dasia       : constant Unicode_Char := 16#1F21#;
   Greek_Small_Letter_Eta_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F22#;
   Greek_Small_Letter_Eta_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F23#;
   Greek_Small_Letter_Eta_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F24#;
   Greek_Small_Letter_Eta_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F25#;
   Greek_Small_Letter_Eta_With_Psili_And_Perispomeni :
      constant Unicode_Char := 16#1F26#;
   Greek_Small_Letter_Eta_With_Dasia_And_Perispomeni :
      constant Unicode_Char := 16#1F27#;
   Greek_Capital_Letter_Eta_With_Psili     : constant Unicode_Char := 16#1F28#;
   Greek_Capital_Letter_Eta_With_Dasia     : constant Unicode_Char := 16#1F29#;
   Greek_Capital_Letter_Eta_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F2A#;
   Greek_Capital_Letter_Eta_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F2B#;
   Greek_Capital_Letter_Eta_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F2C#;
   Greek_Capital_Letter_Eta_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F2D#;
   Greek_Capital_Letter_Eta_With_Psili_And_Perispomeni :
      constant Unicode_Char := 16#1F2E#;
   Greek_Capital_Letter_Eta_With_Dasia_And_Perispomeni :
      constant Unicode_Char := 16#1F2F#;
   Greek_Small_Letter_Iota_With_Psili      : constant Unicode_Char := 16#1F30#;
   Greek_Small_Letter_Iota_With_Dasia      : constant Unicode_Char := 16#1F31#;
   Greek_Small_Letter_Iota_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F32#;
   Greek_Small_Letter_Iota_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F33#;
   Greek_Small_Letter_Iota_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F34#;
   Greek_Small_Letter_Iota_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F35#;
   Greek_Small_Letter_Iota_With_Psili_And_Perispomeni :
      constant Unicode_Char := 16#1F36#;
   Greek_Small_Letter_Iota_With_Dasia_And_Perispomeni :
      constant Unicode_Char := 16#1F37#;
   Greek_Capital_Letter_Iota_With_Psili    : constant Unicode_Char := 16#1F38#;
   Greek_Capital_Letter_Iota_With_Dasia    : constant Unicode_Char := 16#1F39#;
   Greek_Capital_Letter_Iota_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F3A#;
   Greek_Capital_Letter_Iota_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F3B#;
   Greek_Capital_Letter_Iota_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F3C#;
   Greek_Capital_Letter_Iota_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F3D#;
   Greek_Capital_Letter_Iota_With_Psili_And_Perispomeni :
      constant Unicode_Char := 16#1F3E#;
   Greek_Capital_Letter_Iota_With_Dasia_And_Perispomeni :
      constant Unicode_Char := 16#1F3F#;
   Greek_Small_Letter_Omicron_With_Psili   : constant Unicode_Char := 16#1F40#;
   Greek_Small_Letter_Omicron_With_Dasia   : constant Unicode_Char := 16#1F41#;
   Greek_Small_Letter_Omicron_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F42#;
   Greek_Small_Letter_Omicron_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F43#;
   Greek_Small_Letter_Omicron_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F44#;
   Greek_Small_Letter_Omicron_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F45#;
   Greek_Capital_Letter_Omicron_With_Psili : constant Unicode_Char := 16#1F48#;
   Greek_Capital_Letter_Omicron_With_Dasia : constant Unicode_Char := 16#1F49#;
   Greek_Capital_Letter_Omicron_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F4A#;
   Greek_Capital_Letter_Omicron_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F4B#;
   Greek_Capital_Letter_Omicron_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F4C#;
   Greek_Capital_Letter_Omicron_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F4D#;
   Greek_Small_Letter_Upsilon_With_Psili   : constant Unicode_Char := 16#1F50#;
   Greek_Small_Letter_Upsilon_With_Dasia   : constant Unicode_Char := 16#1F51#;
   Greek_Small_Letter_Upsilon_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F52#;
   Greek_Small_Letter_Upsilon_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F53#;
   Greek_Small_Letter_Upsilon_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F54#;
   Greek_Small_Letter_Upsilon_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F55#;
   Greek_Small_Letter_Upsilon_With_Psili_And_Perispomeni :
      constant Unicode_Char := 16#1F56#;
   Greek_Small_Letter_Upsilon_With_Dasia_And_Perispomeni :
      constant Unicode_Char := 16#1F57#;
   Greek_Capital_Letter_Upsilon_With_Dasia : constant Unicode_Char := 16#1F59#;
   Greek_Capital_Letter_Upsilon_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F5B#;
   Greek_Capital_Letter_Upsilon_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F5D#;
   Greek_Capital_Letter_Upsilon_With_Dasia_And_Perispomeni :
      constant Unicode_Char := 16#1F5F#;
   Greek_Small_Letter_Omega_With_Psili     : constant Unicode_Char := 16#1F60#;
   Greek_Small_Letter_Omega_With_Dasia     : constant Unicode_Char := 16#1F61#;
   Greek_Small_Letter_Omega_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F62#;
   Greek_Small_Letter_Omega_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F63#;
   Greek_Small_Letter_Omega_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F64#;
   Greek_Small_Letter_Omega_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F65#;
   Greek_Small_Letter_Omega_With_Psili_And_Perispomeni :
      constant Unicode_Char := 16#1F66#;
   Greek_Small_Letter_Omega_With_Dasia_And_Perispomeni :
      constant Unicode_Char := 16#1F67#;
   Greek_Capital_Letter_Omega_With_Psili   : constant Unicode_Char := 16#1F68#;
   Greek_Capital_Letter_Omega_With_Dasia   : constant Unicode_Char := 16#1F69#;
   Greek_Capital_Letter_Omega_With_Psili_And_Varia :
      constant Unicode_Char := 16#1F6A#;
   Greek_Capital_Letter_Omega_With_Dasia_And_Varia :
      constant Unicode_Char := 16#1F6B#;
   Greek_Capital_Letter_Omega_With_Psili_And_Oxia :
      constant Unicode_Char := 16#1F6C#;
   Greek_Capital_Letter_Omega_With_Dasia_And_Oxia :
      constant Unicode_Char := 16#1F6D#;
   Greek_Capital_Letter_Omega_With_Psili_And_Perispomeni :
      constant Unicode_Char := 16#1F6E#;
   Greek_Capital_Letter_Omega_With_Dasia_And_Perispomeni :
      constant Unicode_Char := 16#1F6F#;
   Greek_Small_Letter_Alpha_With_Varia     : constant Unicode_Char := 16#1F70#;
   Greek_Small_Letter_Alpha_With_Oxia      : constant Unicode_Char := 16#1F71#;
   Greek_Small_Letter_Epsilon_With_Varia   : constant Unicode_Char := 16#1F72#;
   Greek_Small_Letter_Epsilon_With_Oxia    : constant Unicode_Char := 16#1F73#;
   Greek_Small_Letter_Eta_With_Varia       : constant Unicode_Char := 16#1F74#;
   Greek_Small_Letter_Eta_With_Oxia        : constant Unicode_Char := 16#1F75#;
   Greek_Small_Letter_Iota_With_Varia      : constant Unicode_Char := 16#1F76#;
   Greek_Small_Letter_Iota_With_Oxia       : constant Unicode_Char := 16#1F77#;
   Greek_Small_Letter_Omicron_With_Varia   : constant Unicode_Char := 16#1F78#;
   Greek_Small_Letter_Omicron_With_Oxia    : constant Unicode_Char := 16#1F79#;
   Greek_Small_Letter_Upsilon_With_Varia   : constant Unicode_Char := 16#1F7A#;
   Greek_Small_Letter_Upsilon_With_Oxia    : constant Unicode_Char := 16#1F7B#;
   Greek_Small_Letter_Omega_With_Varia     : constant Unicode_Char := 16#1F7C#;
   Greek_Small_Letter_Omega_With_Oxia      : constant Unicode_Char := 16#1F7D#;
   Greek_Small_Letter_Alpha_With_Psili_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F80#;
   Greek_Small_Letter_Alpha_With_Dasia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F81#;
   Greek_Small_Letter_Alpha_With_Psili_And_Varia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F82#;
   Greek_Small_Letter_Alpha_With_Dasia_And_Varia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F83#;
   Greek_Small_Letter_Alpha_With_Psili_And_Oxia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F84#;
   Greek_Small_Letter_Alpha_With_Dasia_And_Oxia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F85#;
   Greek_Small_Letter_Alpha_With_Psili_And_Perispomeni_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F86#;
   Greek_Small_Letter_Alpha_With_Dasia_And_Perispomeni_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F87#;
   Greek_Capital_Letter_Alpha_With_Psili_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F88#;
   Greek_Capital_Letter_Alpha_With_Dasia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F89#;
   Greek_Capital_Letter_Alpha_With_Psili_And_Varia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F8A#;
   Greek_Capital_Letter_Alpha_With_Dasia_And_Varia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F8B#;
   Greek_Capital_Letter_Alpha_With_Psili_And_Oxia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F8C#;
   Greek_Capital_Letter_Alpha_With_Dasia_And_Oxia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F8D#;
   Greek_Capital_Letter_Alpha_With_Psili_And_Perispomeni_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F8E#;
   Greek_Capital_Letter_Alpha_With_Dasia_And_Perispomeni_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F8F#;
   Greek_Small_Letter_Eta_With_Psili_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F90#;
   Greek_Small_Letter_Eta_With_Dasia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F91#;
   Greek_Small_Letter_Eta_With_Psili_And_Varia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F92#;
   Greek_Small_Letter_Eta_With_Dasia_And_Varia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F93#;
   Greek_Small_Letter_Eta_With_Psili_And_Oxia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F94#;
   Greek_Small_Letter_Eta_With_Dasia_And_Oxia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F95#;
   Greek_Small_Letter_Eta_With_Psili_And_Perispomeni_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F96#;
   Greek_Small_Letter_Eta_With_Dasia_And_Perispomeni_And_Ypogegrammeni :
      constant Unicode_Char := 16#1F97#;
   Greek_Capital_Letter_Eta_With_Psili_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F98#;
   Greek_Capital_Letter_Eta_With_Dasia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F99#;
   Greek_Capital_Letter_Eta_With_Psili_And_Varia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F9A#;
   Greek_Capital_Letter_Eta_With_Dasia_And_Varia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F9B#;
   Greek_Capital_Letter_Eta_With_Psili_And_Oxia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F9C#;
   Greek_Capital_Letter_Eta_With_Dasia_And_Oxia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F9D#;
   Greek_Capital_Letter_Eta_With_Psili_And_Perispomeni_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F9E#;
   Greek_Capital_Letter_Eta_With_Dasia_And_Perispomeni_And_Prosgegrammeni :
      constant Unicode_Char := 16#1F9F#;
   Greek_Small_Letter_Omega_With_Psili_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FA0#;
   Greek_Small_Letter_Omega_With_Dasia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FA1#;
   Greek_Small_Letter_Omega_With_Psili_And_Varia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FA2#;
   Greek_Small_Letter_Omega_With_Dasia_And_Varia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FA3#;
   Greek_Small_Letter_Omega_With_Psili_And_Oxia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FA4#;
   Greek_Small_Letter_Omega_With_Dasia_And_Oxia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FA5#;
   Greek_Small_Letter_Omega_With_Psili_And_Perispomeni_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FA6#;
   Greek_Small_Letter_Omega_With_Dasia_And_Perispomeni_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FA7#;
   Greek_Capital_Letter_Omega_With_Psili_And_Prosgegrammeni :
      constant Unicode_Char := 16#1FA8#;
   Greek_Capital_Letter_Omega_With_Dasia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1FA9#;
   Greek_Capital_Letter_Omega_With_Psili_And_Varia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1FAA#;
   Greek_Capital_Letter_Omega_With_Dasia_And_Varia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1FAB#;
   Greek_Capital_Letter_Omega_With_Psili_And_Oxia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1FAC#;
   Greek_Capital_Letter_Omega_With_Dasia_And_Oxia_And_Prosgegrammeni :
      constant Unicode_Char := 16#1FAD#;
   Greek_Capital_Letter_Omega_With_Psili_And_Perispomeni_And_Prosgegrammeni :
      constant Unicode_Char := 16#1FAE#;
   Greek_Capital_Letter_Omega_With_Dasia_And_Perispomeni_And_Prosgegrammeni :
      constant Unicode_Char := 16#1FAF#;
   Greek_Small_Letter_Alpha_With_Vrachy    : constant Unicode_Char := 16#1FB0#;
   Greek_Small_Letter_Alpha_With_Macron    : constant Unicode_Char := 16#1FB1#;
   Greek_Small_Letter_Alpha_With_Varia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FB2#;
   Greek_Small_Letter_Alpha_With_Ypogegrammeni :
      constant Unicode_Char := 16#1FB3#;
   Greek_Small_Letter_Alpha_With_Oxia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FB4#;
   Greek_Small_Letter_Alpha_With_Perispomeni :
      constant Unicode_Char := 16#1FB6#;
   Greek_Small_Letter_Alpha_With_Perispomeni_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FB7#;
   Greek_Capital_Letter_Alpha_With_Vrachy  : constant Unicode_Char := 16#1FB8#;
   Greek_Capital_Letter_Alpha_With_Macron  : constant Unicode_Char := 16#1FB9#;
   Greek_Capital_Letter_Alpha_With_Varia   : constant Unicode_Char := 16#1FBA#;
   Greek_Capital_Letter_Alpha_With_Oxia    : constant Unicode_Char := 16#1FBB#;
   Greek_Capital_Letter_Alpha_With_Prosgegrammeni :
      constant Unicode_Char := 16#1FBC#;
   Greek_Koronis                           : constant Unicode_Char := 16#1FBD#;
   Greek_Prosgegrammeni                    : constant Unicode_Char := 16#1FBE#;
   Greek_Psili                             : constant Unicode_Char := 16#1FBF#;
   Greek_Perispomeni                       : constant Unicode_Char := 16#1FC0#;
   Greek_Dialytika_And_Perispomeni         : constant Unicode_Char := 16#1FC1#;
   Greek_Small_Letter_Eta_With_Varia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FC2#;
   Greek_Small_Letter_Eta_With_Ypogegrammeni :
      constant Unicode_Char := 16#1FC3#;
   Greek_Small_Letter_Eta_With_Oxia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FC4#;
   Greek_Small_Letter_Eta_With_Perispomeni : constant Unicode_Char := 16#1FC6#;
   Greek_Small_Letter_Eta_With_Perispomeni_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FC7#;
   Greek_Capital_Letter_Epsilon_With_Varia : constant Unicode_Char := 16#1FC8#;
   Greek_Capital_Letter_Epsilon_With_Oxia  : constant Unicode_Char := 16#1FC9#;
   Greek_Capital_Letter_Eta_With_Varia     : constant Unicode_Char := 16#1FCA#;
   Greek_Capital_Letter_Eta_With_Oxia      : constant Unicode_Char := 16#1FCB#;
   Greek_Capital_Letter_Eta_With_Prosgegrammeni :
      constant Unicode_Char := 16#1FCC#;
   Greek_Psili_And_Varia                   : constant Unicode_Char := 16#1FCD#;
   Greek_Psili_And_Oxia                    : constant Unicode_Char := 16#1FCE#;
   Greek_Psili_And_Perispomeni             : constant Unicode_Char := 16#1FCF#;
   Greek_Small_Letter_Iota_With_Vrachy     : constant Unicode_Char := 16#1FD0#;
   Greek_Small_Letter_Iota_With_Macron     : constant Unicode_Char := 16#1FD1#;
   Greek_Small_Letter_Iota_With_Dialytika_And_Varia :
      constant Unicode_Char := 16#1FD2#;
   Greek_Small_Letter_Iota_With_Dialytika_And_Oxia :
      constant Unicode_Char := 16#1FD3#;
   Greek_Small_Letter_Iota_With_Perispomeni :
      constant Unicode_Char := 16#1FD6#;
   Greek_Small_Letter_Iota_With_Dialytika_And_Perispomeni :
      constant Unicode_Char := 16#1FD7#;
   Greek_Capital_Letter_Iota_With_Vrachy   : constant Unicode_Char := 16#1FD8#;
   Greek_Capital_Letter_Iota_With_Macron   : constant Unicode_Char := 16#1FD9#;
   Greek_Capital_Letter_Iota_With_Varia    : constant Unicode_Char := 16#1FDA#;
   Greek_Capital_Letter_Iota_With_Oxia     : constant Unicode_Char := 16#1FDB#;
   Greek_Dasia_And_Varia                   : constant Unicode_Char := 16#1FDD#;
   Greek_Dasia_And_Oxia                    : constant Unicode_Char := 16#1FDE#;
   Greek_Dasia_And_Perispomeni             : constant Unicode_Char := 16#1FDF#;
   Greek_Small_Letter_Upsilon_With_Vrachy  : constant Unicode_Char := 16#1FE0#;
   Greek_Small_Letter_Upsilon_With_Macron  : constant Unicode_Char := 16#1FE1#;
   Greek_Small_Letter_Upsilon_With_Dialytika_And_Varia :
      constant Unicode_Char := 16#1FE2#;
   Greek_Small_Letter_Upsilon_With_Dialytika_And_Oxia :
      constant Unicode_Char := 16#1FE3#;
   Greek_Small_Letter_Rho_With_Psili       : constant Unicode_Char := 16#1FE4#;
   Greek_Small_Letter_Rho_With_Dasia       : constant Unicode_Char := 16#1FE5#;
   Greek_Small_Letter_Upsilon_With_Perispomeni :
      constant Unicode_Char := 16#1FE6#;
   Greek_Small_Letter_Upsilon_With_Dialytika_And_Perispomeni :
      constant Unicode_Char := 16#1FE7#;
   Greek_Capital_Letter_Upsilon_With_Vrachy :
      constant Unicode_Char := 16#1FE8#;
   Greek_Capital_Letter_Upsilon_With_Macron :
      constant Unicode_Char := 16#1FE9#;
   Greek_Capital_Letter_Upsilon_With_Varia : constant Unicode_Char := 16#1FEA#;
   Greek_Capital_Letter_Upsilon_With_Oxia  : constant Unicode_Char := 16#1FEB#;
   Greek_Capital_Letter_Rho_With_Dasia     : constant Unicode_Char := 16#1FEC#;
   Greek_Dialytika_And_Varia               : constant Unicode_Char := 16#1FED#;
   Greek_Dialytika_And_Oxia                : constant Unicode_Char := 16#1FEE#;
   Greek_Varia                             : constant Unicode_Char := 16#1FEF#;
   Greek_Small_Letter_Omega_With_Varia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FF2#;
   Greek_Small_Letter_Omega_With_Ypogegrammeni :
      constant Unicode_Char := 16#1FF3#;
   Greek_Small_Letter_Omega_With_Oxia_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FF4#;
   Greek_Small_Letter_Omega_With_Perispomeni :
      constant Unicode_Char := 16#1FF6#;
   Greek_Small_Letter_Omega_With_Perispomeni_And_Ypogegrammeni :
      constant Unicode_Char := 16#1FF7#;
   Greek_Capital_Letter_Omicron_With_Varia : constant Unicode_Char := 16#1FF8#;
   Greek_Capital_Letter_Omicron_With_Oxia  : constant Unicode_Char := 16#1FF9#;
   Greek_Capital_Letter_Omega_With_Varia   : constant Unicode_Char := 16#1FFA#;
   Greek_Capital_Letter_Omega_With_Oxia    : constant Unicode_Char := 16#1FFB#;
   Greek_Capital_Letter_Omega_With_Prosgegrammeni :
      constant Unicode_Char := 16#1FFC#;
   Greek_Oxia                              : constant Unicode_Char := 16#1FFD#;
   Greek_Dasia                             : constant Unicode_Char := 16#1FFE#;
end Unicode.Names.Greek_Extended;
