--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Old_Italic is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Old_Italic_Letter_A                     :
      constant Unicode_Char := 16#10300#;
   Old_Italic_Letter_Be                    :
      constant Unicode_Char := 16#10301#;
   Old_Italic_Letter_Ke                    :
      constant Unicode_Char := 16#10302#;
   Old_Italic_Letter_De                    :
      constant Unicode_Char := 16#10303#;
   Old_Italic_Letter_E                     :
      constant Unicode_Char := 16#10304#;
   Old_Italic_Letter_Ve                    :
      constant Unicode_Char := 16#10305#;
   Old_Italic_Letter_Ze                    :
      constant Unicode_Char := 16#10306#;
   Old_Italic_Letter_He                    :
      constant Unicode_Char := 16#10307#;
   Old_Italic_Letter_The                   :
      constant Unicode_Char := 16#10308#;
   Old_Italic_Letter_I                     :
      constant Unicode_Char := 16#10309#;
   Old_Italic_Letter_Ka                    :
      constant Unicode_Char := 16#1030A#;
   Old_Italic_Letter_El                    :
      constant Unicode_Char := 16#1030B#;
   Old_Italic_Letter_Em                    :
      constant Unicode_Char := 16#1030C#;
   Old_Italic_Letter_En                    :
      constant Unicode_Char := 16#1030D#;
   Old_Italic_Letter_Esh                   :
      constant Unicode_Char := 16#1030E#;
   Old_Italic_Letter_O                     :
      constant Unicode_Char := 16#1030F#;
   Old_Italic_Letter_Pe                    :
      constant Unicode_Char := 16#10310#;
   Old_Italic_Letter_She                   :
      constant Unicode_Char := 16#10311#;
   Old_Italic_Letter_Ku                    :
      constant Unicode_Char := 16#10312#;
   Old_Italic_Letter_Er                    :
      constant Unicode_Char := 16#10313#;
   Old_Italic_Letter_Es                    :
      constant Unicode_Char := 16#10314#;
   Old_Italic_Letter_Te                    :
      constant Unicode_Char := 16#10315#;
   Old_Italic_Letter_U                     :
      constant Unicode_Char := 16#10316#;
   Old_Italic_Letter_Eks                   :
      constant Unicode_Char := 16#10317#;
   Old_Italic_Letter_Phe                   :
      constant Unicode_Char := 16#10318#;
   Old_Italic_Letter_Khe                   :
      constant Unicode_Char := 16#10319#;
   Old_Italic_Letter_Ef                    :
      constant Unicode_Char := 16#1031A#;
   Old_Italic_Letter_Ers                   :
      constant Unicode_Char := 16#1031B#;
   Old_Italic_Letter_Che                   :
      constant Unicode_Char := 16#1031C#;
   Old_Italic_Letter_Ii                    :
      constant Unicode_Char := 16#1031D#;
   Old_Italic_Letter_Uu                    :
      constant Unicode_Char := 16#1031E#;
   Old_Italic_Letter_Ess                   :
      constant Unicode_Char := 16#1031F#;
   Old_Italic_Numeral_One                  :
      constant Unicode_Char := 16#10320#;
   Old_Italic_Numeral_Five                 :
      constant Unicode_Char := 16#10321#;
   Old_Italic_Numeral_Ten                  :
      constant Unicode_Char := 16#10322#;
   Old_Italic_Numeral_Fifty                :
      constant Unicode_Char := 16#10323#;
end Unicode.Names.Old_Italic;
