--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Mongolian is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Mongolian_Birga                         : constant Unicode_Char := 16#1800#;
   Mongolian_Ellipsis                      : constant Unicode_Char := 16#1801#;
   Mongolian_Comma                         : constant Unicode_Char := 16#1802#;
   Mongolian_Full_Stop                     : constant Unicode_Char := 16#1803#;
   Mongolian_Colon                         : constant Unicode_Char := 16#1804#;
   Mongolian_Four_Dots                     : constant Unicode_Char := 16#1805#;
   Mongolian_Todo_Soft_Hyphen              : constant Unicode_Char := 16#1806#;
   Mongolian_Sibe_Syllable_Boundary_Marker : constant Unicode_Char := 16#1807#;
   Mongolian_Manchu_Comma                  : constant Unicode_Char := 16#1808#;
   Mongolian_Manchu_Full_Stop              : constant Unicode_Char := 16#1809#;
   Mongolian_Nirugu                        : constant Unicode_Char := 16#180A#;
   Mongolian_Free_Variation_Selector_One   : constant Unicode_Char := 16#180B#;
   Fvs1                                    :
      Unicode_Char renames Mongolian_Free_Variation_Selector_One;
   Mongolian_Free_Variation_Selector_Two   : constant Unicode_Char := 16#180C#;
   Fvs2                                    :
      Unicode_Char renames Mongolian_Free_Variation_Selector_Two;
   Mongolian_Free_Variation_Selector_Three : constant Unicode_Char := 16#180D#;
   Fvs3                                    :
      Unicode_Char renames Mongolian_Free_Variation_Selector_Three;
   Mongolian_Vowel_Separator               : constant Unicode_Char := 16#180E#;
   Mvs                                     :
      Unicode_Char renames Mongolian_Vowel_Separator;
   Mongolian_Digit_Zero                    : constant Unicode_Char := 16#1810#;
   Mongolian_Digit_One                     : constant Unicode_Char := 16#1811#;
   Mongolian_Digit_Two                     : constant Unicode_Char := 16#1812#;
   Mongolian_Digit_Three                   : constant Unicode_Char := 16#1813#;
   Mongolian_Digit_Four                    : constant Unicode_Char := 16#1814#;
   Mongolian_Digit_Five                    : constant Unicode_Char := 16#1815#;
   Mongolian_Digit_Six                     : constant Unicode_Char := 16#1816#;
   Mongolian_Digit_Seven                   : constant Unicode_Char := 16#1817#;
   Mongolian_Digit_Eight                   : constant Unicode_Char := 16#1818#;
   Mongolian_Digit_Nine                    : constant Unicode_Char := 16#1819#;
   Mongolian_Letter_A                      : constant Unicode_Char := 16#1820#;
   Mongolian_Letter_E                      : constant Unicode_Char := 16#1821#;
   Mongolian_Letter_I                      : constant Unicode_Char := 16#1822#;
   Mongolian_Letter_O                      : constant Unicode_Char := 16#1823#;
   Mongolian_Letter_U                      : constant Unicode_Char := 16#1824#;
   Mongolian_Letter_Oe                     : constant Unicode_Char := 16#1825#;
   Mongolian_Letter_Ue                     : constant Unicode_Char := 16#1826#;
   Mongolian_Letter_Ee                     : constant Unicode_Char := 16#1827#;
   Mongolian_Letter_Na                     : constant Unicode_Char := 16#1828#;
   Mongolian_Letter_Ang                    : constant Unicode_Char := 16#1829#;
   Mongolian_Letter_Ba                     : constant Unicode_Char := 16#182A#;
   Mongolian_Letter_Pa                     : constant Unicode_Char := 16#182B#;
   Mongolian_Letter_Qa                     : constant Unicode_Char := 16#182C#;
   Mongolian_Letter_Ga                     : constant Unicode_Char := 16#182D#;
   Mongolian_Letter_Ma                     : constant Unicode_Char := 16#182E#;
   Mongolian_Letter_La                     : constant Unicode_Char := 16#182F#;
   Mongolian_Letter_Sa                     : constant Unicode_Char := 16#1830#;
   Mongolian_Letter_Sha                    : constant Unicode_Char := 16#1831#;
   Mongolian_Letter_Ta                     : constant Unicode_Char := 16#1832#;
   Mongolian_Letter_Da                     : constant Unicode_Char := 16#1833#;
   Mongolian_Letter_Cha                    : constant Unicode_Char := 16#1834#;
   Mongolian_Letter_Ja                     : constant Unicode_Char := 16#1835#;
   Mongolian_Letter_Ya                     : constant Unicode_Char := 16#1836#;
   Mongolian_Letter_Ra                     : constant Unicode_Char := 16#1837#;
   Mongolian_Letter_Wa                     : constant Unicode_Char := 16#1838#;
   Mongolian_Letter_Fa                     : constant Unicode_Char := 16#1839#;
   Mongolian_Letter_Ka                     : constant Unicode_Char := 16#183A#;
   Mongolian_Letter_Kha                    : constant Unicode_Char := 16#183B#;
   Mongolian_Letter_Tsa                    : constant Unicode_Char := 16#183C#;
   Mongolian_Letter_Za                     : constant Unicode_Char := 16#183D#;
   Mongolian_Letter_Haa                    : constant Unicode_Char := 16#183E#;
   Mongolian_Letter_Zra                    : constant Unicode_Char := 16#183F#;
   Mongolian_Letter_Lha                    : constant Unicode_Char := 16#1840#;
   Mongolian_Letter_Zhi                    : constant Unicode_Char := 16#1841#;
   Mongolian_Letter_Chi                    : constant Unicode_Char := 16#1842#;
   Mongolian_Letter_Todo_Long_Vowel_Sign   : constant Unicode_Char := 16#1843#;
   Mongolian_Letter_Todo_E                 : constant Unicode_Char := 16#1844#;
   Mongolian_Letter_Todo_I                 : constant Unicode_Char := 16#1845#;
   Mongolian_Letter_Todo_O                 : constant Unicode_Char := 16#1846#;
   Mongolian_Letter_Todo_U                 : constant Unicode_Char := 16#1847#;
   Mongolian_Letter_Todo_Oe                : constant Unicode_Char := 16#1848#;
   Mongolian_Letter_Todo_Ue                : constant Unicode_Char := 16#1849#;
   Mongolian_Letter_Todo_Ang               : constant Unicode_Char := 16#184A#;
   Mongolian_Letter_Todo_Ba                : constant Unicode_Char := 16#184B#;
   Mongolian_Letter_Todo_Pa                : constant Unicode_Char := 16#184C#;
   Mongolian_Letter_Todo_Qa                : constant Unicode_Char := 16#184D#;
   Mongolian_Letter_Todo_Ga                : constant Unicode_Char := 16#184E#;
   Mongolian_Letter_Todo_Ma                : constant Unicode_Char := 16#184F#;
   Mongolian_Letter_Todo_Ta                : constant Unicode_Char := 16#1850#;
   Mongolian_Letter_Todo_Da                : constant Unicode_Char := 16#1851#;
   Mongolian_Letter_Todo_Cha               : constant Unicode_Char := 16#1852#;
   Mongolian_Letter_Todo_Ja                : constant Unicode_Char := 16#1853#;
   Mongolian_Letter_Todo_Tsa               : constant Unicode_Char := 16#1854#;
   Mongolian_Letter_Todo_Ya                : constant Unicode_Char := 16#1855#;
   Mongolian_Letter_Todo_Wa                : constant Unicode_Char := 16#1856#;
   Mongolian_Letter_Todo_Ka                : constant Unicode_Char := 16#1857#;
   Mongolian_Letter_Todo_Gaa               : constant Unicode_Char := 16#1858#;
   Mongolian_Letter_Todo_Haa               : constant Unicode_Char := 16#1859#;
   Mongolian_Letter_Todo_Jia               : constant Unicode_Char := 16#185A#;
   Mongolian_Letter_Todo_Nia               : constant Unicode_Char := 16#185B#;
   Mongolian_Letter_Todo_Dza               : constant Unicode_Char := 16#185C#;
   Mongolian_Letter_Sibe_E                 : constant Unicode_Char := 16#185D#;
   Mongolian_Letter_Sibe_I                 : constant Unicode_Char := 16#185E#;
   Mongolian_Letter_Sibe_Iy                : constant Unicode_Char := 16#185F#;
   Mongolian_Letter_Sibe_Ue                : constant Unicode_Char := 16#1860#;
   Mongolian_Letter_Sibe_U                 : constant Unicode_Char := 16#1861#;
   Mongolian_Letter_Sibe_Ang               : constant Unicode_Char := 16#1862#;
   Mongolian_Letter_Sibe_Ka                : constant Unicode_Char := 16#1863#;
   Mongolian_Letter_Sibe_Ga                : constant Unicode_Char := 16#1864#;
   Mongolian_Letter_Sibe_Ha                : constant Unicode_Char := 16#1865#;
   Mongolian_Letter_Sibe_Pa                : constant Unicode_Char := 16#1866#;
   Mongolian_Letter_Sibe_Sha               : constant Unicode_Char := 16#1867#;
   Mongolian_Letter_Sibe_Ta                : constant Unicode_Char := 16#1868#;
   Mongolian_Letter_Sibe_Da                : constant Unicode_Char := 16#1869#;
   Mongolian_Letter_Sibe_Ja                : constant Unicode_Char := 16#186A#;
   Mongolian_Letter_Sibe_Fa                : constant Unicode_Char := 16#186B#;
   Mongolian_Letter_Sibe_Gaa               : constant Unicode_Char := 16#186C#;
   Mongolian_Letter_Sibe_Haa               : constant Unicode_Char := 16#186D#;
   Mongolian_Letter_Sibe_Tsa               : constant Unicode_Char := 16#186E#;
   Mongolian_Letter_Sibe_Za                : constant Unicode_Char := 16#186F#;
   Mongolian_Letter_Sibe_Raa               : constant Unicode_Char := 16#1870#;
   Mongolian_Letter_Sibe_Cha               : constant Unicode_Char := 16#1871#;
   Mongolian_Letter_Sibe_Zha               : constant Unicode_Char := 16#1872#;
   Mongolian_Letter_Manchu_I               : constant Unicode_Char := 16#1873#;
   Mongolian_Letter_Manchu_Ka              : constant Unicode_Char := 16#1874#;
   Mongolian_Letter_Manchu_Ra              : constant Unicode_Char := 16#1875#;
   Mongolian_Letter_Manchu_Fa              : constant Unicode_Char := 16#1876#;
   Mongolian_Letter_Manchu_Zha             : constant Unicode_Char := 16#1877#;
   Mongolian_Letter_Ali_Gali_Anusvara_One  : constant Unicode_Char := 16#1880#;
   Mongolian_Letter_Ali_Gali_Visarga_One   : constant Unicode_Char := 16#1881#;
   Mongolian_Letter_Ali_Gali_Damaru        : constant Unicode_Char := 16#1882#;
   Mongolian_Letter_Ali_Gali_Ubadama       : constant Unicode_Char := 16#1883#;
   Mongolian_Letter_Ali_Gali_Inverted_Ubadama :
      constant Unicode_Char := 16#1884#;
   Mongolian_Letter_Ali_Gali_Baluda        : constant Unicode_Char := 16#1885#;
   Mongolian_Letter_Ali_Gali_Three_Baluda  : constant Unicode_Char := 16#1886#;
   Mongolian_Letter_Ali_Gali_A             : constant Unicode_Char := 16#1887#;
   Mongolian_Letter_Ali_Gali_I             : constant Unicode_Char := 16#1888#;
   Mongolian_Letter_Ali_Gali_Ka            : constant Unicode_Char := 16#1889#;
   Mongolian_Letter_Ali_Gali_Nga           : constant Unicode_Char := 16#188A#;
   Mongolian_Letter_Ali_Gali_Ca            : constant Unicode_Char := 16#188B#;
   Mongolian_Letter_Ali_Gali_Tta           : constant Unicode_Char := 16#188C#;
   Mongolian_Letter_Ali_Gali_Ttha          : constant Unicode_Char := 16#188D#;
   Mongolian_Letter_Ali_Gali_Dda           : constant Unicode_Char := 16#188E#;
   Mongolian_Letter_Ali_Gali_Nna           : constant Unicode_Char := 16#188F#;
   Mongolian_Letter_Ali_Gali_Ta            : constant Unicode_Char := 16#1890#;
   Mongolian_Letter_Ali_Gali_Da            : constant Unicode_Char := 16#1891#;
   Mongolian_Letter_Ali_Gali_Pa            : constant Unicode_Char := 16#1892#;
   Mongolian_Letter_Ali_Gali_Pha           : constant Unicode_Char := 16#1893#;
   Mongolian_Letter_Ali_Gali_Ssa           : constant Unicode_Char := 16#1894#;
   Mongolian_Letter_Ali_Gali_Zha           : constant Unicode_Char := 16#1895#;
   Mongolian_Letter_Ali_Gali_Za            : constant Unicode_Char := 16#1896#;
   Mongolian_Letter_Ali_Gali_Ah            : constant Unicode_Char := 16#1897#;
   Mongolian_Letter_Todo_Ali_Gali_Ta       : constant Unicode_Char := 16#1898#;
   Mongolian_Letter_Todo_Ali_Gali_Zha      : constant Unicode_Char := 16#1899#;
   Mongolian_Letter_Manchu_Ali_Gali_Gha    : constant Unicode_Char := 16#189A#;
   Mongolian_Letter_Manchu_Ali_Gali_Nga    : constant Unicode_Char := 16#189B#;
   Mongolian_Letter_Manchu_Ali_Gali_Ca     : constant Unicode_Char := 16#189C#;
   Mongolian_Letter_Manchu_Ali_Gali_Jha    : constant Unicode_Char := 16#189D#;
   Mongolian_Letter_Manchu_Ali_Gali_Tta    : constant Unicode_Char := 16#189E#;
   Mongolian_Letter_Manchu_Ali_Gali_Ddha   : constant Unicode_Char := 16#189F#;
   Mongolian_Letter_Manchu_Ali_Gali_Ta     : constant Unicode_Char := 16#18A0#;
   Mongolian_Letter_Manchu_Ali_Gali_Dha    : constant Unicode_Char := 16#18A1#;
   Mongolian_Letter_Manchu_Ali_Gali_Ssa    : constant Unicode_Char := 16#18A2#;
   Mongolian_Letter_Manchu_Ali_Gali_Cya    : constant Unicode_Char := 16#18A3#;
   Mongolian_Letter_Manchu_Ali_Gali_Zha    : constant Unicode_Char := 16#18A4#;
   Mongolian_Letter_Manchu_Ali_Gali_Za     : constant Unicode_Char := 16#18A5#;
   Mongolian_Letter_Ali_Gali_Half_U        : constant Unicode_Char := 16#18A6#;
   Mongolian_Letter_Ali_Gali_Half_Ya       : constant Unicode_Char := 16#18A7#;
   Mongolian_Letter_Manchu_Ali_Gali_Bha    : constant Unicode_Char := 16#18A8#;
   Mongolian_Letter_Ali_Gali_Dagalga       : constant Unicode_Char := 16#18A9#;
   Mongolian_Letter_Manchu_Ali_Gali_Lha    : constant Unicode_Char := 16#18AA#;
end Unicode.Names.Mongolian;
