--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Warang_Citi is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Warang_Citi_Capital_Letter_Ngaa         :
      constant Unicode_Char := 16#118A0#;
   Warang_Citi_Capital_Letter_A            :
      constant Unicode_Char := 16#118A1#;
   Warang_Citi_Capital_Letter_Wi           :
      constant Unicode_Char := 16#118A2#;
   Warang_Citi_Capital_Letter_Yu           :
      constant Unicode_Char := 16#118A3#;
   Warang_Citi_Capital_Letter_Ya           :
      constant Unicode_Char := 16#118A4#;
   Warang_Citi_Capital_Letter_Yo           :
      constant Unicode_Char := 16#118A5#;
   Warang_Citi_Capital_Letter_Ii           :
      constant Unicode_Char := 16#118A6#;
   Warang_Citi_Capital_Letter_Uu           :
      constant Unicode_Char := 16#118A7#;
   Warang_Citi_Capital_Letter_E            :
      constant Unicode_Char := 16#118A8#;
   Warang_Citi_Capital_Letter_O            :
      constant Unicode_Char := 16#118A9#;
   Warang_Citi_Capital_Letter_Ang          :
      constant Unicode_Char := 16#118AA#;
   Warang_Citi_Capital_Letter_Ga           :
      constant Unicode_Char := 16#118AB#;
   Warang_Citi_Capital_Letter_Ko           :
      constant Unicode_Char := 16#118AC#;
   Warang_Citi_Capital_Letter_Eny          :
      constant Unicode_Char := 16#118AD#;
   Warang_Citi_Capital_Letter_Yuj          :
      constant Unicode_Char := 16#118AE#;
   Warang_Citi_Capital_Letter_Uc           :
      constant Unicode_Char := 16#118AF#;
   Warang_Citi_Capital_Letter_Enn          :
      constant Unicode_Char := 16#118B0#;
   Warang_Citi_Capital_Letter_Odd          :
      constant Unicode_Char := 16#118B1#;
   Warang_Citi_Capital_Letter_Tte          :
      constant Unicode_Char := 16#118B2#;
   Warang_Citi_Capital_Letter_Nung         :
      constant Unicode_Char := 16#118B3#;
   Warang_Citi_Capital_Letter_Da           :
      constant Unicode_Char := 16#118B4#;
   Warang_Citi_Capital_Letter_At           :
      constant Unicode_Char := 16#118B5#;
   Warang_Citi_Capital_Letter_Am           :
      constant Unicode_Char := 16#118B6#;
   Warang_Citi_Capital_Letter_Bu           :
      constant Unicode_Char := 16#118B7#;
   Warang_Citi_Capital_Letter_Pu           :
      constant Unicode_Char := 16#118B8#;
   Warang_Citi_Capital_Letter_Hiyo         :
      constant Unicode_Char := 16#118B9#;
   Warang_Citi_Capital_Letter_Holo         :
      constant Unicode_Char := 16#118BA#;
   Warang_Citi_Capital_Letter_Horr         :
      constant Unicode_Char := 16#118BB#;
   Warang_Citi_Capital_Letter_Har          :
      constant Unicode_Char := 16#118BC#;
   Warang_Citi_Capital_Letter_Ssuu         :
      constant Unicode_Char := 16#118BD#;
   Warang_Citi_Capital_Letter_Sii          :
      constant Unicode_Char := 16#118BE#;
   Warang_Citi_Capital_Letter_Viyo         :
      constant Unicode_Char := 16#118BF#;
   Warang_Citi_Small_Letter_Ngaa           :
      constant Unicode_Char := 16#118C0#;
   Warang_Citi_Small_Letter_A              :
      constant Unicode_Char := 16#118C1#;
   Warang_Citi_Small_Letter_Wi             :
      constant Unicode_Char := 16#118C2#;
   Warang_Citi_Small_Letter_Yu             :
      constant Unicode_Char := 16#118C3#;
   Warang_Citi_Small_Letter_Ya             :
      constant Unicode_Char := 16#118C4#;
   Warang_Citi_Small_Letter_Yo             :
      constant Unicode_Char := 16#118C5#;
   Warang_Citi_Small_Letter_Ii             :
      constant Unicode_Char := 16#118C6#;
   Warang_Citi_Small_Letter_Uu             :
      constant Unicode_Char := 16#118C7#;
   Warang_Citi_Small_Letter_E              :
      constant Unicode_Char := 16#118C8#;
   Warang_Citi_Small_Letter_O              :
      constant Unicode_Char := 16#118C9#;
   Warang_Citi_Small_Letter_Ang            :
      constant Unicode_Char := 16#118CA#;
   Warang_Citi_Small_Letter_Ga             :
      constant Unicode_Char := 16#118CB#;
   Warang_Citi_Small_Letter_Ko             :
      constant Unicode_Char := 16#118CC#;
   Warang_Citi_Small_Letter_Eny            :
      constant Unicode_Char := 16#118CD#;
   Warang_Citi_Small_Letter_Yuj            :
      constant Unicode_Char := 16#118CE#;
   Warang_Citi_Small_Letter_Uc             :
      constant Unicode_Char := 16#118CF#;
   Warang_Citi_Small_Letter_Enn            :
      constant Unicode_Char := 16#118D0#;
   Warang_Citi_Small_Letter_Odd            :
      constant Unicode_Char := 16#118D1#;
   Warang_Citi_Small_Letter_Tte            :
      constant Unicode_Char := 16#118D2#;
   Warang_Citi_Small_Letter_Nung           :
      constant Unicode_Char := 16#118D3#;
   Warang_Citi_Small_Letter_Da             :
      constant Unicode_Char := 16#118D4#;
   Warang_Citi_Small_Letter_At             :
      constant Unicode_Char := 16#118D5#;
   Warang_Citi_Small_Letter_Am             :
      constant Unicode_Char := 16#118D6#;
   Warang_Citi_Small_Letter_Bu             :
      constant Unicode_Char := 16#118D7#;
   Warang_Citi_Small_Letter_Pu             :
      constant Unicode_Char := 16#118D8#;
   Warang_Citi_Small_Letter_Hiyo           :
      constant Unicode_Char := 16#118D9#;
   Warang_Citi_Small_Letter_Holo           :
      constant Unicode_Char := 16#118DA#;
   Warang_Citi_Small_Letter_Horr           :
      constant Unicode_Char := 16#118DB#;
   Warang_Citi_Small_Letter_Har            :
      constant Unicode_Char := 16#118DC#;
   Warang_Citi_Small_Letter_Ssuu           :
      constant Unicode_Char := 16#118DD#;
   Warang_Citi_Small_Letter_Sii            :
      constant Unicode_Char := 16#118DE#;
   Warang_Citi_Small_Letter_Viyo           :
      constant Unicode_Char := 16#118DF#;
   Warang_Citi_Digit_Zero                  :
      constant Unicode_Char := 16#118E0#;
   Warang_Citi_Digit_One                   :
      constant Unicode_Char := 16#118E1#;
   Warang_Citi_Digit_Two                   :
      constant Unicode_Char := 16#118E2#;
   Warang_Citi_Digit_Three                 :
      constant Unicode_Char := 16#118E3#;
   Warang_Citi_Digit_Four                  :
      constant Unicode_Char := 16#118E4#;
   Warang_Citi_Digit_Five                  :
      constant Unicode_Char := 16#118E5#;
   Warang_Citi_Digit_Six                   :
      constant Unicode_Char := 16#118E6#;
   Warang_Citi_Digit_Seven                 :
      constant Unicode_Char := 16#118E7#;
   Warang_Citi_Digit_Eight                 :
      constant Unicode_Char := 16#118E8#;
   Warang_Citi_Digit_Nine                  :
      constant Unicode_Char := 16#118E9#;
   Warang_Citi_Number_Ten                  :
      constant Unicode_Char := 16#118EA#;
   Warang_Citi_Number_Twenty               :
      constant Unicode_Char := 16#118EB#;
   Warang_Citi_Number_Thirty               :
      constant Unicode_Char := 16#118EC#;
   Warang_Citi_Number_Forty                :
      constant Unicode_Char := 16#118ED#;
   Warang_Citi_Number_Fifty                :
      constant Unicode_Char := 16#118EE#;
   Warang_Citi_Number_Sixty                :
      constant Unicode_Char := 16#118EF#;
   Warang_Citi_Number_Seventy              :
      constant Unicode_Char := 16#118F0#;
   Warang_Citi_Number_Eighty               :
      constant Unicode_Char := 16#118F1#;
   Warang_Citi_Number_Ninety               :
      constant Unicode_Char := 16#118F2#;
   Warang_Citi_Om                          :
      constant Unicode_Char := 16#118FF#;
end Unicode.Names.Warang_Citi;
