--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Canadian_Aboriginal_Ext is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Canadian_Syllabics_Oy                   : constant Unicode_Char := 16#18B0#;
   Canadian_Syllabics_Ay                   : constant Unicode_Char := 16#18B1#;
   Canadian_Syllabics_Aay                  : constant Unicode_Char := 16#18B2#;
   Canadian_Syllabics_Way                  : constant Unicode_Char := 16#18B3#;
   Canadian_Syllabics_Poy                  : constant Unicode_Char := 16#18B4#;
   Canadian_Syllabics_Pay                  : constant Unicode_Char := 16#18B5#;
   Canadian_Syllabics_Pwoy                 : constant Unicode_Char := 16#18B6#;
   Canadian_Syllabics_Tay                  : constant Unicode_Char := 16#18B7#;
   Canadian_Syllabics_Kay                  : constant Unicode_Char := 16#18B8#;
   Canadian_Syllabics_Kway                 : constant Unicode_Char := 16#18B9#;
   Canadian_Syllabics_May                  : constant Unicode_Char := 16#18BA#;
   Canadian_Syllabics_Noy                  : constant Unicode_Char := 16#18BB#;
   Canadian_Syllabics_Nay                  : constant Unicode_Char := 16#18BC#;
   Canadian_Syllabics_Lay                  : constant Unicode_Char := 16#18BD#;
   Canadian_Syllabics_Soy                  : constant Unicode_Char := 16#18BE#;
   Canadian_Syllabics_Say                  : constant Unicode_Char := 16#18BF#;
   Canadian_Syllabics_Shoy                 : constant Unicode_Char := 16#18C0#;
   Canadian_Syllabics_Shay                 : constant Unicode_Char := 16#18C1#;
   Canadian_Syllabics_Shwoy                : constant Unicode_Char := 16#18C2#;
   Canadian_Syllabics_Yoy                  : constant Unicode_Char := 16#18C3#;
   Canadian_Syllabics_Yay                  : constant Unicode_Char := 16#18C4#;
   Canadian_Syllabics_Ray                  : constant Unicode_Char := 16#18C5#;
   Canadian_Syllabics_Nwi                  : constant Unicode_Char := 16#18C6#;
   Canadian_Syllabics_Ojibway_Nwi          : constant Unicode_Char := 16#18C7#;
   Canadian_Syllabics_Nwii                 : constant Unicode_Char := 16#18C8#;
   Canadian_Syllabics_Ojibway_Nwii         : constant Unicode_Char := 16#18C9#;
   Canadian_Syllabics_Nwo                  : constant Unicode_Char := 16#18CA#;
   Canadian_Syllabics_Ojibway_Nwo          : constant Unicode_Char := 16#18CB#;
   Canadian_Syllabics_Nwoo                 : constant Unicode_Char := 16#18CC#;
   Canadian_Syllabics_Ojibway_Nwoo         : constant Unicode_Char := 16#18CD#;
   Canadian_Syllabics_Rwee                 : constant Unicode_Char := 16#18CE#;
   Canadian_Syllabics_Rwi                  : constant Unicode_Char := 16#18CF#;
   Canadian_Syllabics_Rwii                 : constant Unicode_Char := 16#18D0#;
   Canadian_Syllabics_Rwo                  : constant Unicode_Char := 16#18D1#;
   Canadian_Syllabics_Rwoo                 : constant Unicode_Char := 16#18D2#;
   Canadian_Syllabics_Rwa                  : constant Unicode_Char := 16#18D3#;
   Canadian_Syllabics_Ojibway_P            : constant Unicode_Char := 16#18D4#;
   Canadian_Syllabics_Ojibway_T            : constant Unicode_Char := 16#18D5#;
   Canadian_Syllabics_Ojibway_K            : constant Unicode_Char := 16#18D6#;
   Canadian_Syllabics_Ojibway_C            : constant Unicode_Char := 16#18D7#;
   Canadian_Syllabics_Ojibway_M            : constant Unicode_Char := 16#18D8#;
   Canadian_Syllabics_Ojibway_N            : constant Unicode_Char := 16#18D9#;
   Canadian_Syllabics_Ojibway_S            : constant Unicode_Char := 16#18DA#;
   Canadian_Syllabics_Ojibway_Sh           : constant Unicode_Char := 16#18DB#;
   Canadian_Syllabics_Eastern_W            : constant Unicode_Char := 16#18DC#;
   Canadian_Syllabics_Western_W            : constant Unicode_Char := 16#18DD#;
   Canadian_Syllabics_Final_Small_Ring     : constant Unicode_Char := 16#18DE#;
   Canadian_Syllabics_Final_Raised_Dot     : constant Unicode_Char := 16#18DF#;
   Canadian_Syllabics_R_Cree_Rwe           : constant Unicode_Char := 16#18E0#;
   Canadian_Syllabics_West_Cree_Loo        : constant Unicode_Char := 16#18E1#;
   Canadian_Syllabics_West_Cree_Laa        : constant Unicode_Char := 16#18E2#;
   Canadian_Syllabics_Thwe                 : constant Unicode_Char := 16#18E3#;
   Canadian_Syllabics_Thwa                 : constant Unicode_Char := 16#18E4#;
   Canadian_Syllabics_Tthwe                : constant Unicode_Char := 16#18E5#;
   Canadian_Syllabics_Tthoo                : constant Unicode_Char := 16#18E6#;
   Canadian_Syllabics_Tthaa                : constant Unicode_Char := 16#18E7#;
   Canadian_Syllabics_Tlhwe                : constant Unicode_Char := 16#18E8#;
   Canadian_Syllabics_Tlhoo                : constant Unicode_Char := 16#18E9#;
   Canadian_Syllabics_Sayisi_Shwe          : constant Unicode_Char := 16#18EA#;
   Canadian_Syllabics_Sayisi_Shoo          : constant Unicode_Char := 16#18EB#;
   Canadian_Syllabics_Sayisi_Hoo           : constant Unicode_Char := 16#18EC#;
   Canadian_Syllabics_Carrier_Gwu          : constant Unicode_Char := 16#18ED#;
   Canadian_Syllabics_Carrier_Dene_Gee     : constant Unicode_Char := 16#18EE#;
   Canadian_Syllabics_Carrier_Gaa          : constant Unicode_Char := 16#18EF#;
   Canadian_Syllabics_Carrier_Gwa          : constant Unicode_Char := 16#18F0#;
   Canadian_Syllabics_Sayisi_Juu           : constant Unicode_Char := 16#18F1#;
   Canadian_Syllabics_Carrier_Jwa          : constant Unicode_Char := 16#18F2#;
   Canadian_Syllabics_Beaver_Dene_L        : constant Unicode_Char := 16#18F3#;
   Canadian_Syllabics_Beaver_Dene_R        : constant Unicode_Char := 16#18F4#;
   Canadian_Syllabics_Carrier_Dental_S     : constant Unicode_Char := 16#18F5#;
end Unicode.Names.Canadian_Aboriginal_Ext;
