--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Alchemical_Symbols is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Alchemical_Symbol_For_Quintessence      :
      constant Unicode_Char := 16#1F700#;
   Alchemical_Symbol_For_Air               :
      constant Unicode_Char := 16#1F701#;
   Alchemical_Symbol_For_Fire              :
      constant Unicode_Char := 16#1F702#;
   Alchemical_Symbol_For_Earth             :
      constant Unicode_Char := 16#1F703#;
   Alchemical_Symbol_For_Water             :
      constant Unicode_Char := 16#1F704#;
   Alchemical_Symbol_For_Aquafortis        :
      constant Unicode_Char := 16#1F705#;
   Alchemical_Symbol_For_Aqua_Regia        :
      constant Unicode_Char := 16#1F706#;
   Alchemical_Symbol_For_Aqua_Regia_2      :
      constant Unicode_Char := 16#1F707#;
   Alchemical_Symbol_For_Aqua_Vitae        :
      constant Unicode_Char := 16#1F708#;
   Alchemical_Symbol_For_Aqua_Vitae_2      :
      constant Unicode_Char := 16#1F709#;
   Alchemical_Symbol_For_Vinegar           :
      constant Unicode_Char := 16#1F70A#;
   Alchemical_Symbol_For_Vinegar_2         :
      constant Unicode_Char := 16#1F70B#;
   Alchemical_Symbol_For_Vinegar_3         :
      constant Unicode_Char := 16#1F70C#;
   Alchemical_Symbol_For_Sulfur            :
      constant Unicode_Char := 16#1F70D#;
   Alchemical_Symbol_For_Philosophers_Sulfur :
      constant Unicode_Char := 16#1F70E#;
   Alchemical_Symbol_For_Black_Sulfur      :
      constant Unicode_Char := 16#1F70F#;
   Alchemical_Symbol_For_Mercury_Sublimate :
      constant Unicode_Char := 16#1F710#;
   Alchemical_Symbol_For_Mercury_Sublimate_2 :
      constant Unicode_Char := 16#1F711#;
   Alchemical_Symbol_For_Mercury_Sublimate_3 :
      constant Unicode_Char := 16#1F712#;
   Alchemical_Symbol_For_Cinnabar          :
      constant Unicode_Char := 16#1F713#;
   Alchemical_Symbol_For_Salt              :
      constant Unicode_Char := 16#1F714#;
   Alchemical_Symbol_For_Nitre             :
      constant Unicode_Char := 16#1F715#;
   Alchemical_Symbol_For_Vitriol           :
      constant Unicode_Char := 16#1F716#;
   Alchemical_Symbol_For_Vitriol_2         :
      constant Unicode_Char := 16#1F717#;
   Alchemical_Symbol_For_Rock_Salt         :
      constant Unicode_Char := 16#1F718#;
   Alchemical_Symbol_For_Rock_Salt_2       :
      constant Unicode_Char := 16#1F719#;
   Alchemical_Symbol_For_Gold              :
      constant Unicode_Char := 16#1F71A#;
   Alchemical_Symbol_For_Silver            :
      constant Unicode_Char := 16#1F71B#;
   Alchemical_Symbol_For_Iron_Ore          :
      constant Unicode_Char := 16#1F71C#;
   Alchemical_Symbol_For_Iron_Ore_2        :
      constant Unicode_Char := 16#1F71D#;
   Alchemical_Symbol_For_Crocus_Of_Iron    :
      constant Unicode_Char := 16#1F71E#;
   Alchemical_Symbol_For_Regulus_Of_Iron   :
      constant Unicode_Char := 16#1F71F#;
   Alchemical_Symbol_For_Copper_Ore        :
      constant Unicode_Char := 16#1F720#;
   Alchemical_Symbol_For_Iron_Copper_Ore   :
      constant Unicode_Char := 16#1F721#;
   Alchemical_Symbol_For_Sublimate_Of_Copper :
      constant Unicode_Char := 16#1F722#;
   Alchemical_Symbol_For_Crocus_Of_Copper  :
      constant Unicode_Char := 16#1F723#;
   Alchemical_Symbol_For_Crocus_Of_Copper_2 :
      constant Unicode_Char := 16#1F724#;
   Alchemical_Symbol_For_Copper_Antimoniate :
      constant Unicode_Char := 16#1F725#;
   Alchemical_Symbol_For_Salt_Of_Copper_Antimoniate :
      constant Unicode_Char := 16#1F726#;
   Alchemical_Symbol_For_Sublimate_Of_Salt_Of_Copper :
      constant Unicode_Char := 16#1F727#;
   Alchemical_Symbol_For_Verdigris         :
      constant Unicode_Char := 16#1F728#;
   Alchemical_Symbol_For_Tin_Ore           :
      constant Unicode_Char := 16#1F729#;
   Alchemical_Symbol_For_Lead_Ore          :
      constant Unicode_Char := 16#1F72A#;
   Alchemical_Symbol_For_Antimony_Ore      :
      constant Unicode_Char := 16#1F72B#;
   Alchemical_Symbol_For_Sublimate_Of_Antimony :
      constant Unicode_Char := 16#1F72C#;
   Alchemical_Symbol_For_Salt_Of_Antimony  :
      constant Unicode_Char := 16#1F72D#;
   Alchemical_Symbol_For_Sublimate_Of_Salt_Of_Antimony :
      constant Unicode_Char := 16#1F72E#;
   Alchemical_Symbol_For_Vinegar_Of_Antimony :
      constant Unicode_Char := 16#1F72F#;
   Alchemical_Symbol_For_Regulus_Of_Antimony :
      constant Unicode_Char := 16#1F730#;
   Alchemical_Symbol_For_Regulus_Of_Antimony_2 :
      constant Unicode_Char := 16#1F731#;
   Alchemical_Symbol_For_Regulus           :
      constant Unicode_Char := 16#1F732#;
   Alchemical_Symbol_For_Regulus_2         :
      constant Unicode_Char := 16#1F733#;
   Alchemical_Symbol_For_Regulus_3         :
      constant Unicode_Char := 16#1F734#;
   Alchemical_Symbol_For_Regulus_4         :
      constant Unicode_Char := 16#1F735#;
   Alchemical_Symbol_For_Alkali            :
      constant Unicode_Char := 16#1F736#;
   Alchemical_Symbol_For_Alkali_2          :
      constant Unicode_Char := 16#1F737#;
   Alchemical_Symbol_For_Marcasite         :
      constant Unicode_Char := 16#1F738#;
   Alchemical_Symbol_For_Sal_Ammoniac      :
      constant Unicode_Char := 16#1F739#;
   Alchemical_Symbol_For_Arsenic           :
      constant Unicode_Char := 16#1F73A#;
   Alchemical_Symbol_For_Realgar           :
      constant Unicode_Char := 16#1F73B#;
   Alchemical_Symbol_For_Realgar_2         :
      constant Unicode_Char := 16#1F73C#;
   Alchemical_Symbol_For_Auripigment       :
      constant Unicode_Char := 16#1F73D#;
   Alchemical_Symbol_For_Bismuth_Ore       :
      constant Unicode_Char := 16#1F73E#;
   Alchemical_Symbol_For_Tartar            :
      constant Unicode_Char := 16#1F73F#;
   Alchemical_Symbol_For_Tartar_2          :
      constant Unicode_Char := 16#1F740#;
   Alchemical_Symbol_For_Quick_Lime        :
      constant Unicode_Char := 16#1F741#;
   Alchemical_Symbol_For_Borax             :
      constant Unicode_Char := 16#1F742#;
   Alchemical_Symbol_For_Borax_2           :
      constant Unicode_Char := 16#1F743#;
   Alchemical_Symbol_For_Borax_3           :
      constant Unicode_Char := 16#1F744#;
   Alchemical_Symbol_For_Alum              :
      constant Unicode_Char := 16#1F745#;
   Alchemical_Symbol_For_Oil               :
      constant Unicode_Char := 16#1F746#;
   Alchemical_Symbol_For_Spirit            :
      constant Unicode_Char := 16#1F747#;
   Alchemical_Symbol_For_Tincture          :
      constant Unicode_Char := 16#1F748#;
   Alchemical_Symbol_For_Gum               :
      constant Unicode_Char := 16#1F749#;
   Alchemical_Symbol_For_Wax               :
      constant Unicode_Char := 16#1F74A#;
   Alchemical_Symbol_For_Powder            :
      constant Unicode_Char := 16#1F74B#;
   Alchemical_Symbol_For_Calx              :
      constant Unicode_Char := 16#1F74C#;
   Alchemical_Symbol_For_Tutty             :
      constant Unicode_Char := 16#1F74D#;
   Alchemical_Symbol_For_Caput_Mortuum     :
      constant Unicode_Char := 16#1F74E#;
   Alchemical_Symbol_For_Scepter_Of_Jove   :
      constant Unicode_Char := 16#1F74F#;
   Alchemical_Symbol_For_Caduceus          :
      constant Unicode_Char := 16#1F750#;
   Alchemical_Symbol_For_Trident           :
      constant Unicode_Char := 16#1F751#;
   Alchemical_Symbol_For_Starred_Trident   :
      constant Unicode_Char := 16#1F752#;
   Alchemical_Symbol_For_Lodestone         :
      constant Unicode_Char := 16#1F753#;
   Alchemical_Symbol_For_Soap              :
      constant Unicode_Char := 16#1F754#;
   Alchemical_Symbol_For_Urine             :
      constant Unicode_Char := 16#1F755#;
   Alchemical_Symbol_For_Horse_Dung        :
      constant Unicode_Char := 16#1F756#;
   Alchemical_Symbol_For_Ashes             :
      constant Unicode_Char := 16#1F757#;
   Alchemical_Symbol_For_Pot_Ashes         :
      constant Unicode_Char := 16#1F758#;
   Alchemical_Symbol_For_Brick             :
      constant Unicode_Char := 16#1F759#;
   Alchemical_Symbol_For_Powdered_Brick    :
      constant Unicode_Char := 16#1F75A#;
   Alchemical_Symbol_For_Amalgam           :
      constant Unicode_Char := 16#1F75B#;
   Alchemical_Symbol_For_Stratum_Super_Stratum :
      constant Unicode_Char := 16#1F75C#;
   Alchemical_Symbol_For_Stratum_Super_Stratum_2 :
      constant Unicode_Char := 16#1F75D#;
   Alchemical_Symbol_For_Sublimation       :
      constant Unicode_Char := 16#1F75E#;
   Alchemical_Symbol_For_Precipitate       :
      constant Unicode_Char := 16#1F75F#;
   Alchemical_Symbol_For_Distill           :
      constant Unicode_Char := 16#1F760#;
   Alchemical_Symbol_For_Dissolve          :
      constant Unicode_Char := 16#1F761#;
   Alchemical_Symbol_For_Dissolve_2        :
      constant Unicode_Char := 16#1F762#;
   Alchemical_Symbol_For_Purify            :
      constant Unicode_Char := 16#1F763#;
   Alchemical_Symbol_For_Putrefaction      :
      constant Unicode_Char := 16#1F764#;
   Alchemical_Symbol_For_Crucible          :
      constant Unicode_Char := 16#1F765#;
   Alchemical_Symbol_For_Crucible_2        :
      constant Unicode_Char := 16#1F766#;
   Alchemical_Symbol_For_Crucible_3        :
      constant Unicode_Char := 16#1F767#;
   Alchemical_Symbol_For_Crucible_4        :
      constant Unicode_Char := 16#1F768#;
   Alchemical_Symbol_For_Crucible_5        :
      constant Unicode_Char := 16#1F769#;
   Alchemical_Symbol_For_Alembic           :
      constant Unicode_Char := 16#1F76A#;
   Alchemical_Symbol_For_Bath_Of_Mary      :
      constant Unicode_Char := 16#1F76B#;
   Alchemical_Symbol_For_Bath_Of_Vapours   :
      constant Unicode_Char := 16#1F76C#;
   Alchemical_Symbol_For_Retort            :
      constant Unicode_Char := 16#1F76D#;
   Alchemical_Symbol_For_Hour              :
      constant Unicode_Char := 16#1F76E#;
   Alchemical_Symbol_For_Night             :
      constant Unicode_Char := 16#1F76F#;
   Alchemical_Symbol_For_Day_Night         :
      constant Unicode_Char := 16#1F770#;
   Alchemical_Symbol_For_Month             :
      constant Unicode_Char := 16#1F771#;
   Alchemical_Symbol_For_Half_Dram         :
      constant Unicode_Char := 16#1F772#;
   Alchemical_Symbol_For_Half_Ounce        :
      constant Unicode_Char := 16#1F773#;
end Unicode.Names.Alchemical_Symbols;
