--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Runic is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Runic_Letter_Fehu_Feoh_Fe_F             : constant Unicode_Char := 16#16A0#;
   Runic_Letter_V                          : constant Unicode_Char := 16#16A1#;
   Runic_Letter_Uruz_Ur_U                  : constant Unicode_Char := 16#16A2#;
   Runic_Letter_Yr                         : constant Unicode_Char := 16#16A3#;
   Runic_Letter_Y                          : constant Unicode_Char := 16#16A4#;
   Runic_Letter_W                          : constant Unicode_Char := 16#16A5#;
   Runic_Letter_Thurisaz_Thurs_Thorn       : constant Unicode_Char := 16#16A6#;
   Runic_Letter_Eth                        : constant Unicode_Char := 16#16A7#;
   Runic_Letter_Ansuz_A                    : constant Unicode_Char := 16#16A8#;
   Runic_Letter_Os_O                       : constant Unicode_Char := 16#16A9#;
   Runic_Letter_Ac_A                       : constant Unicode_Char := 16#16AA#;
   Runic_Letter_Aesc                       : constant Unicode_Char := 16#16AB#;
   Runic_Letter_Long_Branch_Oss_O          : constant Unicode_Char := 16#16AC#;
   Runic_Letter_Short_Twig_Oss_O           : constant Unicode_Char := 16#16AD#;
   Runic_Letter_O                          : constant Unicode_Char := 16#16AE#;
   Runic_Letter_Oe                         : constant Unicode_Char := 16#16AF#;
   Runic_Letter_On                         : constant Unicode_Char := 16#16B0#;
   Runic_Letter_Raido_Rad_Reid_R           : constant Unicode_Char := 16#16B1#;
   Runic_Letter_Kauna                      : constant Unicode_Char := 16#16B2#;
   Runic_Letter_Cen                        : constant Unicode_Char := 16#16B3#;
   Runic_Letter_Kaun_K                     : constant Unicode_Char := 16#16B4#;
   Runic_Letter_G                          : constant Unicode_Char := 16#16B5#;
   Runic_Letter_Eng                        : constant Unicode_Char := 16#16B6#;
   Runic_Letter_Gebo_Gyfu_G                : constant Unicode_Char := 16#16B7#;
   Runic_Letter_Gar                        : constant Unicode_Char := 16#16B8#;
   Runic_Letter_Wunjo_Wynn_W               : constant Unicode_Char := 16#16B9#;
   Runic_Letter_Haglaz_H                   : constant Unicode_Char := 16#16BA#;
   Runic_Letter_Haegl_H                    : constant Unicode_Char := 16#16BB#;
   Runic_Letter_Long_Branch_Hagall_H       : constant Unicode_Char := 16#16BC#;
   Runic_Letter_Short_Twig_Hagall_H        : constant Unicode_Char := 16#16BD#;
   Runic_Letter_Naudiz_Nyd_Naud_N          : constant Unicode_Char := 16#16BE#;
   Runic_Letter_Short_Twig_Naud_N          : constant Unicode_Char := 16#16BF#;
   Runic_Letter_Dotted_N                   : constant Unicode_Char := 16#16C0#;
   Runic_Letter_Isaz_Is_Iss_I              : constant Unicode_Char := 16#16C1#;
   Runic_Letter_E                          : constant Unicode_Char := 16#16C2#;
   Runic_Letter_Jeran_J                    : constant Unicode_Char := 16#16C3#;
   Runic_Letter_Ger                        : constant Unicode_Char := 16#16C4#;
   Runic_Letter_Long_Branch_Ar_Ae          : constant Unicode_Char := 16#16C5#;
   Runic_Letter_Short_Twig_Ar_A            : constant Unicode_Char := 16#16C6#;
   Runic_Letter_Iwaz_Eoh                   : constant Unicode_Char := 16#16C7#;
   Runic_Letter_Pertho_Peorth_P            : constant Unicode_Char := 16#16C8#;
   Runic_Letter_Algiz_Eolhx                : constant Unicode_Char := 16#16C9#;
   Runic_Letter_Sowilo_S                   : constant Unicode_Char := 16#16CA#;
   Runic_Letter_Sigel_Long_Branch_Sol_S    : constant Unicode_Char := 16#16CB#;
   Runic_Letter_Short_Twig_Sol_S           : constant Unicode_Char := 16#16CC#;
   Runic_Letter_C                          : constant Unicode_Char := 16#16CD#;
   Runic_Letter_Z                          : constant Unicode_Char := 16#16CE#;
   Runic_Letter_Tiwaz_Tir_Tyr_T            : constant Unicode_Char := 16#16CF#;
   Runic_Letter_Short_Twig_Tyr_T           : constant Unicode_Char := 16#16D0#;
   Runic_Letter_D                          : constant Unicode_Char := 16#16D1#;
   Runic_Letter_Berkanan_Beorc_Bjarkan_B   : constant Unicode_Char := 16#16D2#;
   Runic_Letter_Short_Twig_Bjarkan_B       : constant Unicode_Char := 16#16D3#;
   Runic_Letter_Dotted_P                   : constant Unicode_Char := 16#16D4#;
   Runic_Letter_Open_P                     : constant Unicode_Char := 16#16D5#;
   Runic_Letter_Ehwaz_Eh_E                 : constant Unicode_Char := 16#16D6#;
   Runic_Letter_Mannaz_Man_M               : constant Unicode_Char := 16#16D7#;
   Runic_Letter_Long_Branch_Madr_M         : constant Unicode_Char := 16#16D8#;
   Runic_Letter_Short_Twig_Madr_M          : constant Unicode_Char := 16#16D9#;
   Runic_Letter_Laukaz_Lagu_Logr_L         : constant Unicode_Char := 16#16DA#;
   Runic_Letter_Dotted_L                   : constant Unicode_Char := 16#16DB#;
   Runic_Letter_Ingwaz                     : constant Unicode_Char := 16#16DC#;
   Runic_Letter_Ing                        : constant Unicode_Char := 16#16DD#;
   Runic_Letter_Dagaz_Daeg_D               : constant Unicode_Char := 16#16DE#;
   Runic_Letter_Othalan_Ethel_O            : constant Unicode_Char := 16#16DF#;
   Runic_Letter_Ear                        : constant Unicode_Char := 16#16E0#;
   Runic_Letter_Ior                        : constant Unicode_Char := 16#16E1#;
   Runic_Letter_Cweorth                    : constant Unicode_Char := 16#16E2#;
   Runic_Letter_Calc                       : constant Unicode_Char := 16#16E3#;
   Runic_Letter_Cealc                      : constant Unicode_Char := 16#16E4#;
   Runic_Letter_Stan                       : constant Unicode_Char := 16#16E5#;
   Runic_Letter_Long_Branch_Yr             : constant Unicode_Char := 16#16E6#;
   Runic_Letter_Short_Twig_Yr              : constant Unicode_Char := 16#16E7#;
   Runic_Letter_Icelandic_Yr               : constant Unicode_Char := 16#16E8#;
   Runic_Letter_Q                          : constant Unicode_Char := 16#16E9#;
   Runic_Letter_X                          : constant Unicode_Char := 16#16EA#;
   Runic_Single_Punctuation                : constant Unicode_Char := 16#16EB#;
   Runic_Multiple_Punctuation              : constant Unicode_Char := 16#16EC#;
   Runic_Cross_Punctuation                 : constant Unicode_Char := 16#16ED#;
   Runic_Arlaug_Symbol                     : constant Unicode_Char := 16#16EE#;
   Runic_Tvimadur_Symbol                   : constant Unicode_Char := 16#16EF#;
   Runic_Belgthor_Symbol                   : constant Unicode_Char := 16#16F0#;
   Runic_Letter_K                          : constant Unicode_Char := 16#16F1#;
   Runic_Letter_Sh                         : constant Unicode_Char := 16#16F2#;
   Runic_Letter_Oo                         : constant Unicode_Char := 16#16F3#;
   Runic_Letter_Franks_Casket_Os           : constant Unicode_Char := 16#16F4#;
   Runic_Letter_Franks_Casket_Is           : constant Unicode_Char := 16#16F5#;
   Runic_Letter_Franks_Casket_Eh           : constant Unicode_Char := 16#16F6#;
   Runic_Letter_Franks_Casket_Ac           : constant Unicode_Char := 16#16F7#;
   Runic_Letter_Franks_Casket_Aesc         : constant Unicode_Char := 16#16F8#;
end Unicode.Names.Runic;
