--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Arabic_Math_Alpha_Symb is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Arabic_Mathematical_Alef                :
      constant Unicode_Char := 16#1EE00#;
   Arabic_Mathematical_Beh                 :
      constant Unicode_Char := 16#1EE01#;
   Arabic_Mathematical_Jeem                :
      constant Unicode_Char := 16#1EE02#;
   Arabic_Mathematical_Dal                 :
      constant Unicode_Char := 16#1EE03#;
   Arabic_Mathematical_Waw                 :
      constant Unicode_Char := 16#1EE05#;
   Arabic_Mathematical_Zain                :
      constant Unicode_Char := 16#1EE06#;
   Arabic_Mathematical_Hah                 :
      constant Unicode_Char := 16#1EE07#;
   Arabic_Mathematical_Tah                 :
      constant Unicode_Char := 16#1EE08#;
   Arabic_Mathematical_Yeh                 :
      constant Unicode_Char := 16#1EE09#;
   Arabic_Mathematical_Kaf                 :
      constant Unicode_Char := 16#1EE0A#;
   Arabic_Mathematical_Lam                 :
      constant Unicode_Char := 16#1EE0B#;
   Arabic_Mathematical_Meem                :
      constant Unicode_Char := 16#1EE0C#;
   Arabic_Mathematical_Noon                :
      constant Unicode_Char := 16#1EE0D#;
   Arabic_Mathematical_Seen                :
      constant Unicode_Char := 16#1EE0E#;
   Arabic_Mathematical_Ain                 :
      constant Unicode_Char := 16#1EE0F#;
   Arabic_Mathematical_Feh                 :
      constant Unicode_Char := 16#1EE10#;
   Arabic_Mathematical_Sad                 :
      constant Unicode_Char := 16#1EE11#;
   Arabic_Mathematical_Qaf                 :
      constant Unicode_Char := 16#1EE12#;
   Arabic_Mathematical_Reh                 :
      constant Unicode_Char := 16#1EE13#;
   Arabic_Mathematical_Sheen               :
      constant Unicode_Char := 16#1EE14#;
   Arabic_Mathematical_Teh                 :
      constant Unicode_Char := 16#1EE15#;
   Arabic_Mathematical_Theh                :
      constant Unicode_Char := 16#1EE16#;
   Arabic_Mathematical_Khah                :
      constant Unicode_Char := 16#1EE17#;
   Arabic_Mathematical_Thal                :
      constant Unicode_Char := 16#1EE18#;
   Arabic_Mathematical_Dad                 :
      constant Unicode_Char := 16#1EE19#;
   Arabic_Mathematical_Zah                 :
      constant Unicode_Char := 16#1EE1A#;
   Arabic_Mathematical_Ghain               :
      constant Unicode_Char := 16#1EE1B#;
   Arabic_Mathematical_Dotless_Beh         :
      constant Unicode_Char := 16#1EE1C#;
   Arabic_Mathematical_Dotless_Noon        :
      constant Unicode_Char := 16#1EE1D#;
   Arabic_Mathematical_Dotless_Feh         :
      constant Unicode_Char := 16#1EE1E#;
   Arabic_Mathematical_Dotless_Qaf         :
      constant Unicode_Char := 16#1EE1F#;
   Arabic_Mathematical_Initial_Beh         :
      constant Unicode_Char := 16#1EE21#;
   Arabic_Mathematical_Initial_Jeem        :
      constant Unicode_Char := 16#1EE22#;
   Arabic_Mathematical_Initial_Heh         :
      constant Unicode_Char := 16#1EE24#;
   Arabic_Mathematical_Initial_Hah         :
      constant Unicode_Char := 16#1EE27#;
   Arabic_Mathematical_Initial_Yeh         :
      constant Unicode_Char := 16#1EE29#;
   Arabic_Mathematical_Initial_Kaf         :
      constant Unicode_Char := 16#1EE2A#;
   Arabic_Mathematical_Initial_Lam         :
      constant Unicode_Char := 16#1EE2B#;
   Arabic_Mathematical_Initial_Meem        :
      constant Unicode_Char := 16#1EE2C#;
   Arabic_Mathematical_Initial_Noon        :
      constant Unicode_Char := 16#1EE2D#;
   Arabic_Mathematical_Initial_Seen        :
      constant Unicode_Char := 16#1EE2E#;
   Arabic_Mathematical_Initial_Ain         :
      constant Unicode_Char := 16#1EE2F#;
   Arabic_Mathematical_Initial_Feh         :
      constant Unicode_Char := 16#1EE30#;
   Arabic_Mathematical_Initial_Sad         :
      constant Unicode_Char := 16#1EE31#;
   Arabic_Mathematical_Initial_Qaf         :
      constant Unicode_Char := 16#1EE32#;
   Arabic_Mathematical_Initial_Sheen       :
      constant Unicode_Char := 16#1EE34#;
   Arabic_Mathematical_Initial_Teh         :
      constant Unicode_Char := 16#1EE35#;
   Arabic_Mathematical_Initial_Theh        :
      constant Unicode_Char := 16#1EE36#;
   Arabic_Mathematical_Initial_Khah        :
      constant Unicode_Char := 16#1EE37#;
   Arabic_Mathematical_Initial_Dad         :
      constant Unicode_Char := 16#1EE39#;
   Arabic_Mathematical_Initial_Ghain       :
      constant Unicode_Char := 16#1EE3B#;
   Arabic_Mathematical_Tailed_Jeem         :
      constant Unicode_Char := 16#1EE42#;
   Arabic_Mathematical_Tailed_Hah          :
      constant Unicode_Char := 16#1EE47#;
   Arabic_Mathematical_Tailed_Yeh          :
      constant Unicode_Char := 16#1EE49#;
   Arabic_Mathematical_Tailed_Lam          :
      constant Unicode_Char := 16#1EE4B#;
   Arabic_Mathematical_Tailed_Noon         :
      constant Unicode_Char := 16#1EE4D#;
   Arabic_Mathematical_Tailed_Seen         :
      constant Unicode_Char := 16#1EE4E#;
   Arabic_Mathematical_Tailed_Ain          :
      constant Unicode_Char := 16#1EE4F#;
   Arabic_Mathematical_Tailed_Sad          :
      constant Unicode_Char := 16#1EE51#;
   Arabic_Mathematical_Tailed_Qaf          :
      constant Unicode_Char := 16#1EE52#;
   Arabic_Mathematical_Tailed_Sheen        :
      constant Unicode_Char := 16#1EE54#;
   Arabic_Mathematical_Tailed_Khah         :
      constant Unicode_Char := 16#1EE57#;
   Arabic_Mathematical_Tailed_Dad          :
      constant Unicode_Char := 16#1EE59#;
   Arabic_Mathematical_Tailed_Ghain        :
      constant Unicode_Char := 16#1EE5B#;
   Arabic_Mathematical_Tailed_Dotless_Noon :
      constant Unicode_Char := 16#1EE5D#;
   Arabic_Mathematical_Tailed_Dotless_Qaf  :
      constant Unicode_Char := 16#1EE5F#;
   Arabic_Mathematical_Stretched_Beh       :
      constant Unicode_Char := 16#1EE61#;
   Arabic_Mathematical_Stretched_Jeem      :
      constant Unicode_Char := 16#1EE62#;
   Arabic_Mathematical_Stretched_Heh       :
      constant Unicode_Char := 16#1EE64#;
   Arabic_Mathematical_Stretched_Hah       :
      constant Unicode_Char := 16#1EE67#;
   Arabic_Mathematical_Stretched_Tah       :
      constant Unicode_Char := 16#1EE68#;
   Arabic_Mathematical_Stretched_Yeh       :
      constant Unicode_Char := 16#1EE69#;
   Arabic_Mathematical_Stretched_Kaf       :
      constant Unicode_Char := 16#1EE6A#;
   Arabic_Mathematical_Stretched_Meem      :
      constant Unicode_Char := 16#1EE6C#;
   Arabic_Mathematical_Stretched_Noon      :
      constant Unicode_Char := 16#1EE6D#;
   Arabic_Mathematical_Stretched_Seen      :
      constant Unicode_Char := 16#1EE6E#;
   Arabic_Mathematical_Stretched_Ain       :
      constant Unicode_Char := 16#1EE6F#;
   Arabic_Mathematical_Stretched_Feh       :
      constant Unicode_Char := 16#1EE70#;
   Arabic_Mathematical_Stretched_Sad       :
      constant Unicode_Char := 16#1EE71#;
   Arabic_Mathematical_Stretched_Qaf       :
      constant Unicode_Char := 16#1EE72#;
   Arabic_Mathematical_Stretched_Sheen     :
      constant Unicode_Char := 16#1EE74#;
   Arabic_Mathematical_Stretched_Teh       :
      constant Unicode_Char := 16#1EE75#;
   Arabic_Mathematical_Stretched_Theh      :
      constant Unicode_Char := 16#1EE76#;
   Arabic_Mathematical_Stretched_Khah      :
      constant Unicode_Char := 16#1EE77#;
   Arabic_Mathematical_Stretched_Dad       :
      constant Unicode_Char := 16#1EE79#;
   Arabic_Mathematical_Stretched_Zah       :
      constant Unicode_Char := 16#1EE7A#;
   Arabic_Mathematical_Stretched_Ghain     :
      constant Unicode_Char := 16#1EE7B#;
   Arabic_Mathematical_Stretched_Dotless_Beh :
      constant Unicode_Char := 16#1EE7C#;
   Arabic_Mathematical_Stretched_Dotless_Feh :
      constant Unicode_Char := 16#1EE7E#;
   Arabic_Mathematical_Looped_Alef         :
      constant Unicode_Char := 16#1EE80#;
   Arabic_Mathematical_Looped_Beh          :
      constant Unicode_Char := 16#1EE81#;
   Arabic_Mathematical_Looped_Jeem         :
      constant Unicode_Char := 16#1EE82#;
   Arabic_Mathematical_Looped_Dal          :
      constant Unicode_Char := 16#1EE83#;
   Arabic_Mathematical_Looped_Heh          :
      constant Unicode_Char := 16#1EE84#;
   Arabic_Mathematical_Looped_Waw          :
      constant Unicode_Char := 16#1EE85#;
   Arabic_Mathematical_Looped_Zain         :
      constant Unicode_Char := 16#1EE86#;
   Arabic_Mathematical_Looped_Hah          :
      constant Unicode_Char := 16#1EE87#;
   Arabic_Mathematical_Looped_Tah          :
      constant Unicode_Char := 16#1EE88#;
   Arabic_Mathematical_Looped_Yeh          :
      constant Unicode_Char := 16#1EE89#;
   Arabic_Mathematical_Looped_Lam          :
      constant Unicode_Char := 16#1EE8B#;
   Arabic_Mathematical_Looped_Meem         :
      constant Unicode_Char := 16#1EE8C#;
   Arabic_Mathematical_Looped_Noon         :
      constant Unicode_Char := 16#1EE8D#;
   Arabic_Mathematical_Looped_Seen         :
      constant Unicode_Char := 16#1EE8E#;
   Arabic_Mathematical_Looped_Ain          :
      constant Unicode_Char := 16#1EE8F#;
   Arabic_Mathematical_Looped_Feh          :
      constant Unicode_Char := 16#1EE90#;
   Arabic_Mathematical_Looped_Sad          :
      constant Unicode_Char := 16#1EE91#;
   Arabic_Mathematical_Looped_Qaf          :
      constant Unicode_Char := 16#1EE92#;
   Arabic_Mathematical_Looped_Reh          :
      constant Unicode_Char := 16#1EE93#;
   Arabic_Mathematical_Looped_Sheen        :
      constant Unicode_Char := 16#1EE94#;
   Arabic_Mathematical_Looped_Teh          :
      constant Unicode_Char := 16#1EE95#;
   Arabic_Mathematical_Looped_Theh         :
      constant Unicode_Char := 16#1EE96#;
   Arabic_Mathematical_Looped_Khah         :
      constant Unicode_Char := 16#1EE97#;
   Arabic_Mathematical_Looped_Thal         :
      constant Unicode_Char := 16#1EE98#;
   Arabic_Mathematical_Looped_Dad          :
      constant Unicode_Char := 16#1EE99#;
   Arabic_Mathematical_Looped_Zah          :
      constant Unicode_Char := 16#1EE9A#;
   Arabic_Mathematical_Looped_Ghain        :
      constant Unicode_Char := 16#1EE9B#;
   Arabic_Mathematical_Double_Struck_Beh   :
      constant Unicode_Char := 16#1EEA1#;
   Arabic_Mathematical_Double_Struck_Jeem  :
      constant Unicode_Char := 16#1EEA2#;
   Arabic_Mathematical_Double_Struck_Dal   :
      constant Unicode_Char := 16#1EEA3#;
   Arabic_Mathematical_Double_Struck_Waw   :
      constant Unicode_Char := 16#1EEA5#;
   Arabic_Mathematical_Double_Struck_Zain  :
      constant Unicode_Char := 16#1EEA6#;
   Arabic_Mathematical_Double_Struck_Hah   :
      constant Unicode_Char := 16#1EEA7#;
   Arabic_Mathematical_Double_Struck_Tah   :
      constant Unicode_Char := 16#1EEA8#;
   Arabic_Mathematical_Double_Struck_Yeh   :
      constant Unicode_Char := 16#1EEA9#;
   Arabic_Mathematical_Double_Struck_Lam   :
      constant Unicode_Char := 16#1EEAB#;
   Arabic_Mathematical_Double_Struck_Meem  :
      constant Unicode_Char := 16#1EEAC#;
   Arabic_Mathematical_Double_Struck_Noon  :
      constant Unicode_Char := 16#1EEAD#;
   Arabic_Mathematical_Double_Struck_Seen  :
      constant Unicode_Char := 16#1EEAE#;
   Arabic_Mathematical_Double_Struck_Ain   :
      constant Unicode_Char := 16#1EEAF#;
   Arabic_Mathematical_Double_Struck_Feh   :
      constant Unicode_Char := 16#1EEB0#;
   Arabic_Mathematical_Double_Struck_Sad   :
      constant Unicode_Char := 16#1EEB1#;
   Arabic_Mathematical_Double_Struck_Qaf   :
      constant Unicode_Char := 16#1EEB2#;
   Arabic_Mathematical_Double_Struck_Reh   :
      constant Unicode_Char := 16#1EEB3#;
   Arabic_Mathematical_Double_Struck_Sheen :
      constant Unicode_Char := 16#1EEB4#;
   Arabic_Mathematical_Double_Struck_Teh   :
      constant Unicode_Char := 16#1EEB5#;
   Arabic_Mathematical_Double_Struck_Theh  :
      constant Unicode_Char := 16#1EEB6#;
   Arabic_Mathematical_Double_Struck_Khah  :
      constant Unicode_Char := 16#1EEB7#;
   Arabic_Mathematical_Double_Struck_Thal  :
      constant Unicode_Char := 16#1EEB8#;
   Arabic_Mathematical_Double_Struck_Dad   :
      constant Unicode_Char := 16#1EEB9#;
   Arabic_Mathematical_Double_Struck_Zah   :
      constant Unicode_Char := 16#1EEBA#;
   Arabic_Mathematical_Double_Struck_Ghain :
      constant Unicode_Char := 16#1EEBB#;
   Arabic_Mathematical_Operator_Meem_With_Hah_With_Tatweel :
      constant Unicode_Char := 16#1EEF0#;
   Arabic_Mathematical_Operator_Hah_With_Dal :
      constant Unicode_Char := 16#1EEF1#;
end Unicode.Names.Arabic_Math_Alpha_Symb;
