--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Arabic_Supplement is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Arabic_Letter_Beh_With_Three_Dots_Horizontally_Below :
      constant Unicode_Char := 16#0750#;
   Arabic_Letter_Beh_With_Dot_Below_And_Three_Dots_Above :
      constant Unicode_Char := 16#0751#;
   Arabic_Letter_Beh_With_Three_Dots_Pointing_Upwards_Below :
      constant Unicode_Char := 16#0752#;
   Arabic_Letter_Beh_With_Three_Dots_Pointing_Upwards_Below_And_Two_Dots_Above :
      constant Unicode_Char := 16#0753#;
   Arabic_Letter_Beh_With_Two_Dots_Below_And_Dot_Above :
      constant Unicode_Char := 16#0754#;
   Arabic_Letter_Beh_With_Inverted_Small_V_Below :
      constant Unicode_Char := 16#0755#;
   Arabic_Letter_Beh_With_Small_V          : constant Unicode_Char := 16#0756#;
   Arabic_Letter_Hah_With_Two_Dots_Above   : constant Unicode_Char := 16#0757#;
   Arabic_Letter_Hah_With_Three_Dots_Pointing_Upwards_Below :
      constant Unicode_Char := 16#0758#;
   Arabic_Letter_Dal_With_Two_Dots_Vertically_Below_And_Small_Tah :
      constant Unicode_Char := 16#0759#;
   Arabic_Letter_Dal_With_Inverted_Small_V_Below :
      constant Unicode_Char := 16#075A#;
   Arabic_Letter_Reh_With_Stroke           : constant Unicode_Char := 16#075B#;
   Arabic_Letter_Seen_With_Four_Dots_Above : constant Unicode_Char := 16#075C#;
   Arabic_Letter_Ain_With_Two_Dots_Above   : constant Unicode_Char := 16#075D#;
   Arabic_Letter_Ain_With_Three_Dots_Pointing_Downwards_Above :
      constant Unicode_Char := 16#075E#;
   Arabic_Letter_Ain_With_Two_Dots_Vertically_Above :
      constant Unicode_Char := 16#075F#;
   Arabic_Letter_Feh_With_Two_Dots_Below   : constant Unicode_Char := 16#0760#;
   Arabic_Letter_Feh_With_Three_Dots_Pointing_Upwards_Below :
      constant Unicode_Char := 16#0761#;
   Arabic_Letter_Keheh_With_Dot_Above      : constant Unicode_Char := 16#0762#;
   Arabic_Letter_Keheh_With_Three_Dots_Above :
      constant Unicode_Char := 16#0763#;
   Arabic_Letter_Keheh_With_Three_Dots_Pointing_Upwards_Below :
      constant Unicode_Char := 16#0764#;
   Arabic_Letter_Meem_With_Dot_Above       : constant Unicode_Char := 16#0765#;
   Arabic_Letter_Meem_With_Dot_Below       : constant Unicode_Char := 16#0766#;
   Arabic_Letter_Noon_With_Two_Dots_Below  : constant Unicode_Char := 16#0767#;
   Arabic_Letter_Noon_With_Small_Tah       : constant Unicode_Char := 16#0768#;
   Arabic_Letter_Noon_With_Small_V         : constant Unicode_Char := 16#0769#;
   Arabic_Letter_Lam_With_Bar              : constant Unicode_Char := 16#076A#;
   Arabic_Letter_Reh_With_Two_Dots_Vertically_Above :
      constant Unicode_Char := 16#076B#;
   Arabic_Letter_Reh_With_Hamza_Above      : constant Unicode_Char := 16#076C#;
   Arabic_Letter_Seen_With_Two_Dots_Vertically_Above :
      constant Unicode_Char := 16#076D#;
   Arabic_Letter_Hah_With_Small_Arabic_Letter_Tah_Below :
      constant Unicode_Char := 16#076E#;
   Arabic_Letter_Hah_With_Small_Arabic_Letter_Tah_And_Two_Dots :
      constant Unicode_Char := 16#076F#;
   Arabic_Letter_Seen_With_Small_Arabic_Letter_Tah_And_Two_Dots :
      constant Unicode_Char := 16#0770#;
   Arabic_Letter_Reh_With_Small_Arabic_Letter_Tah_And_Two_Dots :
      constant Unicode_Char := 16#0771#;
   Arabic_Letter_Hah_With_Small_Arabic_Letter_Tah_Above :
      constant Unicode_Char := 16#0772#;
   Arabic_Letter_Alef_With_Extended_Arabic_Indic_Digit_Two_Above :
      constant Unicode_Char := 16#0773#;
   Arabic_Letter_Alef_With_Extended_Arabic_Indic_Digit_Three_Above :
      constant Unicode_Char := 16#0774#;
   Arabic_Letter_Farsi_Yeh_With_Extended_Arabic_Indic_Digit_Two_Above :
      constant Unicode_Char := 16#0775#;
   Arabic_Letter_Farsi_Yeh_With_Extended_Arabic_Indic_Digit_Three_Above :
      constant Unicode_Char := 16#0776#;
   Arabic_Letter_Farsi_Yeh_With_Extended_Arabic_Indic_Digit_Four_Below :
      constant Unicode_Char := 16#0777#;
   Arabic_Letter_Waw_With_Extended_Arabic_Indic_Digit_Two_Above :
      constant Unicode_Char := 16#0778#;
   Arabic_Letter_Waw_With_Extended_Arabic_Indic_Digit_Three_Above :
      constant Unicode_Char := 16#0779#;
   Arabic_Letter_Yeh_Barree_With_Extended_Arabic_Indic_Digit_Two_Above :
      constant Unicode_Char := 16#077A#;
   Arabic_Letter_Yeh_Barree_With_Extended_Arabic_Indic_Digit_Three_Above :
      constant Unicode_Char := 16#077B#;
   Arabic_Letter_Hah_With_Extended_Arabic_Indic_Digit_Four_Below :
      constant Unicode_Char := 16#077C#;
   Arabic_Letter_Seen_With_Extended_Arabic_Indic_Digit_Four_Above :
      constant Unicode_Char := 16#077D#;
   Arabic_Letter_Seen_With_Inverted_V      : constant Unicode_Char := 16#077E#;
   Arabic_Letter_Kaf_With_Two_Dots_Above   : constant Unicode_Char := 16#077F#;
end Unicode.Names.Arabic_Supplement;
