--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Siddham is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Siddham_Letter_A                        :
      constant Unicode_Char := 16#11580#;
   Siddham_Letter_Aa                       :
      constant Unicode_Char := 16#11581#;
   Siddham_Letter_I                        :
      constant Unicode_Char := 16#11582#;
   Siddham_Letter_Ii                       :
      constant Unicode_Char := 16#11583#;
   Siddham_Letter_U                        :
      constant Unicode_Char := 16#11584#;
   Siddham_Letter_Uu                       :
      constant Unicode_Char := 16#11585#;
   Siddham_Letter_Vocalic_R                :
      constant Unicode_Char := 16#11586#;
   Siddham_Letter_Vocalic_Rr               :
      constant Unicode_Char := 16#11587#;
   Siddham_Letter_Vocalic_L                :
      constant Unicode_Char := 16#11588#;
   Siddham_Letter_Vocalic_Ll               :
      constant Unicode_Char := 16#11589#;
   Siddham_Letter_E                        :
      constant Unicode_Char := 16#1158A#;
   Siddham_Letter_Ai                       :
      constant Unicode_Char := 16#1158B#;
   Siddham_Letter_O                        :
      constant Unicode_Char := 16#1158C#;
   Siddham_Letter_Au                       :
      constant Unicode_Char := 16#1158D#;
   Siddham_Letter_Ka                       :
      constant Unicode_Char := 16#1158E#;
   Siddham_Letter_Kha                      :
      constant Unicode_Char := 16#1158F#;
   Siddham_Letter_Ga                       :
      constant Unicode_Char := 16#11590#;
   Siddham_Letter_Gha                      :
      constant Unicode_Char := 16#11591#;
   Siddham_Letter_Nga                      :
      constant Unicode_Char := 16#11592#;
   Siddham_Letter_Ca                       :
      constant Unicode_Char := 16#11593#;
   Siddham_Letter_Cha                      :
      constant Unicode_Char := 16#11594#;
   Siddham_Letter_Ja                       :
      constant Unicode_Char := 16#11595#;
   Siddham_Letter_Jha                      :
      constant Unicode_Char := 16#11596#;
   Siddham_Letter_Nya                      :
      constant Unicode_Char := 16#11597#;
   Siddham_Letter_Tta                      :
      constant Unicode_Char := 16#11598#;
   Siddham_Letter_Ttha                     :
      constant Unicode_Char := 16#11599#;
   Siddham_Letter_Dda                      :
      constant Unicode_Char := 16#1159A#;
   Siddham_Letter_Ddha                     :
      constant Unicode_Char := 16#1159B#;
   Siddham_Letter_Nna                      :
      constant Unicode_Char := 16#1159C#;
   Siddham_Letter_Ta                       :
      constant Unicode_Char := 16#1159D#;
   Siddham_Letter_Tha                      :
      constant Unicode_Char := 16#1159E#;
   Siddham_Letter_Da                       :
      constant Unicode_Char := 16#1159F#;
   Siddham_Letter_Dha                      :
      constant Unicode_Char := 16#115A0#;
   Siddham_Letter_Na                       :
      constant Unicode_Char := 16#115A1#;
   Siddham_Letter_Pa                       :
      constant Unicode_Char := 16#115A2#;
   Siddham_Letter_Pha                      :
      constant Unicode_Char := 16#115A3#;
   Siddham_Letter_Ba                       :
      constant Unicode_Char := 16#115A4#;
   Siddham_Letter_Bha                      :
      constant Unicode_Char := 16#115A5#;
   Siddham_Letter_Ma                       :
      constant Unicode_Char := 16#115A6#;
   Siddham_Letter_Ya                       :
      constant Unicode_Char := 16#115A7#;
   Siddham_Letter_Ra                       :
      constant Unicode_Char := 16#115A8#;
   Siddham_Letter_La                       :
      constant Unicode_Char := 16#115A9#;
   Siddham_Letter_Va                       :
      constant Unicode_Char := 16#115AA#;
   Siddham_Letter_Sha                      :
      constant Unicode_Char := 16#115AB#;
   Siddham_Letter_Ssa                      :
      constant Unicode_Char := 16#115AC#;
   Siddham_Letter_Sa                       :
      constant Unicode_Char := 16#115AD#;
   Siddham_Letter_Ha                       :
      constant Unicode_Char := 16#115AE#;
   Siddham_Vowel_Sign_Aa                   :
      constant Unicode_Char := 16#115AF#;
   Siddham_Vowel_Sign_I                    :
      constant Unicode_Char := 16#115B0#;
   Siddham_Vowel_Sign_Ii                   :
      constant Unicode_Char := 16#115B1#;
   Siddham_Vowel_Sign_U                    :
      constant Unicode_Char := 16#115B2#;
   Siddham_Vowel_Sign_Uu                   :
      constant Unicode_Char := 16#115B3#;
   Siddham_Vowel_Sign_Vocalic_R            :
      constant Unicode_Char := 16#115B4#;
   Siddham_Vowel_Sign_Vocalic_Rr           :
      constant Unicode_Char := 16#115B5#;
   Siddham_Vowel_Sign_E                    :
      constant Unicode_Char := 16#115B8#;
   Siddham_Vowel_Sign_Ai                   :
      constant Unicode_Char := 16#115B9#;
   Siddham_Vowel_Sign_O                    :
      constant Unicode_Char := 16#115BA#;
   Siddham_Vowel_Sign_Au                   :
      constant Unicode_Char := 16#115BB#;
   Siddham_Sign_Candrabindu                :
      constant Unicode_Char := 16#115BC#;
   Siddham_Sign_Anusvara                   :
      constant Unicode_Char := 16#115BD#;
   Siddham_Sign_Visarga                    :
      constant Unicode_Char := 16#115BE#;
   Siddham_Sign_Virama                     :
      constant Unicode_Char := 16#115BF#;
   Siddham_Sign_Nukta                      :
      constant Unicode_Char := 16#115C0#;
   Siddham_Sign_Siddham                    :
      constant Unicode_Char := 16#115C1#;
   Siddham_Danda                           :
      constant Unicode_Char := 16#115C2#;
   Siddham_Double_Danda                    :
      constant Unicode_Char := 16#115C3#;
   Siddham_Separator_Dot                   :
      constant Unicode_Char := 16#115C4#;
   Siddham_Separator_Bar                   :
      constant Unicode_Char := 16#115C5#;
   Siddham_Repetition_Mark_1               :
      constant Unicode_Char := 16#115C6#;
   Siddham_Repetition_Mark_2               :
      constant Unicode_Char := 16#115C7#;
   Siddham_Repetition_Mark_3               :
      constant Unicode_Char := 16#115C8#;
   Siddham_End_Of_Text_Mark                :
      constant Unicode_Char := 16#115C9#;
   Siddham_Section_Mark_With_Trident_And_U_Shaped_Ornaments :
      constant Unicode_Char := 16#115CA#;
   Siddham_Section_Mark_With_Trident_And_Dotted_Crescents :
      constant Unicode_Char := 16#115CB#;
   Siddham_Section_Mark_With_Rays_And_Dotted_Crescents :
      constant Unicode_Char := 16#115CC#;
   Siddham_Section_Mark_With_Rays_And_Dotted_Double_Crescents :
      constant Unicode_Char := 16#115CD#;
   Siddham_Section_Mark_With_Rays_And_Dotted_Triple_Crescents :
      constant Unicode_Char := 16#115CE#;
   Siddham_Section_Mark_Double_Ring        :
      constant Unicode_Char := 16#115CF#;
   Siddham_Section_Mark_Double_Ring_With_Rays :
      constant Unicode_Char := 16#115D0#;
   Siddham_Section_Mark_With_Double_Crescents :
      constant Unicode_Char := 16#115D1#;
   Siddham_Section_Mark_With_Triple_Crescents :
      constant Unicode_Char := 16#115D2#;
   Siddham_Section_Mark_With_Quadruple_Crescents :
      constant Unicode_Char := 16#115D3#;
   Siddham_Section_Mark_With_Septuple_Crescents :
      constant Unicode_Char := 16#115D4#;
   Siddham_Section_Mark_With_Circles_And_Rays :
      constant Unicode_Char := 16#115D5#;
   Siddham_Section_Mark_With_Circles_And_Two_Enclosures :
      constant Unicode_Char := 16#115D6#;
   Siddham_Section_Mark_With_Circles_And_Four_Enclosures :
      constant Unicode_Char := 16#115D7#;
   Siddham_Letter_Three_Circle_Alternate_I :
      constant Unicode_Char := 16#115D8#;
   Siddham_Letter_Two_Circle_Alternate_I   :
      constant Unicode_Char := 16#115D9#;
   Siddham_Letter_Two_Circle_Alternate_Ii  :
      constant Unicode_Char := 16#115DA#;
   Siddham_Letter_Alternate_U              :
      constant Unicode_Char := 16#115DB#;
   Siddham_Vowel_Sign_Alternate_U          :
      constant Unicode_Char := 16#115DC#;
   Siddham_Vowel_Sign_Alternate_Uu         :
      constant Unicode_Char := 16#115DD#;
end Unicode.Names.Siddham;
