--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Supplemental_Punctuation is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Right_Angle_Substitution_Marker         : constant Unicode_Char := 16#2E00#;
   Right_Angle_Dotted_Substitution_Marker  : constant Unicode_Char := 16#2E01#;
   Left_Substitution_Bracket               : constant Unicode_Char := 16#2E02#;
   Right_Substitution_Bracket              : constant Unicode_Char := 16#2E03#;
   Left_Dotted_Substitution_Bracket        : constant Unicode_Char := 16#2E04#;
   Right_Dotted_Substitution_Bracket       : constant Unicode_Char := 16#2E05#;
   Raised_Interpolation_Marker             : constant Unicode_Char := 16#2E06#;
   Raised_Dotted_Interpolation_Marker      : constant Unicode_Char := 16#2E07#;
   Dotted_Transposition_Marker             : constant Unicode_Char := 16#2E08#;
   Left_Transposition_Bracket              : constant Unicode_Char := 16#2E09#;
   Right_Transposition_Bracket             : constant Unicode_Char := 16#2E0A#;
   Raised_Square                           : constant Unicode_Char := 16#2E0B#;
   Left_Raised_Omission_Bracket            : constant Unicode_Char := 16#2E0C#;
   Right_Raised_Omission_Bracket           : constant Unicode_Char := 16#2E0D#;
   Editorial_Coronis                       : constant Unicode_Char := 16#2E0E#;
   Paragraphos                             : constant Unicode_Char := 16#2E0F#;
   Forked_Paragraphos                      : constant Unicode_Char := 16#2E10#;
   Reversed_Forked_Paragraphos             : constant Unicode_Char := 16#2E11#;
   Hypodiastole                            : constant Unicode_Char := 16#2E12#;
   Dotted_Obelos                           : constant Unicode_Char := 16#2E13#;
   Downwards_Ancora                        : constant Unicode_Char := 16#2E14#;
   Upwards_Ancora                          : constant Unicode_Char := 16#2E15#;
   Dotted_Right_Pointing_Angle             : constant Unicode_Char := 16#2E16#;
   Double_Oblique_Hyphen                   : constant Unicode_Char := 16#2E17#;
   Inverted_Interrobang                    : constant Unicode_Char := 16#2E18#;
   Palm_Branch                             : constant Unicode_Char := 16#2E19#;
   Hyphen_With_Diaeresis                   : constant Unicode_Char := 16#2E1A#;
   Tilde_With_Ring_Above                   : constant Unicode_Char := 16#2E1B#;
   Left_Low_Paraphrase_Bracket             : constant Unicode_Char := 16#2E1C#;
   Right_Low_Paraphrase_Bracket            : constant Unicode_Char := 16#2E1D#;
   Tilde_With_Dot_Above                    : constant Unicode_Char := 16#2E1E#;
   Tilde_With_Dot_Below                    : constant Unicode_Char := 16#2E1F#;
   Left_Vertical_Bar_With_Quill            : constant Unicode_Char := 16#2E20#;
   Right_Vertical_Bar_With_Quill           : constant Unicode_Char := 16#2E21#;
   Top_Left_Half_Bracket                   : constant Unicode_Char := 16#2E22#;
   Top_Right_Half_Bracket                  : constant Unicode_Char := 16#2E23#;
   Bottom_Left_Half_Bracket                : constant Unicode_Char := 16#2E24#;
   Bottom_Right_Half_Bracket               : constant Unicode_Char := 16#2E25#;
   Left_Sideways_U_Bracket                 : constant Unicode_Char := 16#2E26#;
   Right_Sideways_U_Bracket                : constant Unicode_Char := 16#2E27#;
   Left_Double_Parenthesis                 : constant Unicode_Char := 16#2E28#;
   Right_Double_Parenthesis                : constant Unicode_Char := 16#2E29#;
   Two_Dots_Over_One_Dot_Punctuation       : constant Unicode_Char := 16#2E2A#;
   One_Dot_Over_Two_Dots_Punctuation       : constant Unicode_Char := 16#2E2B#;
   Squared_Four_Dot_Punctuation            : constant Unicode_Char := 16#2E2C#;
   Five_Dot_Mark                           : constant Unicode_Char := 16#2E2D#;
   Reversed_Question_Mark                  : constant Unicode_Char := 16#2E2E#;
   Vertical_Tilde                          : constant Unicode_Char := 16#2E2F#;
   Ring_Point                              : constant Unicode_Char := 16#2E30#;
   Word_Separator_Middle_Dot               : constant Unicode_Char := 16#2E31#;
   Turned_Comma                            : constant Unicode_Char := 16#2E32#;
   Raised_Dot                              : constant Unicode_Char := 16#2E33#;
   Raised_Comma                            : constant Unicode_Char := 16#2E34#;
   Turned_Semicolon                        : constant Unicode_Char := 16#2E35#;
   Dagger_With_Left_Guard                  : constant Unicode_Char := 16#2E36#;
   Dagger_With_Right_Guard                 : constant Unicode_Char := 16#2E37#;
   Turned_Dagger                           : constant Unicode_Char := 16#2E38#;
   Top_Half_Section_Sign                   : constant Unicode_Char := 16#2E39#;
   Two_Em_Dash                             : constant Unicode_Char := 16#2E3A#;
   Three_Em_Dash                           : constant Unicode_Char := 16#2E3B#;
   Stenographic_Full_Stop                  : constant Unicode_Char := 16#2E3C#;
   Vertical_Six_Dots                       : constant Unicode_Char := 16#2E3D#;
   Wiggly_Vertical_Line                    : constant Unicode_Char := 16#2E3E#;
   Capitulum                               : constant Unicode_Char := 16#2E3F#;
   Double_Hyphen                           : constant Unicode_Char := 16#2E40#;
   Reversed_Comma                          : constant Unicode_Char := 16#2E41#;
   Double_Low_Reversed_9_Quotation_Mark    : constant Unicode_Char := 16#2E42#;
end Unicode.Names.Supplemental_Punctuation;
