--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cyrillic is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cyrillic_Capital_Letter_Ie_With_Grave   : constant Unicode_Char := 16#0400#;
   Cyrillic_Capital_Letter_Io              : constant Unicode_Char := 16#0401#;
   Cyrillic_Capital_Letter_Dje             : constant Unicode_Char := 16#0402#;
   Cyrillic_Capital_Letter_Gje             : constant Unicode_Char := 16#0403#;
   Cyrillic_Capital_Letter_Ukrainian_Ie    : constant Unicode_Char := 16#0404#;
   Cyrillic_Capital_Letter_Dze             : constant Unicode_Char := 16#0405#;
   Cyrillic_Capital_Letter_Byelorussian_Ukrainian_I :
      constant Unicode_Char := 16#0406#;
   Cyrillic_Capital_Letter_Yi              : constant Unicode_Char := 16#0407#;
   Cyrillic_Capital_Letter_Je              : constant Unicode_Char := 16#0408#;
   Cyrillic_Capital_Letter_Lje             : constant Unicode_Char := 16#0409#;
   Cyrillic_Capital_Letter_Nje             : constant Unicode_Char := 16#040A#;
   Cyrillic_Capital_Letter_Tshe            : constant Unicode_Char := 16#040B#;
   Cyrillic_Capital_Letter_Kje             : constant Unicode_Char := 16#040C#;
   Cyrillic_Capital_Letter_I_With_Grave    : constant Unicode_Char := 16#040D#;
   Cyrillic_Capital_Letter_Short_U         : constant Unicode_Char := 16#040E#;
   Cyrillic_Capital_Letter_Dzhe            : constant Unicode_Char := 16#040F#;
   Cyrillic_Capital_Letter_A               : constant Unicode_Char := 16#0410#;
   Cyrillic_Capital_Letter_Be              : constant Unicode_Char := 16#0411#;
   Cyrillic_Capital_Letter_Ve              : constant Unicode_Char := 16#0412#;
   Cyrillic_Capital_Letter_Ghe             : constant Unicode_Char := 16#0413#;
   Cyrillic_Capital_Letter_De              : constant Unicode_Char := 16#0414#;
   Cyrillic_Capital_Letter_Ie              : constant Unicode_Char := 16#0415#;
   Cyrillic_Capital_Letter_Zhe             : constant Unicode_Char := 16#0416#;
   Cyrillic_Capital_Letter_Ze              : constant Unicode_Char := 16#0417#;
   Cyrillic_Capital_Letter_I               : constant Unicode_Char := 16#0418#;
   Cyrillic_Capital_Letter_Short_I         : constant Unicode_Char := 16#0419#;
   Cyrillic_Capital_Letter_Ka              : constant Unicode_Char := 16#041A#;
   Cyrillic_Capital_Letter_El              : constant Unicode_Char := 16#041B#;
   Cyrillic_Capital_Letter_Em              : constant Unicode_Char := 16#041C#;
   Cyrillic_Capital_Letter_En              : constant Unicode_Char := 16#041D#;
   Cyrillic_Capital_Letter_O               : constant Unicode_Char := 16#041E#;
   Cyrillic_Capital_Letter_Pe              : constant Unicode_Char := 16#041F#;
   Cyrillic_Capital_Letter_Er              : constant Unicode_Char := 16#0420#;
   Cyrillic_Capital_Letter_Es              : constant Unicode_Char := 16#0421#;
   Cyrillic_Capital_Letter_Te              : constant Unicode_Char := 16#0422#;
   Cyrillic_Capital_Letter_U               : constant Unicode_Char := 16#0423#;
   Cyrillic_Capital_Letter_Ef              : constant Unicode_Char := 16#0424#;
   Cyrillic_Capital_Letter_Ha              : constant Unicode_Char := 16#0425#;
   Cyrillic_Capital_Letter_Tse             : constant Unicode_Char := 16#0426#;
   Cyrillic_Capital_Letter_Che             : constant Unicode_Char := 16#0427#;
   Cyrillic_Capital_Letter_Sha             : constant Unicode_Char := 16#0428#;
   Cyrillic_Capital_Letter_Shcha           : constant Unicode_Char := 16#0429#;
   Cyrillic_Capital_Letter_Hard_Sign       : constant Unicode_Char := 16#042A#;
   Cyrillic_Capital_Letter_Yeru            : constant Unicode_Char := 16#042B#;
   Cyrillic_Capital_Letter_Soft_Sign       : constant Unicode_Char := 16#042C#;
   Cyrillic_Capital_Letter_E               : constant Unicode_Char := 16#042D#;
   Cyrillic_Capital_Letter_Yu              : constant Unicode_Char := 16#042E#;
   Cyrillic_Capital_Letter_Ya              : constant Unicode_Char := 16#042F#;
   Cyrillic_Small_Letter_A                 : constant Unicode_Char := 16#0430#;
   Cyrillic_Small_Letter_Be                : constant Unicode_Char := 16#0431#;
   Cyrillic_Small_Letter_Ve                : constant Unicode_Char := 16#0432#;
   Cyrillic_Small_Letter_Ghe               : constant Unicode_Char := 16#0433#;
   Cyrillic_Small_Letter_De                : constant Unicode_Char := 16#0434#;
   Cyrillic_Small_Letter_Ie                : constant Unicode_Char := 16#0435#;
   Cyrillic_Small_Letter_Zhe               : constant Unicode_Char := 16#0436#;
   Cyrillic_Small_Letter_Ze                : constant Unicode_Char := 16#0437#;
   Cyrillic_Small_Letter_I                 : constant Unicode_Char := 16#0438#;
   Cyrillic_Small_Letter_Short_I           : constant Unicode_Char := 16#0439#;
   Cyrillic_Small_Letter_Ka                : constant Unicode_Char := 16#043A#;
   Cyrillic_Small_Letter_El                : constant Unicode_Char := 16#043B#;
   Cyrillic_Small_Letter_Em                : constant Unicode_Char := 16#043C#;
   Cyrillic_Small_Letter_En                : constant Unicode_Char := 16#043D#;
   Cyrillic_Small_Letter_O                 : constant Unicode_Char := 16#043E#;
   Cyrillic_Small_Letter_Pe                : constant Unicode_Char := 16#043F#;
   Cyrillic_Small_Letter_Er                : constant Unicode_Char := 16#0440#;
   Cyrillic_Small_Letter_Es                : constant Unicode_Char := 16#0441#;
   Cyrillic_Small_Letter_Te                : constant Unicode_Char := 16#0442#;
   Cyrillic_Small_Letter_U                 : constant Unicode_Char := 16#0443#;
   Cyrillic_Small_Letter_Ef                : constant Unicode_Char := 16#0444#;
   Cyrillic_Small_Letter_Ha                : constant Unicode_Char := 16#0445#;
   Cyrillic_Small_Letter_Tse               : constant Unicode_Char := 16#0446#;
   Cyrillic_Small_Letter_Che               : constant Unicode_Char := 16#0447#;
   Cyrillic_Small_Letter_Sha               : constant Unicode_Char := 16#0448#;
   Cyrillic_Small_Letter_Shcha             : constant Unicode_Char := 16#0449#;
   Cyrillic_Small_Letter_Hard_Sign         : constant Unicode_Char := 16#044A#;
   Cyrillic_Small_Letter_Yeru              : constant Unicode_Char := 16#044B#;
   Cyrillic_Small_Letter_Soft_Sign         : constant Unicode_Char := 16#044C#;
   Cyrillic_Small_Letter_E                 : constant Unicode_Char := 16#044D#;
   Cyrillic_Small_Letter_Yu                : constant Unicode_Char := 16#044E#;
   Cyrillic_Small_Letter_Ya                : constant Unicode_Char := 16#044F#;
   Cyrillic_Small_Letter_Ie_With_Grave     : constant Unicode_Char := 16#0450#;
   Cyrillic_Small_Letter_Io                : constant Unicode_Char := 16#0451#;
   Cyrillic_Small_Letter_Dje               : constant Unicode_Char := 16#0452#;
   Cyrillic_Small_Letter_Gje               : constant Unicode_Char := 16#0453#;
   Cyrillic_Small_Letter_Ukrainian_Ie      : constant Unicode_Char := 16#0454#;
   Cyrillic_Small_Letter_Dze               : constant Unicode_Char := 16#0455#;
   Cyrillic_Small_Letter_Byelorussian_Ukrainian_I :
      constant Unicode_Char := 16#0456#;
   Cyrillic_Small_Letter_Yi                : constant Unicode_Char := 16#0457#;
   Cyrillic_Small_Letter_Je                : constant Unicode_Char := 16#0458#;
   Cyrillic_Small_Letter_Lje               : constant Unicode_Char := 16#0459#;
   Cyrillic_Small_Letter_Nje               : constant Unicode_Char := 16#045A#;
   Cyrillic_Small_Letter_Tshe              : constant Unicode_Char := 16#045B#;
   Cyrillic_Small_Letter_Kje               : constant Unicode_Char := 16#045C#;
   Cyrillic_Small_Letter_I_With_Grave      : constant Unicode_Char := 16#045D#;
   Cyrillic_Small_Letter_Short_U           : constant Unicode_Char := 16#045E#;
   Cyrillic_Small_Letter_Dzhe              : constant Unicode_Char := 16#045F#;
   Cyrillic_Capital_Letter_Omega           : constant Unicode_Char := 16#0460#;
   Cyrillic_Small_Letter_Omega             : constant Unicode_Char := 16#0461#;
   Cyrillic_Capital_Letter_Yat             : constant Unicode_Char := 16#0462#;
   Cyrillic_Small_Letter_Yat               : constant Unicode_Char := 16#0463#;
   Cyrillic_Capital_Letter_Iotified_E      : constant Unicode_Char := 16#0464#;
   Cyrillic_Small_Letter_Iotified_E        : constant Unicode_Char := 16#0465#;
   Cyrillic_Capital_Letter_Little_Yus      : constant Unicode_Char := 16#0466#;
   Cyrillic_Small_Letter_Little_Yus        : constant Unicode_Char := 16#0467#;
   Cyrillic_Capital_Letter_Iotified_Little_Yus :
      constant Unicode_Char := 16#0468#;
   Cyrillic_Small_Letter_Iotified_Little_Yus :
      constant Unicode_Char := 16#0469#;
   Cyrillic_Capital_Letter_Big_Yus         : constant Unicode_Char := 16#046A#;
   Cyrillic_Small_Letter_Big_Yus           : constant Unicode_Char := 16#046B#;
   Cyrillic_Capital_Letter_Iotified_Big_Yus :
      constant Unicode_Char := 16#046C#;
   Cyrillic_Small_Letter_Iotified_Big_Yus  : constant Unicode_Char := 16#046D#;
   Cyrillic_Capital_Letter_Ksi             : constant Unicode_Char := 16#046E#;
   Cyrillic_Small_Letter_Ksi               : constant Unicode_Char := 16#046F#;
   Cyrillic_Capital_Letter_Psi             : constant Unicode_Char := 16#0470#;
   Cyrillic_Small_Letter_Psi               : constant Unicode_Char := 16#0471#;
   Cyrillic_Capital_Letter_Fita            : constant Unicode_Char := 16#0472#;
   Cyrillic_Small_Letter_Fita              : constant Unicode_Char := 16#0473#;
   Cyrillic_Capital_Letter_Izhitsa         : constant Unicode_Char := 16#0474#;
   Cyrillic_Small_Letter_Izhitsa           : constant Unicode_Char := 16#0475#;
   Cyrillic_Capital_Letter_Izhitsa_With_Double_Grave_Accent :
      constant Unicode_Char := 16#0476#;
   Cyrillic_Small_Letter_Izhitsa_With_Double_Grave_Accent :
      constant Unicode_Char := 16#0477#;
   Cyrillic_Capital_Letter_Uk              : constant Unicode_Char := 16#0478#;
   Cyrillic_Small_Letter_Uk                : constant Unicode_Char := 16#0479#;
   Cyrillic_Capital_Letter_Round_Omega     : constant Unicode_Char := 16#047A#;
   Cyrillic_Small_Letter_Round_Omega       : constant Unicode_Char := 16#047B#;
   Cyrillic_Capital_Letter_Omega_With_Titlo :
      constant Unicode_Char := 16#047C#;
   Cyrillic_Small_Letter_Omega_With_Titlo  : constant Unicode_Char := 16#047D#;
   Cyrillic_Capital_Letter_Ot              : constant Unicode_Char := 16#047E#;
   Cyrillic_Small_Letter_Ot                : constant Unicode_Char := 16#047F#;
   Cyrillic_Capital_Letter_Koppa           : constant Unicode_Char := 16#0480#;
   Cyrillic_Small_Letter_Koppa             : constant Unicode_Char := 16#0481#;
   Cyrillic_Thousands_Sign                 : constant Unicode_Char := 16#0482#;
   Combining_Cyrillic_Titlo                : constant Unicode_Char := 16#0483#;
   Combining_Cyrillic_Palatalization       : constant Unicode_Char := 16#0484#;
   Combining_Cyrillic_Dasia_Pneumata       : constant Unicode_Char := 16#0485#;
   Combining_Cyrillic_Psili_Pneumata       : constant Unicode_Char := 16#0486#;
   Combining_Cyrillic_Pokrytie             : constant Unicode_Char := 16#0487#;
   Combining_Cyrillic_Hundred_Thousands_Sign :
      constant Unicode_Char := 16#0488#;
   Combining_Cyrillic_Millions_Sign        : constant Unicode_Char := 16#0489#;
   Cyrillic_Capital_Letter_Short_I_With_Tail :
      constant Unicode_Char := 16#048A#;
   Cyrillic_Small_Letter_Short_I_With_Tail : constant Unicode_Char := 16#048B#;
   Cyrillic_Capital_Letter_Semisoft_Sign   : constant Unicode_Char := 16#048C#;
   Cyrillic_Small_Letter_Semisoft_Sign     : constant Unicode_Char := 16#048D#;
   Cyrillic_Capital_Letter_Er_With_Tick    : constant Unicode_Char := 16#048E#;
   Cyrillic_Small_Letter_Er_With_Tick      : constant Unicode_Char := 16#048F#;
   Cyrillic_Capital_Letter_Ghe_With_Upturn : constant Unicode_Char := 16#0490#;
   Cyrillic_Small_Letter_Ghe_With_Upturn   : constant Unicode_Char := 16#0491#;
   Cyrillic_Capital_Letter_Ghe_With_Stroke : constant Unicode_Char := 16#0492#;
   Cyrillic_Small_Letter_Ghe_With_Stroke   : constant Unicode_Char := 16#0493#;
   Cyrillic_Capital_Letter_Ghe_With_Middle_Hook :
      constant Unicode_Char := 16#0494#;
   Cyrillic_Small_Letter_Ghe_With_Middle_Hook :
      constant Unicode_Char := 16#0495#;
   Cyrillic_Capital_Letter_Zhe_With_Descender :
      constant Unicode_Char := 16#0496#;
   Cyrillic_Small_Letter_Zhe_With_Descender :
      constant Unicode_Char := 16#0497#;
   Cyrillic_Capital_Letter_Ze_With_Descender :
      constant Unicode_Char := 16#0498#;
   Cyrillic_Small_Letter_Ze_With_Descender : constant Unicode_Char := 16#0499#;
   Cyrillic_Capital_Letter_Ka_With_Descender :
      constant Unicode_Char := 16#049A#;
   Cyrillic_Small_Letter_Ka_With_Descender : constant Unicode_Char := 16#049B#;
   Cyrillic_Capital_Letter_Ka_With_Vertical_Stroke :
      constant Unicode_Char := 16#049C#;
   Cyrillic_Small_Letter_Ka_With_Vertical_Stroke :
      constant Unicode_Char := 16#049D#;
   Cyrillic_Capital_Letter_Ka_With_Stroke  : constant Unicode_Char := 16#049E#;
   Cyrillic_Small_Letter_Ka_With_Stroke    : constant Unicode_Char := 16#049F#;
   Cyrillic_Capital_Letter_Bashkir_Ka      : constant Unicode_Char := 16#04A0#;
   Cyrillic_Small_Letter_Bashkir_Ka        : constant Unicode_Char := 16#04A1#;
   Cyrillic_Capital_Letter_En_With_Descender :
      constant Unicode_Char := 16#04A2#;
   Cyrillic_Small_Letter_En_With_Descender : constant Unicode_Char := 16#04A3#;
   Cyrillic_Capital_Ligature_En_Ghe        : constant Unicode_Char := 16#04A4#;
   Cyrillic_Small_Ligature_En_Ghe          : constant Unicode_Char := 16#04A5#;
   Cyrillic_Capital_Letter_Pe_With_Middle_Hook :
      constant Unicode_Char := 16#04A6#;
   Cyrillic_Small_Letter_Pe_With_Middle_Hook :
      constant Unicode_Char := 16#04A7#;
   Cyrillic_Capital_Letter_Abkhasian_Ha    : constant Unicode_Char := 16#04A8#;
   Cyrillic_Small_Letter_Abkhasian_Ha      : constant Unicode_Char := 16#04A9#;
   Cyrillic_Capital_Letter_Es_With_Descender :
      constant Unicode_Char := 16#04AA#;
   Cyrillic_Small_Letter_Es_With_Descender : constant Unicode_Char := 16#04AB#;
   Cyrillic_Capital_Letter_Te_With_Descender :
      constant Unicode_Char := 16#04AC#;
   Cyrillic_Small_Letter_Te_With_Descender : constant Unicode_Char := 16#04AD#;
   Cyrillic_Capital_Letter_Straight_U      : constant Unicode_Char := 16#04AE#;
   Cyrillic_Small_Letter_Straight_U        : constant Unicode_Char := 16#04AF#;
   Cyrillic_Capital_Letter_Straight_U_With_Stroke :
      constant Unicode_Char := 16#04B0#;
   Cyrillic_Small_Letter_Straight_U_With_Stroke :
      constant Unicode_Char := 16#04B1#;
   Cyrillic_Capital_Letter_Ha_With_Descender :
      constant Unicode_Char := 16#04B2#;
   Cyrillic_Small_Letter_Ha_With_Descender : constant Unicode_Char := 16#04B3#;
   Cyrillic_Capital_Ligature_Te_Tse        : constant Unicode_Char := 16#04B4#;
   Cyrillic_Small_Ligature_Te_Tse          : constant Unicode_Char := 16#04B5#;
   Cyrillic_Capital_Letter_Che_With_Descender :
      constant Unicode_Char := 16#04B6#;
   Cyrillic_Small_Letter_Che_With_Descender :
      constant Unicode_Char := 16#04B7#;
   Cyrillic_Capital_Letter_Che_With_Vertical_Stroke :
      constant Unicode_Char := 16#04B8#;
   Cyrillic_Small_Letter_Che_With_Vertical_Stroke :
      constant Unicode_Char := 16#04B9#;
   Cyrillic_Capital_Letter_Shha            : constant Unicode_Char := 16#04BA#;
   Cyrillic_Small_Letter_Shha              : constant Unicode_Char := 16#04BB#;
   Cyrillic_Capital_Letter_Abkhasian_Che   : constant Unicode_Char := 16#04BC#;
   Cyrillic_Small_Letter_Abkhasian_Che     : constant Unicode_Char := 16#04BD#;
   Cyrillic_Capital_Letter_Abkhasian_Che_With_Descender :
      constant Unicode_Char := 16#04BE#;
   Cyrillic_Small_Letter_Abkhasian_Che_With_Descender :
      constant Unicode_Char := 16#04BF#;
   Cyrillic_Letter_Palochka                : constant Unicode_Char := 16#04C0#;
   Cyrillic_Capital_Letter_Zhe_With_Breve  : constant Unicode_Char := 16#04C1#;
   Cyrillic_Small_Letter_Zhe_With_Breve    : constant Unicode_Char := 16#04C2#;
   Cyrillic_Capital_Letter_Ka_With_Hook    : constant Unicode_Char := 16#04C3#;
   Cyrillic_Small_Letter_Ka_With_Hook      : constant Unicode_Char := 16#04C4#;
   Cyrillic_Capital_Letter_El_With_Tail    : constant Unicode_Char := 16#04C5#;
   Cyrillic_Small_Letter_El_With_Tail      : constant Unicode_Char := 16#04C6#;
   Cyrillic_Capital_Letter_En_With_Hook    : constant Unicode_Char := 16#04C7#;
   Cyrillic_Small_Letter_En_With_Hook      : constant Unicode_Char := 16#04C8#;
   Cyrillic_Capital_Letter_En_With_Tail    : constant Unicode_Char := 16#04C9#;
   Cyrillic_Small_Letter_En_With_Tail      : constant Unicode_Char := 16#04CA#;
   Cyrillic_Capital_Letter_Khakassian_Che  : constant Unicode_Char := 16#04CB#;
   Cyrillic_Small_Letter_Khakassian_Che    : constant Unicode_Char := 16#04CC#;
   Cyrillic_Capital_Letter_Em_With_Tail    : constant Unicode_Char := 16#04CD#;
   Cyrillic_Small_Letter_Em_With_Tail      : constant Unicode_Char := 16#04CE#;
   Cyrillic_Small_Letter_Palochka          : constant Unicode_Char := 16#04CF#;
   Cyrillic_Capital_Letter_A_With_Breve    : constant Unicode_Char := 16#04D0#;
   Cyrillic_Small_Letter_A_With_Breve      : constant Unicode_Char := 16#04D1#;
   Cyrillic_Capital_Letter_A_With_Diaeresis :
      constant Unicode_Char := 16#04D2#;
   Cyrillic_Small_Letter_A_With_Diaeresis  : constant Unicode_Char := 16#04D3#;
   Cyrillic_Capital_Ligature_A_Ie          : constant Unicode_Char := 16#04D4#;
   Cyrillic_Small_Ligature_A_Ie            : constant Unicode_Char := 16#04D5#;
   Cyrillic_Capital_Letter_Ie_With_Breve   : constant Unicode_Char := 16#04D6#;
   Cyrillic_Small_Letter_Ie_With_Breve     : constant Unicode_Char := 16#04D7#;
   Cyrillic_Capital_Letter_Schwa           : constant Unicode_Char := 16#04D8#;
   Cyrillic_Small_Letter_Schwa             : constant Unicode_Char := 16#04D9#;
   Cyrillic_Capital_Letter_Schwa_With_Diaeresis :
      constant Unicode_Char := 16#04DA#;
   Cyrillic_Small_Letter_Schwa_With_Diaeresis :
      constant Unicode_Char := 16#04DB#;
   Cyrillic_Capital_Letter_Zhe_With_Diaeresis :
      constant Unicode_Char := 16#04DC#;
   Cyrillic_Small_Letter_Zhe_With_Diaeresis :
      constant Unicode_Char := 16#04DD#;
   Cyrillic_Capital_Letter_Ze_With_Diaeresis :
      constant Unicode_Char := 16#04DE#;
   Cyrillic_Small_Letter_Ze_With_Diaeresis : constant Unicode_Char := 16#04DF#;
   Cyrillic_Capital_Letter_Abkhasian_Dze   : constant Unicode_Char := 16#04E0#;
   Cyrillic_Small_Letter_Abkhasian_Dze     : constant Unicode_Char := 16#04E1#;
   Cyrillic_Capital_Letter_I_With_Macron   : constant Unicode_Char := 16#04E2#;
   Cyrillic_Small_Letter_I_With_Macron     : constant Unicode_Char := 16#04E3#;
   Cyrillic_Capital_Letter_I_With_Diaeresis :
      constant Unicode_Char := 16#04E4#;
   Cyrillic_Small_Letter_I_With_Diaeresis  : constant Unicode_Char := 16#04E5#;
   Cyrillic_Capital_Letter_O_With_Diaeresis :
      constant Unicode_Char := 16#04E6#;
   Cyrillic_Small_Letter_O_With_Diaeresis  : constant Unicode_Char := 16#04E7#;
   Cyrillic_Capital_Letter_Barred_O        : constant Unicode_Char := 16#04E8#;
   Cyrillic_Small_Letter_Barred_O          : constant Unicode_Char := 16#04E9#;
   Cyrillic_Capital_Letter_Barred_O_With_Diaeresis :
      constant Unicode_Char := 16#04EA#;
   Cyrillic_Small_Letter_Barred_O_With_Diaeresis :
      constant Unicode_Char := 16#04EB#;
   Cyrillic_Capital_Letter_E_With_Diaeresis :
      constant Unicode_Char := 16#04EC#;
   Cyrillic_Small_Letter_E_With_Diaeresis  : constant Unicode_Char := 16#04ED#;
   Cyrillic_Capital_Letter_U_With_Macron   : constant Unicode_Char := 16#04EE#;
   Cyrillic_Small_Letter_U_With_Macron     : constant Unicode_Char := 16#04EF#;
   Cyrillic_Capital_Letter_U_With_Diaeresis :
      constant Unicode_Char := 16#04F0#;
   Cyrillic_Small_Letter_U_With_Diaeresis  : constant Unicode_Char := 16#04F1#;
   Cyrillic_Capital_Letter_U_With_Double_Acute :
      constant Unicode_Char := 16#04F2#;
   Cyrillic_Small_Letter_U_With_Double_Acute :
      constant Unicode_Char := 16#04F3#;
   Cyrillic_Capital_Letter_Che_With_Diaeresis :
      constant Unicode_Char := 16#04F4#;
   Cyrillic_Small_Letter_Che_With_Diaeresis :
      constant Unicode_Char := 16#04F5#;
   Cyrillic_Capital_Letter_Ghe_With_Descender :
      constant Unicode_Char := 16#04F6#;
   Cyrillic_Small_Letter_Ghe_With_Descender :
      constant Unicode_Char := 16#04F7#;
   Cyrillic_Capital_Letter_Yeru_With_Diaeresis :
      constant Unicode_Char := 16#04F8#;
   Cyrillic_Small_Letter_Yeru_With_Diaeresis :
      constant Unicode_Char := 16#04F9#;
   Cyrillic_Capital_Letter_Ghe_With_Stroke_And_Hook :
      constant Unicode_Char := 16#04FA#;
   Cyrillic_Small_Letter_Ghe_With_Stroke_And_Hook :
      constant Unicode_Char := 16#04FB#;
   Cyrillic_Capital_Letter_Ha_With_Hook    : constant Unicode_Char := 16#04FC#;
   Cyrillic_Small_Letter_Ha_With_Hook      : constant Unicode_Char := 16#04FD#;
   Cyrillic_Capital_Letter_Ha_With_Stroke  : constant Unicode_Char := 16#04FE#;
   Cyrillic_Small_Letter_Ha_With_Stroke    : constant Unicode_Char := 16#04FF#;
end Unicode.Names.Cyrillic;
