--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cjk_Radicals_Supplement is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cjk_Radical_Repeat                      : constant Unicode_Char := 16#2E80#;
   Cjk_Radical_Cliff                       : constant Unicode_Char := 16#2E81#;
   Cjk_Radical_Second_One                  : constant Unicode_Char := 16#2E82#;
   Cjk_Radical_Second_Two                  : constant Unicode_Char := 16#2E83#;
   Cjk_Radical_Second_Three                : constant Unicode_Char := 16#2E84#;
   Cjk_Radical_Person                      : constant Unicode_Char := 16#2E85#;
   Cjk_Radical_Box                         : constant Unicode_Char := 16#2E86#;
   Cjk_Radical_Table                       : constant Unicode_Char := 16#2E87#;
   Cjk_Radical_Knife_One                   : constant Unicode_Char := 16#2E88#;
   Cjk_Radical_Knife_Two                   : constant Unicode_Char := 16#2E89#;
   Cjk_Radical_Divination                  : constant Unicode_Char := 16#2E8A#;
   Cjk_Radical_Seal                        : constant Unicode_Char := 16#2E8B#;
   Cjk_Radical_Small_One                   : constant Unicode_Char := 16#2E8C#;
   Cjk_Radical_Small_Two                   : constant Unicode_Char := 16#2E8D#;
   Cjk_Radical_Lame_One                    : constant Unicode_Char := 16#2E8E#;
   Cjk_Radical_Lame_Two                    : constant Unicode_Char := 16#2E8F#;
   Cjk_Radical_Lame_Three                  : constant Unicode_Char := 16#2E90#;
   Cjk_Radical_Lame_Four                   : constant Unicode_Char := 16#2E91#;
   Cjk_Radical_Snake                       : constant Unicode_Char := 16#2E92#;
   Cjk_Radical_Thread                      : constant Unicode_Char := 16#2E93#;
   Cjk_Radical_Snout_One                   : constant Unicode_Char := 16#2E94#;
   Cjk_Radical_Snout_Two                   : constant Unicode_Char := 16#2E95#;
   Cjk_Radical_Heart_One                   : constant Unicode_Char := 16#2E96#;
   Cjk_Radical_Heart_Two                   : constant Unicode_Char := 16#2E97#;
   Cjk_Radical_Hand                        : constant Unicode_Char := 16#2E98#;
   Cjk_Radical_Rap                         : constant Unicode_Char := 16#2E99#;
   Cjk_Radical_Choke                       : constant Unicode_Char := 16#2E9B#;
   Cjk_Radical_Sun                         : constant Unicode_Char := 16#2E9C#;
   Cjk_Radical_Moon                        : constant Unicode_Char := 16#2E9D#;
   Cjk_Radical_Death                       : constant Unicode_Char := 16#2E9E#;
   Cjk_Radical_Mother                      : constant Unicode_Char := 16#2E9F#;
   Cjk_Radical_Civilian                    : constant Unicode_Char := 16#2EA0#;
   Cjk_Radical_Water_One                   : constant Unicode_Char := 16#2EA1#;
   Cjk_Radical_Water_Two                   : constant Unicode_Char := 16#2EA2#;
   Cjk_Radical_Fire                        : constant Unicode_Char := 16#2EA3#;
   Cjk_Radical_Paw_One                     : constant Unicode_Char := 16#2EA4#;
   Cjk_Radical_Paw_Two                     : constant Unicode_Char := 16#2EA5#;
   Cjk_Radical_Simplified_Half_Tree_Trunk  : constant Unicode_Char := 16#2EA6#;
   Cjk_Radical_Cow                         : constant Unicode_Char := 16#2EA7#;
   Cjk_Radical_Dog                         : constant Unicode_Char := 16#2EA8#;
   Cjk_Radical_Jade                        : constant Unicode_Char := 16#2EA9#;
   Cjk_Radical_Bolt_Of_Cloth               : constant Unicode_Char := 16#2EAA#;
   Cjk_Radical_Eye                         : constant Unicode_Char := 16#2EAB#;
   Cjk_Radical_Spirit_One                  : constant Unicode_Char := 16#2EAC#;
   Cjk_Radical_Spirit_Two                  : constant Unicode_Char := 16#2EAD#;
   Cjk_Radical_Bamboo                      : constant Unicode_Char := 16#2EAE#;
   Cjk_Radical_Silk                        : constant Unicode_Char := 16#2EAF#;
   Cjk_Radical_C_Simplified_Silk           : constant Unicode_Char := 16#2EB0#;
   Cjk_Radical_Net_One                     : constant Unicode_Char := 16#2EB1#;
   Cjk_Radical_Net_Two                     : constant Unicode_Char := 16#2EB2#;
   Cjk_Radical_Net_Three                   : constant Unicode_Char := 16#2EB3#;
   Cjk_Radical_Net_Four                    : constant Unicode_Char := 16#2EB4#;
   Cjk_Radical_Mesh                        : constant Unicode_Char := 16#2EB5#;
   Cjk_Radical_Sheep                       : constant Unicode_Char := 16#2EB6#;
   Cjk_Radical_Ram                         : constant Unicode_Char := 16#2EB7#;
   Cjk_Radical_Ewe                         : constant Unicode_Char := 16#2EB8#;
   Cjk_Radical_Old                         : constant Unicode_Char := 16#2EB9#;
   Cjk_Radical_Brush_One                   : constant Unicode_Char := 16#2EBA#;
   Cjk_Radical_Brush_Two                   : constant Unicode_Char := 16#2EBB#;
   Cjk_Radical_Meat                        : constant Unicode_Char := 16#2EBC#;
   Cjk_Radical_Mortar                      : constant Unicode_Char := 16#2EBD#;
   Cjk_Radical_Grass_One                   : constant Unicode_Char := 16#2EBE#;
   Cjk_Radical_Grass_Two                   : constant Unicode_Char := 16#2EBF#;
   Cjk_Radical_Grass_Three                 : constant Unicode_Char := 16#2EC0#;
   Cjk_Radical_Tiger                       : constant Unicode_Char := 16#2EC1#;
   Cjk_Radical_Clothes                     : constant Unicode_Char := 16#2EC2#;
   Cjk_Radical_West_One                    : constant Unicode_Char := 16#2EC3#;
   Cjk_Radical_West_Two                    : constant Unicode_Char := 16#2EC4#;
   Cjk_Radical_C_Simplified_See            : constant Unicode_Char := 16#2EC5#;
   Cjk_Radical_Simplified_Horn             : constant Unicode_Char := 16#2EC6#;
   Cjk_Radical_Horn                        : constant Unicode_Char := 16#2EC7#;
   Cjk_Radical_C_Simplified_Speech         : constant Unicode_Char := 16#2EC8#;
   Cjk_Radical_C_Simplified_Shell          : constant Unicode_Char := 16#2EC9#;
   Cjk_Radical_Foot                        : constant Unicode_Char := 16#2ECA#;
   Cjk_Radical_C_Simplified_Cart           : constant Unicode_Char := 16#2ECB#;
   Cjk_Radical_Simplified_Walk             : constant Unicode_Char := 16#2ECC#;
   Cjk_Radical_Walk_One                    : constant Unicode_Char := 16#2ECD#;
   Cjk_Radical_Walk_Two                    : constant Unicode_Char := 16#2ECE#;
   Cjk_Radical_City                        : constant Unicode_Char := 16#2ECF#;
   Cjk_Radical_C_Simplified_Gold           : constant Unicode_Char := 16#2ED0#;
   Cjk_Radical_Long_One                    : constant Unicode_Char := 16#2ED1#;
   Cjk_Radical_Long_Two                    : constant Unicode_Char := 16#2ED2#;
   Cjk_Radical_C_Simplified_Long           : constant Unicode_Char := 16#2ED3#;
   Cjk_Radical_C_Simplified_Gate           : constant Unicode_Char := 16#2ED4#;
   Cjk_Radical_Mound_One                   : constant Unicode_Char := 16#2ED5#;
   Cjk_Radical_Mound_Two                   : constant Unicode_Char := 16#2ED6#;
   Cjk_Radical_Rain                        : constant Unicode_Char := 16#2ED7#;
   Cjk_Radical_Blue                        : constant Unicode_Char := 16#2ED8#;
   Cjk_Radical_C_Simplified_Tanned_Leather : constant Unicode_Char := 16#2ED9#;
   Cjk_Radical_C_Simplified_Leaf           : constant Unicode_Char := 16#2EDA#;
   Cjk_Radical_C_Simplified_Wind           : constant Unicode_Char := 16#2EDB#;
   Cjk_Radical_C_Simplified_Fly            : constant Unicode_Char := 16#2EDC#;
   Cjk_Radical_Eat_One                     : constant Unicode_Char := 16#2EDD#;
   Cjk_Radical_Eat_Two                     : constant Unicode_Char := 16#2EDE#;
   Cjk_Radical_Eat_Three                   : constant Unicode_Char := 16#2EDF#;
   Cjk_Radical_C_Simplified_Eat            : constant Unicode_Char := 16#2EE0#;
   Cjk_Radical_Head                        : constant Unicode_Char := 16#2EE1#;
   Cjk_Radical_C_Simplified_Horse          : constant Unicode_Char := 16#2EE2#;
   Cjk_Radical_Bone                        : constant Unicode_Char := 16#2EE3#;
   Cjk_Radical_Ghost                       : constant Unicode_Char := 16#2EE4#;
   Cjk_Radical_C_Simplified_Fish           : constant Unicode_Char := 16#2EE5#;
   Cjk_Radical_C_Simplified_Bird           : constant Unicode_Char := 16#2EE6#;
   Cjk_Radical_C_Simplified_Salt           : constant Unicode_Char := 16#2EE7#;
   Cjk_Radical_Simplified_Wheat            : constant Unicode_Char := 16#2EE8#;
   Cjk_Radical_Simplified_Yellow           : constant Unicode_Char := 16#2EE9#;
   Cjk_Radical_C_Simplified_Frog           : constant Unicode_Char := 16#2EEA#;
   Cjk_Radical_J_Simplified_Even           : constant Unicode_Char := 16#2EEB#;
   Cjk_Radical_C_Simplified_Even           : constant Unicode_Char := 16#2EEC#;
   Cjk_Radical_J_Simplified_Tooth          : constant Unicode_Char := 16#2EED#;
   Cjk_Radical_C_Simplified_Tooth          : constant Unicode_Char := 16#2EEE#;
   Cjk_Radical_J_Simplified_Dragon         : constant Unicode_Char := 16#2EEF#;
   Cjk_Radical_C_Simplified_Dragon         : constant Unicode_Char := 16#2EF0#;
   Cjk_Radical_Turtle                      : constant Unicode_Char := 16#2EF1#;
   Cjk_Radical_J_Simplified_Turtle         : constant Unicode_Char := 16#2EF2#;
   Cjk_Radical_C_Simplified_Turtle         : constant Unicode_Char := 16#2EF3#;
end Unicode.Names.Cjk_Radicals_Supplement;
