--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Takri is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Takri_Letter_A                          :
      constant Unicode_Char := 16#11680#;
   Takri_Letter_Aa                         :
      constant Unicode_Char := 16#11681#;
   Takri_Letter_I                          :
      constant Unicode_Char := 16#11682#;
   Takri_Letter_Ii                         :
      constant Unicode_Char := 16#11683#;
   Takri_Letter_U                          :
      constant Unicode_Char := 16#11684#;
   Takri_Letter_Uu                         :
      constant Unicode_Char := 16#11685#;
   Takri_Letter_E                          :
      constant Unicode_Char := 16#11686#;
   Takri_Letter_Ai                         :
      constant Unicode_Char := 16#11687#;
   Takri_Letter_O                          :
      constant Unicode_Char := 16#11688#;
   Takri_Letter_Au                         :
      constant Unicode_Char := 16#11689#;
   Takri_Letter_Ka                         :
      constant Unicode_Char := 16#1168A#;
   Takri_Letter_Kha                        :
      constant Unicode_Char := 16#1168B#;
   Takri_Letter_Ga                         :
      constant Unicode_Char := 16#1168C#;
   Takri_Letter_Gha                        :
      constant Unicode_Char := 16#1168D#;
   Takri_Letter_Nga                        :
      constant Unicode_Char := 16#1168E#;
   Takri_Letter_Ca                         :
      constant Unicode_Char := 16#1168F#;
   Takri_Letter_Cha                        :
      constant Unicode_Char := 16#11690#;
   Takri_Letter_Ja                         :
      constant Unicode_Char := 16#11691#;
   Takri_Letter_Jha                        :
      constant Unicode_Char := 16#11692#;
   Takri_Letter_Nya                        :
      constant Unicode_Char := 16#11693#;
   Takri_Letter_Tta                        :
      constant Unicode_Char := 16#11694#;
   Takri_Letter_Ttha                       :
      constant Unicode_Char := 16#11695#;
   Takri_Letter_Dda                        :
      constant Unicode_Char := 16#11696#;
   Takri_Letter_Ddha                       :
      constant Unicode_Char := 16#11697#;
   Takri_Letter_Nna                        :
      constant Unicode_Char := 16#11698#;
   Takri_Letter_Ta                         :
      constant Unicode_Char := 16#11699#;
   Takri_Letter_Tha                        :
      constant Unicode_Char := 16#1169A#;
   Takri_Letter_Da                         :
      constant Unicode_Char := 16#1169B#;
   Takri_Letter_Dha                        :
      constant Unicode_Char := 16#1169C#;
   Takri_Letter_Na                         :
      constant Unicode_Char := 16#1169D#;
   Takri_Letter_Pa                         :
      constant Unicode_Char := 16#1169E#;
   Takri_Letter_Pha                        :
      constant Unicode_Char := 16#1169F#;
   Takri_Letter_Ba                         :
      constant Unicode_Char := 16#116A0#;
   Takri_Letter_Bha                        :
      constant Unicode_Char := 16#116A1#;
   Takri_Letter_Ma                         :
      constant Unicode_Char := 16#116A2#;
   Takri_Letter_Ya                         :
      constant Unicode_Char := 16#116A3#;
   Takri_Letter_Ra                         :
      constant Unicode_Char := 16#116A4#;
   Takri_Letter_La                         :
      constant Unicode_Char := 16#116A5#;
   Takri_Letter_Va                         :
      constant Unicode_Char := 16#116A6#;
   Takri_Letter_Sha                        :
      constant Unicode_Char := 16#116A7#;
   Takri_Letter_Sa                         :
      constant Unicode_Char := 16#116A8#;
   Takri_Letter_Ha                         :
      constant Unicode_Char := 16#116A9#;
   Takri_Letter_Rra                        :
      constant Unicode_Char := 16#116AA#;
   Takri_Sign_Anusvara                     :
      constant Unicode_Char := 16#116AB#;
   Takri_Sign_Visarga                      :
      constant Unicode_Char := 16#116AC#;
   Takri_Vowel_Sign_Aa                     :
      constant Unicode_Char := 16#116AD#;
   Takri_Vowel_Sign_I                      :
      constant Unicode_Char := 16#116AE#;
   Takri_Vowel_Sign_Ii                     :
      constant Unicode_Char := 16#116AF#;
   Takri_Vowel_Sign_U                      :
      constant Unicode_Char := 16#116B0#;
   Takri_Vowel_Sign_Uu                     :
      constant Unicode_Char := 16#116B1#;
   Takri_Vowel_Sign_E                      :
      constant Unicode_Char := 16#116B2#;
   Takri_Vowel_Sign_Ai                     :
      constant Unicode_Char := 16#116B3#;
   Takri_Vowel_Sign_O                      :
      constant Unicode_Char := 16#116B4#;
   Takri_Vowel_Sign_Au                     :
      constant Unicode_Char := 16#116B5#;
   Takri_Sign_Virama                       :
      constant Unicode_Char := 16#116B6#;
   Takri_Sign_Nukta                        :
      constant Unicode_Char := 16#116B7#;
   Takri_Digit_Zero                        :
      constant Unicode_Char := 16#116C0#;
   Takri_Digit_One                         :
      constant Unicode_Char := 16#116C1#;
   Takri_Digit_Two                         :
      constant Unicode_Char := 16#116C2#;
   Takri_Digit_Three                       :
      constant Unicode_Char := 16#116C3#;
   Takri_Digit_Four                        :
      constant Unicode_Char := 16#116C4#;
   Takri_Digit_Five                        :
      constant Unicode_Char := 16#116C5#;
   Takri_Digit_Six                         :
      constant Unicode_Char := 16#116C6#;
   Takri_Digit_Seven                       :
      constant Unicode_Char := 16#116C7#;
   Takri_Digit_Eight                       :
      constant Unicode_Char := 16#116C8#;
   Takri_Digit_Nine                        :
      constant Unicode_Char := 16#116C9#;
end Unicode.Names.Takri;
