--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Anatolian_Hieroglyphs is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Anatolian_Hieroglyph_A001               :
      constant Unicode_Char := 16#14400#;
   Anatolian_Hieroglyph_A002               :
      constant Unicode_Char := 16#14401#;
   Anatolian_Hieroglyph_A003               :
      constant Unicode_Char := 16#14402#;
   Anatolian_Hieroglyph_A004               :
      constant Unicode_Char := 16#14403#;
   Anatolian_Hieroglyph_A005               :
      constant Unicode_Char := 16#14404#;
   Anatolian_Hieroglyph_A006               :
      constant Unicode_Char := 16#14405#;
   Anatolian_Hieroglyph_A007               :
      constant Unicode_Char := 16#14406#;
   Anatolian_Hieroglyph_A008               :
      constant Unicode_Char := 16#14407#;
   Anatolian_Hieroglyph_A009               :
      constant Unicode_Char := 16#14408#;
   Anatolian_Hieroglyph_A010               :
      constant Unicode_Char := 16#14409#;
   Anatolian_Hieroglyph_A010a              :
      constant Unicode_Char := 16#1440A#;
   Anatolian_Hieroglyph_A011               :
      constant Unicode_Char := 16#1440B#;
   Anatolian_Hieroglyph_A012               :
      constant Unicode_Char := 16#1440C#;
   Anatolian_Hieroglyph_A013               :
      constant Unicode_Char := 16#1440D#;
   Anatolian_Hieroglyph_A014               :
      constant Unicode_Char := 16#1440E#;
   Anatolian_Hieroglyph_A015               :
      constant Unicode_Char := 16#1440F#;
   Anatolian_Hieroglyph_A016               :
      constant Unicode_Char := 16#14410#;
   Anatolian_Hieroglyph_A017               :
      constant Unicode_Char := 16#14411#;
   Anatolian_Hieroglyph_A018               :
      constant Unicode_Char := 16#14412#;
   Anatolian_Hieroglyph_A019               :
      constant Unicode_Char := 16#14413#;
   Anatolian_Hieroglyph_A020               :
      constant Unicode_Char := 16#14414#;
   Anatolian_Hieroglyph_A021               :
      constant Unicode_Char := 16#14415#;
   Anatolian_Hieroglyph_A022               :
      constant Unicode_Char := 16#14416#;
   Anatolian_Hieroglyph_A023               :
      constant Unicode_Char := 16#14417#;
   Anatolian_Hieroglyph_A024               :
      constant Unicode_Char := 16#14418#;
   Anatolian_Hieroglyph_A025               :
      constant Unicode_Char := 16#14419#;
   Anatolian_Hieroglyph_A026               :
      constant Unicode_Char := 16#1441A#;
   Anatolian_Hieroglyph_A026a              :
      constant Unicode_Char := 16#1441B#;
   Anatolian_Hieroglyph_A027               :
      constant Unicode_Char := 16#1441C#;
   Anatolian_Hieroglyph_A028               :
      constant Unicode_Char := 16#1441D#;
   Anatolian_Hieroglyph_A029               :
      constant Unicode_Char := 16#1441E#;
   Anatolian_Hieroglyph_A030               :
      constant Unicode_Char := 16#1441F#;
   Anatolian_Hieroglyph_A031               :
      constant Unicode_Char := 16#14420#;
   Anatolian_Hieroglyph_A032               :
      constant Unicode_Char := 16#14421#;
   Anatolian_Hieroglyph_A033               :
      constant Unicode_Char := 16#14422#;
   Anatolian_Hieroglyph_A034               :
      constant Unicode_Char := 16#14423#;
   Anatolian_Hieroglyph_A035               :
      constant Unicode_Char := 16#14424#;
   Anatolian_Hieroglyph_A036               :
      constant Unicode_Char := 16#14425#;
   Anatolian_Hieroglyph_A037               :
      constant Unicode_Char := 16#14426#;
   Anatolian_Hieroglyph_A038               :
      constant Unicode_Char := 16#14427#;
   Anatolian_Hieroglyph_A039               :
      constant Unicode_Char := 16#14428#;
   Anatolian_Hieroglyph_A039a              :
      constant Unicode_Char := 16#14429#;
   Anatolian_Hieroglyph_A040               :
      constant Unicode_Char := 16#1442A#;
   Anatolian_Hieroglyph_A041               :
      constant Unicode_Char := 16#1442B#;
   Anatolian_Hieroglyph_A041a              :
      constant Unicode_Char := 16#1442C#;
   Anatolian_Hieroglyph_A042               :
      constant Unicode_Char := 16#1442D#;
   Anatolian_Hieroglyph_A043               :
      constant Unicode_Char := 16#1442E#;
   Anatolian_Hieroglyph_A044               :
      constant Unicode_Char := 16#1442F#;
   Anatolian_Hieroglyph_A045               :
      constant Unicode_Char := 16#14430#;
   Anatolian_Hieroglyph_A045a              :
      constant Unicode_Char := 16#14431#;
   Anatolian_Hieroglyph_A046               :
      constant Unicode_Char := 16#14432#;
   Anatolian_Hieroglyph_A046a              :
      constant Unicode_Char := 16#14433#;
   Anatolian_Hieroglyph_A046b              :
      constant Unicode_Char := 16#14434#;
   Anatolian_Hieroglyph_A047               :
      constant Unicode_Char := 16#14435#;
   Anatolian_Hieroglyph_A048               :
      constant Unicode_Char := 16#14436#;
   Anatolian_Hieroglyph_A049               :
      constant Unicode_Char := 16#14437#;
   Anatolian_Hieroglyph_A050               :
      constant Unicode_Char := 16#14438#;
   Anatolian_Hieroglyph_A051               :
      constant Unicode_Char := 16#14439#;
   Anatolian_Hieroglyph_A052               :
      constant Unicode_Char := 16#1443A#;
   Anatolian_Hieroglyph_A053               :
      constant Unicode_Char := 16#1443B#;
   Anatolian_Hieroglyph_A054               :
      constant Unicode_Char := 16#1443C#;
   Anatolian_Hieroglyph_A055               :
      constant Unicode_Char := 16#1443D#;
   Anatolian_Hieroglyph_A056               :
      constant Unicode_Char := 16#1443E#;
   Anatolian_Hieroglyph_A057               :
      constant Unicode_Char := 16#1443F#;
   Anatolian_Hieroglyph_A058               :
      constant Unicode_Char := 16#14440#;
   Anatolian_Hieroglyph_A059               :
      constant Unicode_Char := 16#14441#;
   Anatolian_Hieroglyph_A060               :
      constant Unicode_Char := 16#14442#;
   Anatolian_Hieroglyph_A061               :
      constant Unicode_Char := 16#14443#;
   Anatolian_Hieroglyph_A062               :
      constant Unicode_Char := 16#14444#;
   Anatolian_Hieroglyph_A063               :
      constant Unicode_Char := 16#14445#;
   Anatolian_Hieroglyph_A064               :
      constant Unicode_Char := 16#14446#;
   Anatolian_Hieroglyph_A065               :
      constant Unicode_Char := 16#14447#;
   Anatolian_Hieroglyph_A066               :
      constant Unicode_Char := 16#14448#;
   Anatolian_Hieroglyph_A066a              :
      constant Unicode_Char := 16#14449#;
   Anatolian_Hieroglyph_A066b              :
      constant Unicode_Char := 16#1444A#;
   Anatolian_Hieroglyph_A066c              :
      constant Unicode_Char := 16#1444B#;
   Anatolian_Hieroglyph_A067               :
      constant Unicode_Char := 16#1444C#;
   Anatolian_Hieroglyph_A068               :
      constant Unicode_Char := 16#1444D#;
   Anatolian_Hieroglyph_A069               :
      constant Unicode_Char := 16#1444E#;
   Anatolian_Hieroglyph_A070               :
      constant Unicode_Char := 16#1444F#;
   Anatolian_Hieroglyph_A071               :
      constant Unicode_Char := 16#14450#;
   Anatolian_Hieroglyph_A072               :
      constant Unicode_Char := 16#14451#;
   Anatolian_Hieroglyph_A073               :
      constant Unicode_Char := 16#14452#;
   Anatolian_Hieroglyph_A074               :
      constant Unicode_Char := 16#14453#;
   Anatolian_Hieroglyph_A075               :
      constant Unicode_Char := 16#14454#;
   Anatolian_Hieroglyph_A076               :
      constant Unicode_Char := 16#14455#;
   Anatolian_Hieroglyph_A077               :
      constant Unicode_Char := 16#14456#;
   Anatolian_Hieroglyph_A078               :
      constant Unicode_Char := 16#14457#;
   Anatolian_Hieroglyph_A079               :
      constant Unicode_Char := 16#14458#;
   Anatolian_Hieroglyph_A080               :
      constant Unicode_Char := 16#14459#;
   Anatolian_Hieroglyph_A081               :
      constant Unicode_Char := 16#1445A#;
   Anatolian_Hieroglyph_A082               :
      constant Unicode_Char := 16#1445B#;
   Anatolian_Hieroglyph_A083               :
      constant Unicode_Char := 16#1445C#;
   Anatolian_Hieroglyph_A084               :
      constant Unicode_Char := 16#1445D#;
   Anatolian_Hieroglyph_A085               :
      constant Unicode_Char := 16#1445E#;
   Anatolian_Hieroglyph_A086               :
      constant Unicode_Char := 16#1445F#;
   Anatolian_Hieroglyph_A087               :
      constant Unicode_Char := 16#14460#;
   Anatolian_Hieroglyph_A088               :
      constant Unicode_Char := 16#14461#;
   Anatolian_Hieroglyph_A089               :
      constant Unicode_Char := 16#14462#;
   Anatolian_Hieroglyph_A090               :
      constant Unicode_Char := 16#14463#;
   Anatolian_Hieroglyph_A091               :
      constant Unicode_Char := 16#14464#;
   Anatolian_Hieroglyph_A092               :
      constant Unicode_Char := 16#14465#;
   Anatolian_Hieroglyph_A093               :
      constant Unicode_Char := 16#14466#;
   Anatolian_Hieroglyph_A094               :
      constant Unicode_Char := 16#14467#;
   Anatolian_Hieroglyph_A095               :
      constant Unicode_Char := 16#14468#;
   Anatolian_Hieroglyph_A096               :
      constant Unicode_Char := 16#14469#;
   Anatolian_Hieroglyph_A097               :
      constant Unicode_Char := 16#1446A#;
   Anatolian_Hieroglyph_A097a              :
      constant Unicode_Char := 16#1446B#;
   Anatolian_Hieroglyph_A098               :
      constant Unicode_Char := 16#1446C#;
   Anatolian_Hieroglyph_A098a              :
      constant Unicode_Char := 16#1446D#;
   Anatolian_Hieroglyph_A099               :
      constant Unicode_Char := 16#1446E#;
   Anatolian_Hieroglyph_A100               :
      constant Unicode_Char := 16#1446F#;
   Anatolian_Hieroglyph_A100a              :
      constant Unicode_Char := 16#14470#;
   Anatolian_Hieroglyph_A101               :
      constant Unicode_Char := 16#14471#;
   Anatolian_Hieroglyph_A101a              :
      constant Unicode_Char := 16#14472#;
   Anatolian_Hieroglyph_A102               :
      constant Unicode_Char := 16#14473#;
   Anatolian_Hieroglyph_A102a              :
      constant Unicode_Char := 16#14474#;
   Anatolian_Hieroglyph_A103               :
      constant Unicode_Char := 16#14475#;
   Anatolian_Hieroglyph_A104               :
      constant Unicode_Char := 16#14476#;
   Anatolian_Hieroglyph_A104a              :
      constant Unicode_Char := 16#14477#;
   Anatolian_Hieroglyph_A104b              :
      constant Unicode_Char := 16#14478#;
   Anatolian_Hieroglyph_A104c              :
      constant Unicode_Char := 16#14479#;
   Anatolian_Hieroglyph_A105               :
      constant Unicode_Char := 16#1447A#;
   Anatolian_Hieroglyph_A105a              :
      constant Unicode_Char := 16#1447B#;
   Anatolian_Hieroglyph_A105b              :
      constant Unicode_Char := 16#1447C#;
   Anatolian_Hieroglyph_A106               :
      constant Unicode_Char := 16#1447D#;
   Anatolian_Hieroglyph_A107               :
      constant Unicode_Char := 16#1447E#;
   Anatolian_Hieroglyph_A107a              :
      constant Unicode_Char := 16#1447F#;
   Anatolian_Hieroglyph_A107b              :
      constant Unicode_Char := 16#14480#;
   Anatolian_Hieroglyph_A107c              :
      constant Unicode_Char := 16#14481#;
   Anatolian_Hieroglyph_A108               :
      constant Unicode_Char := 16#14482#;
   Anatolian_Hieroglyph_A109               :
      constant Unicode_Char := 16#14483#;
   Anatolian_Hieroglyph_A110               :
      constant Unicode_Char := 16#14484#;
   Anatolian_Hieroglyph_A110a              :
      constant Unicode_Char := 16#14485#;
   Anatolian_Hieroglyph_A110b              :
      constant Unicode_Char := 16#14486#;
   Anatolian_Hieroglyph_A111               :
      constant Unicode_Char := 16#14487#;
   Anatolian_Hieroglyph_A112               :
      constant Unicode_Char := 16#14488#;
   Anatolian_Hieroglyph_A113               :
      constant Unicode_Char := 16#14489#;
   Anatolian_Hieroglyph_A114               :
      constant Unicode_Char := 16#1448A#;
   Anatolian_Hieroglyph_A115               :
      constant Unicode_Char := 16#1448B#;
   Anatolian_Hieroglyph_A115a              :
      constant Unicode_Char := 16#1448C#;
   Anatolian_Hieroglyph_A116               :
      constant Unicode_Char := 16#1448D#;
   Anatolian_Hieroglyph_A117               :
      constant Unicode_Char := 16#1448E#;
   Anatolian_Hieroglyph_A118               :
      constant Unicode_Char := 16#1448F#;
   Anatolian_Hieroglyph_A119               :
      constant Unicode_Char := 16#14490#;
   Anatolian_Hieroglyph_A120               :
      constant Unicode_Char := 16#14491#;
   Anatolian_Hieroglyph_A121               :
      constant Unicode_Char := 16#14492#;
   Anatolian_Hieroglyph_A122               :
      constant Unicode_Char := 16#14493#;
   Anatolian_Hieroglyph_A123               :
      constant Unicode_Char := 16#14494#;
   Anatolian_Hieroglyph_A124               :
      constant Unicode_Char := 16#14495#;
   Anatolian_Hieroglyph_A125               :
      constant Unicode_Char := 16#14496#;
   Anatolian_Hieroglyph_A125a              :
      constant Unicode_Char := 16#14497#;
   Anatolian_Hieroglyph_A126               :
      constant Unicode_Char := 16#14498#;
   Anatolian_Hieroglyph_A127               :
      constant Unicode_Char := 16#14499#;
   Anatolian_Hieroglyph_A128               :
      constant Unicode_Char := 16#1449A#;
   Anatolian_Hieroglyph_A129               :
      constant Unicode_Char := 16#1449B#;
   Anatolian_Hieroglyph_A130               :
      constant Unicode_Char := 16#1449C#;
   Anatolian_Hieroglyph_A131               :
      constant Unicode_Char := 16#1449D#;
   Anatolian_Hieroglyph_A132               :
      constant Unicode_Char := 16#1449E#;
   Anatolian_Hieroglyph_A133               :
      constant Unicode_Char := 16#1449F#;
   Anatolian_Hieroglyph_A134               :
      constant Unicode_Char := 16#144A0#;
   Anatolian_Hieroglyph_A135               :
      constant Unicode_Char := 16#144A1#;
   Anatolian_Hieroglyph_A135a              :
      constant Unicode_Char := 16#144A2#;
   Anatolian_Hieroglyph_A136               :
      constant Unicode_Char := 16#144A3#;
   Anatolian_Hieroglyph_A137               :
      constant Unicode_Char := 16#144A4#;
   Anatolian_Hieroglyph_A138               :
      constant Unicode_Char := 16#144A5#;
   Anatolian_Hieroglyph_A139               :
      constant Unicode_Char := 16#144A6#;
   Anatolian_Hieroglyph_A140               :
      constant Unicode_Char := 16#144A7#;
   Anatolian_Hieroglyph_A141               :
      constant Unicode_Char := 16#144A8#;
   Anatolian_Hieroglyph_A142               :
      constant Unicode_Char := 16#144A9#;
   Anatolian_Hieroglyph_A143               :
      constant Unicode_Char := 16#144AA#;
   Anatolian_Hieroglyph_A144               :
      constant Unicode_Char := 16#144AB#;
   Anatolian_Hieroglyph_A145               :
      constant Unicode_Char := 16#144AC#;
   Anatolian_Hieroglyph_A146               :
      constant Unicode_Char := 16#144AD#;
   Anatolian_Hieroglyph_A147               :
      constant Unicode_Char := 16#144AE#;
   Anatolian_Hieroglyph_A148               :
      constant Unicode_Char := 16#144AF#;
   Anatolian_Hieroglyph_A149               :
      constant Unicode_Char := 16#144B0#;
   Anatolian_Hieroglyph_A150               :
      constant Unicode_Char := 16#144B1#;
   Anatolian_Hieroglyph_A151               :
      constant Unicode_Char := 16#144B2#;
   Anatolian_Hieroglyph_A152               :
      constant Unicode_Char := 16#144B3#;
   Anatolian_Hieroglyph_A153               :
      constant Unicode_Char := 16#144B4#;
   Anatolian_Hieroglyph_A154               :
      constant Unicode_Char := 16#144B5#;
   Anatolian_Hieroglyph_A155               :
      constant Unicode_Char := 16#144B6#;
   Anatolian_Hieroglyph_A156               :
      constant Unicode_Char := 16#144B7#;
   Anatolian_Hieroglyph_A157               :
      constant Unicode_Char := 16#144B8#;
   Anatolian_Hieroglyph_A158               :
      constant Unicode_Char := 16#144B9#;
   Anatolian_Hieroglyph_A159               :
      constant Unicode_Char := 16#144BA#;
   Anatolian_Hieroglyph_A160               :
      constant Unicode_Char := 16#144BB#;
   Anatolian_Hieroglyph_A161               :
      constant Unicode_Char := 16#144BC#;
   Anatolian_Hieroglyph_A162               :
      constant Unicode_Char := 16#144BD#;
   Anatolian_Hieroglyph_A163               :
      constant Unicode_Char := 16#144BE#;
   Anatolian_Hieroglyph_A164               :
      constant Unicode_Char := 16#144BF#;
   Anatolian_Hieroglyph_A165               :
      constant Unicode_Char := 16#144C0#;
   Anatolian_Hieroglyph_A166               :
      constant Unicode_Char := 16#144C1#;
   Anatolian_Hieroglyph_A167               :
      constant Unicode_Char := 16#144C2#;
   Anatolian_Hieroglyph_A168               :
      constant Unicode_Char := 16#144C3#;
   Anatolian_Hieroglyph_A169               :
      constant Unicode_Char := 16#144C4#;
   Anatolian_Hieroglyph_A170               :
      constant Unicode_Char := 16#144C5#;
   Anatolian_Hieroglyph_A171               :
      constant Unicode_Char := 16#144C6#;
   Anatolian_Hieroglyph_A172               :
      constant Unicode_Char := 16#144C7#;
   Anatolian_Hieroglyph_A173               :
      constant Unicode_Char := 16#144C8#;
   Anatolian_Hieroglyph_A174               :
      constant Unicode_Char := 16#144C9#;
   Anatolian_Hieroglyph_A175               :
      constant Unicode_Char := 16#144CA#;
   Anatolian_Hieroglyph_A176               :
      constant Unicode_Char := 16#144CB#;
   Anatolian_Hieroglyph_A177               :
      constant Unicode_Char := 16#144CC#;
   Anatolian_Hieroglyph_A178               :
      constant Unicode_Char := 16#144CD#;
   Anatolian_Hieroglyph_A179               :
      constant Unicode_Char := 16#144CE#;
   Anatolian_Hieroglyph_A180               :
      constant Unicode_Char := 16#144CF#;
   Anatolian_Hieroglyph_A181               :
      constant Unicode_Char := 16#144D0#;
   Anatolian_Hieroglyph_A182               :
      constant Unicode_Char := 16#144D1#;
   Anatolian_Hieroglyph_A183               :
      constant Unicode_Char := 16#144D2#;
   Anatolian_Hieroglyph_A184               :
      constant Unicode_Char := 16#144D3#;
   Anatolian_Hieroglyph_A185               :
      constant Unicode_Char := 16#144D4#;
   Anatolian_Hieroglyph_A186               :
      constant Unicode_Char := 16#144D5#;
   Anatolian_Hieroglyph_A187               :
      constant Unicode_Char := 16#144D6#;
   Anatolian_Hieroglyph_A188               :
      constant Unicode_Char := 16#144D7#;
   Anatolian_Hieroglyph_A189               :
      constant Unicode_Char := 16#144D8#;
   Anatolian_Hieroglyph_A190               :
      constant Unicode_Char := 16#144D9#;
   Anatolian_Hieroglyph_A191               :
      constant Unicode_Char := 16#144DA#;
   Anatolian_Hieroglyph_A192               :
      constant Unicode_Char := 16#144DB#;
   Anatolian_Hieroglyph_A193               :
      constant Unicode_Char := 16#144DC#;
   Anatolian_Hieroglyph_A194               :
      constant Unicode_Char := 16#144DD#;
   Anatolian_Hieroglyph_A195               :
      constant Unicode_Char := 16#144DE#;
   Anatolian_Hieroglyph_A196               :
      constant Unicode_Char := 16#144DF#;
   Anatolian_Hieroglyph_A197               :
      constant Unicode_Char := 16#144E0#;
   Anatolian_Hieroglyph_A198               :
      constant Unicode_Char := 16#144E1#;
   Anatolian_Hieroglyph_A199               :
      constant Unicode_Char := 16#144E2#;
   Anatolian_Hieroglyph_A200               :
      constant Unicode_Char := 16#144E3#;
   Anatolian_Hieroglyph_A201               :
      constant Unicode_Char := 16#144E4#;
   Anatolian_Hieroglyph_A202               :
      constant Unicode_Char := 16#144E5#;
   Anatolian_Hieroglyph_A202a              :
      constant Unicode_Char := 16#144E6#;
   Anatolian_Hieroglyph_A202b              :
      constant Unicode_Char := 16#144E7#;
   Anatolian_Hieroglyph_A203               :
      constant Unicode_Char := 16#144E8#;
   Anatolian_Hieroglyph_A204               :
      constant Unicode_Char := 16#144E9#;
   Anatolian_Hieroglyph_A205               :
      constant Unicode_Char := 16#144EA#;
   Anatolian_Hieroglyph_A206               :
      constant Unicode_Char := 16#144EB#;
   Anatolian_Hieroglyph_A207               :
      constant Unicode_Char := 16#144EC#;
   Anatolian_Hieroglyph_A207a              :
      constant Unicode_Char := 16#144ED#;
   Anatolian_Hieroglyph_A208               :
      constant Unicode_Char := 16#144EE#;
   Anatolian_Hieroglyph_A209               :
      constant Unicode_Char := 16#144EF#;
   Anatolian_Hieroglyph_A209a              :
      constant Unicode_Char := 16#144F0#;
   Anatolian_Hieroglyph_A210               :
      constant Unicode_Char := 16#144F1#;
   Anatolian_Hieroglyph_A211               :
      constant Unicode_Char := 16#144F2#;
   Anatolian_Hieroglyph_A212               :
      constant Unicode_Char := 16#144F3#;
   Anatolian_Hieroglyph_A213               :
      constant Unicode_Char := 16#144F4#;
   Anatolian_Hieroglyph_A214               :
      constant Unicode_Char := 16#144F5#;
   Anatolian_Hieroglyph_A215               :
      constant Unicode_Char := 16#144F6#;
   Anatolian_Hieroglyph_A215a              :
      constant Unicode_Char := 16#144F7#;
   Anatolian_Hieroglyph_A216               :
      constant Unicode_Char := 16#144F8#;
   Anatolian_Hieroglyph_A216a              :
      constant Unicode_Char := 16#144F9#;
   Anatolian_Hieroglyph_A217               :
      constant Unicode_Char := 16#144FA#;
   Anatolian_Hieroglyph_A218               :
      constant Unicode_Char := 16#144FB#;
   Anatolian_Hieroglyph_A219               :
      constant Unicode_Char := 16#144FC#;
   Anatolian_Hieroglyph_A220               :
      constant Unicode_Char := 16#144FD#;
   Anatolian_Hieroglyph_A221               :
      constant Unicode_Char := 16#144FE#;
   Anatolian_Hieroglyph_A222               :
      constant Unicode_Char := 16#144FF#;
   Anatolian_Hieroglyph_A223               :
      constant Unicode_Char := 16#14500#;
   Anatolian_Hieroglyph_A224               :
      constant Unicode_Char := 16#14501#;
   Anatolian_Hieroglyph_A225               :
      constant Unicode_Char := 16#14502#;
   Anatolian_Hieroglyph_A226               :
      constant Unicode_Char := 16#14503#;
   Anatolian_Hieroglyph_A227               :
      constant Unicode_Char := 16#14504#;
   Anatolian_Hieroglyph_A227a              :
      constant Unicode_Char := 16#14505#;
   Anatolian_Hieroglyph_A228               :
      constant Unicode_Char := 16#14506#;
   Anatolian_Hieroglyph_A229               :
      constant Unicode_Char := 16#14507#;
   Anatolian_Hieroglyph_A230               :
      constant Unicode_Char := 16#14508#;
   Anatolian_Hieroglyph_A231               :
      constant Unicode_Char := 16#14509#;
   Anatolian_Hieroglyph_A232               :
      constant Unicode_Char := 16#1450A#;
   Anatolian_Hieroglyph_A233               :
      constant Unicode_Char := 16#1450B#;
   Anatolian_Hieroglyph_A234               :
      constant Unicode_Char := 16#1450C#;
   Anatolian_Hieroglyph_A235               :
      constant Unicode_Char := 16#1450D#;
   Anatolian_Hieroglyph_A236               :
      constant Unicode_Char := 16#1450E#;
   Anatolian_Hieroglyph_A237               :
      constant Unicode_Char := 16#1450F#;
   Anatolian_Hieroglyph_A238               :
      constant Unicode_Char := 16#14510#;
   Anatolian_Hieroglyph_A239               :
      constant Unicode_Char := 16#14511#;
   Anatolian_Hieroglyph_A240               :
      constant Unicode_Char := 16#14512#;
   Anatolian_Hieroglyph_A241               :
      constant Unicode_Char := 16#14513#;
   Anatolian_Hieroglyph_A242               :
      constant Unicode_Char := 16#14514#;
   Anatolian_Hieroglyph_A243               :
      constant Unicode_Char := 16#14515#;
   Anatolian_Hieroglyph_A244               :
      constant Unicode_Char := 16#14516#;
   Anatolian_Hieroglyph_A245               :
      constant Unicode_Char := 16#14517#;
   Anatolian_Hieroglyph_A246               :
      constant Unicode_Char := 16#14518#;
   Anatolian_Hieroglyph_A247               :
      constant Unicode_Char := 16#14519#;
   Anatolian_Hieroglyph_A248               :
      constant Unicode_Char := 16#1451A#;
   Anatolian_Hieroglyph_A249               :
      constant Unicode_Char := 16#1451B#;
   Anatolian_Hieroglyph_A250               :
      constant Unicode_Char := 16#1451C#;
   Anatolian_Hieroglyph_A251               :
      constant Unicode_Char := 16#1451D#;
   Anatolian_Hieroglyph_A252               :
      constant Unicode_Char := 16#1451E#;
   Anatolian_Hieroglyph_A253               :
      constant Unicode_Char := 16#1451F#;
   Anatolian_Hieroglyph_A254               :
      constant Unicode_Char := 16#14520#;
   Anatolian_Hieroglyph_A255               :
      constant Unicode_Char := 16#14521#;
   Anatolian_Hieroglyph_A256               :
      constant Unicode_Char := 16#14522#;
   Anatolian_Hieroglyph_A257               :
      constant Unicode_Char := 16#14523#;
   Anatolian_Hieroglyph_A258               :
      constant Unicode_Char := 16#14524#;
   Anatolian_Hieroglyph_A259               :
      constant Unicode_Char := 16#14525#;
   Anatolian_Hieroglyph_A260               :
      constant Unicode_Char := 16#14526#;
   Anatolian_Hieroglyph_A261               :
      constant Unicode_Char := 16#14527#;
   Anatolian_Hieroglyph_A262               :
      constant Unicode_Char := 16#14528#;
   Anatolian_Hieroglyph_A263               :
      constant Unicode_Char := 16#14529#;
   Anatolian_Hieroglyph_A264               :
      constant Unicode_Char := 16#1452A#;
   Anatolian_Hieroglyph_A265               :
      constant Unicode_Char := 16#1452B#;
   Anatolian_Hieroglyph_A266               :
      constant Unicode_Char := 16#1452C#;
   Anatolian_Hieroglyph_A267               :
      constant Unicode_Char := 16#1452D#;
   Anatolian_Hieroglyph_A267a              :
      constant Unicode_Char := 16#1452E#;
   Anatolian_Hieroglyph_A268               :
      constant Unicode_Char := 16#1452F#;
   Anatolian_Hieroglyph_A269               :
      constant Unicode_Char := 16#14530#;
   Anatolian_Hieroglyph_A270               :
      constant Unicode_Char := 16#14531#;
   Anatolian_Hieroglyph_A271               :
      constant Unicode_Char := 16#14532#;
   Anatolian_Hieroglyph_A272               :
      constant Unicode_Char := 16#14533#;
   Anatolian_Hieroglyph_A273               :
      constant Unicode_Char := 16#14534#;
   Anatolian_Hieroglyph_A274               :
      constant Unicode_Char := 16#14535#;
   Anatolian_Hieroglyph_A275               :
      constant Unicode_Char := 16#14536#;
   Anatolian_Hieroglyph_A276               :
      constant Unicode_Char := 16#14537#;
   Anatolian_Hieroglyph_A277               :
      constant Unicode_Char := 16#14538#;
   Anatolian_Hieroglyph_A278               :
      constant Unicode_Char := 16#14539#;
   Anatolian_Hieroglyph_A279               :
      constant Unicode_Char := 16#1453A#;
   Anatolian_Hieroglyph_A280               :
      constant Unicode_Char := 16#1453B#;
   Anatolian_Hieroglyph_A281               :
      constant Unicode_Char := 16#1453C#;
   Anatolian_Hieroglyph_A282               :
      constant Unicode_Char := 16#1453D#;
   Anatolian_Hieroglyph_A283               :
      constant Unicode_Char := 16#1453E#;
   Anatolian_Hieroglyph_A284               :
      constant Unicode_Char := 16#1453F#;
   Anatolian_Hieroglyph_A285               :
      constant Unicode_Char := 16#14540#;
   Anatolian_Hieroglyph_A286               :
      constant Unicode_Char := 16#14541#;
   Anatolian_Hieroglyph_A287               :
      constant Unicode_Char := 16#14542#;
   Anatolian_Hieroglyph_A288               :
      constant Unicode_Char := 16#14543#;
   Anatolian_Hieroglyph_A289               :
      constant Unicode_Char := 16#14544#;
   Anatolian_Hieroglyph_A289a              :
      constant Unicode_Char := 16#14545#;
   Anatolian_Hieroglyph_A290               :
      constant Unicode_Char := 16#14546#;
   Anatolian_Hieroglyph_A291               :
      constant Unicode_Char := 16#14547#;
   Anatolian_Hieroglyph_A292               :
      constant Unicode_Char := 16#14548#;
   Anatolian_Hieroglyph_A293               :
      constant Unicode_Char := 16#14549#;
   Anatolian_Hieroglyph_A294               :
      constant Unicode_Char := 16#1454A#;
   Anatolian_Hieroglyph_A294a              :
      constant Unicode_Char := 16#1454B#;
   Anatolian_Hieroglyph_A295               :
      constant Unicode_Char := 16#1454C#;
   Anatolian_Hieroglyph_A296               :
      constant Unicode_Char := 16#1454D#;
   Anatolian_Hieroglyph_A297               :
      constant Unicode_Char := 16#1454E#;
   Anatolian_Hieroglyph_A298               :
      constant Unicode_Char := 16#1454F#;
   Anatolian_Hieroglyph_A299               :
      constant Unicode_Char := 16#14550#;
   Anatolian_Hieroglyph_A299a              :
      constant Unicode_Char := 16#14551#;
   Anatolian_Hieroglyph_A300               :
      constant Unicode_Char := 16#14552#;
   Anatolian_Hieroglyph_A301               :
      constant Unicode_Char := 16#14553#;
   Anatolian_Hieroglyph_A302               :
      constant Unicode_Char := 16#14554#;
   Anatolian_Hieroglyph_A303               :
      constant Unicode_Char := 16#14555#;
   Anatolian_Hieroglyph_A304               :
      constant Unicode_Char := 16#14556#;
   Anatolian_Hieroglyph_A305               :
      constant Unicode_Char := 16#14557#;
   Anatolian_Hieroglyph_A306               :
      constant Unicode_Char := 16#14558#;
   Anatolian_Hieroglyph_A307               :
      constant Unicode_Char := 16#14559#;
   Anatolian_Hieroglyph_A308               :
      constant Unicode_Char := 16#1455A#;
   Anatolian_Hieroglyph_A309               :
      constant Unicode_Char := 16#1455B#;
   Anatolian_Hieroglyph_A309a              :
      constant Unicode_Char := 16#1455C#;
   Anatolian_Hieroglyph_A310               :
      constant Unicode_Char := 16#1455D#;
   Anatolian_Hieroglyph_A311               :
      constant Unicode_Char := 16#1455E#;
   Anatolian_Hieroglyph_A312               :
      constant Unicode_Char := 16#1455F#;
   Anatolian_Hieroglyph_A313               :
      constant Unicode_Char := 16#14560#;
   Anatolian_Hieroglyph_A314               :
      constant Unicode_Char := 16#14561#;
   Anatolian_Hieroglyph_A315               :
      constant Unicode_Char := 16#14562#;
   Anatolian_Hieroglyph_A316               :
      constant Unicode_Char := 16#14563#;
   Anatolian_Hieroglyph_A317               :
      constant Unicode_Char := 16#14564#;
   Anatolian_Hieroglyph_A318               :
      constant Unicode_Char := 16#14565#;
   Anatolian_Hieroglyph_A319               :
      constant Unicode_Char := 16#14566#;
   Anatolian_Hieroglyph_A320               :
      constant Unicode_Char := 16#14567#;
   Anatolian_Hieroglyph_A321               :
      constant Unicode_Char := 16#14568#;
   Anatolian_Hieroglyph_A322               :
      constant Unicode_Char := 16#14569#;
   Anatolian_Hieroglyph_A323               :
      constant Unicode_Char := 16#1456A#;
   Anatolian_Hieroglyph_A324               :
      constant Unicode_Char := 16#1456B#;
   Anatolian_Hieroglyph_A325               :
      constant Unicode_Char := 16#1456C#;
   Anatolian_Hieroglyph_A326               :
      constant Unicode_Char := 16#1456D#;
   Anatolian_Hieroglyph_A327               :
      constant Unicode_Char := 16#1456E#;
   Anatolian_Hieroglyph_A328               :
      constant Unicode_Char := 16#1456F#;
   Anatolian_Hieroglyph_A329               :
      constant Unicode_Char := 16#14570#;
   Anatolian_Hieroglyph_A329a              :
      constant Unicode_Char := 16#14571#;
   Anatolian_Hieroglyph_A330               :
      constant Unicode_Char := 16#14572#;
   Anatolian_Hieroglyph_A331               :
      constant Unicode_Char := 16#14573#;
   Anatolian_Hieroglyph_A332a              :
      constant Unicode_Char := 16#14574#;
   Anatolian_Hieroglyph_A332b              :
      constant Unicode_Char := 16#14575#;
   Anatolian_Hieroglyph_A332c              :
      constant Unicode_Char := 16#14576#;
   Anatolian_Hieroglyph_A333               :
      constant Unicode_Char := 16#14577#;
   Anatolian_Hieroglyph_A334               :
      constant Unicode_Char := 16#14578#;
   Anatolian_Hieroglyph_A335               :
      constant Unicode_Char := 16#14579#;
   Anatolian_Hieroglyph_A336               :
      constant Unicode_Char := 16#1457A#;
   Anatolian_Hieroglyph_A336a              :
      constant Unicode_Char := 16#1457B#;
   Anatolian_Hieroglyph_A336b              :
      constant Unicode_Char := 16#1457C#;
   Anatolian_Hieroglyph_A336c              :
      constant Unicode_Char := 16#1457D#;
   Anatolian_Hieroglyph_A337               :
      constant Unicode_Char := 16#1457E#;
   Anatolian_Hieroglyph_A338               :
      constant Unicode_Char := 16#1457F#;
   Anatolian_Hieroglyph_A339               :
      constant Unicode_Char := 16#14580#;
   Anatolian_Hieroglyph_A340               :
      constant Unicode_Char := 16#14581#;
   Anatolian_Hieroglyph_A341               :
      constant Unicode_Char := 16#14582#;
   Anatolian_Hieroglyph_A342               :
      constant Unicode_Char := 16#14583#;
   Anatolian_Hieroglyph_A343               :
      constant Unicode_Char := 16#14584#;
   Anatolian_Hieroglyph_A344               :
      constant Unicode_Char := 16#14585#;
   Anatolian_Hieroglyph_A345               :
      constant Unicode_Char := 16#14586#;
   Anatolian_Hieroglyph_A346               :
      constant Unicode_Char := 16#14587#;
   Anatolian_Hieroglyph_A347               :
      constant Unicode_Char := 16#14588#;
   Anatolian_Hieroglyph_A348               :
      constant Unicode_Char := 16#14589#;
   Anatolian_Hieroglyph_A349               :
      constant Unicode_Char := 16#1458A#;
   Anatolian_Hieroglyph_A350               :
      constant Unicode_Char := 16#1458B#;
   Anatolian_Hieroglyph_A351               :
      constant Unicode_Char := 16#1458C#;
   Anatolian_Hieroglyph_A352               :
      constant Unicode_Char := 16#1458D#;
   Anatolian_Hieroglyph_A353               :
      constant Unicode_Char := 16#1458E#;
   Anatolian_Hieroglyph_A354               :
      constant Unicode_Char := 16#1458F#;
   Anatolian_Hieroglyph_A355               :
      constant Unicode_Char := 16#14590#;
   Anatolian_Hieroglyph_A356               :
      constant Unicode_Char := 16#14591#;
   Anatolian_Hieroglyph_A357               :
      constant Unicode_Char := 16#14592#;
   Anatolian_Hieroglyph_A358               :
      constant Unicode_Char := 16#14593#;
   Anatolian_Hieroglyph_A359               :
      constant Unicode_Char := 16#14594#;
   Anatolian_Hieroglyph_A359a              :
      constant Unicode_Char := 16#14595#;
   Anatolian_Hieroglyph_A360               :
      constant Unicode_Char := 16#14596#;
   Anatolian_Hieroglyph_A361               :
      constant Unicode_Char := 16#14597#;
   Anatolian_Hieroglyph_A362               :
      constant Unicode_Char := 16#14598#;
   Anatolian_Hieroglyph_A363               :
      constant Unicode_Char := 16#14599#;
   Anatolian_Hieroglyph_A364               :
      constant Unicode_Char := 16#1459A#;
   Anatolian_Hieroglyph_A364a              :
      constant Unicode_Char := 16#1459B#;
   Anatolian_Hieroglyph_A365               :
      constant Unicode_Char := 16#1459C#;
   Anatolian_Hieroglyph_A366               :
      constant Unicode_Char := 16#1459D#;
   Anatolian_Hieroglyph_A367               :
      constant Unicode_Char := 16#1459E#;
   Anatolian_Hieroglyph_A368               :
      constant Unicode_Char := 16#1459F#;
   Anatolian_Hieroglyph_A368a              :
      constant Unicode_Char := 16#145A0#;
   Anatolian_Hieroglyph_A369               :
      constant Unicode_Char := 16#145A1#;
   Anatolian_Hieroglyph_A370               :
      constant Unicode_Char := 16#145A2#;
   Anatolian_Hieroglyph_A371               :
      constant Unicode_Char := 16#145A3#;
   Anatolian_Hieroglyph_A371a              :
      constant Unicode_Char := 16#145A4#;
   Anatolian_Hieroglyph_A372               :
      constant Unicode_Char := 16#145A5#;
   Anatolian_Hieroglyph_A373               :
      constant Unicode_Char := 16#145A6#;
   Anatolian_Hieroglyph_A374               :
      constant Unicode_Char := 16#145A7#;
   Anatolian_Hieroglyph_A375               :
      constant Unicode_Char := 16#145A8#;
   Anatolian_Hieroglyph_A376               :
      constant Unicode_Char := 16#145A9#;
   Anatolian_Hieroglyph_A377               :
      constant Unicode_Char := 16#145AA#;
   Anatolian_Hieroglyph_A378               :
      constant Unicode_Char := 16#145AB#;
   Anatolian_Hieroglyph_A379               :
      constant Unicode_Char := 16#145AC#;
   Anatolian_Hieroglyph_A380               :
      constant Unicode_Char := 16#145AD#;
   Anatolian_Hieroglyph_A381               :
      constant Unicode_Char := 16#145AE#;
   Anatolian_Hieroglyph_A381a              :
      constant Unicode_Char := 16#145AF#;
   Anatolian_Hieroglyph_A382               :
      constant Unicode_Char := 16#145B0#;
   Anatolian_Hieroglyph_A383_Ra_Or_Ri      :
      constant Unicode_Char := 16#145B1#;
   Anatolian_Hieroglyph_A383a              :
      constant Unicode_Char := 16#145B2#;
   Anatolian_Hieroglyph_A384               :
      constant Unicode_Char := 16#145B3#;
   Anatolian_Hieroglyph_A385               :
      constant Unicode_Char := 16#145B4#;
   Anatolian_Hieroglyph_A386               :
      constant Unicode_Char := 16#145B5#;
   Anatolian_Hieroglyph_A386a              :
      constant Unicode_Char := 16#145B6#;
   Anatolian_Hieroglyph_A387               :
      constant Unicode_Char := 16#145B7#;
   Anatolian_Hieroglyph_A388               :
      constant Unicode_Char := 16#145B8#;
   Anatolian_Hieroglyph_A389               :
      constant Unicode_Char := 16#145B9#;
   Anatolian_Hieroglyph_A390               :
      constant Unicode_Char := 16#145BA#;
   Anatolian_Hieroglyph_A391               :
      constant Unicode_Char := 16#145BB#;
   Anatolian_Hieroglyph_A392               :
      constant Unicode_Char := 16#145BC#;
   Anatolian_Hieroglyph_A393_Eight         :
      constant Unicode_Char := 16#145BD#;
   Anatolian_Hieroglyph_A394               :
      constant Unicode_Char := 16#145BE#;
   Anatolian_Hieroglyph_A395               :
      constant Unicode_Char := 16#145BF#;
   Anatolian_Hieroglyph_A396               :
      constant Unicode_Char := 16#145C0#;
   Anatolian_Hieroglyph_A397               :
      constant Unicode_Char := 16#145C1#;
   Anatolian_Hieroglyph_A398               :
      constant Unicode_Char := 16#145C2#;
   Anatolian_Hieroglyph_A399               :
      constant Unicode_Char := 16#145C3#;
   Anatolian_Hieroglyph_A400               :
      constant Unicode_Char := 16#145C4#;
   Anatolian_Hieroglyph_A401               :
      constant Unicode_Char := 16#145C5#;
   Anatolian_Hieroglyph_A402               :
      constant Unicode_Char := 16#145C6#;
   Anatolian_Hieroglyph_A403               :
      constant Unicode_Char := 16#145C7#;
   Anatolian_Hieroglyph_A404               :
      constant Unicode_Char := 16#145C8#;
   Anatolian_Hieroglyph_A405               :
      constant Unicode_Char := 16#145C9#;
   Anatolian_Hieroglyph_A406               :
      constant Unicode_Char := 16#145CA#;
   Anatolian_Hieroglyph_A407               :
      constant Unicode_Char := 16#145CB#;
   Anatolian_Hieroglyph_A408               :
      constant Unicode_Char := 16#145CC#;
   Anatolian_Hieroglyph_A409               :
      constant Unicode_Char := 16#145CD#;
   Anatolian_Hieroglyph_A410_Begin_Logogram_Mark :
      constant Unicode_Char := 16#145CE#;
   Anatolian_Hieroglyph_A410a_End_Logogram_Mark :
      constant Unicode_Char := 16#145CF#;
   Anatolian_Hieroglyph_A411               :
      constant Unicode_Char := 16#145D0#;
   Anatolian_Hieroglyph_A412               :
      constant Unicode_Char := 16#145D1#;
   Anatolian_Hieroglyph_A413               :
      constant Unicode_Char := 16#145D2#;
   Anatolian_Hieroglyph_A414               :
      constant Unicode_Char := 16#145D3#;
   Anatolian_Hieroglyph_A415               :
      constant Unicode_Char := 16#145D4#;
   Anatolian_Hieroglyph_A416               :
      constant Unicode_Char := 16#145D5#;
   Anatolian_Hieroglyph_A417               :
      constant Unicode_Char := 16#145D6#;
   Anatolian_Hieroglyph_A418               :
      constant Unicode_Char := 16#145D7#;
   Anatolian_Hieroglyph_A419               :
      constant Unicode_Char := 16#145D8#;
   Anatolian_Hieroglyph_A420               :
      constant Unicode_Char := 16#145D9#;
   Anatolian_Hieroglyph_A421               :
      constant Unicode_Char := 16#145DA#;
   Anatolian_Hieroglyph_A422               :
      constant Unicode_Char := 16#145DB#;
   Anatolian_Hieroglyph_A423               :
      constant Unicode_Char := 16#145DC#;
   Anatolian_Hieroglyph_A424               :
      constant Unicode_Char := 16#145DD#;
   Anatolian_Hieroglyph_A425               :
      constant Unicode_Char := 16#145DE#;
   Anatolian_Hieroglyph_A426               :
      constant Unicode_Char := 16#145DF#;
   Anatolian_Hieroglyph_A427               :
      constant Unicode_Char := 16#145E0#;
   Anatolian_Hieroglyph_A428               :
      constant Unicode_Char := 16#145E1#;
   Anatolian_Hieroglyph_A429               :
      constant Unicode_Char := 16#145E2#;
   Anatolian_Hieroglyph_A430               :
      constant Unicode_Char := 16#145E3#;
   Anatolian_Hieroglyph_A431               :
      constant Unicode_Char := 16#145E4#;
   Anatolian_Hieroglyph_A432               :
      constant Unicode_Char := 16#145E5#;
   Anatolian_Hieroglyph_A433               :
      constant Unicode_Char := 16#145E6#;
   Anatolian_Hieroglyph_A434               :
      constant Unicode_Char := 16#145E7#;
   Anatolian_Hieroglyph_A435               :
      constant Unicode_Char := 16#145E8#;
   Anatolian_Hieroglyph_A436               :
      constant Unicode_Char := 16#145E9#;
   Anatolian_Hieroglyph_A437               :
      constant Unicode_Char := 16#145EA#;
   Anatolian_Hieroglyph_A438               :
      constant Unicode_Char := 16#145EB#;
   Anatolian_Hieroglyph_A439               :
      constant Unicode_Char := 16#145EC#;
   Anatolian_Hieroglyph_A440               :
      constant Unicode_Char := 16#145ED#;
   Anatolian_Hieroglyph_A441               :
      constant Unicode_Char := 16#145EE#;
   Anatolian_Hieroglyph_A442               :
      constant Unicode_Char := 16#145EF#;
   Anatolian_Hieroglyph_A443               :
      constant Unicode_Char := 16#145F0#;
   Anatolian_Hieroglyph_A444               :
      constant Unicode_Char := 16#145F1#;
   Anatolian_Hieroglyph_A445               :
      constant Unicode_Char := 16#145F2#;
   Anatolian_Hieroglyph_A446               :
      constant Unicode_Char := 16#145F3#;
   Anatolian_Hieroglyph_A447               :
      constant Unicode_Char := 16#145F4#;
   Anatolian_Hieroglyph_A448               :
      constant Unicode_Char := 16#145F5#;
   Anatolian_Hieroglyph_A449               :
      constant Unicode_Char := 16#145F6#;
   Anatolian_Hieroglyph_A450               :
      constant Unicode_Char := 16#145F7#;
   Anatolian_Hieroglyph_A450a              :
      constant Unicode_Char := 16#145F8#;
   Anatolian_Hieroglyph_A451               :
      constant Unicode_Char := 16#145F9#;
   Anatolian_Hieroglyph_A452               :
      constant Unicode_Char := 16#145FA#;
   Anatolian_Hieroglyph_A453               :
      constant Unicode_Char := 16#145FB#;
   Anatolian_Hieroglyph_A454               :
      constant Unicode_Char := 16#145FC#;
   Anatolian_Hieroglyph_A455               :
      constant Unicode_Char := 16#145FD#;
   Anatolian_Hieroglyph_A456               :
      constant Unicode_Char := 16#145FE#;
   Anatolian_Hieroglyph_A457               :
      constant Unicode_Char := 16#145FF#;
   Anatolian_Hieroglyph_A457a              :
      constant Unicode_Char := 16#14600#;
   Anatolian_Hieroglyph_A458               :
      constant Unicode_Char := 16#14601#;
   Anatolian_Hieroglyph_A459               :
      constant Unicode_Char := 16#14602#;
   Anatolian_Hieroglyph_A460               :
      constant Unicode_Char := 16#14603#;
   Anatolian_Hieroglyph_A461               :
      constant Unicode_Char := 16#14604#;
   Anatolian_Hieroglyph_A462               :
      constant Unicode_Char := 16#14605#;
   Anatolian_Hieroglyph_A463               :
      constant Unicode_Char := 16#14606#;
   Anatolian_Hieroglyph_A464               :
      constant Unicode_Char := 16#14607#;
   Anatolian_Hieroglyph_A465               :
      constant Unicode_Char := 16#14608#;
   Anatolian_Hieroglyph_A466               :
      constant Unicode_Char := 16#14609#;
   Anatolian_Hieroglyph_A467               :
      constant Unicode_Char := 16#1460A#;
   Anatolian_Hieroglyph_A468               :
      constant Unicode_Char := 16#1460B#;
   Anatolian_Hieroglyph_A469               :
      constant Unicode_Char := 16#1460C#;
   Anatolian_Hieroglyph_A470               :
      constant Unicode_Char := 16#1460D#;
   Anatolian_Hieroglyph_A471               :
      constant Unicode_Char := 16#1460E#;
   Anatolian_Hieroglyph_A472               :
      constant Unicode_Char := 16#1460F#;
   Anatolian_Hieroglyph_A473               :
      constant Unicode_Char := 16#14610#;
   Anatolian_Hieroglyph_A474               :
      constant Unicode_Char := 16#14611#;
   Anatolian_Hieroglyph_A475               :
      constant Unicode_Char := 16#14612#;
   Anatolian_Hieroglyph_A476               :
      constant Unicode_Char := 16#14613#;
   Anatolian_Hieroglyph_A477               :
      constant Unicode_Char := 16#14614#;
   Anatolian_Hieroglyph_A478               :
      constant Unicode_Char := 16#14615#;
   Anatolian_Hieroglyph_A479               :
      constant Unicode_Char := 16#14616#;
   Anatolian_Hieroglyph_A480               :
      constant Unicode_Char := 16#14617#;
   Anatolian_Hieroglyph_A481               :
      constant Unicode_Char := 16#14618#;
   Anatolian_Hieroglyph_A482               :
      constant Unicode_Char := 16#14619#;
   Anatolian_Hieroglyph_A483               :
      constant Unicode_Char := 16#1461A#;
   Anatolian_Hieroglyph_A484               :
      constant Unicode_Char := 16#1461B#;
   Anatolian_Hieroglyph_A485               :
      constant Unicode_Char := 16#1461C#;
   Anatolian_Hieroglyph_A486               :
      constant Unicode_Char := 16#1461D#;
   Anatolian_Hieroglyph_A487               :
      constant Unicode_Char := 16#1461E#;
   Anatolian_Hieroglyph_A488               :
      constant Unicode_Char := 16#1461F#;
   Anatolian_Hieroglyph_A489               :
      constant Unicode_Char := 16#14620#;
   Anatolian_Hieroglyph_A490               :
      constant Unicode_Char := 16#14621#;
   Anatolian_Hieroglyph_A491               :
      constant Unicode_Char := 16#14622#;
   Anatolian_Hieroglyph_A492               :
      constant Unicode_Char := 16#14623#;
   Anatolian_Hieroglyph_A493               :
      constant Unicode_Char := 16#14624#;
   Anatolian_Hieroglyph_A494               :
      constant Unicode_Char := 16#14625#;
   Anatolian_Hieroglyph_A495               :
      constant Unicode_Char := 16#14626#;
   Anatolian_Hieroglyph_A496               :
      constant Unicode_Char := 16#14627#;
   Anatolian_Hieroglyph_A497               :
      constant Unicode_Char := 16#14628#;
   Anatolian_Hieroglyph_A501               :
      constant Unicode_Char := 16#14629#;
   Anatolian_Hieroglyph_A502               :
      constant Unicode_Char := 16#1462A#;
   Anatolian_Hieroglyph_A503               :
      constant Unicode_Char := 16#1462B#;
   Anatolian_Hieroglyph_A504               :
      constant Unicode_Char := 16#1462C#;
   Anatolian_Hieroglyph_A505               :
      constant Unicode_Char := 16#1462D#;
   Anatolian_Hieroglyph_A506               :
      constant Unicode_Char := 16#1462E#;
   Anatolian_Hieroglyph_A507               :
      constant Unicode_Char := 16#1462F#;
   Anatolian_Hieroglyph_A508               :
      constant Unicode_Char := 16#14630#;
   Anatolian_Hieroglyph_A509               :
      constant Unicode_Char := 16#14631#;
   Anatolian_Hieroglyph_A510               :
      constant Unicode_Char := 16#14632#;
   Anatolian_Hieroglyph_A511               :
      constant Unicode_Char := 16#14633#;
   Anatolian_Hieroglyph_A512               :
      constant Unicode_Char := 16#14634#;
   Anatolian_Hieroglyph_A513               :
      constant Unicode_Char := 16#14635#;
   Anatolian_Hieroglyph_A514               :
      constant Unicode_Char := 16#14636#;
   Anatolian_Hieroglyph_A515               :
      constant Unicode_Char := 16#14637#;
   Anatolian_Hieroglyph_A516               :
      constant Unicode_Char := 16#14638#;
   Anatolian_Hieroglyph_A517               :
      constant Unicode_Char := 16#14639#;
   Anatolian_Hieroglyph_A518               :
      constant Unicode_Char := 16#1463A#;
   Anatolian_Hieroglyph_A519               :
      constant Unicode_Char := 16#1463B#;
   Anatolian_Hieroglyph_A520               :
      constant Unicode_Char := 16#1463C#;
   Anatolian_Hieroglyph_A521               :
      constant Unicode_Char := 16#1463D#;
   Anatolian_Hieroglyph_A522               :
      constant Unicode_Char := 16#1463E#;
   Anatolian_Hieroglyph_A523               :
      constant Unicode_Char := 16#1463F#;
   Anatolian_Hieroglyph_A524               :
      constant Unicode_Char := 16#14640#;
   Anatolian_Hieroglyph_A525               :
      constant Unicode_Char := 16#14641#;
   Anatolian_Hieroglyph_A526               :
      constant Unicode_Char := 16#14642#;
   Anatolian_Hieroglyph_A527               :
      constant Unicode_Char := 16#14643#;
   Anatolian_Hieroglyph_A528               :
      constant Unicode_Char := 16#14644#;
   Anatolian_Hieroglyph_A529               :
      constant Unicode_Char := 16#14645#;
   Anatolian_Hieroglyph_A530               :
      constant Unicode_Char := 16#14646#;
end Unicode.Names.Anatolian_Hieroglyphs;
