--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Combining_Diacritical_Sym is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Combining_Left_Harpoon_Above            : constant Unicode_Char := 16#20D0#;
   Combining_Right_Harpoon_Above           : constant Unicode_Char := 16#20D1#;
   Combining_Long_Vertical_Line_Overlay    : constant Unicode_Char := 16#20D2#;
   Combining_Short_Vertical_Line_Overlay   : constant Unicode_Char := 16#20D3#;
   Combining_Anticlockwise_Arrow_Above     : constant Unicode_Char := 16#20D4#;
   Combining_Clockwise_Arrow_Above         : constant Unicode_Char := 16#20D5#;
   Combining_Left_Arrow_Above              : constant Unicode_Char := 16#20D6#;
   Combining_Right_Arrow_Above             : constant Unicode_Char := 16#20D7#;
   Combining_Ring_Overlay                  : constant Unicode_Char := 16#20D8#;
   Combining_Clockwise_Ring_Overlay        : constant Unicode_Char := 16#20D9#;
   Combining_Anticlockwise_Ring_Overlay    : constant Unicode_Char := 16#20DA#;
   Combining_Three_Dots_Above              : constant Unicode_Char := 16#20DB#;
   Combining_Four_Dots_Above               : constant Unicode_Char := 16#20DC#;
   Combining_Enclosing_Circle              : constant Unicode_Char := 16#20DD#;
   Combining_Enclosing_Square              : constant Unicode_Char := 16#20DE#;
   Combining_Enclosing_Diamond             : constant Unicode_Char := 16#20DF#;
   Combining_Enclosing_Circle_Backslash    : constant Unicode_Char := 16#20E0#;
   Combining_Left_Right_Arrow_Above        : constant Unicode_Char := 16#20E1#;
   Combining_Enclosing_Screen              : constant Unicode_Char := 16#20E2#;
   Combining_Enclosing_Keycap              : constant Unicode_Char := 16#20E3#;
   Combining_Enclosing_Upward_Pointing_Triangle :
      constant Unicode_Char := 16#20E4#;
   Combining_Reverse_Solidus_Overlay       : constant Unicode_Char := 16#20E5#;
   Combining_Double_Vertical_Stroke_Overlay :
      constant Unicode_Char := 16#20E6#;
   Combining_Annuity_Symbol                : constant Unicode_Char := 16#20E7#;
   Combining_Triple_Underdot               : constant Unicode_Char := 16#20E8#;
   Combining_Wide_Bridge_Above             : constant Unicode_Char := 16#20E9#;
   Combining_Leftwards_Arrow_Overlay       : constant Unicode_Char := 16#20EA#;
   Combining_Long_Double_Solidus_Overlay   : constant Unicode_Char := 16#20EB#;
   Combining_Rightwards_Harpoon_With_Barb_Downwards :
      constant Unicode_Char := 16#20EC#;
   Combining_Leftwards_Harpoon_With_Barb_Downwards :
      constant Unicode_Char := 16#20ED#;
   Combining_Left_Arrow_Below              : constant Unicode_Char := 16#20EE#;
   Combining_Right_Arrow_Below             : constant Unicode_Char := 16#20EF#;
   Combining_Asterisk_Above                : constant Unicode_Char := 16#20F0#;
end Unicode.Names.Combining_Diacritical_Sym;
