--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cjk_Letters_Months is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Parenthesized_Hangul_Kiyeok             : constant Unicode_Char := 16#3200#;
   Parenthesized_Hangul_Nieun              : constant Unicode_Char := 16#3201#;
   Parenthesized_Hangul_Tikeut             : constant Unicode_Char := 16#3202#;
   Parenthesized_Hangul_Rieul              : constant Unicode_Char := 16#3203#;
   Parenthesized_Hangul_Mieum              : constant Unicode_Char := 16#3204#;
   Parenthesized_Hangul_Pieup              : constant Unicode_Char := 16#3205#;
   Parenthesized_Hangul_Sios               : constant Unicode_Char := 16#3206#;
   Parenthesized_Hangul_Ieung              : constant Unicode_Char := 16#3207#;
   Parenthesized_Hangul_Cieuc              : constant Unicode_Char := 16#3208#;
   Parenthesized_Hangul_Chieuch            : constant Unicode_Char := 16#3209#;
   Parenthesized_Hangul_Khieukh            : constant Unicode_Char := 16#320A#;
   Parenthesized_Hangul_Thieuth            : constant Unicode_Char := 16#320B#;
   Parenthesized_Hangul_Phieuph            : constant Unicode_Char := 16#320C#;
   Parenthesized_Hangul_Hieuh              : constant Unicode_Char := 16#320D#;
   Parenthesized_Hangul_Kiyeok_A           : constant Unicode_Char := 16#320E#;
   Parenthesized_Hangul_Nieun_A            : constant Unicode_Char := 16#320F#;
   Parenthesized_Hangul_Tikeut_A           : constant Unicode_Char := 16#3210#;
   Parenthesized_Hangul_Rieul_A            : constant Unicode_Char := 16#3211#;
   Parenthesized_Hangul_Mieum_A            : constant Unicode_Char := 16#3212#;
   Parenthesized_Hangul_Pieup_A            : constant Unicode_Char := 16#3213#;
   Parenthesized_Hangul_Sios_A             : constant Unicode_Char := 16#3214#;
   Parenthesized_Hangul_Ieung_A            : constant Unicode_Char := 16#3215#;
   Parenthesized_Hangul_Cieuc_A            : constant Unicode_Char := 16#3216#;
   Parenthesized_Hangul_Chieuch_A          : constant Unicode_Char := 16#3217#;
   Parenthesized_Hangul_Khieukh_A          : constant Unicode_Char := 16#3218#;
   Parenthesized_Hangul_Thieuth_A          : constant Unicode_Char := 16#3219#;
   Parenthesized_Hangul_Phieuph_A          : constant Unicode_Char := 16#321A#;
   Parenthesized_Hangul_Hieuh_A            : constant Unicode_Char := 16#321B#;
   Parenthesized_Hangul_Cieuc_U            : constant Unicode_Char := 16#321C#;
   Parenthesized_Korean_Character_Ojeon    : constant Unicode_Char := 16#321D#;
   Parenthesized_Korean_Character_O_Hu     : constant Unicode_Char := 16#321E#;
   Parenthesized_Ideograph_One             : constant Unicode_Char := 16#3220#;
   Parenthesized_Ideograph_Two             : constant Unicode_Char := 16#3221#;
   Parenthesized_Ideograph_Three           : constant Unicode_Char := 16#3222#;
   Parenthesized_Ideograph_Four            : constant Unicode_Char := 16#3223#;
   Parenthesized_Ideograph_Five            : constant Unicode_Char := 16#3224#;
   Parenthesized_Ideograph_Six             : constant Unicode_Char := 16#3225#;
   Parenthesized_Ideograph_Seven           : constant Unicode_Char := 16#3226#;
   Parenthesized_Ideograph_Eight           : constant Unicode_Char := 16#3227#;
   Parenthesized_Ideograph_Nine            : constant Unicode_Char := 16#3228#;
   Parenthesized_Ideograph_Ten             : constant Unicode_Char := 16#3229#;
   Parenthesized_Ideograph_Moon            : constant Unicode_Char := 16#322A#;
   Parenthesized_Ideograph_Fire            : constant Unicode_Char := 16#322B#;
   Parenthesized_Ideograph_Water           : constant Unicode_Char := 16#322C#;
   Parenthesized_Ideograph_Wood            : constant Unicode_Char := 16#322D#;
   Parenthesized_Ideograph_Metal           : constant Unicode_Char := 16#322E#;
   Parenthesized_Ideograph_Earth           : constant Unicode_Char := 16#322F#;
   Parenthesized_Ideograph_Sun             : constant Unicode_Char := 16#3230#;
   Parenthesized_Ideograph_Stock           : constant Unicode_Char := 16#3231#;
   Parenthesized_Ideograph_Have            : constant Unicode_Char := 16#3232#;
   Parenthesized_Ideograph_Society         : constant Unicode_Char := 16#3233#;
   Parenthesized_Ideograph_Name            : constant Unicode_Char := 16#3234#;
   Parenthesized_Ideograph_Special         : constant Unicode_Char := 16#3235#;
   Parenthesized_Ideograph_Financial       : constant Unicode_Char := 16#3236#;
   Parenthesized_Ideograph_Congratulation  : constant Unicode_Char := 16#3237#;
   Parenthesized_Ideograph_Labor           : constant Unicode_Char := 16#3238#;
   Parenthesized_Ideograph_Represent       : constant Unicode_Char := 16#3239#;
   Parenthesized_Ideograph_Call            : constant Unicode_Char := 16#323A#;
   Parenthesized_Ideograph_Study           : constant Unicode_Char := 16#323B#;
   Parenthesized_Ideograph_Supervise       : constant Unicode_Char := 16#323C#;
   Parenthesized_Ideograph_Enterprise      : constant Unicode_Char := 16#323D#;
   Parenthesized_Ideograph_Resource        : constant Unicode_Char := 16#323E#;
   Parenthesized_Ideograph_Alliance        : constant Unicode_Char := 16#323F#;
   Parenthesized_Ideograph_Festival        : constant Unicode_Char := 16#3240#;
   Parenthesized_Ideograph_Rest            : constant Unicode_Char := 16#3241#;
   Parenthesized_Ideograph_Self            : constant Unicode_Char := 16#3242#;
   Parenthesized_Ideograph_Reach           : constant Unicode_Char := 16#3243#;
   Circled_Ideograph_Question              : constant Unicode_Char := 16#3244#;
   Circled_Ideograph_Kindergarten          : constant Unicode_Char := 16#3245#;
   Circled_Ideograph_School                : constant Unicode_Char := 16#3246#;
   Circled_Ideograph_Koto                  : constant Unicode_Char := 16#3247#;
   Circled_Number_Ten_On_Black_Square      : constant Unicode_Char := 16#3248#;
   Circled_Number_Twenty_On_Black_Square   : constant Unicode_Char := 16#3249#;
   Circled_Number_Thirty_On_Black_Square   : constant Unicode_Char := 16#324A#;
   Circled_Number_Forty_On_Black_Square    : constant Unicode_Char := 16#324B#;
   Circled_Number_Fifty_On_Black_Square    : constant Unicode_Char := 16#324C#;
   Circled_Number_Sixty_On_Black_Square    : constant Unicode_Char := 16#324D#;
   Circled_Number_Seventy_On_Black_Square  : constant Unicode_Char := 16#324E#;
   Circled_Number_Eighty_On_Black_Square   : constant Unicode_Char := 16#324F#;
   Partnership_Sign                        : constant Unicode_Char := 16#3250#;
   Circled_Number_Twenty_One               : constant Unicode_Char := 16#3251#;
   Circled_Number_Twenty_Two               : constant Unicode_Char := 16#3252#;
   Circled_Number_Twenty_Three             : constant Unicode_Char := 16#3253#;
   Circled_Number_Twenty_Four              : constant Unicode_Char := 16#3254#;
   Circled_Number_Twenty_Five              : constant Unicode_Char := 16#3255#;
   Circled_Number_Twenty_Six               : constant Unicode_Char := 16#3256#;
   Circled_Number_Twenty_Seven             : constant Unicode_Char := 16#3257#;
   Circled_Number_Twenty_Eight             : constant Unicode_Char := 16#3258#;
   Circled_Number_Twenty_Nine              : constant Unicode_Char := 16#3259#;
   Circled_Number_Thirty                   : constant Unicode_Char := 16#325A#;
   Circled_Number_Thirty_One               : constant Unicode_Char := 16#325B#;
   Circled_Number_Thirty_Two               : constant Unicode_Char := 16#325C#;
   Circled_Number_Thirty_Three             : constant Unicode_Char := 16#325D#;
   Circled_Number_Thirty_Four              : constant Unicode_Char := 16#325E#;
   Circled_Number_Thirty_Five              : constant Unicode_Char := 16#325F#;
   Circled_Hangul_Kiyeok                   : constant Unicode_Char := 16#3260#;
   Circled_Hangul_Nieun                    : constant Unicode_Char := 16#3261#;
   Circled_Hangul_Tikeut                   : constant Unicode_Char := 16#3262#;
   Circled_Hangul_Rieul                    : constant Unicode_Char := 16#3263#;
   Circled_Hangul_Mieum                    : constant Unicode_Char := 16#3264#;
   Circled_Hangul_Pieup                    : constant Unicode_Char := 16#3265#;
   Circled_Hangul_Sios                     : constant Unicode_Char := 16#3266#;
   Circled_Hangul_Ieung                    : constant Unicode_Char := 16#3267#;
   Circled_Hangul_Cieuc                    : constant Unicode_Char := 16#3268#;
   Circled_Hangul_Chieuch                  : constant Unicode_Char := 16#3269#;
   Circled_Hangul_Khieukh                  : constant Unicode_Char := 16#326A#;
   Circled_Hangul_Thieuth                  : constant Unicode_Char := 16#326B#;
   Circled_Hangul_Phieuph                  : constant Unicode_Char := 16#326C#;
   Circled_Hangul_Hieuh                    : constant Unicode_Char := 16#326D#;
   Circled_Hangul_Kiyeok_A                 : constant Unicode_Char := 16#326E#;
   Circled_Hangul_Nieun_A                  : constant Unicode_Char := 16#326F#;
   Circled_Hangul_Tikeut_A                 : constant Unicode_Char := 16#3270#;
   Circled_Hangul_Rieul_A                  : constant Unicode_Char := 16#3271#;
   Circled_Hangul_Mieum_A                  : constant Unicode_Char := 16#3272#;
   Circled_Hangul_Pieup_A                  : constant Unicode_Char := 16#3273#;
   Circled_Hangul_Sios_A                   : constant Unicode_Char := 16#3274#;
   Circled_Hangul_Ieung_A                  : constant Unicode_Char := 16#3275#;
   Circled_Hangul_Cieuc_A                  : constant Unicode_Char := 16#3276#;
   Circled_Hangul_Chieuch_A                : constant Unicode_Char := 16#3277#;
   Circled_Hangul_Khieukh_A                : constant Unicode_Char := 16#3278#;
   Circled_Hangul_Thieuth_A                : constant Unicode_Char := 16#3279#;
   Circled_Hangul_Phieuph_A                : constant Unicode_Char := 16#327A#;
   Circled_Hangul_Hieuh_A                  : constant Unicode_Char := 16#327B#;
   Circled_Korean_Character_Chamko         : constant Unicode_Char := 16#327C#;
   Circled_Korean_Character_Jueui          : constant Unicode_Char := 16#327D#;
   Circled_Hangul_Ieung_U                  : constant Unicode_Char := 16#327E#;
   Korean_Standard_Symbol                  : constant Unicode_Char := 16#327F#;
   Circled_Ideograph_One                   : constant Unicode_Char := 16#3280#;
   Circled_Ideograph_Two                   : constant Unicode_Char := 16#3281#;
   Circled_Ideograph_Three                 : constant Unicode_Char := 16#3282#;
   Circled_Ideograph_Four                  : constant Unicode_Char := 16#3283#;
   Circled_Ideograph_Five                  : constant Unicode_Char := 16#3284#;
   Circled_Ideograph_Six                   : constant Unicode_Char := 16#3285#;
   Circled_Ideograph_Seven                 : constant Unicode_Char := 16#3286#;
   Circled_Ideograph_Eight                 : constant Unicode_Char := 16#3287#;
   Circled_Ideograph_Nine                  : constant Unicode_Char := 16#3288#;
   Circled_Ideograph_Ten                   : constant Unicode_Char := 16#3289#;
   Circled_Ideograph_Moon                  : constant Unicode_Char := 16#328A#;
   Circled_Ideograph_Fire                  : constant Unicode_Char := 16#328B#;
   Circled_Ideograph_Water                 : constant Unicode_Char := 16#328C#;
   Circled_Ideograph_Wood                  : constant Unicode_Char := 16#328D#;
   Circled_Ideograph_Metal                 : constant Unicode_Char := 16#328E#;
   Circled_Ideograph_Earth                 : constant Unicode_Char := 16#328F#;
   Circled_Ideograph_Sun                   : constant Unicode_Char := 16#3290#;
   Circled_Ideograph_Stock                 : constant Unicode_Char := 16#3291#;
   Circled_Ideograph_Have                  : constant Unicode_Char := 16#3292#;
   Circled_Ideograph_Society               : constant Unicode_Char := 16#3293#;
   Circled_Ideograph_Name                  : constant Unicode_Char := 16#3294#;
   Circled_Ideograph_Special               : constant Unicode_Char := 16#3295#;
   Circled_Ideograph_Financial             : constant Unicode_Char := 16#3296#;
   Circled_Ideograph_Congratulation        : constant Unicode_Char := 16#3297#;
   Circled_Ideograph_Labor                 : constant Unicode_Char := 16#3298#;
   Circled_Ideograph_Secret                : constant Unicode_Char := 16#3299#;
   Circled_Ideograph_Male                  : constant Unicode_Char := 16#329A#;
   Circled_Ideograph_Female                : constant Unicode_Char := 16#329B#;
   Circled_Ideograph_Suitable              : constant Unicode_Char := 16#329C#;
   Circled_Ideograph_Excellent             : constant Unicode_Char := 16#329D#;
   Circled_Ideograph_Print                 : constant Unicode_Char := 16#329E#;
   Circled_Ideograph_Attention             : constant Unicode_Char := 16#329F#;
   Circled_Ideograph_Item                  : constant Unicode_Char := 16#32A0#;
   Circled_Ideograph_Rest                  : constant Unicode_Char := 16#32A1#;
   Circled_Ideograph_Copy                  : constant Unicode_Char := 16#32A2#;
   Circled_Ideograph_Correct               : constant Unicode_Char := 16#32A3#;
   Circled_Ideograph_High                  : constant Unicode_Char := 16#32A4#;
   Circled_Ideograph_Centre                : constant Unicode_Char := 16#32A5#;
   Circled_Ideograph_Low                   : constant Unicode_Char := 16#32A6#;
   Circled_Ideograph_Left                  : constant Unicode_Char := 16#32A7#;
   Circled_Ideograph_Right                 : constant Unicode_Char := 16#32A8#;
   Circled_Ideograph_Medicine              : constant Unicode_Char := 16#32A9#;
   Circled_Ideograph_Religion              : constant Unicode_Char := 16#32AA#;
   Circled_Ideograph_Study                 : constant Unicode_Char := 16#32AB#;
   Circled_Ideograph_Supervise             : constant Unicode_Char := 16#32AC#;
   Circled_Ideograph_Enterprise            : constant Unicode_Char := 16#32AD#;
   Circled_Ideograph_Resource              : constant Unicode_Char := 16#32AE#;
   Circled_Ideograph_Alliance              : constant Unicode_Char := 16#32AF#;
   Circled_Ideograph_Night                 : constant Unicode_Char := 16#32B0#;
   Circled_Number_Thirty_Six               : constant Unicode_Char := 16#32B1#;
   Circled_Number_Thirty_Seven             : constant Unicode_Char := 16#32B2#;
   Circled_Number_Thirty_Eight             : constant Unicode_Char := 16#32B3#;
   Circled_Number_Thirty_Nine              : constant Unicode_Char := 16#32B4#;
   Circled_Number_Forty                    : constant Unicode_Char := 16#32B5#;
   Circled_Number_Forty_One                : constant Unicode_Char := 16#32B6#;
   Circled_Number_Forty_Two                : constant Unicode_Char := 16#32B7#;
   Circled_Number_Forty_Three              : constant Unicode_Char := 16#32B8#;
   Circled_Number_Forty_Four               : constant Unicode_Char := 16#32B9#;
   Circled_Number_Forty_Five               : constant Unicode_Char := 16#32BA#;
   Circled_Number_Forty_Six                : constant Unicode_Char := 16#32BB#;
   Circled_Number_Forty_Seven              : constant Unicode_Char := 16#32BC#;
   Circled_Number_Forty_Eight              : constant Unicode_Char := 16#32BD#;
   Circled_Number_Forty_Nine               : constant Unicode_Char := 16#32BE#;
   Circled_Number_Fifty                    : constant Unicode_Char := 16#32BF#;
   Ideographic_Telegraph_Symbol_For_January :
      constant Unicode_Char := 16#32C0#;
   Ideographic_Telegraph_Symbol_For_February :
      constant Unicode_Char := 16#32C1#;
   Ideographic_Telegraph_Symbol_For_March  : constant Unicode_Char := 16#32C2#;
   Ideographic_Telegraph_Symbol_For_April  : constant Unicode_Char := 16#32C3#;
   Ideographic_Telegraph_Symbol_For_May    : constant Unicode_Char := 16#32C4#;
   Ideographic_Telegraph_Symbol_For_June   : constant Unicode_Char := 16#32C5#;
   Ideographic_Telegraph_Symbol_For_July   : constant Unicode_Char := 16#32C6#;
   Ideographic_Telegraph_Symbol_For_August : constant Unicode_Char := 16#32C7#;
   Ideographic_Telegraph_Symbol_For_September :
      constant Unicode_Char := 16#32C8#;
   Ideographic_Telegraph_Symbol_For_October :
      constant Unicode_Char := 16#32C9#;
   Ideographic_Telegraph_Symbol_For_November :
      constant Unicode_Char := 16#32CA#;
   Ideographic_Telegraph_Symbol_For_December :
      constant Unicode_Char := 16#32CB#;
   Square_Hg                               : constant Unicode_Char := 16#32CC#;
   Square_Erg                              : constant Unicode_Char := 16#32CD#;
   Square_Ev                               : constant Unicode_Char := 16#32CE#;
   Limited_Liability_Sign                  : constant Unicode_Char := 16#32CF#;
   Circled_Katakana_A                      : constant Unicode_Char := 16#32D0#;
   Circled_Katakana_I                      : constant Unicode_Char := 16#32D1#;
   Circled_Katakana_U                      : constant Unicode_Char := 16#32D2#;
   Circled_Katakana_E                      : constant Unicode_Char := 16#32D3#;
   Circled_Katakana_O                      : constant Unicode_Char := 16#32D4#;
   Circled_Katakana_Ka                     : constant Unicode_Char := 16#32D5#;
   Circled_Katakana_Ki                     : constant Unicode_Char := 16#32D6#;
   Circled_Katakana_Ku                     : constant Unicode_Char := 16#32D7#;
   Circled_Katakana_Ke                     : constant Unicode_Char := 16#32D8#;
   Circled_Katakana_Ko                     : constant Unicode_Char := 16#32D9#;
   Circled_Katakana_Sa                     : constant Unicode_Char := 16#32DA#;
   Circled_Katakana_Si                     : constant Unicode_Char := 16#32DB#;
   Circled_Katakana_Su                     : constant Unicode_Char := 16#32DC#;
   Circled_Katakana_Se                     : constant Unicode_Char := 16#32DD#;
   Circled_Katakana_So                     : constant Unicode_Char := 16#32DE#;
   Circled_Katakana_Ta                     : constant Unicode_Char := 16#32DF#;
   Circled_Katakana_Ti                     : constant Unicode_Char := 16#32E0#;
   Circled_Katakana_Tu                     : constant Unicode_Char := 16#32E1#;
   Circled_Katakana_Te                     : constant Unicode_Char := 16#32E2#;
   Circled_Katakana_To                     : constant Unicode_Char := 16#32E3#;
   Circled_Katakana_Na                     : constant Unicode_Char := 16#32E4#;
   Circled_Katakana_Ni                     : constant Unicode_Char := 16#32E5#;
   Circled_Katakana_Nu                     : constant Unicode_Char := 16#32E6#;
   Circled_Katakana_Ne                     : constant Unicode_Char := 16#32E7#;
   Circled_Katakana_No                     : constant Unicode_Char := 16#32E8#;
   Circled_Katakana_Ha                     : constant Unicode_Char := 16#32E9#;
   Circled_Katakana_Hi                     : constant Unicode_Char := 16#32EA#;
   Circled_Katakana_Hu                     : constant Unicode_Char := 16#32EB#;
   Circled_Katakana_He                     : constant Unicode_Char := 16#32EC#;
   Circled_Katakana_Ho                     : constant Unicode_Char := 16#32ED#;
   Circled_Katakana_Ma                     : constant Unicode_Char := 16#32EE#;
   Circled_Katakana_Mi                     : constant Unicode_Char := 16#32EF#;
   Circled_Katakana_Mu                     : constant Unicode_Char := 16#32F0#;
   Circled_Katakana_Me                     : constant Unicode_Char := 16#32F1#;
   Circled_Katakana_Mo                     : constant Unicode_Char := 16#32F2#;
   Circled_Katakana_Ya                     : constant Unicode_Char := 16#32F3#;
   Circled_Katakana_Yu                     : constant Unicode_Char := 16#32F4#;
   Circled_Katakana_Yo                     : constant Unicode_Char := 16#32F5#;
   Circled_Katakana_Ra                     : constant Unicode_Char := 16#32F6#;
   Circled_Katakana_Ri                     : constant Unicode_Char := 16#32F7#;
   Circled_Katakana_Ru                     : constant Unicode_Char := 16#32F8#;
   Circled_Katakana_Re                     : constant Unicode_Char := 16#32F9#;
   Circled_Katakana_Ro                     : constant Unicode_Char := 16#32FA#;
   Circled_Katakana_Wa                     : constant Unicode_Char := 16#32FB#;
   Circled_Katakana_Wi                     : constant Unicode_Char := 16#32FC#;
   Circled_Katakana_We                     : constant Unicode_Char := 16#32FD#;
   Circled_Katakana_Wo                     : constant Unicode_Char := 16#32FE#;
end Unicode.Names.Cjk_Letters_Months;
