--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Latin_Extended_Additional is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Latin_Capital_Letter_A_With_Ring_Below  : constant Unicode_Char := 16#1E00#;
   Latin_Small_Letter_A_With_Ring_Below    : constant Unicode_Char := 16#1E01#;
   Latin_Capital_Letter_B_With_Dot_Above   : constant Unicode_Char := 16#1E02#;
   Latin_Small_Letter_B_With_Dot_Above     : constant Unicode_Char := 16#1E03#;
   Latin_Capital_Letter_B_With_Dot_Below   : constant Unicode_Char := 16#1E04#;
   Latin_Small_Letter_B_With_Dot_Below     : constant Unicode_Char := 16#1E05#;
   Latin_Capital_Letter_B_With_Line_Below  : constant Unicode_Char := 16#1E06#;
   Latin_Small_Letter_B_With_Line_Below    : constant Unicode_Char := 16#1E07#;
   Latin_Capital_Letter_C_With_Cedilla_And_Acute :
      constant Unicode_Char := 16#1E08#;
   Latin_Small_Letter_C_With_Cedilla_And_Acute :
      constant Unicode_Char := 16#1E09#;
   Latin_Capital_Letter_D_With_Dot_Above   : constant Unicode_Char := 16#1E0A#;
   Latin_Small_Letter_D_With_Dot_Above     : constant Unicode_Char := 16#1E0B#;
   Latin_Capital_Letter_D_With_Dot_Below   : constant Unicode_Char := 16#1E0C#;
   Latin_Small_Letter_D_With_Dot_Below     : constant Unicode_Char := 16#1E0D#;
   Latin_Capital_Letter_D_With_Line_Below  : constant Unicode_Char := 16#1E0E#;
   Latin_Small_Letter_D_With_Line_Below    : constant Unicode_Char := 16#1E0F#;
   Latin_Capital_Letter_D_With_Cedilla     : constant Unicode_Char := 16#1E10#;
   Latin_Small_Letter_D_With_Cedilla       : constant Unicode_Char := 16#1E11#;
   Latin_Capital_Letter_D_With_Circumflex_Below :
      constant Unicode_Char := 16#1E12#;
   Latin_Small_Letter_D_With_Circumflex_Below :
      constant Unicode_Char := 16#1E13#;
   Latin_Capital_Letter_E_With_Macron_And_Grave :
      constant Unicode_Char := 16#1E14#;
   Latin_Small_Letter_E_With_Macron_And_Grave :
      constant Unicode_Char := 16#1E15#;
   Latin_Capital_Letter_E_With_Macron_And_Acute :
      constant Unicode_Char := 16#1E16#;
   Latin_Small_Letter_E_With_Macron_And_Acute :
      constant Unicode_Char := 16#1E17#;
   Latin_Capital_Letter_E_With_Circumflex_Below :
      constant Unicode_Char := 16#1E18#;
   Latin_Small_Letter_E_With_Circumflex_Below :
      constant Unicode_Char := 16#1E19#;
   Latin_Capital_Letter_E_With_Tilde_Below : constant Unicode_Char := 16#1E1A#;
   Latin_Small_Letter_E_With_Tilde_Below   : constant Unicode_Char := 16#1E1B#;
   Latin_Capital_Letter_E_With_Cedilla_And_Breve :
      constant Unicode_Char := 16#1E1C#;
   Latin_Small_Letter_E_With_Cedilla_And_Breve :
      constant Unicode_Char := 16#1E1D#;
   Latin_Capital_Letter_F_With_Dot_Above   : constant Unicode_Char := 16#1E1E#;
   Latin_Small_Letter_F_With_Dot_Above     : constant Unicode_Char := 16#1E1F#;
   Latin_Capital_Letter_G_With_Macron      : constant Unicode_Char := 16#1E20#;
   Latin_Small_Letter_G_With_Macron        : constant Unicode_Char := 16#1E21#;
   Latin_Capital_Letter_H_With_Dot_Above   : constant Unicode_Char := 16#1E22#;
   Latin_Small_Letter_H_With_Dot_Above     : constant Unicode_Char := 16#1E23#;
   Latin_Capital_Letter_H_With_Dot_Below   : constant Unicode_Char := 16#1E24#;
   Latin_Small_Letter_H_With_Dot_Below     : constant Unicode_Char := 16#1E25#;
   Latin_Capital_Letter_H_With_Diaeresis   : constant Unicode_Char := 16#1E26#;
   Latin_Small_Letter_H_With_Diaeresis     : constant Unicode_Char := 16#1E27#;
   Latin_Capital_Letter_H_With_Cedilla     : constant Unicode_Char := 16#1E28#;
   Latin_Small_Letter_H_With_Cedilla       : constant Unicode_Char := 16#1E29#;
   Latin_Capital_Letter_H_With_Breve_Below : constant Unicode_Char := 16#1E2A#;
   Latin_Small_Letter_H_With_Breve_Below   : constant Unicode_Char := 16#1E2B#;
   Latin_Capital_Letter_I_With_Tilde_Below : constant Unicode_Char := 16#1E2C#;
   Latin_Small_Letter_I_With_Tilde_Below   : constant Unicode_Char := 16#1E2D#;
   Latin_Capital_Letter_I_With_Diaeresis_And_Acute :
      constant Unicode_Char := 16#1E2E#;
   Latin_Small_Letter_I_With_Diaeresis_And_Acute :
      constant Unicode_Char := 16#1E2F#;
   Latin_Capital_Letter_K_With_Acute       : constant Unicode_Char := 16#1E30#;
   Latin_Small_Letter_K_With_Acute         : constant Unicode_Char := 16#1E31#;
   Latin_Capital_Letter_K_With_Dot_Below   : constant Unicode_Char := 16#1E32#;
   Latin_Small_Letter_K_With_Dot_Below     : constant Unicode_Char := 16#1E33#;
   Latin_Capital_Letter_K_With_Line_Below  : constant Unicode_Char := 16#1E34#;
   Latin_Small_Letter_K_With_Line_Below    : constant Unicode_Char := 16#1E35#;
   Latin_Capital_Letter_L_With_Dot_Below   : constant Unicode_Char := 16#1E36#;
   Latin_Small_Letter_L_With_Dot_Below     : constant Unicode_Char := 16#1E37#;
   Latin_Capital_Letter_L_With_Dot_Below_And_Macron :
      constant Unicode_Char := 16#1E38#;
   Latin_Small_Letter_L_With_Dot_Below_And_Macron :
      constant Unicode_Char := 16#1E39#;
   Latin_Capital_Letter_L_With_Line_Below  : constant Unicode_Char := 16#1E3A#;
   Latin_Small_Letter_L_With_Line_Below    : constant Unicode_Char := 16#1E3B#;
   Latin_Capital_Letter_L_With_Circumflex_Below :
      constant Unicode_Char := 16#1E3C#;
   Latin_Small_Letter_L_With_Circumflex_Below :
      constant Unicode_Char := 16#1E3D#;
   Latin_Capital_Letter_M_With_Acute       : constant Unicode_Char := 16#1E3E#;
   Latin_Small_Letter_M_With_Acute         : constant Unicode_Char := 16#1E3F#;
   Latin_Capital_Letter_M_With_Dot_Above   : constant Unicode_Char := 16#1E40#;
   Latin_Small_Letter_M_With_Dot_Above     : constant Unicode_Char := 16#1E41#;
   Latin_Capital_Letter_M_With_Dot_Below   : constant Unicode_Char := 16#1E42#;
   Latin_Small_Letter_M_With_Dot_Below     : constant Unicode_Char := 16#1E43#;
   Latin_Capital_Letter_N_With_Dot_Above   : constant Unicode_Char := 16#1E44#;
   Latin_Small_Letter_N_With_Dot_Above     : constant Unicode_Char := 16#1E45#;
   Latin_Capital_Letter_N_With_Dot_Below   : constant Unicode_Char := 16#1E46#;
   Latin_Small_Letter_N_With_Dot_Below     : constant Unicode_Char := 16#1E47#;
   Latin_Capital_Letter_N_With_Line_Below  : constant Unicode_Char := 16#1E48#;
   Latin_Small_Letter_N_With_Line_Below    : constant Unicode_Char := 16#1E49#;
   Latin_Capital_Letter_N_With_Circumflex_Below :
      constant Unicode_Char := 16#1E4A#;
   Latin_Small_Letter_N_With_Circumflex_Below :
      constant Unicode_Char := 16#1E4B#;
   Latin_Capital_Letter_O_With_Tilde_And_Acute :
      constant Unicode_Char := 16#1E4C#;
   Latin_Small_Letter_O_With_Tilde_And_Acute :
      constant Unicode_Char := 16#1E4D#;
   Latin_Capital_Letter_O_With_Tilde_And_Diaeresis :
      constant Unicode_Char := 16#1E4E#;
   Latin_Small_Letter_O_With_Tilde_And_Diaeresis :
      constant Unicode_Char := 16#1E4F#;
   Latin_Capital_Letter_O_With_Macron_And_Grave :
      constant Unicode_Char := 16#1E50#;
   Latin_Small_Letter_O_With_Macron_And_Grave :
      constant Unicode_Char := 16#1E51#;
   Latin_Capital_Letter_O_With_Macron_And_Acute :
      constant Unicode_Char := 16#1E52#;
   Latin_Small_Letter_O_With_Macron_And_Acute :
      constant Unicode_Char := 16#1E53#;
   Latin_Capital_Letter_P_With_Acute       : constant Unicode_Char := 16#1E54#;
   Latin_Small_Letter_P_With_Acute         : constant Unicode_Char := 16#1E55#;
   Latin_Capital_Letter_P_With_Dot_Above   : constant Unicode_Char := 16#1E56#;
   Latin_Small_Letter_P_With_Dot_Above     : constant Unicode_Char := 16#1E57#;
   Latin_Capital_Letter_R_With_Dot_Above   : constant Unicode_Char := 16#1E58#;
   Latin_Small_Letter_R_With_Dot_Above     : constant Unicode_Char := 16#1E59#;
   Latin_Capital_Letter_R_With_Dot_Below   : constant Unicode_Char := 16#1E5A#;
   Latin_Small_Letter_R_With_Dot_Below     : constant Unicode_Char := 16#1E5B#;
   Latin_Capital_Letter_R_With_Dot_Below_And_Macron :
      constant Unicode_Char := 16#1E5C#;
   Latin_Small_Letter_R_With_Dot_Below_And_Macron :
      constant Unicode_Char := 16#1E5D#;
   Latin_Capital_Letter_R_With_Line_Below  : constant Unicode_Char := 16#1E5E#;
   Latin_Small_Letter_R_With_Line_Below    : constant Unicode_Char := 16#1E5F#;
   Latin_Capital_Letter_S_With_Dot_Above   : constant Unicode_Char := 16#1E60#;
   Latin_Small_Letter_S_With_Dot_Above     : constant Unicode_Char := 16#1E61#;
   Latin_Capital_Letter_S_With_Dot_Below   : constant Unicode_Char := 16#1E62#;
   Latin_Small_Letter_S_With_Dot_Below     : constant Unicode_Char := 16#1E63#;
   Latin_Capital_Letter_S_With_Acute_And_Dot_Above :
      constant Unicode_Char := 16#1E64#;
   Latin_Small_Letter_S_With_Acute_And_Dot_Above :
      constant Unicode_Char := 16#1E65#;
   Latin_Capital_Letter_S_With_Caron_And_Dot_Above :
      constant Unicode_Char := 16#1E66#;
   Latin_Small_Letter_S_With_Caron_And_Dot_Above :
      constant Unicode_Char := 16#1E67#;
   Latin_Capital_Letter_S_With_Dot_Below_And_Dot_Above :
      constant Unicode_Char := 16#1E68#;
   Latin_Small_Letter_S_With_Dot_Below_And_Dot_Above :
      constant Unicode_Char := 16#1E69#;
   Latin_Capital_Letter_T_With_Dot_Above   : constant Unicode_Char := 16#1E6A#;
   Latin_Small_Letter_T_With_Dot_Above     : constant Unicode_Char := 16#1E6B#;
   Latin_Capital_Letter_T_With_Dot_Below   : constant Unicode_Char := 16#1E6C#;
   Latin_Small_Letter_T_With_Dot_Below     : constant Unicode_Char := 16#1E6D#;
   Latin_Capital_Letter_T_With_Line_Below  : constant Unicode_Char := 16#1E6E#;
   Latin_Small_Letter_T_With_Line_Below    : constant Unicode_Char := 16#1E6F#;
   Latin_Capital_Letter_T_With_Circumflex_Below :
      constant Unicode_Char := 16#1E70#;
   Latin_Small_Letter_T_With_Circumflex_Below :
      constant Unicode_Char := 16#1E71#;
   Latin_Capital_Letter_U_With_Diaeresis_Below :
      constant Unicode_Char := 16#1E72#;
   Latin_Small_Letter_U_With_Diaeresis_Below :
      constant Unicode_Char := 16#1E73#;
   Latin_Capital_Letter_U_With_Tilde_Below : constant Unicode_Char := 16#1E74#;
   Latin_Small_Letter_U_With_Tilde_Below   : constant Unicode_Char := 16#1E75#;
   Latin_Capital_Letter_U_With_Circumflex_Below :
      constant Unicode_Char := 16#1E76#;
   Latin_Small_Letter_U_With_Circumflex_Below :
      constant Unicode_Char := 16#1E77#;
   Latin_Capital_Letter_U_With_Tilde_And_Acute :
      constant Unicode_Char := 16#1E78#;
   Latin_Small_Letter_U_With_Tilde_And_Acute :
      constant Unicode_Char := 16#1E79#;
   Latin_Capital_Letter_U_With_Macron_And_Diaeresis :
      constant Unicode_Char := 16#1E7A#;
   Latin_Small_Letter_U_With_Macron_And_Diaeresis :
      constant Unicode_Char := 16#1E7B#;
   Latin_Capital_Letter_V_With_Tilde       : constant Unicode_Char := 16#1E7C#;
   Latin_Small_Letter_V_With_Tilde         : constant Unicode_Char := 16#1E7D#;
   Latin_Capital_Letter_V_With_Dot_Below   : constant Unicode_Char := 16#1E7E#;
   Latin_Small_Letter_V_With_Dot_Below     : constant Unicode_Char := 16#1E7F#;
   Latin_Capital_Letter_W_With_Grave       : constant Unicode_Char := 16#1E80#;
   Latin_Small_Letter_W_With_Grave         : constant Unicode_Char := 16#1E81#;
   Latin_Capital_Letter_W_With_Acute       : constant Unicode_Char := 16#1E82#;
   Latin_Small_Letter_W_With_Acute         : constant Unicode_Char := 16#1E83#;
   Latin_Capital_Letter_W_With_Diaeresis   : constant Unicode_Char := 16#1E84#;
   Latin_Small_Letter_W_With_Diaeresis     : constant Unicode_Char := 16#1E85#;
   Latin_Capital_Letter_W_With_Dot_Above   : constant Unicode_Char := 16#1E86#;
   Latin_Small_Letter_W_With_Dot_Above     : constant Unicode_Char := 16#1E87#;
   Latin_Capital_Letter_W_With_Dot_Below   : constant Unicode_Char := 16#1E88#;
   Latin_Small_Letter_W_With_Dot_Below     : constant Unicode_Char := 16#1E89#;
   Latin_Capital_Letter_X_With_Dot_Above   : constant Unicode_Char := 16#1E8A#;
   Latin_Small_Letter_X_With_Dot_Above     : constant Unicode_Char := 16#1E8B#;
   Latin_Capital_Letter_X_With_Diaeresis   : constant Unicode_Char := 16#1E8C#;
   Latin_Small_Letter_X_With_Diaeresis     : constant Unicode_Char := 16#1E8D#;
   Latin_Capital_Letter_Y_With_Dot_Above   : constant Unicode_Char := 16#1E8E#;
   Latin_Small_Letter_Y_With_Dot_Above     : constant Unicode_Char := 16#1E8F#;
   Latin_Capital_Letter_Z_With_Circumflex  : constant Unicode_Char := 16#1E90#;
   Latin_Small_Letter_Z_With_Circumflex    : constant Unicode_Char := 16#1E91#;
   Latin_Capital_Letter_Z_With_Dot_Below   : constant Unicode_Char := 16#1E92#;
   Latin_Small_Letter_Z_With_Dot_Below     : constant Unicode_Char := 16#1E93#;
   Latin_Capital_Letter_Z_With_Line_Below  : constant Unicode_Char := 16#1E94#;
   Latin_Small_Letter_Z_With_Line_Below    : constant Unicode_Char := 16#1E95#;
   Latin_Small_Letter_H_With_Line_Below    : constant Unicode_Char := 16#1E96#;
   Latin_Small_Letter_T_With_Diaeresis     : constant Unicode_Char := 16#1E97#;
   Latin_Small_Letter_W_With_Ring_Above    : constant Unicode_Char := 16#1E98#;
   Latin_Small_Letter_Y_With_Ring_Above    : constant Unicode_Char := 16#1E99#;
   Latin_Small_Letter_A_With_Right_Half_Ring :
      constant Unicode_Char := 16#1E9A#;
   Latin_Small_Letter_Long_S_With_Dot_Above :
      constant Unicode_Char := 16#1E9B#;
   Latin_Small_Letter_Long_S_With_Diagonal_Stroke :
      constant Unicode_Char := 16#1E9C#;
   Latin_Small_Letter_Long_S_With_High_Stroke :
      constant Unicode_Char := 16#1E9D#;
   Latin_Capital_Letter_Sharp_S            : constant Unicode_Char := 16#1E9E#;
   Latin_Small_Letter_Delta                : constant Unicode_Char := 16#1E9F#;
   Latin_Capital_Letter_A_With_Dot_Below   : constant Unicode_Char := 16#1EA0#;
   Latin_Small_Letter_A_With_Dot_Below     : constant Unicode_Char := 16#1EA1#;
   Latin_Capital_Letter_A_With_Hook_Above  : constant Unicode_Char := 16#1EA2#;
   Latin_Small_Letter_A_With_Hook_Above    : constant Unicode_Char := 16#1EA3#;
   Latin_Capital_Letter_A_With_Circumflex_And_Acute :
      constant Unicode_Char := 16#1EA4#;
   Latin_Small_Letter_A_With_Circumflex_And_Acute :
      constant Unicode_Char := 16#1EA5#;
   Latin_Capital_Letter_A_With_Circumflex_And_Grave :
      constant Unicode_Char := 16#1EA6#;
   Latin_Small_Letter_A_With_Circumflex_And_Grave :
      constant Unicode_Char := 16#1EA7#;
   Latin_Capital_Letter_A_With_Circumflex_And_Hook_Above :
      constant Unicode_Char := 16#1EA8#;
   Latin_Small_Letter_A_With_Circumflex_And_Hook_Above :
      constant Unicode_Char := 16#1EA9#;
   Latin_Capital_Letter_A_With_Circumflex_And_Tilde :
      constant Unicode_Char := 16#1EAA#;
   Latin_Small_Letter_A_With_Circumflex_And_Tilde :
      constant Unicode_Char := 16#1EAB#;
   Latin_Capital_Letter_A_With_Circumflex_And_Dot_Below :
      constant Unicode_Char := 16#1EAC#;
   Latin_Small_Letter_A_With_Circumflex_And_Dot_Below :
      constant Unicode_Char := 16#1EAD#;
   Latin_Capital_Letter_A_With_Breve_And_Acute :
      constant Unicode_Char := 16#1EAE#;
   Latin_Small_Letter_A_With_Breve_And_Acute :
      constant Unicode_Char := 16#1EAF#;
   Latin_Capital_Letter_A_With_Breve_And_Grave :
      constant Unicode_Char := 16#1EB0#;
   Latin_Small_Letter_A_With_Breve_And_Grave :
      constant Unicode_Char := 16#1EB1#;
   Latin_Capital_Letter_A_With_Breve_And_Hook_Above :
      constant Unicode_Char := 16#1EB2#;
   Latin_Small_Letter_A_With_Breve_And_Hook_Above :
      constant Unicode_Char := 16#1EB3#;
   Latin_Capital_Letter_A_With_Breve_And_Tilde :
      constant Unicode_Char := 16#1EB4#;
   Latin_Small_Letter_A_With_Breve_And_Tilde :
      constant Unicode_Char := 16#1EB5#;
   Latin_Capital_Letter_A_With_Breve_And_Dot_Below :
      constant Unicode_Char := 16#1EB6#;
   Latin_Small_Letter_A_With_Breve_And_Dot_Below :
      constant Unicode_Char := 16#1EB7#;
   Latin_Capital_Letter_E_With_Dot_Below   : constant Unicode_Char := 16#1EB8#;
   Latin_Small_Letter_E_With_Dot_Below     : constant Unicode_Char := 16#1EB9#;
   Latin_Capital_Letter_E_With_Hook_Above  : constant Unicode_Char := 16#1EBA#;
   Latin_Small_Letter_E_With_Hook_Above    : constant Unicode_Char := 16#1EBB#;
   Latin_Capital_Letter_E_With_Tilde       : constant Unicode_Char := 16#1EBC#;
   Latin_Small_Letter_E_With_Tilde         : constant Unicode_Char := 16#1EBD#;
   Latin_Capital_Letter_E_With_Circumflex_And_Acute :
      constant Unicode_Char := 16#1EBE#;
   Latin_Small_Letter_E_With_Circumflex_And_Acute :
      constant Unicode_Char := 16#1EBF#;
   Latin_Capital_Letter_E_With_Circumflex_And_Grave :
      constant Unicode_Char := 16#1EC0#;
   Latin_Small_Letter_E_With_Circumflex_And_Grave :
      constant Unicode_Char := 16#1EC1#;
   Latin_Capital_Letter_E_With_Circumflex_And_Hook_Above :
      constant Unicode_Char := 16#1EC2#;
   Latin_Small_Letter_E_With_Circumflex_And_Hook_Above :
      constant Unicode_Char := 16#1EC3#;
   Latin_Capital_Letter_E_With_Circumflex_And_Tilde :
      constant Unicode_Char := 16#1EC4#;
   Latin_Small_Letter_E_With_Circumflex_And_Tilde :
      constant Unicode_Char := 16#1EC5#;
   Latin_Capital_Letter_E_With_Circumflex_And_Dot_Below :
      constant Unicode_Char := 16#1EC6#;
   Latin_Small_Letter_E_With_Circumflex_And_Dot_Below :
      constant Unicode_Char := 16#1EC7#;
   Latin_Capital_Letter_I_With_Hook_Above  : constant Unicode_Char := 16#1EC8#;
   Latin_Small_Letter_I_With_Hook_Above    : constant Unicode_Char := 16#1EC9#;
   Latin_Capital_Letter_I_With_Dot_Below   : constant Unicode_Char := 16#1ECA#;
   Latin_Small_Letter_I_With_Dot_Below     : constant Unicode_Char := 16#1ECB#;
   Latin_Capital_Letter_O_With_Dot_Below   : constant Unicode_Char := 16#1ECC#;
   Latin_Small_Letter_O_With_Dot_Below     : constant Unicode_Char := 16#1ECD#;
   Latin_Capital_Letter_O_With_Hook_Above  : constant Unicode_Char := 16#1ECE#;
   Latin_Small_Letter_O_With_Hook_Above    : constant Unicode_Char := 16#1ECF#;
   Latin_Capital_Letter_O_With_Circumflex_And_Acute :
      constant Unicode_Char := 16#1ED0#;
   Latin_Small_Letter_O_With_Circumflex_And_Acute :
      constant Unicode_Char := 16#1ED1#;
   Latin_Capital_Letter_O_With_Circumflex_And_Grave :
      constant Unicode_Char := 16#1ED2#;
   Latin_Small_Letter_O_With_Circumflex_And_Grave :
      constant Unicode_Char := 16#1ED3#;
   Latin_Capital_Letter_O_With_Circumflex_And_Hook_Above :
      constant Unicode_Char := 16#1ED4#;
   Latin_Small_Letter_O_With_Circumflex_And_Hook_Above :
      constant Unicode_Char := 16#1ED5#;
   Latin_Capital_Letter_O_With_Circumflex_And_Tilde :
      constant Unicode_Char := 16#1ED6#;
   Latin_Small_Letter_O_With_Circumflex_And_Tilde :
      constant Unicode_Char := 16#1ED7#;
   Latin_Capital_Letter_O_With_Circumflex_And_Dot_Below :
      constant Unicode_Char := 16#1ED8#;
   Latin_Small_Letter_O_With_Circumflex_And_Dot_Below :
      constant Unicode_Char := 16#1ED9#;
   Latin_Capital_Letter_O_With_Horn_And_Acute :
      constant Unicode_Char := 16#1EDA#;
   Latin_Small_Letter_O_With_Horn_And_Acute :
      constant Unicode_Char := 16#1EDB#;
   Latin_Capital_Letter_O_With_Horn_And_Grave :
      constant Unicode_Char := 16#1EDC#;
   Latin_Small_Letter_O_With_Horn_And_Grave :
      constant Unicode_Char := 16#1EDD#;
   Latin_Capital_Letter_O_With_Horn_And_Hook_Above :
      constant Unicode_Char := 16#1EDE#;
   Latin_Small_Letter_O_With_Horn_And_Hook_Above :
      constant Unicode_Char := 16#1EDF#;
   Latin_Capital_Letter_O_With_Horn_And_Tilde :
      constant Unicode_Char := 16#1EE0#;
   Latin_Small_Letter_O_With_Horn_And_Tilde :
      constant Unicode_Char := 16#1EE1#;
   Latin_Capital_Letter_O_With_Horn_And_Dot_Below :
      constant Unicode_Char := 16#1EE2#;
   Latin_Small_Letter_O_With_Horn_And_Dot_Below :
      constant Unicode_Char := 16#1EE3#;
   Latin_Capital_Letter_U_With_Dot_Below   : constant Unicode_Char := 16#1EE4#;
   Latin_Small_Letter_U_With_Dot_Below     : constant Unicode_Char := 16#1EE5#;
   Latin_Capital_Letter_U_With_Hook_Above  : constant Unicode_Char := 16#1EE6#;
   Latin_Small_Letter_U_With_Hook_Above    : constant Unicode_Char := 16#1EE7#;
   Latin_Capital_Letter_U_With_Horn_And_Acute :
      constant Unicode_Char := 16#1EE8#;
   Latin_Small_Letter_U_With_Horn_And_Acute :
      constant Unicode_Char := 16#1EE9#;
   Latin_Capital_Letter_U_With_Horn_And_Grave :
      constant Unicode_Char := 16#1EEA#;
   Latin_Small_Letter_U_With_Horn_And_Grave :
      constant Unicode_Char := 16#1EEB#;
   Latin_Capital_Letter_U_With_Horn_And_Hook_Above :
      constant Unicode_Char := 16#1EEC#;
   Latin_Small_Letter_U_With_Horn_And_Hook_Above :
      constant Unicode_Char := 16#1EED#;
   Latin_Capital_Letter_U_With_Horn_And_Tilde :
      constant Unicode_Char := 16#1EEE#;
   Latin_Small_Letter_U_With_Horn_And_Tilde :
      constant Unicode_Char := 16#1EEF#;
   Latin_Capital_Letter_U_With_Horn_And_Dot_Below :
      constant Unicode_Char := 16#1EF0#;
   Latin_Small_Letter_U_With_Horn_And_Dot_Below :
      constant Unicode_Char := 16#1EF1#;
   Latin_Capital_Letter_Y_With_Grave       : constant Unicode_Char := 16#1EF2#;
   Latin_Small_Letter_Y_With_Grave         : constant Unicode_Char := 16#1EF3#;
   Latin_Capital_Letter_Y_With_Dot_Below   : constant Unicode_Char := 16#1EF4#;
   Latin_Small_Letter_Y_With_Dot_Below     : constant Unicode_Char := 16#1EF5#;
   Latin_Capital_Letter_Y_With_Hook_Above  : constant Unicode_Char := 16#1EF6#;
   Latin_Small_Letter_Y_With_Hook_Above    : constant Unicode_Char := 16#1EF7#;
   Latin_Capital_Letter_Y_With_Tilde       : constant Unicode_Char := 16#1EF8#;
   Latin_Small_Letter_Y_With_Tilde         : constant Unicode_Char := 16#1EF9#;
   Latin_Capital_Letter_Middle_Welsh_Ll    : constant Unicode_Char := 16#1EFA#;
   Latin_Small_Letter_Middle_Welsh_Ll      : constant Unicode_Char := 16#1EFB#;
   Latin_Capital_Letter_Middle_Welsh_V     : constant Unicode_Char := 16#1EFC#;
   Latin_Small_Letter_Middle_Welsh_V       : constant Unicode_Char := 16#1EFD#;
   Latin_Capital_Letter_Y_With_Loop        : constant Unicode_Char := 16#1EFE#;
   Latin_Small_Letter_Y_With_Loop          : constant Unicode_Char := 16#1EFF#;
end Unicode.Names.Latin_Extended_Additional;
