--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Coptic is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Coptic_Capital_Letter_Alfa              : constant Unicode_Char := 16#2C80#;
   Coptic_Small_Letter_Alfa                : constant Unicode_Char := 16#2C81#;
   Coptic_Capital_Letter_Vida              : constant Unicode_Char := 16#2C82#;
   Coptic_Small_Letter_Vida                : constant Unicode_Char := 16#2C83#;
   Coptic_Capital_Letter_Gamma             : constant Unicode_Char := 16#2C84#;
   Coptic_Small_Letter_Gamma               : constant Unicode_Char := 16#2C85#;
   Coptic_Capital_Letter_Dalda             : constant Unicode_Char := 16#2C86#;
   Coptic_Small_Letter_Dalda               : constant Unicode_Char := 16#2C87#;
   Coptic_Capital_Letter_Eie               : constant Unicode_Char := 16#2C88#;
   Coptic_Small_Letter_Eie                 : constant Unicode_Char := 16#2C89#;
   Coptic_Capital_Letter_Sou               : constant Unicode_Char := 16#2C8A#;
   Coptic_Small_Letter_Sou                 : constant Unicode_Char := 16#2C8B#;
   Coptic_Capital_Letter_Zata              : constant Unicode_Char := 16#2C8C#;
   Coptic_Small_Letter_Zata                : constant Unicode_Char := 16#2C8D#;
   Coptic_Capital_Letter_Hate              : constant Unicode_Char := 16#2C8E#;
   Coptic_Small_Letter_Hate                : constant Unicode_Char := 16#2C8F#;
   Coptic_Capital_Letter_Thethe            : constant Unicode_Char := 16#2C90#;
   Coptic_Small_Letter_Thethe              : constant Unicode_Char := 16#2C91#;
   Coptic_Capital_Letter_Iauda             : constant Unicode_Char := 16#2C92#;
   Coptic_Small_Letter_Iauda               : constant Unicode_Char := 16#2C93#;
   Coptic_Capital_Letter_Kapa              : constant Unicode_Char := 16#2C94#;
   Coptic_Small_Letter_Kapa                : constant Unicode_Char := 16#2C95#;
   Coptic_Capital_Letter_Laula             : constant Unicode_Char := 16#2C96#;
   Coptic_Small_Letter_Laula               : constant Unicode_Char := 16#2C97#;
   Coptic_Capital_Letter_Mi                : constant Unicode_Char := 16#2C98#;
   Coptic_Small_Letter_Mi                  : constant Unicode_Char := 16#2C99#;
   Coptic_Capital_Letter_Ni                : constant Unicode_Char := 16#2C9A#;
   Coptic_Small_Letter_Ni                  : constant Unicode_Char := 16#2C9B#;
   Coptic_Capital_Letter_Ksi               : constant Unicode_Char := 16#2C9C#;
   Coptic_Small_Letter_Ksi                 : constant Unicode_Char := 16#2C9D#;
   Coptic_Capital_Letter_O                 : constant Unicode_Char := 16#2C9E#;
   Coptic_Small_Letter_O                   : constant Unicode_Char := 16#2C9F#;
   Coptic_Capital_Letter_Pi                : constant Unicode_Char := 16#2CA0#;
   Coptic_Small_Letter_Pi                  : constant Unicode_Char := 16#2CA1#;
   Coptic_Capital_Letter_Ro                : constant Unicode_Char := 16#2CA2#;
   Coptic_Small_Letter_Ro                  : constant Unicode_Char := 16#2CA3#;
   Coptic_Capital_Letter_Sima              : constant Unicode_Char := 16#2CA4#;
   Coptic_Small_Letter_Sima                : constant Unicode_Char := 16#2CA5#;
   Coptic_Capital_Letter_Tau               : constant Unicode_Char := 16#2CA6#;
   Coptic_Small_Letter_Tau                 : constant Unicode_Char := 16#2CA7#;
   Coptic_Capital_Letter_Ua                : constant Unicode_Char := 16#2CA8#;
   Coptic_Small_Letter_Ua                  : constant Unicode_Char := 16#2CA9#;
   Coptic_Capital_Letter_Fi                : constant Unicode_Char := 16#2CAA#;
   Coptic_Small_Letter_Fi                  : constant Unicode_Char := 16#2CAB#;
   Coptic_Capital_Letter_Khi               : constant Unicode_Char := 16#2CAC#;
   Coptic_Small_Letter_Khi                 : constant Unicode_Char := 16#2CAD#;
   Coptic_Capital_Letter_Psi               : constant Unicode_Char := 16#2CAE#;
   Coptic_Small_Letter_Psi                 : constant Unicode_Char := 16#2CAF#;
   Coptic_Capital_Letter_Oou               : constant Unicode_Char := 16#2CB0#;
   Coptic_Small_Letter_Oou                 : constant Unicode_Char := 16#2CB1#;
   Coptic_Capital_Letter_Dialect_P_Alef    : constant Unicode_Char := 16#2CB2#;
   Coptic_Small_Letter_Dialect_P_Alef      : constant Unicode_Char := 16#2CB3#;
   Coptic_Capital_Letter_Old_Coptic_Ain    : constant Unicode_Char := 16#2CB4#;
   Coptic_Small_Letter_Old_Coptic_Ain      : constant Unicode_Char := 16#2CB5#;
   Coptic_Capital_Letter_Cryptogrammic_Eie : constant Unicode_Char := 16#2CB6#;
   Coptic_Small_Letter_Cryptogrammic_Eie   : constant Unicode_Char := 16#2CB7#;
   Coptic_Capital_Letter_Dialect_P_Kapa    : constant Unicode_Char := 16#2CB8#;
   Coptic_Small_Letter_Dialect_P_Kapa      : constant Unicode_Char := 16#2CB9#;
   Coptic_Capital_Letter_Dialect_P_Ni      : constant Unicode_Char := 16#2CBA#;
   Coptic_Small_Letter_Dialect_P_Ni        : constant Unicode_Char := 16#2CBB#;
   Coptic_Capital_Letter_Cryptogrammic_Ni  : constant Unicode_Char := 16#2CBC#;
   Coptic_Small_Letter_Cryptogrammic_Ni    : constant Unicode_Char := 16#2CBD#;
   Coptic_Capital_Letter_Old_Coptic_Oou    : constant Unicode_Char := 16#2CBE#;
   Coptic_Small_Letter_Old_Coptic_Oou      : constant Unicode_Char := 16#2CBF#;
   Coptic_Capital_Letter_Sampi             : constant Unicode_Char := 16#2CC0#;
   Coptic_Small_Letter_Sampi               : constant Unicode_Char := 16#2CC1#;
   Coptic_Capital_Letter_Crossed_Shei      : constant Unicode_Char := 16#2CC2#;
   Coptic_Small_Letter_Crossed_Shei        : constant Unicode_Char := 16#2CC3#;
   Coptic_Capital_Letter_Old_Coptic_Shei   : constant Unicode_Char := 16#2CC4#;
   Coptic_Small_Letter_Old_Coptic_Shei     : constant Unicode_Char := 16#2CC5#;
   Coptic_Capital_Letter_Old_Coptic_Esh    : constant Unicode_Char := 16#2CC6#;
   Coptic_Small_Letter_Old_Coptic_Esh      : constant Unicode_Char := 16#2CC7#;
   Coptic_Capital_Letter_Akhmimic_Khei     : constant Unicode_Char := 16#2CC8#;
   Coptic_Small_Letter_Akhmimic_Khei       : constant Unicode_Char := 16#2CC9#;
   Coptic_Capital_Letter_Dialect_P_Hori    : constant Unicode_Char := 16#2CCA#;
   Coptic_Small_Letter_Dialect_P_Hori      : constant Unicode_Char := 16#2CCB#;
   Coptic_Capital_Letter_Old_Coptic_Hori   : constant Unicode_Char := 16#2CCC#;
   Coptic_Small_Letter_Old_Coptic_Hori     : constant Unicode_Char := 16#2CCD#;
   Coptic_Capital_Letter_Old_Coptic_Ha     : constant Unicode_Char := 16#2CCE#;
   Coptic_Small_Letter_Old_Coptic_Ha       : constant Unicode_Char := 16#2CCF#;
   Coptic_Capital_Letter_L_Shaped_Ha       : constant Unicode_Char := 16#2CD0#;
   Coptic_Small_Letter_L_Shaped_Ha         : constant Unicode_Char := 16#2CD1#;
   Coptic_Capital_Letter_Old_Coptic_Hei    : constant Unicode_Char := 16#2CD2#;
   Coptic_Small_Letter_Old_Coptic_Hei      : constant Unicode_Char := 16#2CD3#;
   Coptic_Capital_Letter_Old_Coptic_Hat    : constant Unicode_Char := 16#2CD4#;
   Coptic_Small_Letter_Old_Coptic_Hat      : constant Unicode_Char := 16#2CD5#;
   Coptic_Capital_Letter_Old_Coptic_Gangia : constant Unicode_Char := 16#2CD6#;
   Coptic_Small_Letter_Old_Coptic_Gangia   : constant Unicode_Char := 16#2CD7#;
   Coptic_Capital_Letter_Old_Coptic_Dja    : constant Unicode_Char := 16#2CD8#;
   Coptic_Small_Letter_Old_Coptic_Dja      : constant Unicode_Char := 16#2CD9#;
   Coptic_Capital_Letter_Old_Coptic_Shima  : constant Unicode_Char := 16#2CDA#;
   Coptic_Small_Letter_Old_Coptic_Shima    : constant Unicode_Char := 16#2CDB#;
   Coptic_Capital_Letter_Old_Nubian_Shima  : constant Unicode_Char := 16#2CDC#;
   Coptic_Small_Letter_Old_Nubian_Shima    : constant Unicode_Char := 16#2CDD#;
   Coptic_Capital_Letter_Old_Nubian_Ngi    : constant Unicode_Char := 16#2CDE#;
   Coptic_Small_Letter_Old_Nubian_Ngi      : constant Unicode_Char := 16#2CDF#;
   Coptic_Capital_Letter_Old_Nubian_Nyi    : constant Unicode_Char := 16#2CE0#;
   Coptic_Small_Letter_Old_Nubian_Nyi      : constant Unicode_Char := 16#2CE1#;
   Coptic_Capital_Letter_Old_Nubian_Wau    : constant Unicode_Char := 16#2CE2#;
   Coptic_Small_Letter_Old_Nubian_Wau      : constant Unicode_Char := 16#2CE3#;
   Coptic_Symbol_Kai                       : constant Unicode_Char := 16#2CE4#;
   Coptic_Symbol_Mi_Ro                     : constant Unicode_Char := 16#2CE5#;
   Coptic_Symbol_Pi_Ro                     : constant Unicode_Char := 16#2CE6#;
   Coptic_Symbol_Stauros                   : constant Unicode_Char := 16#2CE7#;
   Coptic_Symbol_Tau_Ro                    : constant Unicode_Char := 16#2CE8#;
   Coptic_Symbol_Khi_Ro                    : constant Unicode_Char := 16#2CE9#;
   Coptic_Symbol_Shima_Sima                : constant Unicode_Char := 16#2CEA#;
   Coptic_Capital_Letter_Cryptogrammic_Shei :
      constant Unicode_Char := 16#2CEB#;
   Coptic_Small_Letter_Cryptogrammic_Shei  : constant Unicode_Char := 16#2CEC#;
   Coptic_Capital_Letter_Cryptogrammic_Gangia :
      constant Unicode_Char := 16#2CED#;
   Coptic_Small_Letter_Cryptogrammic_Gangia :
      constant Unicode_Char := 16#2CEE#;
   Coptic_Combining_Ni_Above               : constant Unicode_Char := 16#2CEF#;
   Coptic_Combining_Spiritus_Asper         : constant Unicode_Char := 16#2CF0#;
   Coptic_Combining_Spiritus_Lenis         : constant Unicode_Char := 16#2CF1#;
   Coptic_Capital_Letter_Bohairic_Khei     : constant Unicode_Char := 16#2CF2#;
   Coptic_Small_Letter_Bohairic_Khei       : constant Unicode_Char := 16#2CF3#;
   Coptic_Old_Nubian_Full_Stop             : constant Unicode_Char := 16#2CF9#;
   Coptic_Old_Nubian_Direct_Question_Mark  : constant Unicode_Char := 16#2CFA#;
   Coptic_Old_Nubian_Indirect_Question_Mark :
      constant Unicode_Char := 16#2CFB#;
   Coptic_Old_Nubian_Verse_Divider         : constant Unicode_Char := 16#2CFC#;
   Coptic_Fraction_One_Half                : constant Unicode_Char := 16#2CFD#;
   Coptic_Full_Stop                        : constant Unicode_Char := 16#2CFE#;
   Coptic_Morphological_Divider            : constant Unicode_Char := 16#2CFF#;
end Unicode.Names.Coptic;
