--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Musical_Symbols is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Musical_Symbol_Single_Barline           :
      constant Unicode_Char := 16#1D100#;
   Musical_Symbol_Double_Barline           :
      constant Unicode_Char := 16#1D101#;
   Musical_Symbol_Final_Barline            :
      constant Unicode_Char := 16#1D102#;
   Musical_Symbol_Reverse_Final_Barline    :
      constant Unicode_Char := 16#1D103#;
   Musical_Symbol_Dashed_Barline           :
      constant Unicode_Char := 16#1D104#;
   Musical_Symbol_Short_Barline            :
      constant Unicode_Char := 16#1D105#;
   Musical_Symbol_Left_Repeat_Sign         :
      constant Unicode_Char := 16#1D106#;
   Musical_Symbol_Right_Repeat_Sign        :
      constant Unicode_Char := 16#1D107#;
   Musical_Symbol_Repeat_Dots              :
      constant Unicode_Char := 16#1D108#;
   Musical_Symbol_Dal_Segno                :
      constant Unicode_Char := 16#1D109#;
   Musical_Symbol_Da_Capo                  :
      constant Unicode_Char := 16#1D10A#;
   Musical_Symbol_Segno                    :
      constant Unicode_Char := 16#1D10B#;
   Musical_Symbol_Coda                     :
      constant Unicode_Char := 16#1D10C#;
   Musical_Symbol_Repeated_Figure_1        :
      constant Unicode_Char := 16#1D10D#;
   Musical_Symbol_Repeated_Figure_2        :
      constant Unicode_Char := 16#1D10E#;
   Musical_Symbol_Repeated_Figure_3        :
      constant Unicode_Char := 16#1D10F#;
   Musical_Symbol_Fermata                  :
      constant Unicode_Char := 16#1D110#;
   Musical_Symbol_Fermata_Below            :
      constant Unicode_Char := 16#1D111#;
   Musical_Symbol_Breath_Mark              :
      constant Unicode_Char := 16#1D112#;
   Musical_Symbol_Caesura                  :
      constant Unicode_Char := 16#1D113#;
   Musical_Symbol_Brace                    :
      constant Unicode_Char := 16#1D114#;
   Musical_Symbol_Bracket                  :
      constant Unicode_Char := 16#1D115#;
   Musical_Symbol_One_Line_Staff           :
      constant Unicode_Char := 16#1D116#;
   Musical_Symbol_Two_Line_Staff           :
      constant Unicode_Char := 16#1D117#;
   Musical_Symbol_Three_Line_Staff         :
      constant Unicode_Char := 16#1D118#;
   Musical_Symbol_Four_Line_Staff          :
      constant Unicode_Char := 16#1D119#;
   Musical_Symbol_Five_Line_Staff          :
      constant Unicode_Char := 16#1D11A#;
   Musical_Symbol_Six_Line_Staff           :
      constant Unicode_Char := 16#1D11B#;
   Musical_Symbol_Six_String_Fretboard     :
      constant Unicode_Char := 16#1D11C#;
   Musical_Symbol_Four_String_Fretboard    :
      constant Unicode_Char := 16#1D11D#;
   Musical_Symbol_G_Clef                   :
      constant Unicode_Char := 16#1D11E#;
   Musical_Symbol_G_Clef_Ottava_Alta       :
      constant Unicode_Char := 16#1D11F#;
   Musical_Symbol_G_Clef_Ottava_Bassa      :
      constant Unicode_Char := 16#1D120#;
   Musical_Symbol_C_Clef                   :
      constant Unicode_Char := 16#1D121#;
   Musical_Symbol_F_Clef                   :
      constant Unicode_Char := 16#1D122#;
   Musical_Symbol_F_Clef_Ottava_Alta       :
      constant Unicode_Char := 16#1D123#;
   Musical_Symbol_F_Clef_Ottava_Bassa      :
      constant Unicode_Char := 16#1D124#;
   Musical_Symbol_Drum_Clef_1              :
      constant Unicode_Char := 16#1D125#;
   Musical_Symbol_Drum_Clef_2              :
      constant Unicode_Char := 16#1D126#;
   Musical_Symbol_Multiple_Measure_Rest    :
      constant Unicode_Char := 16#1D129#;
   Musical_Symbol_Double_Sharp             :
      constant Unicode_Char := 16#1D12A#;
   Musical_Symbol_Double_Flat              :
      constant Unicode_Char := 16#1D12B#;
   Musical_Symbol_Flat_Up                  :
      constant Unicode_Char := 16#1D12C#;
   Musical_Symbol_Flat_Down                :
      constant Unicode_Char := 16#1D12D#;
   Musical_Symbol_Natural_Up               :
      constant Unicode_Char := 16#1D12E#;
   Musical_Symbol_Natural_Down             :
      constant Unicode_Char := 16#1D12F#;
   Musical_Symbol_Sharp_Up                 :
      constant Unicode_Char := 16#1D130#;
   Musical_Symbol_Sharp_Down               :
      constant Unicode_Char := 16#1D131#;
   Musical_Symbol_Quarter_Tone_Sharp       :
      constant Unicode_Char := 16#1D132#;
   Musical_Symbol_Quarter_Tone_Flat        :
      constant Unicode_Char := 16#1D133#;
   Musical_Symbol_Common_Time              :
      constant Unicode_Char := 16#1D134#;
   Musical_Symbol_Cut_Time                 :
      constant Unicode_Char := 16#1D135#;
   Musical_Symbol_Ottava_Alta              :
      constant Unicode_Char := 16#1D136#;
   Musical_Symbol_Ottava_Bassa             :
      constant Unicode_Char := 16#1D137#;
   Musical_Symbol_Quindicesima_Alta        :
      constant Unicode_Char := 16#1D138#;
   Musical_Symbol_Quindicesima_Bassa       :
      constant Unicode_Char := 16#1D139#;
   Musical_Symbol_Multi_Rest               :
      constant Unicode_Char := 16#1D13A#;
   Musical_Symbol_Whole_Rest               :
      constant Unicode_Char := 16#1D13B#;
   Musical_Symbol_Half_Rest                :
      constant Unicode_Char := 16#1D13C#;
   Musical_Symbol_Quarter_Rest             :
      constant Unicode_Char := 16#1D13D#;
   Musical_Symbol_Eighth_Rest              :
      constant Unicode_Char := 16#1D13E#;
   Musical_Symbol_Sixteenth_Rest           :
      constant Unicode_Char := 16#1D13F#;
   Musical_Symbol_Thirty_Second_Rest       :
      constant Unicode_Char := 16#1D140#;
   Musical_Symbol_Sixty_Fourth_Rest        :
      constant Unicode_Char := 16#1D141#;
   Musical_Symbol_One_Hundred_Twenty_Eighth_Rest :
      constant Unicode_Char := 16#1D142#;
   Musical_Symbol_X_Notehead               :
      constant Unicode_Char := 16#1D143#;
   Musical_Symbol_Plus_Notehead            :
      constant Unicode_Char := 16#1D144#;
   Musical_Symbol_Circle_X_Notehead        :
      constant Unicode_Char := 16#1D145#;
   Musical_Symbol_Square_Notehead_White    :
      constant Unicode_Char := 16#1D146#;
   Musical_Symbol_Square_Notehead_Black    :
      constant Unicode_Char := 16#1D147#;
   Musical_Symbol_Triangle_Notehead_Up_White :
      constant Unicode_Char := 16#1D148#;
   Musical_Symbol_Triangle_Notehead_Up_Black :
      constant Unicode_Char := 16#1D149#;
   Musical_Symbol_Triangle_Notehead_Left_White :
      constant Unicode_Char := 16#1D14A#;
   Musical_Symbol_Triangle_Notehead_Left_Black :
      constant Unicode_Char := 16#1D14B#;
   Musical_Symbol_Triangle_Notehead_Right_White :
      constant Unicode_Char := 16#1D14C#;
   Musical_Symbol_Triangle_Notehead_Right_Black :
      constant Unicode_Char := 16#1D14D#;
   Musical_Symbol_Triangle_Notehead_Down_White :
      constant Unicode_Char := 16#1D14E#;
   Musical_Symbol_Triangle_Notehead_Down_Black :
      constant Unicode_Char := 16#1D14F#;
   Musical_Symbol_Triangle_Notehead_Up_Right_White :
      constant Unicode_Char := 16#1D150#;
   Musical_Symbol_Triangle_Notehead_Up_Right_Black :
      constant Unicode_Char := 16#1D151#;
   Musical_Symbol_Moon_Notehead_White      :
      constant Unicode_Char := 16#1D152#;
   Musical_Symbol_Moon_Notehead_Black      :
      constant Unicode_Char := 16#1D153#;
   Musical_Symbol_Triangle_Round_Notehead_Down_White :
      constant Unicode_Char := 16#1D154#;
   Musical_Symbol_Triangle_Round_Notehead_Down_Black :
      constant Unicode_Char := 16#1D155#;
   Musical_Symbol_Parenthesis_Notehead     :
      constant Unicode_Char := 16#1D156#;
   Musical_Symbol_Void_Notehead            :
      constant Unicode_Char := 16#1D157#;
   Musical_Symbol_Notehead_Black           :
      constant Unicode_Char := 16#1D158#;
   Musical_Symbol_Null_Notehead            :
      constant Unicode_Char := 16#1D159#;
   Musical_Symbol_Cluster_Notehead_White   :
      constant Unicode_Char := 16#1D15A#;
   Musical_Symbol_Cluster_Notehead_Black   :
      constant Unicode_Char := 16#1D15B#;
   Musical_Symbol_Breve                    :
      constant Unicode_Char := 16#1D15C#;
   Musical_Symbol_Whole_Note               :
      constant Unicode_Char := 16#1D15D#;
   Musical_Symbol_Half_Note                :
      constant Unicode_Char := 16#1D15E#;
   Musical_Symbol_Quarter_Note             :
      constant Unicode_Char := 16#1D15F#;
   Musical_Symbol_Eighth_Note              :
      constant Unicode_Char := 16#1D160#;
   Musical_Symbol_Sixteenth_Note           :
      constant Unicode_Char := 16#1D161#;
   Musical_Symbol_Thirty_Second_Note       :
      constant Unicode_Char := 16#1D162#;
   Musical_Symbol_Sixty_Fourth_Note        :
      constant Unicode_Char := 16#1D163#;
   Musical_Symbol_One_Hundred_Twenty_Eighth_Note :
      constant Unicode_Char := 16#1D164#;
   Musical_Symbol_Combining_Stem           :
      constant Unicode_Char := 16#1D165#;
   Musical_Symbol_Combining_Sprechgesang_Stem :
      constant Unicode_Char := 16#1D166#;
   Musical_Symbol_Combining_Tremolo_1      :
      constant Unicode_Char := 16#1D167#;
   Musical_Symbol_Combining_Tremolo_2      :
      constant Unicode_Char := 16#1D168#;
   Musical_Symbol_Combining_Tremolo_3      :
      constant Unicode_Char := 16#1D169#;
   Musical_Symbol_Fingered_Tremolo_1       :
      constant Unicode_Char := 16#1D16A#;
   Musical_Symbol_Fingered_Tremolo_2       :
      constant Unicode_Char := 16#1D16B#;
   Musical_Symbol_Fingered_Tremolo_3       :
      constant Unicode_Char := 16#1D16C#;
   Musical_Symbol_Combining_Augmentation_Dot :
      constant Unicode_Char := 16#1D16D#;
   Musical_Symbol_Combining_Flag_1         :
      constant Unicode_Char := 16#1D16E#;
   Musical_Symbol_Combining_Flag_2         :
      constant Unicode_Char := 16#1D16F#;
   Musical_Symbol_Combining_Flag_3         :
      constant Unicode_Char := 16#1D170#;
   Musical_Symbol_Combining_Flag_4         :
      constant Unicode_Char := 16#1D171#;
   Musical_Symbol_Combining_Flag_5         :
      constant Unicode_Char := 16#1D172#;
   Musical_Symbol_Begin_Beam               :
      constant Unicode_Char := 16#1D173#;
   Musical_Symbol_End_Beam                 :
      constant Unicode_Char := 16#1D174#;
   Musical_Symbol_Begin_Tie                :
      constant Unicode_Char := 16#1D175#;
   Musical_Symbol_End_Tie                  :
      constant Unicode_Char := 16#1D176#;
   Musical_Symbol_Begin_Slur               :
      constant Unicode_Char := 16#1D177#;
   Musical_Symbol_End_Slur                 :
      constant Unicode_Char := 16#1D178#;
   Musical_Symbol_Begin_Phrase             :
      constant Unicode_Char := 16#1D179#;
   Musical_Symbol_End_Phrase               :
      constant Unicode_Char := 16#1D17A#;
   Musical_Symbol_Combining_Accent         :
      constant Unicode_Char := 16#1D17B#;
   Musical_Symbol_Combining_Staccato       :
      constant Unicode_Char := 16#1D17C#;
   Musical_Symbol_Combining_Tenuto         :
      constant Unicode_Char := 16#1D17D#;
   Musical_Symbol_Combining_Staccatissimo  :
      constant Unicode_Char := 16#1D17E#;
   Musical_Symbol_Combining_Marcato        :
      constant Unicode_Char := 16#1D17F#;
   Musical_Symbol_Combining_Marcato_Staccato :
      constant Unicode_Char := 16#1D180#;
   Musical_Symbol_Combining_Accent_Staccato :
      constant Unicode_Char := 16#1D181#;
   Musical_Symbol_Combining_Loure          :
      constant Unicode_Char := 16#1D182#;
   Musical_Symbol_Arpeggiato_Up            :
      constant Unicode_Char := 16#1D183#;
   Musical_Symbol_Arpeggiato_Down          :
      constant Unicode_Char := 16#1D184#;
   Musical_Symbol_Combining_Doit           :
      constant Unicode_Char := 16#1D185#;
   Musical_Symbol_Combining_Rip            :
      constant Unicode_Char := 16#1D186#;
   Musical_Symbol_Combining_Flip           :
      constant Unicode_Char := 16#1D187#;
   Musical_Symbol_Combining_Smear          :
      constant Unicode_Char := 16#1D188#;
   Musical_Symbol_Combining_Bend           :
      constant Unicode_Char := 16#1D189#;
   Musical_Symbol_Combining_Double_Tongue  :
      constant Unicode_Char := 16#1D18A#;
   Musical_Symbol_Combining_Triple_Tongue  :
      constant Unicode_Char := 16#1D18B#;
   Musical_Symbol_Rinforzando              :
      constant Unicode_Char := 16#1D18C#;
   Musical_Symbol_Subito                   :
      constant Unicode_Char := 16#1D18D#;
   Musical_Symbol_Z                        :
      constant Unicode_Char := 16#1D18E#;
   Musical_Symbol_Piano                    :
      constant Unicode_Char := 16#1D18F#;
   Musical_Symbol_Mezzo                    :
      constant Unicode_Char := 16#1D190#;
   Musical_Symbol_Forte                    :
      constant Unicode_Char := 16#1D191#;
   Musical_Symbol_Crescendo                :
      constant Unicode_Char := 16#1D192#;
   Musical_Symbol_Decrescendo              :
      constant Unicode_Char := 16#1D193#;
   Musical_Symbol_Grace_Note_Slash         :
      constant Unicode_Char := 16#1D194#;
   Musical_Symbol_Grace_Note_No_Slash      :
      constant Unicode_Char := 16#1D195#;
   Musical_Symbol_Tr                       :
      constant Unicode_Char := 16#1D196#;
   Musical_Symbol_Turn                     :
      constant Unicode_Char := 16#1D197#;
   Musical_Symbol_Inverted_Turn            :
      constant Unicode_Char := 16#1D198#;
   Musical_Symbol_Turn_Slash               :
      constant Unicode_Char := 16#1D199#;
   Musical_Symbol_Turn_Up                  :
      constant Unicode_Char := 16#1D19A#;
   Musical_Symbol_Ornament_Stroke_1        :
      constant Unicode_Char := 16#1D19B#;
   Musical_Symbol_Ornament_Stroke_2        :
      constant Unicode_Char := 16#1D19C#;
   Musical_Symbol_Ornament_Stroke_3        :
      constant Unicode_Char := 16#1D19D#;
   Musical_Symbol_Ornament_Stroke_4        :
      constant Unicode_Char := 16#1D19E#;
   Musical_Symbol_Ornament_Stroke_5        :
      constant Unicode_Char := 16#1D19F#;
   Musical_Symbol_Ornament_Stroke_6        :
      constant Unicode_Char := 16#1D1A0#;
   Musical_Symbol_Ornament_Stroke_7        :
      constant Unicode_Char := 16#1D1A1#;
   Musical_Symbol_Ornament_Stroke_8        :
      constant Unicode_Char := 16#1D1A2#;
   Musical_Symbol_Ornament_Stroke_9        :
      constant Unicode_Char := 16#1D1A3#;
   Musical_Symbol_Ornament_Stroke_10       :
      constant Unicode_Char := 16#1D1A4#;
   Musical_Symbol_Ornament_Stroke_11       :
      constant Unicode_Char := 16#1D1A5#;
   Musical_Symbol_Hauptstimme              :
      constant Unicode_Char := 16#1D1A6#;
   Musical_Symbol_Nebenstimme              :
      constant Unicode_Char := 16#1D1A7#;
   Musical_Symbol_End_Of_Stimme            :
      constant Unicode_Char := 16#1D1A8#;
   Musical_Symbol_Degree_Slash             :
      constant Unicode_Char := 16#1D1A9#;
   Musical_Symbol_Combining_Down_Bow       :
      constant Unicode_Char := 16#1D1AA#;
   Musical_Symbol_Combining_Up_Bow         :
      constant Unicode_Char := 16#1D1AB#;
   Musical_Symbol_Combining_Harmonic       :
      constant Unicode_Char := 16#1D1AC#;
   Musical_Symbol_Combining_Snap_Pizzicato :
      constant Unicode_Char := 16#1D1AD#;
   Musical_Symbol_Pedal_Mark               :
      constant Unicode_Char := 16#1D1AE#;
   Musical_Symbol_Pedal_Up_Mark            :
      constant Unicode_Char := 16#1D1AF#;
   Musical_Symbol_Half_Pedal_Mark          :
      constant Unicode_Char := 16#1D1B0#;
   Musical_Symbol_Glissando_Up             :
      constant Unicode_Char := 16#1D1B1#;
   Musical_Symbol_Glissando_Down           :
      constant Unicode_Char := 16#1D1B2#;
   Musical_Symbol_With_Fingernails         :
      constant Unicode_Char := 16#1D1B3#;
   Musical_Symbol_Damp                     :
      constant Unicode_Char := 16#1D1B4#;
   Musical_Symbol_Damp_All                 :
      constant Unicode_Char := 16#1D1B5#;
   Musical_Symbol_Maxima                   :
      constant Unicode_Char := 16#1D1B6#;
   Musical_Symbol_Longa                    :
      constant Unicode_Char := 16#1D1B7#;
   Musical_Symbol_Brevis                   :
      constant Unicode_Char := 16#1D1B8#;
   Musical_Symbol_Semibrevis_White         :
      constant Unicode_Char := 16#1D1B9#;
   Musical_Symbol_Semibrevis_Black         :
      constant Unicode_Char := 16#1D1BA#;
   Musical_Symbol_Minima                   :
      constant Unicode_Char := 16#1D1BB#;
   Musical_Symbol_Minima_Black             :
      constant Unicode_Char := 16#1D1BC#;
   Musical_Symbol_Semiminima_White         :
      constant Unicode_Char := 16#1D1BD#;
   Musical_Symbol_Semiminima_Black         :
      constant Unicode_Char := 16#1D1BE#;
   Musical_Symbol_Fusa_White               :
      constant Unicode_Char := 16#1D1BF#;
   Musical_Symbol_Fusa_Black               :
      constant Unicode_Char := 16#1D1C0#;
   Musical_Symbol_Longa_Perfecta_Rest      :
      constant Unicode_Char := 16#1D1C1#;
   Musical_Symbol_Longa_Imperfecta_Rest    :
      constant Unicode_Char := 16#1D1C2#;
   Musical_Symbol_Brevis_Rest              :
      constant Unicode_Char := 16#1D1C3#;
   Musical_Symbol_Semibrevis_Rest          :
      constant Unicode_Char := 16#1D1C4#;
   Musical_Symbol_Minima_Rest              :
      constant Unicode_Char := 16#1D1C5#;
   Musical_Symbol_Semiminima_Rest          :
      constant Unicode_Char := 16#1D1C6#;
   Musical_Symbol_Tempus_Perfectum_Cum_Prolatione_Perfecta :
      constant Unicode_Char := 16#1D1C7#;
   Musical_Symbol_Tempus_Perfectum_Cum_Prolatione_Imperfecta :
      constant Unicode_Char := 16#1D1C8#;
   Musical_Symbol_Tempus_Perfectum_Cum_Prolatione_Perfecta_Diminution_1 :
      constant Unicode_Char := 16#1D1C9#;
   Musical_Symbol_Tempus_Imperfectum_Cum_Prolatione_Perfecta :
      constant Unicode_Char := 16#1D1CA#;
   Musical_Symbol_Tempus_Imperfectum_Cum_Prolatione_Imperfecta :
      constant Unicode_Char := 16#1D1CB#;
   Musical_Symbol_Tempus_Imperfectum_Cum_Prolatione_Imperfecta_Diminution_1 :
      constant Unicode_Char := 16#1D1CC#;
   Musical_Symbol_Tempus_Imperfectum_Cum_Prolatione_Imperfecta_Diminution_2 :
      constant Unicode_Char := 16#1D1CD#;
   Musical_Symbol_Tempus_Imperfectum_Cum_Prolatione_Imperfecta_Diminution_3 :
      constant Unicode_Char := 16#1D1CE#;
   Musical_Symbol_Croix                    :
      constant Unicode_Char := 16#1D1CF#;
   Musical_Symbol_Gregorian_C_Clef         :
      constant Unicode_Char := 16#1D1D0#;
   Musical_Symbol_Gregorian_F_Clef         :
      constant Unicode_Char := 16#1D1D1#;
   Musical_Symbol_Square_B                 :
      constant Unicode_Char := 16#1D1D2#;
   Musical_Symbol_Virga                    :
      constant Unicode_Char := 16#1D1D3#;
   Musical_Symbol_Podatus                  :
      constant Unicode_Char := 16#1D1D4#;
   Musical_Symbol_Clivis                   :
      constant Unicode_Char := 16#1D1D5#;
   Musical_Symbol_Scandicus                :
      constant Unicode_Char := 16#1D1D6#;
   Musical_Symbol_Climacus                 :
      constant Unicode_Char := 16#1D1D7#;
   Musical_Symbol_Torculus                 :
      constant Unicode_Char := 16#1D1D8#;
   Musical_Symbol_Porrectus                :
      constant Unicode_Char := 16#1D1D9#;
   Musical_Symbol_Porrectus_Flexus         :
      constant Unicode_Char := 16#1D1DA#;
   Musical_Symbol_Scandicus_Flexus         :
      constant Unicode_Char := 16#1D1DB#;
   Musical_Symbol_Torculus_Resupinus       :
      constant Unicode_Char := 16#1D1DC#;
   Musical_Symbol_Pes_Subpunctis           :
      constant Unicode_Char := 16#1D1DD#;
   Musical_Symbol_Kievan_C_Clef            :
      constant Unicode_Char := 16#1D1DE#;
   Musical_Symbol_Kievan_End_Of_Piece      :
      constant Unicode_Char := 16#1D1DF#;
   Musical_Symbol_Kievan_Final_Note        :
      constant Unicode_Char := 16#1D1E0#;
   Musical_Symbol_Kievan_Recitative_Mark   :
      constant Unicode_Char := 16#1D1E1#;
   Musical_Symbol_Kievan_Whole_Note        :
      constant Unicode_Char := 16#1D1E2#;
   Musical_Symbol_Kievan_Half_Note         :
      constant Unicode_Char := 16#1D1E3#;
   Musical_Symbol_Kievan_Quarter_Note_Stem_Down :
      constant Unicode_Char := 16#1D1E4#;
   Musical_Symbol_Kievan_Quarter_Note_Stem_Up :
      constant Unicode_Char := 16#1D1E5#;
   Musical_Symbol_Kievan_Eighth_Note_Stem_Down :
      constant Unicode_Char := 16#1D1E6#;
   Musical_Symbol_Kievan_Eighth_Note_Stem_Up :
      constant Unicode_Char := 16#1D1E7#;
   Musical_Symbol_Kievan_Flat_Sign         :
      constant Unicode_Char := 16#1D1E8#;
end Unicode.Names.Musical_Symbols;
