--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Ethiopic_Extended is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Ethiopic_Syllable_Loa                   : constant Unicode_Char := 16#2D80#;
   Ethiopic_Syllable_Moa                   : constant Unicode_Char := 16#2D81#;
   Ethiopic_Syllable_Roa                   : constant Unicode_Char := 16#2D82#;
   Ethiopic_Syllable_Soa                   : constant Unicode_Char := 16#2D83#;
   Ethiopic_Syllable_Shoa                  : constant Unicode_Char := 16#2D84#;
   Ethiopic_Syllable_Boa                   : constant Unicode_Char := 16#2D85#;
   Ethiopic_Syllable_Toa                   : constant Unicode_Char := 16#2D86#;
   Ethiopic_Syllable_Coa                   : constant Unicode_Char := 16#2D87#;
   Ethiopic_Syllable_Noa                   : constant Unicode_Char := 16#2D88#;
   Ethiopic_Syllable_Nyoa                  : constant Unicode_Char := 16#2D89#;
   Ethiopic_Syllable_Glottal_Oa            : constant Unicode_Char := 16#2D8A#;
   Ethiopic_Syllable_Zoa                   : constant Unicode_Char := 16#2D8B#;
   Ethiopic_Syllable_Doa                   : constant Unicode_Char := 16#2D8C#;
   Ethiopic_Syllable_Ddoa                  : constant Unicode_Char := 16#2D8D#;
   Ethiopic_Syllable_Joa                   : constant Unicode_Char := 16#2D8E#;
   Ethiopic_Syllable_Thoa                  : constant Unicode_Char := 16#2D8F#;
   Ethiopic_Syllable_Choa                  : constant Unicode_Char := 16#2D90#;
   Ethiopic_Syllable_Phoa                  : constant Unicode_Char := 16#2D91#;
   Ethiopic_Syllable_Poa                   : constant Unicode_Char := 16#2D92#;
   Ethiopic_Syllable_Ggwa                  : constant Unicode_Char := 16#2D93#;
   Ethiopic_Syllable_Ggwi                  : constant Unicode_Char := 16#2D94#;
   Ethiopic_Syllable_Ggwee                 : constant Unicode_Char := 16#2D95#;
   Ethiopic_Syllable_Ggwe                  : constant Unicode_Char := 16#2D96#;
   Ethiopic_Syllable_Ssa                   : constant Unicode_Char := 16#2DA0#;
   Ethiopic_Syllable_Ssu                   : constant Unicode_Char := 16#2DA1#;
   Ethiopic_Syllable_Ssi                   : constant Unicode_Char := 16#2DA2#;
   Ethiopic_Syllable_Ssaa                  : constant Unicode_Char := 16#2DA3#;
   Ethiopic_Syllable_Ssee                  : constant Unicode_Char := 16#2DA4#;
   Ethiopic_Syllable_Sse                   : constant Unicode_Char := 16#2DA5#;
   Ethiopic_Syllable_Sso                   : constant Unicode_Char := 16#2DA6#;
   Ethiopic_Syllable_Cca                   : constant Unicode_Char := 16#2DA8#;
   Ethiopic_Syllable_Ccu                   : constant Unicode_Char := 16#2DA9#;
   Ethiopic_Syllable_Cci                   : constant Unicode_Char := 16#2DAA#;
   Ethiopic_Syllable_Ccaa                  : constant Unicode_Char := 16#2DAB#;
   Ethiopic_Syllable_Ccee                  : constant Unicode_Char := 16#2DAC#;
   Ethiopic_Syllable_Cce                   : constant Unicode_Char := 16#2DAD#;
   Ethiopic_Syllable_Cco                   : constant Unicode_Char := 16#2DAE#;
   Ethiopic_Syllable_Zza                   : constant Unicode_Char := 16#2DB0#;
   Ethiopic_Syllable_Zzu                   : constant Unicode_Char := 16#2DB1#;
   Ethiopic_Syllable_Zzi                   : constant Unicode_Char := 16#2DB2#;
   Ethiopic_Syllable_Zzaa                  : constant Unicode_Char := 16#2DB3#;
   Ethiopic_Syllable_Zzee                  : constant Unicode_Char := 16#2DB4#;
   Ethiopic_Syllable_Zze                   : constant Unicode_Char := 16#2DB5#;
   Ethiopic_Syllable_Zzo                   : constant Unicode_Char := 16#2DB6#;
   Ethiopic_Syllable_Ccha                  : constant Unicode_Char := 16#2DB8#;
   Ethiopic_Syllable_Cchu                  : constant Unicode_Char := 16#2DB9#;
   Ethiopic_Syllable_Cchi                  : constant Unicode_Char := 16#2DBA#;
   Ethiopic_Syllable_Cchaa                 : constant Unicode_Char := 16#2DBB#;
   Ethiopic_Syllable_Cchee                 : constant Unicode_Char := 16#2DBC#;
   Ethiopic_Syllable_Cche                  : constant Unicode_Char := 16#2DBD#;
   Ethiopic_Syllable_Ccho                  : constant Unicode_Char := 16#2DBE#;
   Ethiopic_Syllable_Qya                   : constant Unicode_Char := 16#2DC0#;
   Ethiopic_Syllable_Qyu                   : constant Unicode_Char := 16#2DC1#;
   Ethiopic_Syllable_Qyi                   : constant Unicode_Char := 16#2DC2#;
   Ethiopic_Syllable_Qyaa                  : constant Unicode_Char := 16#2DC3#;
   Ethiopic_Syllable_Qyee                  : constant Unicode_Char := 16#2DC4#;
   Ethiopic_Syllable_Qye                   : constant Unicode_Char := 16#2DC5#;
   Ethiopic_Syllable_Qyo                   : constant Unicode_Char := 16#2DC6#;
   Ethiopic_Syllable_Kya                   : constant Unicode_Char := 16#2DC8#;
   Ethiopic_Syllable_Kyu                   : constant Unicode_Char := 16#2DC9#;
   Ethiopic_Syllable_Kyi                   : constant Unicode_Char := 16#2DCA#;
   Ethiopic_Syllable_Kyaa                  : constant Unicode_Char := 16#2DCB#;
   Ethiopic_Syllable_Kyee                  : constant Unicode_Char := 16#2DCC#;
   Ethiopic_Syllable_Kye                   : constant Unicode_Char := 16#2DCD#;
   Ethiopic_Syllable_Kyo                   : constant Unicode_Char := 16#2DCE#;
   Ethiopic_Syllable_Xya                   : constant Unicode_Char := 16#2DD0#;
   Ethiopic_Syllable_Xyu                   : constant Unicode_Char := 16#2DD1#;
   Ethiopic_Syllable_Xyi                   : constant Unicode_Char := 16#2DD2#;
   Ethiopic_Syllable_Xyaa                  : constant Unicode_Char := 16#2DD3#;
   Ethiopic_Syllable_Xyee                  : constant Unicode_Char := 16#2DD4#;
   Ethiopic_Syllable_Xye                   : constant Unicode_Char := 16#2DD5#;
   Ethiopic_Syllable_Xyo                   : constant Unicode_Char := 16#2DD6#;
   Ethiopic_Syllable_Gya                   : constant Unicode_Char := 16#2DD8#;
   Ethiopic_Syllable_Gyu                   : constant Unicode_Char := 16#2DD9#;
   Ethiopic_Syllable_Gyi                   : constant Unicode_Char := 16#2DDA#;
   Ethiopic_Syllable_Gyaa                  : constant Unicode_Char := 16#2DDB#;
   Ethiopic_Syllable_Gyee                  : constant Unicode_Char := 16#2DDC#;
   Ethiopic_Syllable_Gye                   : constant Unicode_Char := 16#2DDD#;
   Ethiopic_Syllable_Gyo                   : constant Unicode_Char := 16#2DDE#;
end Unicode.Names.Ethiopic_Extended;
