--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Samaritan is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Samaritan_Letter_Alaf                   : constant Unicode_Char := 16#0800#;
   Samaritan_Letter_Bit                    : constant Unicode_Char := 16#0801#;
   Samaritan_Letter_Gaman                  : constant Unicode_Char := 16#0802#;
   Samaritan_Letter_Dalat                  : constant Unicode_Char := 16#0803#;
   Samaritan_Letter_Iy                     : constant Unicode_Char := 16#0804#;
   Samaritan_Letter_Baa                    : constant Unicode_Char := 16#0805#;
   Samaritan_Letter_Zen                    : constant Unicode_Char := 16#0806#;
   Samaritan_Letter_It                     : constant Unicode_Char := 16#0807#;
   Samaritan_Letter_Tit                    : constant Unicode_Char := 16#0808#;
   Samaritan_Letter_Yut                    : constant Unicode_Char := 16#0809#;
   Samaritan_Letter_Kaaf                   : constant Unicode_Char := 16#080A#;
   Samaritan_Letter_Labat                  : constant Unicode_Char := 16#080B#;
   Samaritan_Letter_Mim                    : constant Unicode_Char := 16#080C#;
   Samaritan_Letter_Nun                    : constant Unicode_Char := 16#080D#;
   Samaritan_Letter_Singaat                : constant Unicode_Char := 16#080E#;
   Samaritan_Letter_In                     : constant Unicode_Char := 16#080F#;
   Samaritan_Letter_Fi                     : constant Unicode_Char := 16#0810#;
   Samaritan_Letter_Tsaadiy                : constant Unicode_Char := 16#0811#;
   Samaritan_Letter_Quf                    : constant Unicode_Char := 16#0812#;
   Samaritan_Letter_Rish                   : constant Unicode_Char := 16#0813#;
   Samaritan_Letter_Shan                   : constant Unicode_Char := 16#0814#;
   Samaritan_Letter_Taaf                   : constant Unicode_Char := 16#0815#;
   Samaritan_Mark_In                       : constant Unicode_Char := 16#0816#;
   Samaritan_Mark_In_Alaf                  : constant Unicode_Char := 16#0817#;
   Samaritan_Mark_Occlusion                : constant Unicode_Char := 16#0818#;
   Samaritan_Mark_Dagesh                   : constant Unicode_Char := 16#0819#;
   Samaritan_Modifier_Letter_Epenthetic_Yut :
      constant Unicode_Char := 16#081A#;
   Samaritan_Mark_Epenthetic_Yut           : constant Unicode_Char := 16#081B#;
   Samaritan_Vowel_Sign_Long_E             : constant Unicode_Char := 16#081C#;
   Samaritan_Vowel_Sign_E                  : constant Unicode_Char := 16#081D#;
   Samaritan_Vowel_Sign_Overlong_Aa        : constant Unicode_Char := 16#081E#;
   Samaritan_Vowel_Sign_Long_Aa            : constant Unicode_Char := 16#081F#;
   Samaritan_Vowel_Sign_Aa                 : constant Unicode_Char := 16#0820#;
   Samaritan_Vowel_Sign_Overlong_A         : constant Unicode_Char := 16#0821#;
   Samaritan_Vowel_Sign_Long_A             : constant Unicode_Char := 16#0822#;
   Samaritan_Vowel_Sign_A                  : constant Unicode_Char := 16#0823#;
   Samaritan_Modifier_Letter_Short_A       : constant Unicode_Char := 16#0824#;
   Samaritan_Vowel_Sign_Short_A            : constant Unicode_Char := 16#0825#;
   Samaritan_Vowel_Sign_Long_U             : constant Unicode_Char := 16#0826#;
   Samaritan_Vowel_Sign_U                  : constant Unicode_Char := 16#0827#;
   Samaritan_Modifier_Letter_I             : constant Unicode_Char := 16#0828#;
   Samaritan_Vowel_Sign_Long_I             : constant Unicode_Char := 16#0829#;
   Samaritan_Vowel_Sign_I                  : constant Unicode_Char := 16#082A#;
   Samaritan_Vowel_Sign_O                  : constant Unicode_Char := 16#082B#;
   Samaritan_Vowel_Sign_Sukun              : constant Unicode_Char := 16#082C#;
   Samaritan_Mark_Nequdaa                  : constant Unicode_Char := 16#082D#;
   Samaritan_Punctuation_Nequdaa           : constant Unicode_Char := 16#0830#;
   Samaritan_Punctuation_Afsaaq            : constant Unicode_Char := 16#0831#;
   Samaritan_Punctuation_Anged             : constant Unicode_Char := 16#0832#;
   Samaritan_Punctuation_Bau               : constant Unicode_Char := 16#0833#;
   Samaritan_Punctuation_Atmaau            : constant Unicode_Char := 16#0834#;
   Samaritan_Punctuation_Shiyyaalaa        : constant Unicode_Char := 16#0835#;
   Samaritan_Abbreviation_Mark             : constant Unicode_Char := 16#0836#;
   Samaritan_Punctuation_Melodic_Qitsa     : constant Unicode_Char := 16#0837#;
   Samaritan_Punctuation_Ziqaa             : constant Unicode_Char := 16#0838#;
   Samaritan_Punctuation_Qitsa             : constant Unicode_Char := 16#0839#;
   Samaritan_Punctuation_Zaef              : constant Unicode_Char := 16#083A#;
   Samaritan_Punctuation_Turu              : constant Unicode_Char := 16#083B#;
   Samaritan_Punctuation_Arkaanu           : constant Unicode_Char := 16#083C#;
   Samaritan_Punctuation_Sof_Mashfaat      : constant Unicode_Char := 16#083D#;
   Samaritan_Punctuation_Annaau            : constant Unicode_Char := 16#083E#;
end Unicode.Names.Samaritan;
