--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Sora_Sompeng is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Sora_Sompeng_Letter_Sah                 :
      constant Unicode_Char := 16#110D0#;
   Sora_Sompeng_Letter_Tah                 :
      constant Unicode_Char := 16#110D1#;
   Sora_Sompeng_Letter_Bah                 :
      constant Unicode_Char := 16#110D2#;
   Sora_Sompeng_Letter_Cah                 :
      constant Unicode_Char := 16#110D3#;
   Sora_Sompeng_Letter_Dah                 :
      constant Unicode_Char := 16#110D4#;
   Sora_Sompeng_Letter_Gah                 :
      constant Unicode_Char := 16#110D5#;
   Sora_Sompeng_Letter_Mah                 :
      constant Unicode_Char := 16#110D6#;
   Sora_Sompeng_Letter_Ngah                :
      constant Unicode_Char := 16#110D7#;
   Sora_Sompeng_Letter_Lah                 :
      constant Unicode_Char := 16#110D8#;
   Sora_Sompeng_Letter_Nah                 :
      constant Unicode_Char := 16#110D9#;
   Sora_Sompeng_Letter_Vah                 :
      constant Unicode_Char := 16#110DA#;
   Sora_Sompeng_Letter_Pah                 :
      constant Unicode_Char := 16#110DB#;
   Sora_Sompeng_Letter_Yah                 :
      constant Unicode_Char := 16#110DC#;
   Sora_Sompeng_Letter_Rah                 :
      constant Unicode_Char := 16#110DD#;
   Sora_Sompeng_Letter_Hah                 :
      constant Unicode_Char := 16#110DE#;
   Sora_Sompeng_Letter_Kah                 :
      constant Unicode_Char := 16#110DF#;
   Sora_Sompeng_Letter_Jah                 :
      constant Unicode_Char := 16#110E0#;
   Sora_Sompeng_Letter_Nyah                :
      constant Unicode_Char := 16#110E1#;
   Sora_Sompeng_Letter_Ah                  :
      constant Unicode_Char := 16#110E2#;
   Sora_Sompeng_Letter_Eeh                 :
      constant Unicode_Char := 16#110E3#;
   Sora_Sompeng_Letter_Ih                  :
      constant Unicode_Char := 16#110E4#;
   Sora_Sompeng_Letter_Uh                  :
      constant Unicode_Char := 16#110E5#;
   Sora_Sompeng_Letter_Oh                  :
      constant Unicode_Char := 16#110E6#;
   Sora_Sompeng_Letter_Eh                  :
      constant Unicode_Char := 16#110E7#;
   Sora_Sompeng_Letter_Mae                 :
      constant Unicode_Char := 16#110E8#;
   Sora_Sompeng_Digit_Zero                 :
      constant Unicode_Char := 16#110F0#;
   Sora_Sompeng_Digit_One                  :
      constant Unicode_Char := 16#110F1#;
   Sora_Sompeng_Digit_Two                  :
      constant Unicode_Char := 16#110F2#;
   Sora_Sompeng_Digit_Three                :
      constant Unicode_Char := 16#110F3#;
   Sora_Sompeng_Digit_Four                 :
      constant Unicode_Char := 16#110F4#;
   Sora_Sompeng_Digit_Five                 :
      constant Unicode_Char := 16#110F5#;
   Sora_Sompeng_Digit_Six                  :
      constant Unicode_Char := 16#110F6#;
   Sora_Sompeng_Digit_Seven                :
      constant Unicode_Char := 16#110F7#;
   Sora_Sompeng_Digit_Eight                :
      constant Unicode_Char := 16#110F8#;
   Sora_Sompeng_Digit_Nine                 :
      constant Unicode_Char := 16#110F9#;
end Unicode.Names.Sora_Sompeng;
