--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Myanmar_Extended_B is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Myanmar_Letter_Shan_Gha                 : constant Unicode_Char := 16#A9E0#;
   Myanmar_Letter_Shan_Cha                 : constant Unicode_Char := 16#A9E1#;
   Myanmar_Letter_Shan_Jha                 : constant Unicode_Char := 16#A9E2#;
   Myanmar_Letter_Shan_Nna                 : constant Unicode_Char := 16#A9E3#;
   Myanmar_Letter_Shan_Bha                 : constant Unicode_Char := 16#A9E4#;
   Myanmar_Sign_Shan_Saw                   : constant Unicode_Char := 16#A9E5#;
   Myanmar_Modifier_Letter_Shan_Reduplication :
      constant Unicode_Char := 16#A9E6#;
   Myanmar_Letter_Tai_Laing_Nya            : constant Unicode_Char := 16#A9E7#;
   Myanmar_Letter_Tai_Laing_Fa             : constant Unicode_Char := 16#A9E8#;
   Myanmar_Letter_Tai_Laing_Ga             : constant Unicode_Char := 16#A9E9#;
   Myanmar_Letter_Tai_Laing_Gha            : constant Unicode_Char := 16#A9EA#;
   Myanmar_Letter_Tai_Laing_Ja             : constant Unicode_Char := 16#A9EB#;
   Myanmar_Letter_Tai_Laing_Jha            : constant Unicode_Char := 16#A9EC#;
   Myanmar_Letter_Tai_Laing_Dda            : constant Unicode_Char := 16#A9ED#;
   Myanmar_Letter_Tai_Laing_Ddha           : constant Unicode_Char := 16#A9EE#;
   Myanmar_Letter_Tai_Laing_Nna            : constant Unicode_Char := 16#A9EF#;
   Myanmar_Tai_Laing_Digit_Zero            : constant Unicode_Char := 16#A9F0#;
   Myanmar_Tai_Laing_Digit_One             : constant Unicode_Char := 16#A9F1#;
   Myanmar_Tai_Laing_Digit_Two             : constant Unicode_Char := 16#A9F2#;
   Myanmar_Tai_Laing_Digit_Three           : constant Unicode_Char := 16#A9F3#;
   Myanmar_Tai_Laing_Digit_Four            : constant Unicode_Char := 16#A9F4#;
   Myanmar_Tai_Laing_Digit_Five            : constant Unicode_Char := 16#A9F5#;
   Myanmar_Tai_Laing_Digit_Six             : constant Unicode_Char := 16#A9F6#;
   Myanmar_Tai_Laing_Digit_Seven           : constant Unicode_Char := 16#A9F7#;
   Myanmar_Tai_Laing_Digit_Eight           : constant Unicode_Char := 16#A9F8#;
   Myanmar_Tai_Laing_Digit_Nine            : constant Unicode_Char := 16#A9F9#;
   Myanmar_Letter_Tai_Laing_Lla            : constant Unicode_Char := 16#A9FA#;
   Myanmar_Letter_Tai_Laing_Da             : constant Unicode_Char := 16#A9FB#;
   Myanmar_Letter_Tai_Laing_Dha            : constant Unicode_Char := 16#A9FC#;
   Myanmar_Letter_Tai_Laing_Ba             : constant Unicode_Char := 16#A9FD#;
   Myanmar_Letter_Tai_Laing_Bha            : constant Unicode_Char := 16#A9FE#;
end Unicode.Names.Myanmar_Extended_B;
