--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Half_Full_Width_Forms is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Fullwidth_Exclamation_Mark              : constant Unicode_Char := 16#FF01#;
   Fullwidth_Quotation_Mark                : constant Unicode_Char := 16#FF02#;
   Fullwidth_Number_Sign                   : constant Unicode_Char := 16#FF03#;
   Fullwidth_Dollar_Sign                   : constant Unicode_Char := 16#FF04#;
   Fullwidth_Percent_Sign                  : constant Unicode_Char := 16#FF05#;
   Fullwidth_Ampersand                     : constant Unicode_Char := 16#FF06#;
   Fullwidth_Apostrophe                    : constant Unicode_Char := 16#FF07#;
   Fullwidth_Left_Parenthesis              : constant Unicode_Char := 16#FF08#;
   Fullwidth_Right_Parenthesis             : constant Unicode_Char := 16#FF09#;
   Fullwidth_Asterisk                      : constant Unicode_Char := 16#FF0A#;
   Fullwidth_Plus_Sign                     : constant Unicode_Char := 16#FF0B#;
   Fullwidth_Comma                         : constant Unicode_Char := 16#FF0C#;
   Fullwidth_Hyphen_Minus                  : constant Unicode_Char := 16#FF0D#;
   Fullwidth_Full_Stop                     : constant Unicode_Char := 16#FF0E#;
   Fullwidth_Solidus                       : constant Unicode_Char := 16#FF0F#;
   Fullwidth_Digit_Zero                    : constant Unicode_Char := 16#FF10#;
   Fullwidth_Digit_One                     : constant Unicode_Char := 16#FF11#;
   Fullwidth_Digit_Two                     : constant Unicode_Char := 16#FF12#;
   Fullwidth_Digit_Three                   : constant Unicode_Char := 16#FF13#;
   Fullwidth_Digit_Four                    : constant Unicode_Char := 16#FF14#;
   Fullwidth_Digit_Five                    : constant Unicode_Char := 16#FF15#;
   Fullwidth_Digit_Six                     : constant Unicode_Char := 16#FF16#;
   Fullwidth_Digit_Seven                   : constant Unicode_Char := 16#FF17#;
   Fullwidth_Digit_Eight                   : constant Unicode_Char := 16#FF18#;
   Fullwidth_Digit_Nine                    : constant Unicode_Char := 16#FF19#;
   Fullwidth_Colon                         : constant Unicode_Char := 16#FF1A#;
   Fullwidth_Semicolon                     : constant Unicode_Char := 16#FF1B#;
   Fullwidth_Less_Than_Sign                : constant Unicode_Char := 16#FF1C#;
   Fullwidth_Equals_Sign                   : constant Unicode_Char := 16#FF1D#;
   Fullwidth_Greater_Than_Sign             : constant Unicode_Char := 16#FF1E#;
   Fullwidth_Question_Mark                 : constant Unicode_Char := 16#FF1F#;
   Fullwidth_Commercial_At                 : constant Unicode_Char := 16#FF20#;
   Fullwidth_Latin_Capital_Letter_A        : constant Unicode_Char := 16#FF21#;
   Fullwidth_Latin_Capital_Letter_B        : constant Unicode_Char := 16#FF22#;
   Fullwidth_Latin_Capital_Letter_C        : constant Unicode_Char := 16#FF23#;
   Fullwidth_Latin_Capital_Letter_D        : constant Unicode_Char := 16#FF24#;
   Fullwidth_Latin_Capital_Letter_E        : constant Unicode_Char := 16#FF25#;
   Fullwidth_Latin_Capital_Letter_F        : constant Unicode_Char := 16#FF26#;
   Fullwidth_Latin_Capital_Letter_G        : constant Unicode_Char := 16#FF27#;
   Fullwidth_Latin_Capital_Letter_H        : constant Unicode_Char := 16#FF28#;
   Fullwidth_Latin_Capital_Letter_I        : constant Unicode_Char := 16#FF29#;
   Fullwidth_Latin_Capital_Letter_J        : constant Unicode_Char := 16#FF2A#;
   Fullwidth_Latin_Capital_Letter_K        : constant Unicode_Char := 16#FF2B#;
   Fullwidth_Latin_Capital_Letter_L        : constant Unicode_Char := 16#FF2C#;
   Fullwidth_Latin_Capital_Letter_M        : constant Unicode_Char := 16#FF2D#;
   Fullwidth_Latin_Capital_Letter_N        : constant Unicode_Char := 16#FF2E#;
   Fullwidth_Latin_Capital_Letter_O        : constant Unicode_Char := 16#FF2F#;
   Fullwidth_Latin_Capital_Letter_P        : constant Unicode_Char := 16#FF30#;
   Fullwidth_Latin_Capital_Letter_Q        : constant Unicode_Char := 16#FF31#;
   Fullwidth_Latin_Capital_Letter_R        : constant Unicode_Char := 16#FF32#;
   Fullwidth_Latin_Capital_Letter_S        : constant Unicode_Char := 16#FF33#;
   Fullwidth_Latin_Capital_Letter_T        : constant Unicode_Char := 16#FF34#;
   Fullwidth_Latin_Capital_Letter_U        : constant Unicode_Char := 16#FF35#;
   Fullwidth_Latin_Capital_Letter_V        : constant Unicode_Char := 16#FF36#;
   Fullwidth_Latin_Capital_Letter_W        : constant Unicode_Char := 16#FF37#;
   Fullwidth_Latin_Capital_Letter_X        : constant Unicode_Char := 16#FF38#;
   Fullwidth_Latin_Capital_Letter_Y        : constant Unicode_Char := 16#FF39#;
   Fullwidth_Latin_Capital_Letter_Z        : constant Unicode_Char := 16#FF3A#;
   Fullwidth_Left_Square_Bracket           : constant Unicode_Char := 16#FF3B#;
   Fullwidth_Reverse_Solidus               : constant Unicode_Char := 16#FF3C#;
   Fullwidth_Right_Square_Bracket          : constant Unicode_Char := 16#FF3D#;
   Fullwidth_Circumflex_Accent             : constant Unicode_Char := 16#FF3E#;
   Fullwidth_Low_Line                      : constant Unicode_Char := 16#FF3F#;
   Fullwidth_Grave_Accent                  : constant Unicode_Char := 16#FF40#;
   Fullwidth_Latin_Small_Letter_A          : constant Unicode_Char := 16#FF41#;
   Fullwidth_Latin_Small_Letter_B          : constant Unicode_Char := 16#FF42#;
   Fullwidth_Latin_Small_Letter_C          : constant Unicode_Char := 16#FF43#;
   Fullwidth_Latin_Small_Letter_D          : constant Unicode_Char := 16#FF44#;
   Fullwidth_Latin_Small_Letter_E          : constant Unicode_Char := 16#FF45#;
   Fullwidth_Latin_Small_Letter_F          : constant Unicode_Char := 16#FF46#;
   Fullwidth_Latin_Small_Letter_G          : constant Unicode_Char := 16#FF47#;
   Fullwidth_Latin_Small_Letter_H          : constant Unicode_Char := 16#FF48#;
   Fullwidth_Latin_Small_Letter_I          : constant Unicode_Char := 16#FF49#;
   Fullwidth_Latin_Small_Letter_J          : constant Unicode_Char := 16#FF4A#;
   Fullwidth_Latin_Small_Letter_K          : constant Unicode_Char := 16#FF4B#;
   Fullwidth_Latin_Small_Letter_L          : constant Unicode_Char := 16#FF4C#;
   Fullwidth_Latin_Small_Letter_M          : constant Unicode_Char := 16#FF4D#;
   Fullwidth_Latin_Small_Letter_N          : constant Unicode_Char := 16#FF4E#;
   Fullwidth_Latin_Small_Letter_O          : constant Unicode_Char := 16#FF4F#;
   Fullwidth_Latin_Small_Letter_P          : constant Unicode_Char := 16#FF50#;
   Fullwidth_Latin_Small_Letter_Q          : constant Unicode_Char := 16#FF51#;
   Fullwidth_Latin_Small_Letter_R          : constant Unicode_Char := 16#FF52#;
   Fullwidth_Latin_Small_Letter_S          : constant Unicode_Char := 16#FF53#;
   Fullwidth_Latin_Small_Letter_T          : constant Unicode_Char := 16#FF54#;
   Fullwidth_Latin_Small_Letter_U          : constant Unicode_Char := 16#FF55#;
   Fullwidth_Latin_Small_Letter_V          : constant Unicode_Char := 16#FF56#;
   Fullwidth_Latin_Small_Letter_W          : constant Unicode_Char := 16#FF57#;
   Fullwidth_Latin_Small_Letter_X          : constant Unicode_Char := 16#FF58#;
   Fullwidth_Latin_Small_Letter_Y          : constant Unicode_Char := 16#FF59#;
   Fullwidth_Latin_Small_Letter_Z          : constant Unicode_Char := 16#FF5A#;
   Fullwidth_Left_Curly_Bracket            : constant Unicode_Char := 16#FF5B#;
   Fullwidth_Vertical_Line                 : constant Unicode_Char := 16#FF5C#;
   Fullwidth_Right_Curly_Bracket           : constant Unicode_Char := 16#FF5D#;
   Fullwidth_Tilde                         : constant Unicode_Char := 16#FF5E#;
   Fullwidth_Left_White_Parenthesis        : constant Unicode_Char := 16#FF5F#;
   Fullwidth_Right_White_Parenthesis       : constant Unicode_Char := 16#FF60#;
   Halfwidth_Ideographic_Full_Stop         : constant Unicode_Char := 16#FF61#;
   Halfwidth_Left_Corner_Bracket           : constant Unicode_Char := 16#FF62#;
   Halfwidth_Right_Corner_Bracket          : constant Unicode_Char := 16#FF63#;
   Halfwidth_Ideographic_Comma             : constant Unicode_Char := 16#FF64#;
   Halfwidth_Katakana_Middle_Dot           : constant Unicode_Char := 16#FF65#;
   Halfwidth_Katakana_Letter_Wo            : constant Unicode_Char := 16#FF66#;
   Halfwidth_Katakana_Letter_Small_A       : constant Unicode_Char := 16#FF67#;
   Halfwidth_Katakana_Letter_Small_I       : constant Unicode_Char := 16#FF68#;
   Halfwidth_Katakana_Letter_Small_U       : constant Unicode_Char := 16#FF69#;
   Halfwidth_Katakana_Letter_Small_E       : constant Unicode_Char := 16#FF6A#;
   Halfwidth_Katakana_Letter_Small_O       : constant Unicode_Char := 16#FF6B#;
   Halfwidth_Katakana_Letter_Small_Ya      : constant Unicode_Char := 16#FF6C#;
   Halfwidth_Katakana_Letter_Small_Yu      : constant Unicode_Char := 16#FF6D#;
   Halfwidth_Katakana_Letter_Small_Yo      : constant Unicode_Char := 16#FF6E#;
   Halfwidth_Katakana_Letter_Small_Tu      : constant Unicode_Char := 16#FF6F#;
   Halfwidth_Katakana_Hiragana_Prolonged_Sound_Mark :
      constant Unicode_Char := 16#FF70#;
   Halfwidth_Katakana_Letter_A             : constant Unicode_Char := 16#FF71#;
   Halfwidth_Katakana_Letter_I             : constant Unicode_Char := 16#FF72#;
   Halfwidth_Katakana_Letter_U             : constant Unicode_Char := 16#FF73#;
   Halfwidth_Katakana_Letter_E             : constant Unicode_Char := 16#FF74#;
   Halfwidth_Katakana_Letter_O             : constant Unicode_Char := 16#FF75#;
   Halfwidth_Katakana_Letter_Ka            : constant Unicode_Char := 16#FF76#;
   Halfwidth_Katakana_Letter_Ki            : constant Unicode_Char := 16#FF77#;
   Halfwidth_Katakana_Letter_Ku            : constant Unicode_Char := 16#FF78#;
   Halfwidth_Katakana_Letter_Ke            : constant Unicode_Char := 16#FF79#;
   Halfwidth_Katakana_Letter_Ko            : constant Unicode_Char := 16#FF7A#;
   Halfwidth_Katakana_Letter_Sa            : constant Unicode_Char := 16#FF7B#;
   Halfwidth_Katakana_Letter_Si            : constant Unicode_Char := 16#FF7C#;
   Halfwidth_Katakana_Letter_Su            : constant Unicode_Char := 16#FF7D#;
   Halfwidth_Katakana_Letter_Se            : constant Unicode_Char := 16#FF7E#;
   Halfwidth_Katakana_Letter_So            : constant Unicode_Char := 16#FF7F#;
   Halfwidth_Katakana_Letter_Ta            : constant Unicode_Char := 16#FF80#;
   Halfwidth_Katakana_Letter_Ti            : constant Unicode_Char := 16#FF81#;
   Halfwidth_Katakana_Letter_Tu            : constant Unicode_Char := 16#FF82#;
   Halfwidth_Katakana_Letter_Te            : constant Unicode_Char := 16#FF83#;
   Halfwidth_Katakana_Letter_To            : constant Unicode_Char := 16#FF84#;
   Halfwidth_Katakana_Letter_Na            : constant Unicode_Char := 16#FF85#;
   Halfwidth_Katakana_Letter_Ni            : constant Unicode_Char := 16#FF86#;
   Halfwidth_Katakana_Letter_Nu            : constant Unicode_Char := 16#FF87#;
   Halfwidth_Katakana_Letter_Ne            : constant Unicode_Char := 16#FF88#;
   Halfwidth_Katakana_Letter_No            : constant Unicode_Char := 16#FF89#;
   Halfwidth_Katakana_Letter_Ha            : constant Unicode_Char := 16#FF8A#;
   Halfwidth_Katakana_Letter_Hi            : constant Unicode_Char := 16#FF8B#;
   Halfwidth_Katakana_Letter_Hu            : constant Unicode_Char := 16#FF8C#;
   Halfwidth_Katakana_Letter_He            : constant Unicode_Char := 16#FF8D#;
   Halfwidth_Katakana_Letter_Ho            : constant Unicode_Char := 16#FF8E#;
   Halfwidth_Katakana_Letter_Ma            : constant Unicode_Char := 16#FF8F#;
   Halfwidth_Katakana_Letter_Mi            : constant Unicode_Char := 16#FF90#;
   Halfwidth_Katakana_Letter_Mu            : constant Unicode_Char := 16#FF91#;
   Halfwidth_Katakana_Letter_Me            : constant Unicode_Char := 16#FF92#;
   Halfwidth_Katakana_Letter_Mo            : constant Unicode_Char := 16#FF93#;
   Halfwidth_Katakana_Letter_Ya            : constant Unicode_Char := 16#FF94#;
   Halfwidth_Katakana_Letter_Yu            : constant Unicode_Char := 16#FF95#;
   Halfwidth_Katakana_Letter_Yo            : constant Unicode_Char := 16#FF96#;
   Halfwidth_Katakana_Letter_Ra            : constant Unicode_Char := 16#FF97#;
   Halfwidth_Katakana_Letter_Ri            : constant Unicode_Char := 16#FF98#;
   Halfwidth_Katakana_Letter_Ru            : constant Unicode_Char := 16#FF99#;
   Halfwidth_Katakana_Letter_Re            : constant Unicode_Char := 16#FF9A#;
   Halfwidth_Katakana_Letter_Ro            : constant Unicode_Char := 16#FF9B#;
   Halfwidth_Katakana_Letter_Wa            : constant Unicode_Char := 16#FF9C#;
   Halfwidth_Katakana_Letter_N             : constant Unicode_Char := 16#FF9D#;
   Halfwidth_Katakana_Voiced_Sound_Mark    : constant Unicode_Char := 16#FF9E#;
   Halfwidth_Katakana_Semi_Voiced_Sound_Mark :
      constant Unicode_Char := 16#FF9F#;
   Halfwidth_Hangul_Filler                 : constant Unicode_Char := 16#FFA0#;
   Halfwidth_Hangul_Letter_Kiyeok          : constant Unicode_Char := 16#FFA1#;
   Halfwidth_Hangul_Letter_Ssangkiyeok     : constant Unicode_Char := 16#FFA2#;
   Halfwidth_Hangul_Letter_Kiyeok_Sios     : constant Unicode_Char := 16#FFA3#;
   Halfwidth_Hangul_Letter_Nieun           : constant Unicode_Char := 16#FFA4#;
   Halfwidth_Hangul_Letter_Nieun_Cieuc     : constant Unicode_Char := 16#FFA5#;
   Halfwidth_Hangul_Letter_Nieun_Hieuh     : constant Unicode_Char := 16#FFA6#;
   Halfwidth_Hangul_Letter_Tikeut          : constant Unicode_Char := 16#FFA7#;
   Halfwidth_Hangul_Letter_Ssangtikeut     : constant Unicode_Char := 16#FFA8#;
   Halfwidth_Hangul_Letter_Rieul           : constant Unicode_Char := 16#FFA9#;
   Halfwidth_Hangul_Letter_Rieul_Kiyeok    : constant Unicode_Char := 16#FFAA#;
   Halfwidth_Hangul_Letter_Rieul_Mieum     : constant Unicode_Char := 16#FFAB#;
   Halfwidth_Hangul_Letter_Rieul_Pieup     : constant Unicode_Char := 16#FFAC#;
   Halfwidth_Hangul_Letter_Rieul_Sios      : constant Unicode_Char := 16#FFAD#;
   Halfwidth_Hangul_Letter_Rieul_Thieuth   : constant Unicode_Char := 16#FFAE#;
   Halfwidth_Hangul_Letter_Rieul_Phieuph   : constant Unicode_Char := 16#FFAF#;
   Halfwidth_Hangul_Letter_Rieul_Hieuh     : constant Unicode_Char := 16#FFB0#;
   Halfwidth_Hangul_Letter_Mieum           : constant Unicode_Char := 16#FFB1#;
   Halfwidth_Hangul_Letter_Pieup           : constant Unicode_Char := 16#FFB2#;
   Halfwidth_Hangul_Letter_Ssangpieup      : constant Unicode_Char := 16#FFB3#;
   Halfwidth_Hangul_Letter_Pieup_Sios      : constant Unicode_Char := 16#FFB4#;
   Halfwidth_Hangul_Letter_Sios            : constant Unicode_Char := 16#FFB5#;
   Halfwidth_Hangul_Letter_Ssangsios       : constant Unicode_Char := 16#FFB6#;
   Halfwidth_Hangul_Letter_Ieung           : constant Unicode_Char := 16#FFB7#;
   Halfwidth_Hangul_Letter_Cieuc           : constant Unicode_Char := 16#FFB8#;
   Halfwidth_Hangul_Letter_Ssangcieuc      : constant Unicode_Char := 16#FFB9#;
   Halfwidth_Hangul_Letter_Chieuch         : constant Unicode_Char := 16#FFBA#;
   Halfwidth_Hangul_Letter_Khieukh         : constant Unicode_Char := 16#FFBB#;
   Halfwidth_Hangul_Letter_Thieuth         : constant Unicode_Char := 16#FFBC#;
   Halfwidth_Hangul_Letter_Phieuph         : constant Unicode_Char := 16#FFBD#;
   Halfwidth_Hangul_Letter_Hieuh           : constant Unicode_Char := 16#FFBE#;
   Halfwidth_Hangul_Letter_A               : constant Unicode_Char := 16#FFC2#;
   Halfwidth_Hangul_Letter_Ae              : constant Unicode_Char := 16#FFC3#;
   Halfwidth_Hangul_Letter_Ya              : constant Unicode_Char := 16#FFC4#;
   Halfwidth_Hangul_Letter_Yae             : constant Unicode_Char := 16#FFC5#;
   Halfwidth_Hangul_Letter_Eo              : constant Unicode_Char := 16#FFC6#;
   Halfwidth_Hangul_Letter_E               : constant Unicode_Char := 16#FFC7#;
   Halfwidth_Hangul_Letter_Yeo             : constant Unicode_Char := 16#FFCA#;
   Halfwidth_Hangul_Letter_Ye              : constant Unicode_Char := 16#FFCB#;
   Halfwidth_Hangul_Letter_O               : constant Unicode_Char := 16#FFCC#;
   Halfwidth_Hangul_Letter_Wa              : constant Unicode_Char := 16#FFCD#;
   Halfwidth_Hangul_Letter_Wae             : constant Unicode_Char := 16#FFCE#;
   Halfwidth_Hangul_Letter_Oe              : constant Unicode_Char := 16#FFCF#;
   Halfwidth_Hangul_Letter_Yo              : constant Unicode_Char := 16#FFD2#;
   Halfwidth_Hangul_Letter_U               : constant Unicode_Char := 16#FFD3#;
   Halfwidth_Hangul_Letter_Weo             : constant Unicode_Char := 16#FFD4#;
   Halfwidth_Hangul_Letter_We              : constant Unicode_Char := 16#FFD5#;
   Halfwidth_Hangul_Letter_Wi              : constant Unicode_Char := 16#FFD6#;
   Halfwidth_Hangul_Letter_Yu              : constant Unicode_Char := 16#FFD7#;
   Halfwidth_Hangul_Letter_Eu              : constant Unicode_Char := 16#FFDA#;
   Halfwidth_Hangul_Letter_Yi              : constant Unicode_Char := 16#FFDB#;
   Halfwidth_Hangul_Letter_I               : constant Unicode_Char := 16#FFDC#;
   Fullwidth_Cent_Sign                     : constant Unicode_Char := 16#FFE0#;
   Fullwidth_Pound_Sign                    : constant Unicode_Char := 16#FFE1#;
   Fullwidth_Not_Sign                      : constant Unicode_Char := 16#FFE2#;
   Fullwidth_Macron                        : constant Unicode_Char := 16#FFE3#;
   Fullwidth_Broken_Bar                    : constant Unicode_Char := 16#FFE4#;
   Fullwidth_Yen_Sign                      : constant Unicode_Char := 16#FFE5#;
   Fullwidth_Won_Sign                      : constant Unicode_Char := 16#FFE6#;
   Halfwidth_Forms_Light_Vertical          : constant Unicode_Char := 16#FFE8#;
   Halfwidth_Leftwards_Arrow               : constant Unicode_Char := 16#FFE9#;
   Halfwidth_Upwards_Arrow                 : constant Unicode_Char := 16#FFEA#;
   Halfwidth_Rightwards_Arrow              : constant Unicode_Char := 16#FFEB#;
   Halfwidth_Downwards_Arrow               : constant Unicode_Char := 16#FFEC#;
   Halfwidth_Black_Square                  : constant Unicode_Char := 16#FFED#;
   Halfwidth_White_Circle                  : constant Unicode_Char := 16#FFEE#;
end Unicode.Names.Half_Full_Width_Forms;
