--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Geometric_Shapes_Extended is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Black_Left_Pointing_Isosceles_Right_Triangle :
      constant Unicode_Char := 16#1F780#;
   Black_Up_Pointing_Isosceles_Right_Triangle :
      constant Unicode_Char := 16#1F781#;
   Black_Right_Pointing_Isosceles_Right_Triangle :
      constant Unicode_Char := 16#1F782#;
   Black_Down_Pointing_Isosceles_Right_Triangle :
      constant Unicode_Char := 16#1F783#;
   Black_Slightly_Small_Circle             :
      constant Unicode_Char := 16#1F784#;
   Medium_Bold_White_Circle                :
      constant Unicode_Char := 16#1F785#;
   Bold_White_Circle                       :
      constant Unicode_Char := 16#1F786#;
   Heavy_White_Circle                      :
      constant Unicode_Char := 16#1F787#;
   Very_Heavy_White_Circle                 :
      constant Unicode_Char := 16#1F788#;
   Extremely_Heavy_White_Circle            :
      constant Unicode_Char := 16#1F789#;
   White_Circle_Containing_Black_Small_Circle :
      constant Unicode_Char := 16#1F78A#;
   Round_Target                            :
      constant Unicode_Char := 16#1F78B#;
   Black_Tiny_Square                       :
      constant Unicode_Char := 16#1F78C#;
   Black_Slightly_Small_Square             :
      constant Unicode_Char := 16#1F78D#;
   Light_White_Square                      :
      constant Unicode_Char := 16#1F78E#;
   Medium_White_Square                     :
      constant Unicode_Char := 16#1F78F#;
   Bold_White_Square                       :
      constant Unicode_Char := 16#1F790#;
   Heavy_White_Square                      :
      constant Unicode_Char := 16#1F791#;
   Very_Heavy_White_Square                 :
      constant Unicode_Char := 16#1F792#;
   Extremely_Heavy_White_Square            :
      constant Unicode_Char := 16#1F793#;
   White_Square_Containing_Black_Very_Small_Square :
      constant Unicode_Char := 16#1F794#;
   White_Square_Containing_Black_Medium_Square :
      constant Unicode_Char := 16#1F795#;
   Square_Target                           :
      constant Unicode_Char := 16#1F796#;
   Black_Tiny_Diamond                      :
      constant Unicode_Char := 16#1F797#;
   Black_Very_Small_Diamond                :
      constant Unicode_Char := 16#1F798#;
   Black_Medium_Small_Diamond              :
      constant Unicode_Char := 16#1F799#;
   White_Diamond_Containing_Black_Very_Small_Diamond :
      constant Unicode_Char := 16#1F79A#;
   White_Diamond_Containing_Black_Medium_Diamond :
      constant Unicode_Char := 16#1F79B#;
   Diamond_Target                          :
      constant Unicode_Char := 16#1F79C#;
   Black_Tiny_Lozenge                      :
      constant Unicode_Char := 16#1F79D#;
   Black_Very_Small_Lozenge                :
      constant Unicode_Char := 16#1F79E#;
   Black_Medium_Small_Lozenge              :
      constant Unicode_Char := 16#1F79F#;
   White_Lozenge_Containing_Black_Small_Lozenge :
      constant Unicode_Char := 16#1F7A0#;
   Thin_Greek_Cross                        :
      constant Unicode_Char := 16#1F7A1#;
   Light_Greek_Cross                       :
      constant Unicode_Char := 16#1F7A2#;
   Medium_Greek_Cross                      :
      constant Unicode_Char := 16#1F7A3#;
   Bold_Greek_Cross                        :
      constant Unicode_Char := 16#1F7A4#;
   Very_Bold_Greek_Cross                   :
      constant Unicode_Char := 16#1F7A5#;
   Very_Heavy_Greek_Cross                  :
      constant Unicode_Char := 16#1F7A6#;
   Extremely_Heavy_Greek_Cross             :
      constant Unicode_Char := 16#1F7A7#;
   Thin_Saltire                            :
      constant Unicode_Char := 16#1F7A8#;
   Light_Saltire                           :
      constant Unicode_Char := 16#1F7A9#;
   Medium_Saltire                          :
      constant Unicode_Char := 16#1F7AA#;
   Bold_Saltire                            :
      constant Unicode_Char := 16#1F7AB#;
   Heavy_Saltire                           :
      constant Unicode_Char := 16#1F7AC#;
   Very_Heavy_Saltire                      :
      constant Unicode_Char := 16#1F7AD#;
   Extremely_Heavy_Saltire                 :
      constant Unicode_Char := 16#1F7AE#;
   Light_Five_Spoked_Asterisk              :
      constant Unicode_Char := 16#1F7AF#;
   Medium_Five_Spoked_Asterisk             :
      constant Unicode_Char := 16#1F7B0#;
   Bold_Five_Spoked_Asterisk               :
      constant Unicode_Char := 16#1F7B1#;
   Heavy_Five_Spoked_Asterisk              :
      constant Unicode_Char := 16#1F7B2#;
   Very_Heavy_Five_Spoked_Asterisk         :
      constant Unicode_Char := 16#1F7B3#;
   Extremely_Heavy_Five_Spoked_Asterisk    :
      constant Unicode_Char := 16#1F7B4#;
   Light_Six_Spoked_Asterisk               :
      constant Unicode_Char := 16#1F7B5#;
   Medium_Six_Spoked_Asterisk              :
      constant Unicode_Char := 16#1F7B6#;
   Bold_Six_Spoked_Asterisk                :
      constant Unicode_Char := 16#1F7B7#;
   Heavy_Six_Spoked_Asterisk               :
      constant Unicode_Char := 16#1F7B8#;
   Very_Heavy_Six_Spoked_Asterisk          :
      constant Unicode_Char := 16#1F7B9#;
   Extremely_Heavy_Six_Spoked_Asterisk     :
      constant Unicode_Char := 16#1F7BA#;
   Light_Eight_Spoked_Asterisk             :
      constant Unicode_Char := 16#1F7BB#;
   Medium_Eight_Spoked_Asterisk            :
      constant Unicode_Char := 16#1F7BC#;
   Bold_Eight_Spoked_Asterisk              :
      constant Unicode_Char := 16#1F7BD#;
   Heavy_Eight_Spoked_Asterisk             :
      constant Unicode_Char := 16#1F7BE#;
   Very_Heavy_Eight_Spoked_Asterisk        :
      constant Unicode_Char := 16#1F7BF#;
   Light_Three_Pointed_Black_Star          :
      constant Unicode_Char := 16#1F7C0#;
   Medium_Three_Pointed_Black_Star         :
      constant Unicode_Char := 16#1F7C1#;
   Three_Pointed_Black_Star                :
      constant Unicode_Char := 16#1F7C2#;
   Medium_Three_Pointed_Pinwheel_Star      :
      constant Unicode_Char := 16#1F7C3#;
   Light_Four_Pointed_Black_Star           :
      constant Unicode_Char := 16#1F7C4#;
   Medium_Four_Pointed_Black_Star          :
      constant Unicode_Char := 16#1F7C5#;
   Four_Pointed_Black_Star                 :
      constant Unicode_Char := 16#1F7C6#;
   Medium_Four_Pointed_Pinwheel_Star       :
      constant Unicode_Char := 16#1F7C7#;
   Reverse_Light_Four_Pointed_Pinwheel_Star :
      constant Unicode_Char := 16#1F7C8#;
   Light_Five_Pointed_Black_Star           :
      constant Unicode_Char := 16#1F7C9#;
   Heavy_Five_Pointed_Black_Star           :
      constant Unicode_Char := 16#1F7CA#;
   Medium_Six_Pointed_Black_Star           :
      constant Unicode_Char := 16#1F7CB#;
   Heavy_Six_Pointed_Black_Star            :
      constant Unicode_Char := 16#1F7CC#;
   Six_Pointed_Pinwheel_Star               :
      constant Unicode_Char := 16#1F7CD#;
   Medium_Eight_Pointed_Black_Star         :
      constant Unicode_Char := 16#1F7CE#;
   Heavy_Eight_Pointed_Black_Star          :
      constant Unicode_Char := 16#1F7CF#;
   Very_Heavy_Eight_Pointed_Black_Star     :
      constant Unicode_Char := 16#1F7D0#;
   Heavy_Eight_Pointed_Pinwheel_Star       :
      constant Unicode_Char := 16#1F7D1#;
   Light_Twelve_Pointed_Black_Star         :
      constant Unicode_Char := 16#1F7D2#;
   Heavy_Twelve_Pointed_Black_Star         :
      constant Unicode_Char := 16#1F7D3#;
   Heavy_Twelve_Pointed_Pinwheel_Star      :
      constant Unicode_Char := 16#1F7D4#;
end Unicode.Names.Geometric_Shapes_Extended;
