--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cjk_Compat_Ideo_Sup is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cjk_Compatibility_Ideograph_2f800       :
      constant Unicode_Char := 16#2F800#;
   Cjk_Compatibility_Ideograph_2f801       :
      constant Unicode_Char := 16#2F801#;
   Cjk_Compatibility_Ideograph_2f802       :
      constant Unicode_Char := 16#2F802#;
   Cjk_Compatibility_Ideograph_2f803       :
      constant Unicode_Char := 16#2F803#;
   Cjk_Compatibility_Ideograph_2f804       :
      constant Unicode_Char := 16#2F804#;
   Cjk_Compatibility_Ideograph_2f805       :
      constant Unicode_Char := 16#2F805#;
   Cjk_Compatibility_Ideograph_2f806       :
      constant Unicode_Char := 16#2F806#;
   Cjk_Compatibility_Ideograph_2f807       :
      constant Unicode_Char := 16#2F807#;
   Cjk_Compatibility_Ideograph_2f808       :
      constant Unicode_Char := 16#2F808#;
   Cjk_Compatibility_Ideograph_2f809       :
      constant Unicode_Char := 16#2F809#;
   Cjk_Compatibility_Ideograph_2f80a       :
      constant Unicode_Char := 16#2F80A#;
   Cjk_Compatibility_Ideograph_2f80b       :
      constant Unicode_Char := 16#2F80B#;
   Cjk_Compatibility_Ideograph_2f80c       :
      constant Unicode_Char := 16#2F80C#;
   Cjk_Compatibility_Ideograph_2f80d       :
      constant Unicode_Char := 16#2F80D#;
   Cjk_Compatibility_Ideograph_2f80e       :
      constant Unicode_Char := 16#2F80E#;
   Cjk_Compatibility_Ideograph_2f80f       :
      constant Unicode_Char := 16#2F80F#;
   Cjk_Compatibility_Ideograph_2f810       :
      constant Unicode_Char := 16#2F810#;
   Cjk_Compatibility_Ideograph_2f811       :
      constant Unicode_Char := 16#2F811#;
   Cjk_Compatibility_Ideograph_2f812       :
      constant Unicode_Char := 16#2F812#;
   Cjk_Compatibility_Ideograph_2f813       :
      constant Unicode_Char := 16#2F813#;
   Cjk_Compatibility_Ideograph_2f814       :
      constant Unicode_Char := 16#2F814#;
   Cjk_Compatibility_Ideograph_2f815       :
      constant Unicode_Char := 16#2F815#;
   Cjk_Compatibility_Ideograph_2f816       :
      constant Unicode_Char := 16#2F816#;
   Cjk_Compatibility_Ideograph_2f817       :
      constant Unicode_Char := 16#2F817#;
   Cjk_Compatibility_Ideograph_2f818       :
      constant Unicode_Char := 16#2F818#;
   Cjk_Compatibility_Ideograph_2f819       :
      constant Unicode_Char := 16#2F819#;
   Cjk_Compatibility_Ideograph_2f81a       :
      constant Unicode_Char := 16#2F81A#;
   Cjk_Compatibility_Ideograph_2f81b       :
      constant Unicode_Char := 16#2F81B#;
   Cjk_Compatibility_Ideograph_2f81c       :
      constant Unicode_Char := 16#2F81C#;
   Cjk_Compatibility_Ideograph_2f81d       :
      constant Unicode_Char := 16#2F81D#;
   Cjk_Compatibility_Ideograph_2f81e       :
      constant Unicode_Char := 16#2F81E#;
   Cjk_Compatibility_Ideograph_2f81f       :
      constant Unicode_Char := 16#2F81F#;
   Cjk_Compatibility_Ideograph_2f820       :
      constant Unicode_Char := 16#2F820#;
   Cjk_Compatibility_Ideograph_2f821       :
      constant Unicode_Char := 16#2F821#;
   Cjk_Compatibility_Ideograph_2f822       :
      constant Unicode_Char := 16#2F822#;
   Cjk_Compatibility_Ideograph_2f823       :
      constant Unicode_Char := 16#2F823#;
   Cjk_Compatibility_Ideograph_2f824       :
      constant Unicode_Char := 16#2F824#;
   Cjk_Compatibility_Ideograph_2f825       :
      constant Unicode_Char := 16#2F825#;
   Cjk_Compatibility_Ideograph_2f826       :
      constant Unicode_Char := 16#2F826#;
   Cjk_Compatibility_Ideograph_2f827       :
      constant Unicode_Char := 16#2F827#;
   Cjk_Compatibility_Ideograph_2f828       :
      constant Unicode_Char := 16#2F828#;
   Cjk_Compatibility_Ideograph_2f829       :
      constant Unicode_Char := 16#2F829#;
   Cjk_Compatibility_Ideograph_2f82a       :
      constant Unicode_Char := 16#2F82A#;
   Cjk_Compatibility_Ideograph_2f82b       :
      constant Unicode_Char := 16#2F82B#;
   Cjk_Compatibility_Ideograph_2f82c       :
      constant Unicode_Char := 16#2F82C#;
   Cjk_Compatibility_Ideograph_2f82d       :
      constant Unicode_Char := 16#2F82D#;
   Cjk_Compatibility_Ideograph_2f82e       :
      constant Unicode_Char := 16#2F82E#;
   Cjk_Compatibility_Ideograph_2f82f       :
      constant Unicode_Char := 16#2F82F#;
   Cjk_Compatibility_Ideograph_2f830       :
      constant Unicode_Char := 16#2F830#;
   Cjk_Compatibility_Ideograph_2f831       :
      constant Unicode_Char := 16#2F831#;
   Cjk_Compatibility_Ideograph_2f832       :
      constant Unicode_Char := 16#2F832#;
   Cjk_Compatibility_Ideograph_2f833       :
      constant Unicode_Char := 16#2F833#;
   Cjk_Compatibility_Ideograph_2f834       :
      constant Unicode_Char := 16#2F834#;
   Cjk_Compatibility_Ideograph_2f835       :
      constant Unicode_Char := 16#2F835#;
   Cjk_Compatibility_Ideograph_2f836       :
      constant Unicode_Char := 16#2F836#;
   Cjk_Compatibility_Ideograph_2f837       :
      constant Unicode_Char := 16#2F837#;
   Cjk_Compatibility_Ideograph_2f838       :
      constant Unicode_Char := 16#2F838#;
   Cjk_Compatibility_Ideograph_2f839       :
      constant Unicode_Char := 16#2F839#;
   Cjk_Compatibility_Ideograph_2f83a       :
      constant Unicode_Char := 16#2F83A#;
   Cjk_Compatibility_Ideograph_2f83b       :
      constant Unicode_Char := 16#2F83B#;
   Cjk_Compatibility_Ideograph_2f83c       :
      constant Unicode_Char := 16#2F83C#;
   Cjk_Compatibility_Ideograph_2f83d       :
      constant Unicode_Char := 16#2F83D#;
   Cjk_Compatibility_Ideograph_2f83e       :
      constant Unicode_Char := 16#2F83E#;
   Cjk_Compatibility_Ideograph_2f83f       :
      constant Unicode_Char := 16#2F83F#;
   Cjk_Compatibility_Ideograph_2f840       :
      constant Unicode_Char := 16#2F840#;
   Cjk_Compatibility_Ideograph_2f841       :
      constant Unicode_Char := 16#2F841#;
   Cjk_Compatibility_Ideograph_2f842       :
      constant Unicode_Char := 16#2F842#;
   Cjk_Compatibility_Ideograph_2f843       :
      constant Unicode_Char := 16#2F843#;
   Cjk_Compatibility_Ideograph_2f844       :
      constant Unicode_Char := 16#2F844#;
   Cjk_Compatibility_Ideograph_2f845       :
      constant Unicode_Char := 16#2F845#;
   Cjk_Compatibility_Ideograph_2f846       :
      constant Unicode_Char := 16#2F846#;
   Cjk_Compatibility_Ideograph_2f847       :
      constant Unicode_Char := 16#2F847#;
   Cjk_Compatibility_Ideograph_2f848       :
      constant Unicode_Char := 16#2F848#;
   Cjk_Compatibility_Ideograph_2f849       :
      constant Unicode_Char := 16#2F849#;
   Cjk_Compatibility_Ideograph_2f84a       :
      constant Unicode_Char := 16#2F84A#;
   Cjk_Compatibility_Ideograph_2f84b       :
      constant Unicode_Char := 16#2F84B#;
   Cjk_Compatibility_Ideograph_2f84c       :
      constant Unicode_Char := 16#2F84C#;
   Cjk_Compatibility_Ideograph_2f84d       :
      constant Unicode_Char := 16#2F84D#;
   Cjk_Compatibility_Ideograph_2f84e       :
      constant Unicode_Char := 16#2F84E#;
   Cjk_Compatibility_Ideograph_2f84f       :
      constant Unicode_Char := 16#2F84F#;
   Cjk_Compatibility_Ideograph_2f850       :
      constant Unicode_Char := 16#2F850#;
   Cjk_Compatibility_Ideograph_2f851       :
      constant Unicode_Char := 16#2F851#;
   Cjk_Compatibility_Ideograph_2f852       :
      constant Unicode_Char := 16#2F852#;
   Cjk_Compatibility_Ideograph_2f853       :
      constant Unicode_Char := 16#2F853#;
   Cjk_Compatibility_Ideograph_2f854       :
      constant Unicode_Char := 16#2F854#;
   Cjk_Compatibility_Ideograph_2f855       :
      constant Unicode_Char := 16#2F855#;
   Cjk_Compatibility_Ideograph_2f856       :
      constant Unicode_Char := 16#2F856#;
   Cjk_Compatibility_Ideograph_2f857       :
      constant Unicode_Char := 16#2F857#;
   Cjk_Compatibility_Ideograph_2f858       :
      constant Unicode_Char := 16#2F858#;
   Cjk_Compatibility_Ideograph_2f859       :
      constant Unicode_Char := 16#2F859#;
   Cjk_Compatibility_Ideograph_2f85a       :
      constant Unicode_Char := 16#2F85A#;
   Cjk_Compatibility_Ideograph_2f85b       :
      constant Unicode_Char := 16#2F85B#;
   Cjk_Compatibility_Ideograph_2f85c       :
      constant Unicode_Char := 16#2F85C#;
   Cjk_Compatibility_Ideograph_2f85d       :
      constant Unicode_Char := 16#2F85D#;
   Cjk_Compatibility_Ideograph_2f85e       :
      constant Unicode_Char := 16#2F85E#;
   Cjk_Compatibility_Ideograph_2f85f       :
      constant Unicode_Char := 16#2F85F#;
   Cjk_Compatibility_Ideograph_2f860       :
      constant Unicode_Char := 16#2F860#;
   Cjk_Compatibility_Ideograph_2f861       :
      constant Unicode_Char := 16#2F861#;
   Cjk_Compatibility_Ideograph_2f862       :
      constant Unicode_Char := 16#2F862#;
   Cjk_Compatibility_Ideograph_2f863       :
      constant Unicode_Char := 16#2F863#;
   Cjk_Compatibility_Ideograph_2f864       :
      constant Unicode_Char := 16#2F864#;
   Cjk_Compatibility_Ideograph_2f865       :
      constant Unicode_Char := 16#2F865#;
   Cjk_Compatibility_Ideograph_2f866       :
      constant Unicode_Char := 16#2F866#;
   Cjk_Compatibility_Ideograph_2f867       :
      constant Unicode_Char := 16#2F867#;
   Cjk_Compatibility_Ideograph_2f868       :
      constant Unicode_Char := 16#2F868#;
   Cjk_Compatibility_Ideograph_2f869       :
      constant Unicode_Char := 16#2F869#;
   Cjk_Compatibility_Ideograph_2f86a       :
      constant Unicode_Char := 16#2F86A#;
   Cjk_Compatibility_Ideograph_2f86b       :
      constant Unicode_Char := 16#2F86B#;
   Cjk_Compatibility_Ideograph_2f86c       :
      constant Unicode_Char := 16#2F86C#;
   Cjk_Compatibility_Ideograph_2f86d       :
      constant Unicode_Char := 16#2F86D#;
   Cjk_Compatibility_Ideograph_2f86e       :
      constant Unicode_Char := 16#2F86E#;
   Cjk_Compatibility_Ideograph_2f86f       :
      constant Unicode_Char := 16#2F86F#;
   Cjk_Compatibility_Ideograph_2f870       :
      constant Unicode_Char := 16#2F870#;
   Cjk_Compatibility_Ideograph_2f871       :
      constant Unicode_Char := 16#2F871#;
   Cjk_Compatibility_Ideograph_2f872       :
      constant Unicode_Char := 16#2F872#;
   Cjk_Compatibility_Ideograph_2f873       :
      constant Unicode_Char := 16#2F873#;
   Cjk_Compatibility_Ideograph_2f874       :
      constant Unicode_Char := 16#2F874#;
   Cjk_Compatibility_Ideograph_2f875       :
      constant Unicode_Char := 16#2F875#;
   Cjk_Compatibility_Ideograph_2f876       :
      constant Unicode_Char := 16#2F876#;
   Cjk_Compatibility_Ideograph_2f877       :
      constant Unicode_Char := 16#2F877#;
   Cjk_Compatibility_Ideograph_2f878       :
      constant Unicode_Char := 16#2F878#;
   Cjk_Compatibility_Ideograph_2f879       :
      constant Unicode_Char := 16#2F879#;
   Cjk_Compatibility_Ideograph_2f87a       :
      constant Unicode_Char := 16#2F87A#;
   Cjk_Compatibility_Ideograph_2f87b       :
      constant Unicode_Char := 16#2F87B#;
   Cjk_Compatibility_Ideograph_2f87c       :
      constant Unicode_Char := 16#2F87C#;
   Cjk_Compatibility_Ideograph_2f87d       :
      constant Unicode_Char := 16#2F87D#;
   Cjk_Compatibility_Ideograph_2f87e       :
      constant Unicode_Char := 16#2F87E#;
   Cjk_Compatibility_Ideograph_2f87f       :
      constant Unicode_Char := 16#2F87F#;
   Cjk_Compatibility_Ideograph_2f880       :
      constant Unicode_Char := 16#2F880#;
   Cjk_Compatibility_Ideograph_2f881       :
      constant Unicode_Char := 16#2F881#;
   Cjk_Compatibility_Ideograph_2f882       :
      constant Unicode_Char := 16#2F882#;
   Cjk_Compatibility_Ideograph_2f883       :
      constant Unicode_Char := 16#2F883#;
   Cjk_Compatibility_Ideograph_2f884       :
      constant Unicode_Char := 16#2F884#;
   Cjk_Compatibility_Ideograph_2f885       :
      constant Unicode_Char := 16#2F885#;
   Cjk_Compatibility_Ideograph_2f886       :
      constant Unicode_Char := 16#2F886#;
   Cjk_Compatibility_Ideograph_2f887       :
      constant Unicode_Char := 16#2F887#;
   Cjk_Compatibility_Ideograph_2f888       :
      constant Unicode_Char := 16#2F888#;
   Cjk_Compatibility_Ideograph_2f889       :
      constant Unicode_Char := 16#2F889#;
   Cjk_Compatibility_Ideograph_2f88a       :
      constant Unicode_Char := 16#2F88A#;
   Cjk_Compatibility_Ideograph_2f88b       :
      constant Unicode_Char := 16#2F88B#;
   Cjk_Compatibility_Ideograph_2f88c       :
      constant Unicode_Char := 16#2F88C#;
   Cjk_Compatibility_Ideograph_2f88d       :
      constant Unicode_Char := 16#2F88D#;
   Cjk_Compatibility_Ideograph_2f88e       :
      constant Unicode_Char := 16#2F88E#;
   Cjk_Compatibility_Ideograph_2f88f       :
      constant Unicode_Char := 16#2F88F#;
   Cjk_Compatibility_Ideograph_2f890       :
      constant Unicode_Char := 16#2F890#;
   Cjk_Compatibility_Ideograph_2f891       :
      constant Unicode_Char := 16#2F891#;
   Cjk_Compatibility_Ideograph_2f892       :
      constant Unicode_Char := 16#2F892#;
   Cjk_Compatibility_Ideograph_2f893       :
      constant Unicode_Char := 16#2F893#;
   Cjk_Compatibility_Ideograph_2f894       :
      constant Unicode_Char := 16#2F894#;
   Cjk_Compatibility_Ideograph_2f895       :
      constant Unicode_Char := 16#2F895#;
   Cjk_Compatibility_Ideograph_2f896       :
      constant Unicode_Char := 16#2F896#;
   Cjk_Compatibility_Ideograph_2f897       :
      constant Unicode_Char := 16#2F897#;
   Cjk_Compatibility_Ideograph_2f898       :
      constant Unicode_Char := 16#2F898#;
   Cjk_Compatibility_Ideograph_2f899       :
      constant Unicode_Char := 16#2F899#;
   Cjk_Compatibility_Ideograph_2f89a       :
      constant Unicode_Char := 16#2F89A#;
   Cjk_Compatibility_Ideograph_2f89b       :
      constant Unicode_Char := 16#2F89B#;
   Cjk_Compatibility_Ideograph_2f89c       :
      constant Unicode_Char := 16#2F89C#;
   Cjk_Compatibility_Ideograph_2f89d       :
      constant Unicode_Char := 16#2F89D#;
   Cjk_Compatibility_Ideograph_2f89e       :
      constant Unicode_Char := 16#2F89E#;
   Cjk_Compatibility_Ideograph_2f89f       :
      constant Unicode_Char := 16#2F89F#;
   Cjk_Compatibility_Ideograph_2f8a0       :
      constant Unicode_Char := 16#2F8A0#;
   Cjk_Compatibility_Ideograph_2f8a1       :
      constant Unicode_Char := 16#2F8A1#;
   Cjk_Compatibility_Ideograph_2f8a2       :
      constant Unicode_Char := 16#2F8A2#;
   Cjk_Compatibility_Ideograph_2f8a3       :
      constant Unicode_Char := 16#2F8A3#;
   Cjk_Compatibility_Ideograph_2f8a4       :
      constant Unicode_Char := 16#2F8A4#;
   Cjk_Compatibility_Ideograph_2f8a5       :
      constant Unicode_Char := 16#2F8A5#;
   Cjk_Compatibility_Ideograph_2f8a6       :
      constant Unicode_Char := 16#2F8A6#;
   Cjk_Compatibility_Ideograph_2f8a7       :
      constant Unicode_Char := 16#2F8A7#;
   Cjk_Compatibility_Ideograph_2f8a8       :
      constant Unicode_Char := 16#2F8A8#;
   Cjk_Compatibility_Ideograph_2f8a9       :
      constant Unicode_Char := 16#2F8A9#;
   Cjk_Compatibility_Ideograph_2f8aa       :
      constant Unicode_Char := 16#2F8AA#;
   Cjk_Compatibility_Ideograph_2f8ab       :
      constant Unicode_Char := 16#2F8AB#;
   Cjk_Compatibility_Ideograph_2f8ac       :
      constant Unicode_Char := 16#2F8AC#;
   Cjk_Compatibility_Ideograph_2f8ad       :
      constant Unicode_Char := 16#2F8AD#;
   Cjk_Compatibility_Ideograph_2f8ae       :
      constant Unicode_Char := 16#2F8AE#;
   Cjk_Compatibility_Ideograph_2f8af       :
      constant Unicode_Char := 16#2F8AF#;
   Cjk_Compatibility_Ideograph_2f8b0       :
      constant Unicode_Char := 16#2F8B0#;
   Cjk_Compatibility_Ideograph_2f8b1       :
      constant Unicode_Char := 16#2F8B1#;
   Cjk_Compatibility_Ideograph_2f8b2       :
      constant Unicode_Char := 16#2F8B2#;
   Cjk_Compatibility_Ideograph_2f8b3       :
      constant Unicode_Char := 16#2F8B3#;
   Cjk_Compatibility_Ideograph_2f8b4       :
      constant Unicode_Char := 16#2F8B4#;
   Cjk_Compatibility_Ideograph_2f8b5       :
      constant Unicode_Char := 16#2F8B5#;
   Cjk_Compatibility_Ideograph_2f8b6       :
      constant Unicode_Char := 16#2F8B6#;
   Cjk_Compatibility_Ideograph_2f8b7       :
      constant Unicode_Char := 16#2F8B7#;
   Cjk_Compatibility_Ideograph_2f8b8       :
      constant Unicode_Char := 16#2F8B8#;
   Cjk_Compatibility_Ideograph_2f8b9       :
      constant Unicode_Char := 16#2F8B9#;
   Cjk_Compatibility_Ideograph_2f8ba       :
      constant Unicode_Char := 16#2F8BA#;
   Cjk_Compatibility_Ideograph_2f8bb       :
      constant Unicode_Char := 16#2F8BB#;
   Cjk_Compatibility_Ideograph_2f8bc       :
      constant Unicode_Char := 16#2F8BC#;
   Cjk_Compatibility_Ideograph_2f8bd       :
      constant Unicode_Char := 16#2F8BD#;
   Cjk_Compatibility_Ideograph_2f8be       :
      constant Unicode_Char := 16#2F8BE#;
   Cjk_Compatibility_Ideograph_2f8bf       :
      constant Unicode_Char := 16#2F8BF#;
   Cjk_Compatibility_Ideograph_2f8c0       :
      constant Unicode_Char := 16#2F8C0#;
   Cjk_Compatibility_Ideograph_2f8c1       :
      constant Unicode_Char := 16#2F8C1#;
   Cjk_Compatibility_Ideograph_2f8c2       :
      constant Unicode_Char := 16#2F8C2#;
   Cjk_Compatibility_Ideograph_2f8c3       :
      constant Unicode_Char := 16#2F8C3#;
   Cjk_Compatibility_Ideograph_2f8c4       :
      constant Unicode_Char := 16#2F8C4#;
   Cjk_Compatibility_Ideograph_2f8c5       :
      constant Unicode_Char := 16#2F8C5#;
   Cjk_Compatibility_Ideograph_2f8c6       :
      constant Unicode_Char := 16#2F8C6#;
   Cjk_Compatibility_Ideograph_2f8c7       :
      constant Unicode_Char := 16#2F8C7#;
   Cjk_Compatibility_Ideograph_2f8c8       :
      constant Unicode_Char := 16#2F8C8#;
   Cjk_Compatibility_Ideograph_2f8c9       :
      constant Unicode_Char := 16#2F8C9#;
   Cjk_Compatibility_Ideograph_2f8ca       :
      constant Unicode_Char := 16#2F8CA#;
   Cjk_Compatibility_Ideograph_2f8cb       :
      constant Unicode_Char := 16#2F8CB#;
   Cjk_Compatibility_Ideograph_2f8cc       :
      constant Unicode_Char := 16#2F8CC#;
   Cjk_Compatibility_Ideograph_2f8cd       :
      constant Unicode_Char := 16#2F8CD#;
   Cjk_Compatibility_Ideograph_2f8ce       :
      constant Unicode_Char := 16#2F8CE#;
   Cjk_Compatibility_Ideograph_2f8cf       :
      constant Unicode_Char := 16#2F8CF#;
   Cjk_Compatibility_Ideograph_2f8d0       :
      constant Unicode_Char := 16#2F8D0#;
   Cjk_Compatibility_Ideograph_2f8d1       :
      constant Unicode_Char := 16#2F8D1#;
   Cjk_Compatibility_Ideograph_2f8d2       :
      constant Unicode_Char := 16#2F8D2#;
   Cjk_Compatibility_Ideograph_2f8d3       :
      constant Unicode_Char := 16#2F8D3#;
   Cjk_Compatibility_Ideograph_2f8d4       :
      constant Unicode_Char := 16#2F8D4#;
   Cjk_Compatibility_Ideograph_2f8d5       :
      constant Unicode_Char := 16#2F8D5#;
   Cjk_Compatibility_Ideograph_2f8d6       :
      constant Unicode_Char := 16#2F8D6#;
   Cjk_Compatibility_Ideograph_2f8d7       :
      constant Unicode_Char := 16#2F8D7#;
   Cjk_Compatibility_Ideograph_2f8d8       :
      constant Unicode_Char := 16#2F8D8#;
   Cjk_Compatibility_Ideograph_2f8d9       :
      constant Unicode_Char := 16#2F8D9#;
   Cjk_Compatibility_Ideograph_2f8da       :
      constant Unicode_Char := 16#2F8DA#;
   Cjk_Compatibility_Ideograph_2f8db       :
      constant Unicode_Char := 16#2F8DB#;
   Cjk_Compatibility_Ideograph_2f8dc       :
      constant Unicode_Char := 16#2F8DC#;
   Cjk_Compatibility_Ideograph_2f8dd       :
      constant Unicode_Char := 16#2F8DD#;
   Cjk_Compatibility_Ideograph_2f8de       :
      constant Unicode_Char := 16#2F8DE#;
   Cjk_Compatibility_Ideograph_2f8df       :
      constant Unicode_Char := 16#2F8DF#;
   Cjk_Compatibility_Ideograph_2f8e0       :
      constant Unicode_Char := 16#2F8E0#;
   Cjk_Compatibility_Ideograph_2f8e1       :
      constant Unicode_Char := 16#2F8E1#;
   Cjk_Compatibility_Ideograph_2f8e2       :
      constant Unicode_Char := 16#2F8E2#;
   Cjk_Compatibility_Ideograph_2f8e3       :
      constant Unicode_Char := 16#2F8E3#;
   Cjk_Compatibility_Ideograph_2f8e4       :
      constant Unicode_Char := 16#2F8E4#;
   Cjk_Compatibility_Ideograph_2f8e5       :
      constant Unicode_Char := 16#2F8E5#;
   Cjk_Compatibility_Ideograph_2f8e6       :
      constant Unicode_Char := 16#2F8E6#;
   Cjk_Compatibility_Ideograph_2f8e7       :
      constant Unicode_Char := 16#2F8E7#;
   Cjk_Compatibility_Ideograph_2f8e8       :
      constant Unicode_Char := 16#2F8E8#;
   Cjk_Compatibility_Ideograph_2f8e9       :
      constant Unicode_Char := 16#2F8E9#;
   Cjk_Compatibility_Ideograph_2f8ea       :
      constant Unicode_Char := 16#2F8EA#;
   Cjk_Compatibility_Ideograph_2f8eb       :
      constant Unicode_Char := 16#2F8EB#;
   Cjk_Compatibility_Ideograph_2f8ec       :
      constant Unicode_Char := 16#2F8EC#;
   Cjk_Compatibility_Ideograph_2f8ed       :
      constant Unicode_Char := 16#2F8ED#;
   Cjk_Compatibility_Ideograph_2f8ee       :
      constant Unicode_Char := 16#2F8EE#;
   Cjk_Compatibility_Ideograph_2f8ef       :
      constant Unicode_Char := 16#2F8EF#;
   Cjk_Compatibility_Ideograph_2f8f0       :
      constant Unicode_Char := 16#2F8F0#;
   Cjk_Compatibility_Ideograph_2f8f1       :
      constant Unicode_Char := 16#2F8F1#;
   Cjk_Compatibility_Ideograph_2f8f2       :
      constant Unicode_Char := 16#2F8F2#;
   Cjk_Compatibility_Ideograph_2f8f3       :
      constant Unicode_Char := 16#2F8F3#;
   Cjk_Compatibility_Ideograph_2f8f4       :
      constant Unicode_Char := 16#2F8F4#;
   Cjk_Compatibility_Ideograph_2f8f5       :
      constant Unicode_Char := 16#2F8F5#;
   Cjk_Compatibility_Ideograph_2f8f6       :
      constant Unicode_Char := 16#2F8F6#;
   Cjk_Compatibility_Ideograph_2f8f7       :
      constant Unicode_Char := 16#2F8F7#;
   Cjk_Compatibility_Ideograph_2f8f8       :
      constant Unicode_Char := 16#2F8F8#;
   Cjk_Compatibility_Ideograph_2f8f9       :
      constant Unicode_Char := 16#2F8F9#;
   Cjk_Compatibility_Ideograph_2f8fa       :
      constant Unicode_Char := 16#2F8FA#;
   Cjk_Compatibility_Ideograph_2f8fb       :
      constant Unicode_Char := 16#2F8FB#;
   Cjk_Compatibility_Ideograph_2f8fc       :
      constant Unicode_Char := 16#2F8FC#;
   Cjk_Compatibility_Ideograph_2f8fd       :
      constant Unicode_Char := 16#2F8FD#;
   Cjk_Compatibility_Ideograph_2f8fe       :
      constant Unicode_Char := 16#2F8FE#;
   Cjk_Compatibility_Ideograph_2f8ff       :
      constant Unicode_Char := 16#2F8FF#;
   Cjk_Compatibility_Ideograph_2f900       :
      constant Unicode_Char := 16#2F900#;
   Cjk_Compatibility_Ideograph_2f901       :
      constant Unicode_Char := 16#2F901#;
   Cjk_Compatibility_Ideograph_2f902       :
      constant Unicode_Char := 16#2F902#;
   Cjk_Compatibility_Ideograph_2f903       :
      constant Unicode_Char := 16#2F903#;
   Cjk_Compatibility_Ideograph_2f904       :
      constant Unicode_Char := 16#2F904#;
   Cjk_Compatibility_Ideograph_2f905       :
      constant Unicode_Char := 16#2F905#;
   Cjk_Compatibility_Ideograph_2f906       :
      constant Unicode_Char := 16#2F906#;
   Cjk_Compatibility_Ideograph_2f907       :
      constant Unicode_Char := 16#2F907#;
   Cjk_Compatibility_Ideograph_2f908       :
      constant Unicode_Char := 16#2F908#;
   Cjk_Compatibility_Ideograph_2f909       :
      constant Unicode_Char := 16#2F909#;
   Cjk_Compatibility_Ideograph_2f90a       :
      constant Unicode_Char := 16#2F90A#;
   Cjk_Compatibility_Ideograph_2f90b       :
      constant Unicode_Char := 16#2F90B#;
   Cjk_Compatibility_Ideograph_2f90c       :
      constant Unicode_Char := 16#2F90C#;
   Cjk_Compatibility_Ideograph_2f90d       :
      constant Unicode_Char := 16#2F90D#;
   Cjk_Compatibility_Ideograph_2f90e       :
      constant Unicode_Char := 16#2F90E#;
   Cjk_Compatibility_Ideograph_2f90f       :
      constant Unicode_Char := 16#2F90F#;
   Cjk_Compatibility_Ideograph_2f910       :
      constant Unicode_Char := 16#2F910#;
   Cjk_Compatibility_Ideograph_2f911       :
      constant Unicode_Char := 16#2F911#;
   Cjk_Compatibility_Ideograph_2f912       :
      constant Unicode_Char := 16#2F912#;
   Cjk_Compatibility_Ideograph_2f913       :
      constant Unicode_Char := 16#2F913#;
   Cjk_Compatibility_Ideograph_2f914       :
      constant Unicode_Char := 16#2F914#;
   Cjk_Compatibility_Ideograph_2f915       :
      constant Unicode_Char := 16#2F915#;
   Cjk_Compatibility_Ideograph_2f916       :
      constant Unicode_Char := 16#2F916#;
   Cjk_Compatibility_Ideograph_2f917       :
      constant Unicode_Char := 16#2F917#;
   Cjk_Compatibility_Ideograph_2f918       :
      constant Unicode_Char := 16#2F918#;
   Cjk_Compatibility_Ideograph_2f919       :
      constant Unicode_Char := 16#2F919#;
   Cjk_Compatibility_Ideograph_2f91a       :
      constant Unicode_Char := 16#2F91A#;
   Cjk_Compatibility_Ideograph_2f91b       :
      constant Unicode_Char := 16#2F91B#;
   Cjk_Compatibility_Ideograph_2f91c       :
      constant Unicode_Char := 16#2F91C#;
   Cjk_Compatibility_Ideograph_2f91d       :
      constant Unicode_Char := 16#2F91D#;
   Cjk_Compatibility_Ideograph_2f91e       :
      constant Unicode_Char := 16#2F91E#;
   Cjk_Compatibility_Ideograph_2f91f       :
      constant Unicode_Char := 16#2F91F#;
   Cjk_Compatibility_Ideograph_2f920       :
      constant Unicode_Char := 16#2F920#;
   Cjk_Compatibility_Ideograph_2f921       :
      constant Unicode_Char := 16#2F921#;
   Cjk_Compatibility_Ideograph_2f922       :
      constant Unicode_Char := 16#2F922#;
   Cjk_Compatibility_Ideograph_2f923       :
      constant Unicode_Char := 16#2F923#;
   Cjk_Compatibility_Ideograph_2f924       :
      constant Unicode_Char := 16#2F924#;
   Cjk_Compatibility_Ideograph_2f925       :
      constant Unicode_Char := 16#2F925#;
   Cjk_Compatibility_Ideograph_2f926       :
      constant Unicode_Char := 16#2F926#;
   Cjk_Compatibility_Ideograph_2f927       :
      constant Unicode_Char := 16#2F927#;
   Cjk_Compatibility_Ideograph_2f928       :
      constant Unicode_Char := 16#2F928#;
   Cjk_Compatibility_Ideograph_2f929       :
      constant Unicode_Char := 16#2F929#;
   Cjk_Compatibility_Ideograph_2f92a       :
      constant Unicode_Char := 16#2F92A#;
   Cjk_Compatibility_Ideograph_2f92b       :
      constant Unicode_Char := 16#2F92B#;
   Cjk_Compatibility_Ideograph_2f92c       :
      constant Unicode_Char := 16#2F92C#;
   Cjk_Compatibility_Ideograph_2f92d       :
      constant Unicode_Char := 16#2F92D#;
   Cjk_Compatibility_Ideograph_2f92e       :
      constant Unicode_Char := 16#2F92E#;
   Cjk_Compatibility_Ideograph_2f92f       :
      constant Unicode_Char := 16#2F92F#;
   Cjk_Compatibility_Ideograph_2f930       :
      constant Unicode_Char := 16#2F930#;
   Cjk_Compatibility_Ideograph_2f931       :
      constant Unicode_Char := 16#2F931#;
   Cjk_Compatibility_Ideograph_2f932       :
      constant Unicode_Char := 16#2F932#;
   Cjk_Compatibility_Ideograph_2f933       :
      constant Unicode_Char := 16#2F933#;
   Cjk_Compatibility_Ideograph_2f934       :
      constant Unicode_Char := 16#2F934#;
   Cjk_Compatibility_Ideograph_2f935       :
      constant Unicode_Char := 16#2F935#;
   Cjk_Compatibility_Ideograph_2f936       :
      constant Unicode_Char := 16#2F936#;
   Cjk_Compatibility_Ideograph_2f937       :
      constant Unicode_Char := 16#2F937#;
   Cjk_Compatibility_Ideograph_2f938       :
      constant Unicode_Char := 16#2F938#;
   Cjk_Compatibility_Ideograph_2f939       :
      constant Unicode_Char := 16#2F939#;
   Cjk_Compatibility_Ideograph_2f93a       :
      constant Unicode_Char := 16#2F93A#;
   Cjk_Compatibility_Ideograph_2f93b       :
      constant Unicode_Char := 16#2F93B#;
   Cjk_Compatibility_Ideograph_2f93c       :
      constant Unicode_Char := 16#2F93C#;
   Cjk_Compatibility_Ideograph_2f93d       :
      constant Unicode_Char := 16#2F93D#;
   Cjk_Compatibility_Ideograph_2f93e       :
      constant Unicode_Char := 16#2F93E#;
   Cjk_Compatibility_Ideograph_2f93f       :
      constant Unicode_Char := 16#2F93F#;
   Cjk_Compatibility_Ideograph_2f940       :
      constant Unicode_Char := 16#2F940#;
   Cjk_Compatibility_Ideograph_2f941       :
      constant Unicode_Char := 16#2F941#;
   Cjk_Compatibility_Ideograph_2f942       :
      constant Unicode_Char := 16#2F942#;
   Cjk_Compatibility_Ideograph_2f943       :
      constant Unicode_Char := 16#2F943#;
   Cjk_Compatibility_Ideograph_2f944       :
      constant Unicode_Char := 16#2F944#;
   Cjk_Compatibility_Ideograph_2f945       :
      constant Unicode_Char := 16#2F945#;
   Cjk_Compatibility_Ideograph_2f946       :
      constant Unicode_Char := 16#2F946#;
   Cjk_Compatibility_Ideograph_2f947       :
      constant Unicode_Char := 16#2F947#;
   Cjk_Compatibility_Ideograph_2f948       :
      constant Unicode_Char := 16#2F948#;
   Cjk_Compatibility_Ideograph_2f949       :
      constant Unicode_Char := 16#2F949#;
   Cjk_Compatibility_Ideograph_2f94a       :
      constant Unicode_Char := 16#2F94A#;
   Cjk_Compatibility_Ideograph_2f94b       :
      constant Unicode_Char := 16#2F94B#;
   Cjk_Compatibility_Ideograph_2f94c       :
      constant Unicode_Char := 16#2F94C#;
   Cjk_Compatibility_Ideograph_2f94d       :
      constant Unicode_Char := 16#2F94D#;
   Cjk_Compatibility_Ideograph_2f94e       :
      constant Unicode_Char := 16#2F94E#;
   Cjk_Compatibility_Ideograph_2f94f       :
      constant Unicode_Char := 16#2F94F#;
   Cjk_Compatibility_Ideograph_2f950       :
      constant Unicode_Char := 16#2F950#;
   Cjk_Compatibility_Ideograph_2f951       :
      constant Unicode_Char := 16#2F951#;
   Cjk_Compatibility_Ideograph_2f952       :
      constant Unicode_Char := 16#2F952#;
   Cjk_Compatibility_Ideograph_2f953       :
      constant Unicode_Char := 16#2F953#;
   Cjk_Compatibility_Ideograph_2f954       :
      constant Unicode_Char := 16#2F954#;
   Cjk_Compatibility_Ideograph_2f955       :
      constant Unicode_Char := 16#2F955#;
   Cjk_Compatibility_Ideograph_2f956       :
      constant Unicode_Char := 16#2F956#;
   Cjk_Compatibility_Ideograph_2f957       :
      constant Unicode_Char := 16#2F957#;
   Cjk_Compatibility_Ideograph_2f958       :
      constant Unicode_Char := 16#2F958#;
   Cjk_Compatibility_Ideograph_2f959       :
      constant Unicode_Char := 16#2F959#;
   Cjk_Compatibility_Ideograph_2f95a       :
      constant Unicode_Char := 16#2F95A#;
   Cjk_Compatibility_Ideograph_2f95b       :
      constant Unicode_Char := 16#2F95B#;
   Cjk_Compatibility_Ideograph_2f95c       :
      constant Unicode_Char := 16#2F95C#;
   Cjk_Compatibility_Ideograph_2f95d       :
      constant Unicode_Char := 16#2F95D#;
   Cjk_Compatibility_Ideograph_2f95e       :
      constant Unicode_Char := 16#2F95E#;
   Cjk_Compatibility_Ideograph_2f95f       :
      constant Unicode_Char := 16#2F95F#;
   Cjk_Compatibility_Ideograph_2f960       :
      constant Unicode_Char := 16#2F960#;
   Cjk_Compatibility_Ideograph_2f961       :
      constant Unicode_Char := 16#2F961#;
   Cjk_Compatibility_Ideograph_2f962       :
      constant Unicode_Char := 16#2F962#;
   Cjk_Compatibility_Ideograph_2f963       :
      constant Unicode_Char := 16#2F963#;
   Cjk_Compatibility_Ideograph_2f964       :
      constant Unicode_Char := 16#2F964#;
   Cjk_Compatibility_Ideograph_2f965       :
      constant Unicode_Char := 16#2F965#;
   Cjk_Compatibility_Ideograph_2f966       :
      constant Unicode_Char := 16#2F966#;
   Cjk_Compatibility_Ideograph_2f967       :
      constant Unicode_Char := 16#2F967#;
   Cjk_Compatibility_Ideograph_2f968       :
      constant Unicode_Char := 16#2F968#;
   Cjk_Compatibility_Ideograph_2f969       :
      constant Unicode_Char := 16#2F969#;
   Cjk_Compatibility_Ideograph_2f96a       :
      constant Unicode_Char := 16#2F96A#;
   Cjk_Compatibility_Ideograph_2f96b       :
      constant Unicode_Char := 16#2F96B#;
   Cjk_Compatibility_Ideograph_2f96c       :
      constant Unicode_Char := 16#2F96C#;
   Cjk_Compatibility_Ideograph_2f96d       :
      constant Unicode_Char := 16#2F96D#;
   Cjk_Compatibility_Ideograph_2f96e       :
      constant Unicode_Char := 16#2F96E#;
   Cjk_Compatibility_Ideograph_2f96f       :
      constant Unicode_Char := 16#2F96F#;
   Cjk_Compatibility_Ideograph_2f970       :
      constant Unicode_Char := 16#2F970#;
   Cjk_Compatibility_Ideograph_2f971       :
      constant Unicode_Char := 16#2F971#;
   Cjk_Compatibility_Ideograph_2f972       :
      constant Unicode_Char := 16#2F972#;
   Cjk_Compatibility_Ideograph_2f973       :
      constant Unicode_Char := 16#2F973#;
   Cjk_Compatibility_Ideograph_2f974       :
      constant Unicode_Char := 16#2F974#;
   Cjk_Compatibility_Ideograph_2f975       :
      constant Unicode_Char := 16#2F975#;
   Cjk_Compatibility_Ideograph_2f976       :
      constant Unicode_Char := 16#2F976#;
   Cjk_Compatibility_Ideograph_2f977       :
      constant Unicode_Char := 16#2F977#;
   Cjk_Compatibility_Ideograph_2f978       :
      constant Unicode_Char := 16#2F978#;
   Cjk_Compatibility_Ideograph_2f979       :
      constant Unicode_Char := 16#2F979#;
   Cjk_Compatibility_Ideograph_2f97a       :
      constant Unicode_Char := 16#2F97A#;
   Cjk_Compatibility_Ideograph_2f97b       :
      constant Unicode_Char := 16#2F97B#;
   Cjk_Compatibility_Ideograph_2f97c       :
      constant Unicode_Char := 16#2F97C#;
   Cjk_Compatibility_Ideograph_2f97d       :
      constant Unicode_Char := 16#2F97D#;
   Cjk_Compatibility_Ideograph_2f97e       :
      constant Unicode_Char := 16#2F97E#;
   Cjk_Compatibility_Ideograph_2f97f       :
      constant Unicode_Char := 16#2F97F#;
   Cjk_Compatibility_Ideograph_2f980       :
      constant Unicode_Char := 16#2F980#;
   Cjk_Compatibility_Ideograph_2f981       :
      constant Unicode_Char := 16#2F981#;
   Cjk_Compatibility_Ideograph_2f982       :
      constant Unicode_Char := 16#2F982#;
   Cjk_Compatibility_Ideograph_2f983       :
      constant Unicode_Char := 16#2F983#;
   Cjk_Compatibility_Ideograph_2f984       :
      constant Unicode_Char := 16#2F984#;
   Cjk_Compatibility_Ideograph_2f985       :
      constant Unicode_Char := 16#2F985#;
   Cjk_Compatibility_Ideograph_2f986       :
      constant Unicode_Char := 16#2F986#;
   Cjk_Compatibility_Ideograph_2f987       :
      constant Unicode_Char := 16#2F987#;
   Cjk_Compatibility_Ideograph_2f988       :
      constant Unicode_Char := 16#2F988#;
   Cjk_Compatibility_Ideograph_2f989       :
      constant Unicode_Char := 16#2F989#;
   Cjk_Compatibility_Ideograph_2f98a       :
      constant Unicode_Char := 16#2F98A#;
   Cjk_Compatibility_Ideograph_2f98b       :
      constant Unicode_Char := 16#2F98B#;
   Cjk_Compatibility_Ideograph_2f98c       :
      constant Unicode_Char := 16#2F98C#;
   Cjk_Compatibility_Ideograph_2f98d       :
      constant Unicode_Char := 16#2F98D#;
   Cjk_Compatibility_Ideograph_2f98e       :
      constant Unicode_Char := 16#2F98E#;
   Cjk_Compatibility_Ideograph_2f98f       :
      constant Unicode_Char := 16#2F98F#;
   Cjk_Compatibility_Ideograph_2f990       :
      constant Unicode_Char := 16#2F990#;
   Cjk_Compatibility_Ideograph_2f991       :
      constant Unicode_Char := 16#2F991#;
   Cjk_Compatibility_Ideograph_2f992       :
      constant Unicode_Char := 16#2F992#;
   Cjk_Compatibility_Ideograph_2f993       :
      constant Unicode_Char := 16#2F993#;
   Cjk_Compatibility_Ideograph_2f994       :
      constant Unicode_Char := 16#2F994#;
   Cjk_Compatibility_Ideograph_2f995       :
      constant Unicode_Char := 16#2F995#;
   Cjk_Compatibility_Ideograph_2f996       :
      constant Unicode_Char := 16#2F996#;
   Cjk_Compatibility_Ideograph_2f997       :
      constant Unicode_Char := 16#2F997#;
   Cjk_Compatibility_Ideograph_2f998       :
      constant Unicode_Char := 16#2F998#;
   Cjk_Compatibility_Ideograph_2f999       :
      constant Unicode_Char := 16#2F999#;
   Cjk_Compatibility_Ideograph_2f99a       :
      constant Unicode_Char := 16#2F99A#;
   Cjk_Compatibility_Ideograph_2f99b       :
      constant Unicode_Char := 16#2F99B#;
   Cjk_Compatibility_Ideograph_2f99c       :
      constant Unicode_Char := 16#2F99C#;
   Cjk_Compatibility_Ideograph_2f99d       :
      constant Unicode_Char := 16#2F99D#;
   Cjk_Compatibility_Ideograph_2f99e       :
      constant Unicode_Char := 16#2F99E#;
   Cjk_Compatibility_Ideograph_2f99f       :
      constant Unicode_Char := 16#2F99F#;
   Cjk_Compatibility_Ideograph_2f9a0       :
      constant Unicode_Char := 16#2F9A0#;
   Cjk_Compatibility_Ideograph_2f9a1       :
      constant Unicode_Char := 16#2F9A1#;
   Cjk_Compatibility_Ideograph_2f9a2       :
      constant Unicode_Char := 16#2F9A2#;
   Cjk_Compatibility_Ideograph_2f9a3       :
      constant Unicode_Char := 16#2F9A3#;
   Cjk_Compatibility_Ideograph_2f9a4       :
      constant Unicode_Char := 16#2F9A4#;
   Cjk_Compatibility_Ideograph_2f9a5       :
      constant Unicode_Char := 16#2F9A5#;
   Cjk_Compatibility_Ideograph_2f9a6       :
      constant Unicode_Char := 16#2F9A6#;
   Cjk_Compatibility_Ideograph_2f9a7       :
      constant Unicode_Char := 16#2F9A7#;
   Cjk_Compatibility_Ideograph_2f9a8       :
      constant Unicode_Char := 16#2F9A8#;
   Cjk_Compatibility_Ideograph_2f9a9       :
      constant Unicode_Char := 16#2F9A9#;
   Cjk_Compatibility_Ideograph_2f9aa       :
      constant Unicode_Char := 16#2F9AA#;
   Cjk_Compatibility_Ideograph_2f9ab       :
      constant Unicode_Char := 16#2F9AB#;
   Cjk_Compatibility_Ideograph_2f9ac       :
      constant Unicode_Char := 16#2F9AC#;
   Cjk_Compatibility_Ideograph_2f9ad       :
      constant Unicode_Char := 16#2F9AD#;
   Cjk_Compatibility_Ideograph_2f9ae       :
      constant Unicode_Char := 16#2F9AE#;
   Cjk_Compatibility_Ideograph_2f9af       :
      constant Unicode_Char := 16#2F9AF#;
   Cjk_Compatibility_Ideograph_2f9b0       :
      constant Unicode_Char := 16#2F9B0#;
   Cjk_Compatibility_Ideograph_2f9b1       :
      constant Unicode_Char := 16#2F9B1#;
   Cjk_Compatibility_Ideograph_2f9b2       :
      constant Unicode_Char := 16#2F9B2#;
   Cjk_Compatibility_Ideograph_2f9b3       :
      constant Unicode_Char := 16#2F9B3#;
   Cjk_Compatibility_Ideograph_2f9b4       :
      constant Unicode_Char := 16#2F9B4#;
   Cjk_Compatibility_Ideograph_2f9b5       :
      constant Unicode_Char := 16#2F9B5#;
   Cjk_Compatibility_Ideograph_2f9b6       :
      constant Unicode_Char := 16#2F9B6#;
   Cjk_Compatibility_Ideograph_2f9b7       :
      constant Unicode_Char := 16#2F9B7#;
   Cjk_Compatibility_Ideograph_2f9b8       :
      constant Unicode_Char := 16#2F9B8#;
   Cjk_Compatibility_Ideograph_2f9b9       :
      constant Unicode_Char := 16#2F9B9#;
   Cjk_Compatibility_Ideograph_2f9ba       :
      constant Unicode_Char := 16#2F9BA#;
   Cjk_Compatibility_Ideograph_2f9bb       :
      constant Unicode_Char := 16#2F9BB#;
   Cjk_Compatibility_Ideograph_2f9bc       :
      constant Unicode_Char := 16#2F9BC#;
   Cjk_Compatibility_Ideograph_2f9bd       :
      constant Unicode_Char := 16#2F9BD#;
   Cjk_Compatibility_Ideograph_2f9be       :
      constant Unicode_Char := 16#2F9BE#;
   Cjk_Compatibility_Ideograph_2f9bf       :
      constant Unicode_Char := 16#2F9BF#;
   Cjk_Compatibility_Ideograph_2f9c0       :
      constant Unicode_Char := 16#2F9C0#;
   Cjk_Compatibility_Ideograph_2f9c1       :
      constant Unicode_Char := 16#2F9C1#;
   Cjk_Compatibility_Ideograph_2f9c2       :
      constant Unicode_Char := 16#2F9C2#;
   Cjk_Compatibility_Ideograph_2f9c3       :
      constant Unicode_Char := 16#2F9C3#;
   Cjk_Compatibility_Ideograph_2f9c4       :
      constant Unicode_Char := 16#2F9C4#;
   Cjk_Compatibility_Ideograph_2f9c5       :
      constant Unicode_Char := 16#2F9C5#;
   Cjk_Compatibility_Ideograph_2f9c6       :
      constant Unicode_Char := 16#2F9C6#;
   Cjk_Compatibility_Ideograph_2f9c7       :
      constant Unicode_Char := 16#2F9C7#;
   Cjk_Compatibility_Ideograph_2f9c8       :
      constant Unicode_Char := 16#2F9C8#;
   Cjk_Compatibility_Ideograph_2f9c9       :
      constant Unicode_Char := 16#2F9C9#;
   Cjk_Compatibility_Ideograph_2f9ca       :
      constant Unicode_Char := 16#2F9CA#;
   Cjk_Compatibility_Ideograph_2f9cb       :
      constant Unicode_Char := 16#2F9CB#;
   Cjk_Compatibility_Ideograph_2f9cc       :
      constant Unicode_Char := 16#2F9CC#;
   Cjk_Compatibility_Ideograph_2f9cd       :
      constant Unicode_Char := 16#2F9CD#;
   Cjk_Compatibility_Ideograph_2f9ce       :
      constant Unicode_Char := 16#2F9CE#;
   Cjk_Compatibility_Ideograph_2f9cf       :
      constant Unicode_Char := 16#2F9CF#;
   Cjk_Compatibility_Ideograph_2f9d0       :
      constant Unicode_Char := 16#2F9D0#;
   Cjk_Compatibility_Ideograph_2f9d1       :
      constant Unicode_Char := 16#2F9D1#;
   Cjk_Compatibility_Ideograph_2f9d2       :
      constant Unicode_Char := 16#2F9D2#;
   Cjk_Compatibility_Ideograph_2f9d3       :
      constant Unicode_Char := 16#2F9D3#;
   Cjk_Compatibility_Ideograph_2f9d4       :
      constant Unicode_Char := 16#2F9D4#;
   Cjk_Compatibility_Ideograph_2f9d5       :
      constant Unicode_Char := 16#2F9D5#;
   Cjk_Compatibility_Ideograph_2f9d6       :
      constant Unicode_Char := 16#2F9D6#;
   Cjk_Compatibility_Ideograph_2f9d7       :
      constant Unicode_Char := 16#2F9D7#;
   Cjk_Compatibility_Ideograph_2f9d8       :
      constant Unicode_Char := 16#2F9D8#;
   Cjk_Compatibility_Ideograph_2f9d9       :
      constant Unicode_Char := 16#2F9D9#;
   Cjk_Compatibility_Ideograph_2f9da       :
      constant Unicode_Char := 16#2F9DA#;
   Cjk_Compatibility_Ideograph_2f9db       :
      constant Unicode_Char := 16#2F9DB#;
   Cjk_Compatibility_Ideograph_2f9dc       :
      constant Unicode_Char := 16#2F9DC#;
   Cjk_Compatibility_Ideograph_2f9dd       :
      constant Unicode_Char := 16#2F9DD#;
   Cjk_Compatibility_Ideograph_2f9de       :
      constant Unicode_Char := 16#2F9DE#;
   Cjk_Compatibility_Ideograph_2f9df       :
      constant Unicode_Char := 16#2F9DF#;
   Cjk_Compatibility_Ideograph_2f9e0       :
      constant Unicode_Char := 16#2F9E0#;
   Cjk_Compatibility_Ideograph_2f9e1       :
      constant Unicode_Char := 16#2F9E1#;
   Cjk_Compatibility_Ideograph_2f9e2       :
      constant Unicode_Char := 16#2F9E2#;
   Cjk_Compatibility_Ideograph_2f9e3       :
      constant Unicode_Char := 16#2F9E3#;
   Cjk_Compatibility_Ideograph_2f9e4       :
      constant Unicode_Char := 16#2F9E4#;
   Cjk_Compatibility_Ideograph_2f9e5       :
      constant Unicode_Char := 16#2F9E5#;
   Cjk_Compatibility_Ideograph_2f9e6       :
      constant Unicode_Char := 16#2F9E6#;
   Cjk_Compatibility_Ideograph_2f9e7       :
      constant Unicode_Char := 16#2F9E7#;
   Cjk_Compatibility_Ideograph_2f9e8       :
      constant Unicode_Char := 16#2F9E8#;
   Cjk_Compatibility_Ideograph_2f9e9       :
      constant Unicode_Char := 16#2F9E9#;
   Cjk_Compatibility_Ideograph_2f9ea       :
      constant Unicode_Char := 16#2F9EA#;
   Cjk_Compatibility_Ideograph_2f9eb       :
      constant Unicode_Char := 16#2F9EB#;
   Cjk_Compatibility_Ideograph_2f9ec       :
      constant Unicode_Char := 16#2F9EC#;
   Cjk_Compatibility_Ideograph_2f9ed       :
      constant Unicode_Char := 16#2F9ED#;
   Cjk_Compatibility_Ideograph_2f9ee       :
      constant Unicode_Char := 16#2F9EE#;
   Cjk_Compatibility_Ideograph_2f9ef       :
      constant Unicode_Char := 16#2F9EF#;
   Cjk_Compatibility_Ideograph_2f9f0       :
      constant Unicode_Char := 16#2F9F0#;
   Cjk_Compatibility_Ideograph_2f9f1       :
      constant Unicode_Char := 16#2F9F1#;
   Cjk_Compatibility_Ideograph_2f9f2       :
      constant Unicode_Char := 16#2F9F2#;
   Cjk_Compatibility_Ideograph_2f9f3       :
      constant Unicode_Char := 16#2F9F3#;
   Cjk_Compatibility_Ideograph_2f9f4       :
      constant Unicode_Char := 16#2F9F4#;
   Cjk_Compatibility_Ideograph_2f9f5       :
      constant Unicode_Char := 16#2F9F5#;
   Cjk_Compatibility_Ideograph_2f9f6       :
      constant Unicode_Char := 16#2F9F6#;
   Cjk_Compatibility_Ideograph_2f9f7       :
      constant Unicode_Char := 16#2F9F7#;
   Cjk_Compatibility_Ideograph_2f9f8       :
      constant Unicode_Char := 16#2F9F8#;
   Cjk_Compatibility_Ideograph_2f9f9       :
      constant Unicode_Char := 16#2F9F9#;
   Cjk_Compatibility_Ideograph_2f9fa       :
      constant Unicode_Char := 16#2F9FA#;
   Cjk_Compatibility_Ideograph_2f9fb       :
      constant Unicode_Char := 16#2F9FB#;
   Cjk_Compatibility_Ideograph_2f9fc       :
      constant Unicode_Char := 16#2F9FC#;
   Cjk_Compatibility_Ideograph_2f9fd       :
      constant Unicode_Char := 16#2F9FD#;
   Cjk_Compatibility_Ideograph_2f9fe       :
      constant Unicode_Char := 16#2F9FE#;
   Cjk_Compatibility_Ideograph_2f9ff       :
      constant Unicode_Char := 16#2F9FF#;
   Cjk_Compatibility_Ideograph_2fa00       :
      constant Unicode_Char := 16#2FA00#;
   Cjk_Compatibility_Ideograph_2fa01       :
      constant Unicode_Char := 16#2FA01#;
   Cjk_Compatibility_Ideograph_2fa02       :
      constant Unicode_Char := 16#2FA02#;
   Cjk_Compatibility_Ideograph_2fa03       :
      constant Unicode_Char := 16#2FA03#;
   Cjk_Compatibility_Ideograph_2fa04       :
      constant Unicode_Char := 16#2FA04#;
   Cjk_Compatibility_Ideograph_2fa05       :
      constant Unicode_Char := 16#2FA05#;
   Cjk_Compatibility_Ideograph_2fa06       :
      constant Unicode_Char := 16#2FA06#;
   Cjk_Compatibility_Ideograph_2fa07       :
      constant Unicode_Char := 16#2FA07#;
   Cjk_Compatibility_Ideograph_2fa08       :
      constant Unicode_Char := 16#2FA08#;
   Cjk_Compatibility_Ideograph_2fa09       :
      constant Unicode_Char := 16#2FA09#;
   Cjk_Compatibility_Ideograph_2fa0a       :
      constant Unicode_Char := 16#2FA0A#;
   Cjk_Compatibility_Ideograph_2fa0b       :
      constant Unicode_Char := 16#2FA0B#;
   Cjk_Compatibility_Ideograph_2fa0c       :
      constant Unicode_Char := 16#2FA0C#;
   Cjk_Compatibility_Ideograph_2fa0d       :
      constant Unicode_Char := 16#2FA0D#;
   Cjk_Compatibility_Ideograph_2fa0e       :
      constant Unicode_Char := 16#2FA0E#;
   Cjk_Compatibility_Ideograph_2fa0f       :
      constant Unicode_Char := 16#2FA0F#;
   Cjk_Compatibility_Ideograph_2fa10       :
      constant Unicode_Char := 16#2FA10#;
   Cjk_Compatibility_Ideograph_2fa11       :
      constant Unicode_Char := 16#2FA11#;
   Cjk_Compatibility_Ideograph_2fa12       :
      constant Unicode_Char := 16#2FA12#;
   Cjk_Compatibility_Ideograph_2fa13       :
      constant Unicode_Char := 16#2FA13#;
   Cjk_Compatibility_Ideograph_2fa14       :
      constant Unicode_Char := 16#2FA14#;
   Cjk_Compatibility_Ideograph_2fa15       :
      constant Unicode_Char := 16#2FA15#;
   Cjk_Compatibility_Ideograph_2fa16       :
      constant Unicode_Char := 16#2FA16#;
   Cjk_Compatibility_Ideograph_2fa17       :
      constant Unicode_Char := 16#2FA17#;
   Cjk_Compatibility_Ideograph_2fa18       :
      constant Unicode_Char := 16#2FA18#;
   Cjk_Compatibility_Ideograph_2fa19       :
      constant Unicode_Char := 16#2FA19#;
   Cjk_Compatibility_Ideograph_2fa1a       :
      constant Unicode_Char := 16#2FA1A#;
   Cjk_Compatibility_Ideograph_2fa1b       :
      constant Unicode_Char := 16#2FA1B#;
   Cjk_Compatibility_Ideograph_2fa1c       :
      constant Unicode_Char := 16#2FA1C#;
   Cjk_Compatibility_Ideograph_2fa1d       :
      constant Unicode_Char := 16#2FA1D#;
end Unicode.Names.Cjk_Compat_Ideo_Sup;
