--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Lisu is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Lisu_Letter_Ba                          : constant Unicode_Char := 16#A4D0#;
   Lisu_Letter_Pa                          : constant Unicode_Char := 16#A4D1#;
   Lisu_Letter_Pha                         : constant Unicode_Char := 16#A4D2#;
   Lisu_Letter_Da                          : constant Unicode_Char := 16#A4D3#;
   Lisu_Letter_Ta                          : constant Unicode_Char := 16#A4D4#;
   Lisu_Letter_Tha                         : constant Unicode_Char := 16#A4D5#;
   Lisu_Letter_Ga                          : constant Unicode_Char := 16#A4D6#;
   Lisu_Letter_Ka                          : constant Unicode_Char := 16#A4D7#;
   Lisu_Letter_Kha                         : constant Unicode_Char := 16#A4D8#;
   Lisu_Letter_Ja                          : constant Unicode_Char := 16#A4D9#;
   Lisu_Letter_Ca                          : constant Unicode_Char := 16#A4DA#;
   Lisu_Letter_Cha                         : constant Unicode_Char := 16#A4DB#;
   Lisu_Letter_Dza                         : constant Unicode_Char := 16#A4DC#;
   Lisu_Letter_Tsa                         : constant Unicode_Char := 16#A4DD#;
   Lisu_Letter_Tsha                        : constant Unicode_Char := 16#A4DE#;
   Lisu_Letter_Ma                          : constant Unicode_Char := 16#A4DF#;
   Lisu_Letter_Na                          : constant Unicode_Char := 16#A4E0#;
   Lisu_Letter_La                          : constant Unicode_Char := 16#A4E1#;
   Lisu_Letter_Sa                          : constant Unicode_Char := 16#A4E2#;
   Lisu_Letter_Zha                         : constant Unicode_Char := 16#A4E3#;
   Lisu_Letter_Za                          : constant Unicode_Char := 16#A4E4#;
   Lisu_Letter_Nga                         : constant Unicode_Char := 16#A4E5#;
   Lisu_Letter_Ha                          : constant Unicode_Char := 16#A4E6#;
   Lisu_Letter_Xa                          : constant Unicode_Char := 16#A4E7#;
   Lisu_Letter_Hha                         : constant Unicode_Char := 16#A4E8#;
   Lisu_Letter_Fa                          : constant Unicode_Char := 16#A4E9#;
   Lisu_Letter_Wa                          : constant Unicode_Char := 16#A4EA#;
   Lisu_Letter_Sha                         : constant Unicode_Char := 16#A4EB#;
   Lisu_Letter_Ya                          : constant Unicode_Char := 16#A4EC#;
   Lisu_Letter_Gha                         : constant Unicode_Char := 16#A4ED#;
   Lisu_Letter_A                           : constant Unicode_Char := 16#A4EE#;
   Lisu_Letter_Ae                          : constant Unicode_Char := 16#A4EF#;
   Lisu_Letter_E                           : constant Unicode_Char := 16#A4F0#;
   Lisu_Letter_Eu                          : constant Unicode_Char := 16#A4F1#;
   Lisu_Letter_I                           : constant Unicode_Char := 16#A4F2#;
   Lisu_Letter_O                           : constant Unicode_Char := 16#A4F3#;
   Lisu_Letter_U                           : constant Unicode_Char := 16#A4F4#;
   Lisu_Letter_Ue                          : constant Unicode_Char := 16#A4F5#;
   Lisu_Letter_Uh                          : constant Unicode_Char := 16#A4F6#;
   Lisu_Letter_Oe                          : constant Unicode_Char := 16#A4F7#;
   Lisu_Letter_Tone_Mya_Ti                 : constant Unicode_Char := 16#A4F8#;
   Lisu_Letter_Tone_Na_Po                  : constant Unicode_Char := 16#A4F9#;
   Lisu_Letter_Tone_Mya_Cya                : constant Unicode_Char := 16#A4FA#;
   Lisu_Letter_Tone_Mya_Bo                 : constant Unicode_Char := 16#A4FB#;
   Lisu_Letter_Tone_Mya_Na                 : constant Unicode_Char := 16#A4FC#;
   Lisu_Letter_Tone_Mya_Jeu                : constant Unicode_Char := 16#A4FD#;
   Lisu_Punctuation_Comma                  : constant Unicode_Char := 16#A4FE#;
   Lisu_Punctuation_Full_Stop              : constant Unicode_Char := 16#A4FF#;
end Unicode.Names.Lisu;
