--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Georgian is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Georgian_Capital_Letter_An              : constant Unicode_Char := 16#10A0#;
   Georgian_Capital_Letter_Ban             : constant Unicode_Char := 16#10A1#;
   Georgian_Capital_Letter_Gan             : constant Unicode_Char := 16#10A2#;
   Georgian_Capital_Letter_Don             : constant Unicode_Char := 16#10A3#;
   Georgian_Capital_Letter_En              : constant Unicode_Char := 16#10A4#;
   Georgian_Capital_Letter_Vin             : constant Unicode_Char := 16#10A5#;
   Georgian_Capital_Letter_Zen             : constant Unicode_Char := 16#10A6#;
   Georgian_Capital_Letter_Tan             : constant Unicode_Char := 16#10A7#;
   Georgian_Capital_Letter_In              : constant Unicode_Char := 16#10A8#;
   Georgian_Capital_Letter_Kan             : constant Unicode_Char := 16#10A9#;
   Georgian_Capital_Letter_Las             : constant Unicode_Char := 16#10AA#;
   Georgian_Capital_Letter_Man             : constant Unicode_Char := 16#10AB#;
   Georgian_Capital_Letter_Nar             : constant Unicode_Char := 16#10AC#;
   Georgian_Capital_Letter_On              : constant Unicode_Char := 16#10AD#;
   Georgian_Capital_Letter_Par             : constant Unicode_Char := 16#10AE#;
   Georgian_Capital_Letter_Zhar            : constant Unicode_Char := 16#10AF#;
   Georgian_Capital_Letter_Rae             : constant Unicode_Char := 16#10B0#;
   Georgian_Capital_Letter_San             : constant Unicode_Char := 16#10B1#;
   Georgian_Capital_Letter_Tar             : constant Unicode_Char := 16#10B2#;
   Georgian_Capital_Letter_Un              : constant Unicode_Char := 16#10B3#;
   Georgian_Capital_Letter_Phar            : constant Unicode_Char := 16#10B4#;
   Georgian_Capital_Letter_Khar            : constant Unicode_Char := 16#10B5#;
   Georgian_Capital_Letter_Ghan            : constant Unicode_Char := 16#10B6#;
   Georgian_Capital_Letter_Qar             : constant Unicode_Char := 16#10B7#;
   Georgian_Capital_Letter_Shin            : constant Unicode_Char := 16#10B8#;
   Georgian_Capital_Letter_Chin            : constant Unicode_Char := 16#10B9#;
   Georgian_Capital_Letter_Can             : constant Unicode_Char := 16#10BA#;
   Georgian_Capital_Letter_Jil             : constant Unicode_Char := 16#10BB#;
   Georgian_Capital_Letter_Cil             : constant Unicode_Char := 16#10BC#;
   Georgian_Capital_Letter_Char            : constant Unicode_Char := 16#10BD#;
   Georgian_Capital_Letter_Xan             : constant Unicode_Char := 16#10BE#;
   Georgian_Capital_Letter_Jhan            : constant Unicode_Char := 16#10BF#;
   Georgian_Capital_Letter_Hae             : constant Unicode_Char := 16#10C0#;
   Georgian_Capital_Letter_He              : constant Unicode_Char := 16#10C1#;
   Georgian_Capital_Letter_Hie             : constant Unicode_Char := 16#10C2#;
   Georgian_Capital_Letter_We              : constant Unicode_Char := 16#10C3#;
   Georgian_Capital_Letter_Har             : constant Unicode_Char := 16#10C4#;
   Georgian_Capital_Letter_Hoe             : constant Unicode_Char := 16#10C5#;
   Georgian_Capital_Letter_Yn              : constant Unicode_Char := 16#10C7#;
   Georgian_Capital_Letter_Aen             : constant Unicode_Char := 16#10CD#;
   Georgian_Letter_An                      : constant Unicode_Char := 16#10D0#;
   Georgian_Letter_Ban                     : constant Unicode_Char := 16#10D1#;
   Georgian_Letter_Gan                     : constant Unicode_Char := 16#10D2#;
   Georgian_Letter_Don                     : constant Unicode_Char := 16#10D3#;
   Georgian_Letter_En                      : constant Unicode_Char := 16#10D4#;
   Georgian_Letter_Vin                     : constant Unicode_Char := 16#10D5#;
   Georgian_Letter_Zen                     : constant Unicode_Char := 16#10D6#;
   Georgian_Letter_Tan                     : constant Unicode_Char := 16#10D7#;
   Georgian_Letter_In                      : constant Unicode_Char := 16#10D8#;
   Georgian_Letter_Kan                     : constant Unicode_Char := 16#10D9#;
   Georgian_Letter_Las                     : constant Unicode_Char := 16#10DA#;
   Georgian_Letter_Man                     : constant Unicode_Char := 16#10DB#;
   Georgian_Letter_Nar                     : constant Unicode_Char := 16#10DC#;
   Georgian_Letter_On                      : constant Unicode_Char := 16#10DD#;
   Georgian_Letter_Par                     : constant Unicode_Char := 16#10DE#;
   Georgian_Letter_Zhar                    : constant Unicode_Char := 16#10DF#;
   Georgian_Letter_Rae                     : constant Unicode_Char := 16#10E0#;
   Georgian_Letter_San                     : constant Unicode_Char := 16#10E1#;
   Georgian_Letter_Tar                     : constant Unicode_Char := 16#10E2#;
   Georgian_Letter_Un                      : constant Unicode_Char := 16#10E3#;
   Georgian_Letter_Phar                    : constant Unicode_Char := 16#10E4#;
   Georgian_Letter_Khar                    : constant Unicode_Char := 16#10E5#;
   Georgian_Letter_Ghan                    : constant Unicode_Char := 16#10E6#;
   Georgian_Letter_Qar                     : constant Unicode_Char := 16#10E7#;
   Georgian_Letter_Shin                    : constant Unicode_Char := 16#10E8#;
   Georgian_Letter_Chin                    : constant Unicode_Char := 16#10E9#;
   Georgian_Letter_Can                     : constant Unicode_Char := 16#10EA#;
   Georgian_Letter_Jil                     : constant Unicode_Char := 16#10EB#;
   Georgian_Letter_Cil                     : constant Unicode_Char := 16#10EC#;
   Georgian_Letter_Char                    : constant Unicode_Char := 16#10ED#;
   Georgian_Letter_Xan                     : constant Unicode_Char := 16#10EE#;
   Georgian_Letter_Jhan                    : constant Unicode_Char := 16#10EF#;
   Georgian_Letter_Hae                     : constant Unicode_Char := 16#10F0#;
   Georgian_Letter_He                      : constant Unicode_Char := 16#10F1#;
   Georgian_Letter_Hie                     : constant Unicode_Char := 16#10F2#;
   Georgian_Letter_We                      : constant Unicode_Char := 16#10F3#;
   Georgian_Letter_Har                     : constant Unicode_Char := 16#10F4#;
   Georgian_Letter_Hoe                     : constant Unicode_Char := 16#10F5#;
   Georgian_Letter_Fi                      : constant Unicode_Char := 16#10F6#;
   Georgian_Letter_Yn                      : constant Unicode_Char := 16#10F7#;
   Georgian_Letter_Elifi                   : constant Unicode_Char := 16#10F8#;
   Georgian_Letter_Turned_Gan              : constant Unicode_Char := 16#10F9#;
   Georgian_Letter_Ain                     : constant Unicode_Char := 16#10FA#;
   Georgian_Paragraph_Separator            : constant Unicode_Char := 16#10FB#;
   Modifier_Letter_Georgian_Nar            : constant Unicode_Char := 16#10FC#;
   Georgian_Letter_Aen                     : constant Unicode_Char := 16#10FD#;
   Georgian_Letter_Hard_Sign               : constant Unicode_Char := 16#10FE#;
   Georgian_Letter_Labial_Sign             : constant Unicode_Char := 16#10FF#;
end Unicode.Names.Georgian;
