--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.New_Tai_Lue is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   New_Tai_Lue_Letter_High_Qa              : constant Unicode_Char := 16#1980#;
   New_Tai_Lue_Letter_Low_Qa               : constant Unicode_Char := 16#1981#;
   New_Tai_Lue_Letter_High_Ka              : constant Unicode_Char := 16#1982#;
   New_Tai_Lue_Letter_High_Xa              : constant Unicode_Char := 16#1983#;
   New_Tai_Lue_Letter_High_Nga             : constant Unicode_Char := 16#1984#;
   New_Tai_Lue_Letter_Low_Ka               : constant Unicode_Char := 16#1985#;
   New_Tai_Lue_Letter_Low_Xa               : constant Unicode_Char := 16#1986#;
   New_Tai_Lue_Letter_Low_Nga              : constant Unicode_Char := 16#1987#;
   New_Tai_Lue_Letter_High_Tsa             : constant Unicode_Char := 16#1988#;
   New_Tai_Lue_Letter_High_Sa              : constant Unicode_Char := 16#1989#;
   New_Tai_Lue_Letter_High_Ya              : constant Unicode_Char := 16#198A#;
   New_Tai_Lue_Letter_Low_Tsa              : constant Unicode_Char := 16#198B#;
   New_Tai_Lue_Letter_Low_Sa               : constant Unicode_Char := 16#198C#;
   New_Tai_Lue_Letter_Low_Ya               : constant Unicode_Char := 16#198D#;
   New_Tai_Lue_Letter_High_Ta              : constant Unicode_Char := 16#198E#;
   New_Tai_Lue_Letter_High_Tha             : constant Unicode_Char := 16#198F#;
   New_Tai_Lue_Letter_High_Na              : constant Unicode_Char := 16#1990#;
   New_Tai_Lue_Letter_Low_Ta               : constant Unicode_Char := 16#1991#;
   New_Tai_Lue_Letter_Low_Tha              : constant Unicode_Char := 16#1992#;
   New_Tai_Lue_Letter_Low_Na               : constant Unicode_Char := 16#1993#;
   New_Tai_Lue_Letter_High_Pa              : constant Unicode_Char := 16#1994#;
   New_Tai_Lue_Letter_High_Pha             : constant Unicode_Char := 16#1995#;
   New_Tai_Lue_Letter_High_Ma              : constant Unicode_Char := 16#1996#;
   New_Tai_Lue_Letter_Low_Pa               : constant Unicode_Char := 16#1997#;
   New_Tai_Lue_Letter_Low_Pha              : constant Unicode_Char := 16#1998#;
   New_Tai_Lue_Letter_Low_Ma               : constant Unicode_Char := 16#1999#;
   New_Tai_Lue_Letter_High_Fa              : constant Unicode_Char := 16#199A#;
   New_Tai_Lue_Letter_High_Va              : constant Unicode_Char := 16#199B#;
   New_Tai_Lue_Letter_High_La              : constant Unicode_Char := 16#199C#;
   New_Tai_Lue_Letter_Low_Fa               : constant Unicode_Char := 16#199D#;
   New_Tai_Lue_Letter_Low_Va               : constant Unicode_Char := 16#199E#;
   New_Tai_Lue_Letter_Low_La               : constant Unicode_Char := 16#199F#;
   New_Tai_Lue_Letter_High_Ha              : constant Unicode_Char := 16#19A0#;
   New_Tai_Lue_Letter_High_Da              : constant Unicode_Char := 16#19A1#;
   New_Tai_Lue_Letter_High_Ba              : constant Unicode_Char := 16#19A2#;
   New_Tai_Lue_Letter_Low_Ha               : constant Unicode_Char := 16#19A3#;
   New_Tai_Lue_Letter_Low_Da               : constant Unicode_Char := 16#19A4#;
   New_Tai_Lue_Letter_Low_Ba               : constant Unicode_Char := 16#19A5#;
   New_Tai_Lue_Letter_High_Kva             : constant Unicode_Char := 16#19A6#;
   New_Tai_Lue_Letter_High_Xva             : constant Unicode_Char := 16#19A7#;
   New_Tai_Lue_Letter_Low_Kva              : constant Unicode_Char := 16#19A8#;
   New_Tai_Lue_Letter_Low_Xva              : constant Unicode_Char := 16#19A9#;
   New_Tai_Lue_Letter_High_Sua             : constant Unicode_Char := 16#19AA#;
   New_Tai_Lue_Letter_Low_Sua              : constant Unicode_Char := 16#19AB#;
   New_Tai_Lue_Vowel_Sign_Vowel_Shortener  : constant Unicode_Char := 16#19B0#;
   New_Tai_Lue_Vowel_Sign_Aa               : constant Unicode_Char := 16#19B1#;
   New_Tai_Lue_Vowel_Sign_Ii               : constant Unicode_Char := 16#19B2#;
   New_Tai_Lue_Vowel_Sign_U                : constant Unicode_Char := 16#19B3#;
   New_Tai_Lue_Vowel_Sign_Uu               : constant Unicode_Char := 16#19B4#;
   New_Tai_Lue_Vowel_Sign_E                : constant Unicode_Char := 16#19B5#;
   New_Tai_Lue_Vowel_Sign_Ae               : constant Unicode_Char := 16#19B6#;
   New_Tai_Lue_Vowel_Sign_O                : constant Unicode_Char := 16#19B7#;
   New_Tai_Lue_Vowel_Sign_Oa               : constant Unicode_Char := 16#19B8#;
   New_Tai_Lue_Vowel_Sign_Ue               : constant Unicode_Char := 16#19B9#;
   New_Tai_Lue_Vowel_Sign_Ay               : constant Unicode_Char := 16#19BA#;
   New_Tai_Lue_Vowel_Sign_Aay              : constant Unicode_Char := 16#19BB#;
   New_Tai_Lue_Vowel_Sign_Uy               : constant Unicode_Char := 16#19BC#;
   New_Tai_Lue_Vowel_Sign_Oy               : constant Unicode_Char := 16#19BD#;
   New_Tai_Lue_Vowel_Sign_Oay              : constant Unicode_Char := 16#19BE#;
   New_Tai_Lue_Vowel_Sign_Uey              : constant Unicode_Char := 16#19BF#;
   New_Tai_Lue_Vowel_Sign_Iy               : constant Unicode_Char := 16#19C0#;
   New_Tai_Lue_Letter_Final_V              : constant Unicode_Char := 16#19C1#;
   New_Tai_Lue_Letter_Final_Ng             : constant Unicode_Char := 16#19C2#;
   New_Tai_Lue_Letter_Final_N              : constant Unicode_Char := 16#19C3#;
   New_Tai_Lue_Letter_Final_M              : constant Unicode_Char := 16#19C4#;
   New_Tai_Lue_Letter_Final_K              : constant Unicode_Char := 16#19C5#;
   New_Tai_Lue_Letter_Final_D              : constant Unicode_Char := 16#19C6#;
   New_Tai_Lue_Letter_Final_B              : constant Unicode_Char := 16#19C7#;
   New_Tai_Lue_Tone_Mark_1                 : constant Unicode_Char := 16#19C8#;
   New_Tai_Lue_Tone_Mark_2                 : constant Unicode_Char := 16#19C9#;
   New_Tai_Lue_Digit_Zero                  : constant Unicode_Char := 16#19D0#;
   New_Tai_Lue_Digit_One                   : constant Unicode_Char := 16#19D1#;
   New_Tai_Lue_Digit_Two                   : constant Unicode_Char := 16#19D2#;
   New_Tai_Lue_Digit_Three                 : constant Unicode_Char := 16#19D3#;
   New_Tai_Lue_Digit_Four                  : constant Unicode_Char := 16#19D4#;
   New_Tai_Lue_Digit_Five                  : constant Unicode_Char := 16#19D5#;
   New_Tai_Lue_Digit_Six                   : constant Unicode_Char := 16#19D6#;
   New_Tai_Lue_Digit_Seven                 : constant Unicode_Char := 16#19D7#;
   New_Tai_Lue_Digit_Eight                 : constant Unicode_Char := 16#19D8#;
   New_Tai_Lue_Digit_Nine                  : constant Unicode_Char := 16#19D9#;
   New_Tai_Lue_Tham_Digit_One              : constant Unicode_Char := 16#19DA#;
   New_Tai_Lue_Sign_Lae                    : constant Unicode_Char := 16#19DE#;
   New_Tai_Lue_Sign_Laev                   : constant Unicode_Char := 16#19DF#;
end Unicode.Names.New_Tai_Lue;
