--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Yi_Radicals is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Yi_Radical_Qot                          : constant Unicode_Char := 16#A490#;
   Yi_Radical_Li                           : constant Unicode_Char := 16#A491#;
   Yi_Radical_Kit                          : constant Unicode_Char := 16#A492#;
   Yi_Radical_Nyip                         : constant Unicode_Char := 16#A493#;
   Yi_Radical_Cyp                          : constant Unicode_Char := 16#A494#;
   Yi_Radical_Ssi                          : constant Unicode_Char := 16#A495#;
   Yi_Radical_Ggop                         : constant Unicode_Char := 16#A496#;
   Yi_Radical_Gep                          : constant Unicode_Char := 16#A497#;
   Yi_Radical_Mi                           : constant Unicode_Char := 16#A498#;
   Yi_Radical_Hxit                         : constant Unicode_Char := 16#A499#;
   Yi_Radical_Lyr                          : constant Unicode_Char := 16#A49A#;
   Yi_Radical_Bbut                         : constant Unicode_Char := 16#A49B#;
   Yi_Radical_Mop                          : constant Unicode_Char := 16#A49C#;
   Yi_Radical_Yo                           : constant Unicode_Char := 16#A49D#;
   Yi_Radical_Put                          : constant Unicode_Char := 16#A49E#;
   Yi_Radical_Hxuo                         : constant Unicode_Char := 16#A49F#;
   Yi_Radical_Tat                          : constant Unicode_Char := 16#A4A0#;
   Yi_Radical_Ga                           : constant Unicode_Char := 16#A4A1#;
   Yi_Radical_Zup                          : constant Unicode_Char := 16#A4A2#;
   Yi_Radical_Cyt                          : constant Unicode_Char := 16#A4A3#;
   Yi_Radical_Ddur                         : constant Unicode_Char := 16#A4A4#;
   Yi_Radical_Bur                          : constant Unicode_Char := 16#A4A5#;
   Yi_Radical_Gguo                         : constant Unicode_Char := 16#A4A6#;
   Yi_Radical_Nyop                         : constant Unicode_Char := 16#A4A7#;
   Yi_Radical_Tu                           : constant Unicode_Char := 16#A4A8#;
   Yi_Radical_Op                           : constant Unicode_Char := 16#A4A9#;
   Yi_Radical_Jjut                         : constant Unicode_Char := 16#A4AA#;
   Yi_Radical_Zot                          : constant Unicode_Char := 16#A4AB#;
   Yi_Radical_Pyt                          : constant Unicode_Char := 16#A4AC#;
   Yi_Radical_Hmo                          : constant Unicode_Char := 16#A4AD#;
   Yi_Radical_Yit                          : constant Unicode_Char := 16#A4AE#;
   Yi_Radical_Vur                          : constant Unicode_Char := 16#A4AF#;
   Yi_Radical_Shy                          : constant Unicode_Char := 16#A4B0#;
   Yi_Radical_Vep                          : constant Unicode_Char := 16#A4B1#;
   Yi_Radical_Za                           : constant Unicode_Char := 16#A4B2#;
   Yi_Radical_Jo                           : constant Unicode_Char := 16#A4B3#;
   Yi_Radical_Nzup                         : constant Unicode_Char := 16#A4B4#;
   Yi_Radical_Jjy                          : constant Unicode_Char := 16#A4B5#;
   Yi_Radical_Got                          : constant Unicode_Char := 16#A4B6#;
   Yi_Radical_Jjie                         : constant Unicode_Char := 16#A4B7#;
   Yi_Radical_Wo                           : constant Unicode_Char := 16#A4B8#;
   Yi_Radical_Du                           : constant Unicode_Char := 16#A4B9#;
   Yi_Radical_Shur                         : constant Unicode_Char := 16#A4BA#;
   Yi_Radical_Lie                          : constant Unicode_Char := 16#A4BB#;
   Yi_Radical_Cy                           : constant Unicode_Char := 16#A4BC#;
   Yi_Radical_Cuop                         : constant Unicode_Char := 16#A4BD#;
   Yi_Radical_Cip                          : constant Unicode_Char := 16#A4BE#;
   Yi_Radical_Hxop                         : constant Unicode_Char := 16#A4BF#;
   Yi_Radical_Shat                         : constant Unicode_Char := 16#A4C0#;
   Yi_Radical_Zur                          : constant Unicode_Char := 16#A4C1#;
   Yi_Radical_Shop                         : constant Unicode_Char := 16#A4C2#;
   Yi_Radical_Che                          : constant Unicode_Char := 16#A4C3#;
   Yi_Radical_Zziet                        : constant Unicode_Char := 16#A4C4#;
   Yi_Radical_Nbie                         : constant Unicode_Char := 16#A4C5#;
   Yi_Radical_Ke                           : constant Unicode_Char := 16#A4C6#;
end Unicode.Names.Yi_Radicals;
