--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Yi_Syllables is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Yi_Syllable_It                          : constant Unicode_Char := 16#A000#;
   Yi_Syllable_Ix                          : constant Unicode_Char := 16#A001#;
   Yi_Syllable_I                           : constant Unicode_Char := 16#A002#;
   Yi_Syllable_Ip                          : constant Unicode_Char := 16#A003#;
   Yi_Syllable_Iet                         : constant Unicode_Char := 16#A004#;
   Yi_Syllable_Iex                         : constant Unicode_Char := 16#A005#;
   Yi_Syllable_Ie                          : constant Unicode_Char := 16#A006#;
   Yi_Syllable_Iep                         : constant Unicode_Char := 16#A007#;
   Yi_Syllable_At                          : constant Unicode_Char := 16#A008#;
   Yi_Syllable_Ax                          : constant Unicode_Char := 16#A009#;
   Yi_Syllable_A                           : constant Unicode_Char := 16#A00A#;
   Yi_Syllable_Ap                          : constant Unicode_Char := 16#A00B#;
   Yi_Syllable_Uox                         : constant Unicode_Char := 16#A00C#;
   Yi_Syllable_Uo                          : constant Unicode_Char := 16#A00D#;
   Yi_Syllable_Uop                         : constant Unicode_Char := 16#A00E#;
   Yi_Syllable_Ot                          : constant Unicode_Char := 16#A00F#;
   Yi_Syllable_Ox                          : constant Unicode_Char := 16#A010#;
   Yi_Syllable_O                           : constant Unicode_Char := 16#A011#;
   Yi_Syllable_Op                          : constant Unicode_Char := 16#A012#;
   Yi_Syllable_Ex                          : constant Unicode_Char := 16#A013#;
   Yi_Syllable_E                           : constant Unicode_Char := 16#A014#;
   Yi_Syllable_Wu                          : constant Unicode_Char := 16#A015#;
   Yi_Syllable_Iteration_Mark              :
      Unicode_Char renames Yi_Syllable_Wu;
   Yi_Syllable_Bit                         : constant Unicode_Char := 16#A016#;
   Yi_Syllable_Bix                         : constant Unicode_Char := 16#A017#;
   Yi_Syllable_Bi                          : constant Unicode_Char := 16#A018#;
   Yi_Syllable_Bip                         : constant Unicode_Char := 16#A019#;
   Yi_Syllable_Biet                        : constant Unicode_Char := 16#A01A#;
   Yi_Syllable_Biex                        : constant Unicode_Char := 16#A01B#;
   Yi_Syllable_Bie                         : constant Unicode_Char := 16#A01C#;
   Yi_Syllable_Biep                        : constant Unicode_Char := 16#A01D#;
   Yi_Syllable_Bat                         : constant Unicode_Char := 16#A01E#;
   Yi_Syllable_Bax                         : constant Unicode_Char := 16#A01F#;
   Yi_Syllable_Ba                          : constant Unicode_Char := 16#A020#;
   Yi_Syllable_Bap                         : constant Unicode_Char := 16#A021#;
   Yi_Syllable_Buox                        : constant Unicode_Char := 16#A022#;
   Yi_Syllable_Buo                         : constant Unicode_Char := 16#A023#;
   Yi_Syllable_Buop                        : constant Unicode_Char := 16#A024#;
   Yi_Syllable_Bot                         : constant Unicode_Char := 16#A025#;
   Yi_Syllable_Box                         : constant Unicode_Char := 16#A026#;
   Yi_Syllable_Bo                          : constant Unicode_Char := 16#A027#;
   Yi_Syllable_Bop                         : constant Unicode_Char := 16#A028#;
   Yi_Syllable_Bex                         : constant Unicode_Char := 16#A029#;
   Yi_Syllable_Be                          : constant Unicode_Char := 16#A02A#;
   Yi_Syllable_Bep                         : constant Unicode_Char := 16#A02B#;
   Yi_Syllable_But                         : constant Unicode_Char := 16#A02C#;
   Yi_Syllable_Bux                         : constant Unicode_Char := 16#A02D#;
   Yi_Syllable_Bu                          : constant Unicode_Char := 16#A02E#;
   Yi_Syllable_Bup                         : constant Unicode_Char := 16#A02F#;
   Yi_Syllable_Burx                        : constant Unicode_Char := 16#A030#;
   Yi_Syllable_Bur                         : constant Unicode_Char := 16#A031#;
   Yi_Syllable_Byt                         : constant Unicode_Char := 16#A032#;
   Yi_Syllable_Byx                         : constant Unicode_Char := 16#A033#;
   Yi_Syllable_By                          : constant Unicode_Char := 16#A034#;
   Yi_Syllable_Byp                         : constant Unicode_Char := 16#A035#;
   Yi_Syllable_Byrx                        : constant Unicode_Char := 16#A036#;
   Yi_Syllable_Byr                         : constant Unicode_Char := 16#A037#;
   Yi_Syllable_Pit                         : constant Unicode_Char := 16#A038#;
   Yi_Syllable_Pix                         : constant Unicode_Char := 16#A039#;
   Yi_Syllable_Pi                          : constant Unicode_Char := 16#A03A#;
   Yi_Syllable_Pip                         : constant Unicode_Char := 16#A03B#;
   Yi_Syllable_Piex                        : constant Unicode_Char := 16#A03C#;
   Yi_Syllable_Pie                         : constant Unicode_Char := 16#A03D#;
   Yi_Syllable_Piep                        : constant Unicode_Char := 16#A03E#;
   Yi_Syllable_Pat                         : constant Unicode_Char := 16#A03F#;
   Yi_Syllable_Pax                         : constant Unicode_Char := 16#A040#;
   Yi_Syllable_Pa                          : constant Unicode_Char := 16#A041#;
   Yi_Syllable_Pap                         : constant Unicode_Char := 16#A042#;
   Yi_Syllable_Puox                        : constant Unicode_Char := 16#A043#;
   Yi_Syllable_Puo                         : constant Unicode_Char := 16#A044#;
   Yi_Syllable_Puop                        : constant Unicode_Char := 16#A045#;
   Yi_Syllable_Pot                         : constant Unicode_Char := 16#A046#;
   Yi_Syllable_Pox                         : constant Unicode_Char := 16#A047#;
   Yi_Syllable_Po                          : constant Unicode_Char := 16#A048#;
   Yi_Syllable_Pop                         : constant Unicode_Char := 16#A049#;
   Yi_Syllable_Put                         : constant Unicode_Char := 16#A04A#;
   Yi_Syllable_Pux                         : constant Unicode_Char := 16#A04B#;
   Yi_Syllable_Pu                          : constant Unicode_Char := 16#A04C#;
   Yi_Syllable_Pup                         : constant Unicode_Char := 16#A04D#;
   Yi_Syllable_Purx                        : constant Unicode_Char := 16#A04E#;
   Yi_Syllable_Pur                         : constant Unicode_Char := 16#A04F#;
   Yi_Syllable_Pyt                         : constant Unicode_Char := 16#A050#;
   Yi_Syllable_Pyx                         : constant Unicode_Char := 16#A051#;
   Yi_Syllable_Py                          : constant Unicode_Char := 16#A052#;
   Yi_Syllable_Pyp                         : constant Unicode_Char := 16#A053#;
   Yi_Syllable_Pyrx                        : constant Unicode_Char := 16#A054#;
   Yi_Syllable_Pyr                         : constant Unicode_Char := 16#A055#;
   Yi_Syllable_Bbit                        : constant Unicode_Char := 16#A056#;
   Yi_Syllable_Bbix                        : constant Unicode_Char := 16#A057#;
   Yi_Syllable_Bbi                         : constant Unicode_Char := 16#A058#;
   Yi_Syllable_Bbip                        : constant Unicode_Char := 16#A059#;
   Yi_Syllable_Bbiet                       : constant Unicode_Char := 16#A05A#;
   Yi_Syllable_Bbiex                       : constant Unicode_Char := 16#A05B#;
   Yi_Syllable_Bbie                        : constant Unicode_Char := 16#A05C#;
   Yi_Syllable_Bbiep                       : constant Unicode_Char := 16#A05D#;
   Yi_Syllable_Bbat                        : constant Unicode_Char := 16#A05E#;
   Yi_Syllable_Bbax                        : constant Unicode_Char := 16#A05F#;
   Yi_Syllable_Bba                         : constant Unicode_Char := 16#A060#;
   Yi_Syllable_Bbap                        : constant Unicode_Char := 16#A061#;
   Yi_Syllable_Bbuox                       : constant Unicode_Char := 16#A062#;
   Yi_Syllable_Bbuo                        : constant Unicode_Char := 16#A063#;
   Yi_Syllable_Bbuop                       : constant Unicode_Char := 16#A064#;
   Yi_Syllable_Bbot                        : constant Unicode_Char := 16#A065#;
   Yi_Syllable_Bbox                        : constant Unicode_Char := 16#A066#;
   Yi_Syllable_Bbo                         : constant Unicode_Char := 16#A067#;
   Yi_Syllable_Bbop                        : constant Unicode_Char := 16#A068#;
   Yi_Syllable_Bbex                        : constant Unicode_Char := 16#A069#;
   Yi_Syllable_Bbe                         : constant Unicode_Char := 16#A06A#;
   Yi_Syllable_Bbep                        : constant Unicode_Char := 16#A06B#;
   Yi_Syllable_Bbut                        : constant Unicode_Char := 16#A06C#;
   Yi_Syllable_Bbux                        : constant Unicode_Char := 16#A06D#;
   Yi_Syllable_Bbu                         : constant Unicode_Char := 16#A06E#;
   Yi_Syllable_Bbup                        : constant Unicode_Char := 16#A06F#;
   Yi_Syllable_Bburx                       : constant Unicode_Char := 16#A070#;
   Yi_Syllable_Bbur                        : constant Unicode_Char := 16#A071#;
   Yi_Syllable_Bbyt                        : constant Unicode_Char := 16#A072#;
   Yi_Syllable_Bbyx                        : constant Unicode_Char := 16#A073#;
   Yi_Syllable_Bby                         : constant Unicode_Char := 16#A074#;
   Yi_Syllable_Bbyp                        : constant Unicode_Char := 16#A075#;
   Yi_Syllable_Nbit                        : constant Unicode_Char := 16#A076#;
   Yi_Syllable_Nbix                        : constant Unicode_Char := 16#A077#;
   Yi_Syllable_Nbi                         : constant Unicode_Char := 16#A078#;
   Yi_Syllable_Nbip                        : constant Unicode_Char := 16#A079#;
   Yi_Syllable_Nbiex                       : constant Unicode_Char := 16#A07A#;
   Yi_Syllable_Nbie                        : constant Unicode_Char := 16#A07B#;
   Yi_Syllable_Nbiep                       : constant Unicode_Char := 16#A07C#;
   Yi_Syllable_Nbat                        : constant Unicode_Char := 16#A07D#;
   Yi_Syllable_Nbax                        : constant Unicode_Char := 16#A07E#;
   Yi_Syllable_Nba                         : constant Unicode_Char := 16#A07F#;
   Yi_Syllable_Nbap                        : constant Unicode_Char := 16#A080#;
   Yi_Syllable_Nbot                        : constant Unicode_Char := 16#A081#;
   Yi_Syllable_Nbox                        : constant Unicode_Char := 16#A082#;
   Yi_Syllable_Nbo                         : constant Unicode_Char := 16#A083#;
   Yi_Syllable_Nbop                        : constant Unicode_Char := 16#A084#;
   Yi_Syllable_Nbut                        : constant Unicode_Char := 16#A085#;
   Yi_Syllable_Nbux                        : constant Unicode_Char := 16#A086#;
   Yi_Syllable_Nbu                         : constant Unicode_Char := 16#A087#;
   Yi_Syllable_Nbup                        : constant Unicode_Char := 16#A088#;
   Yi_Syllable_Nburx                       : constant Unicode_Char := 16#A089#;
   Yi_Syllable_Nbur                        : constant Unicode_Char := 16#A08A#;
   Yi_Syllable_Nbyt                        : constant Unicode_Char := 16#A08B#;
   Yi_Syllable_Nbyx                        : constant Unicode_Char := 16#A08C#;
   Yi_Syllable_Nby                         : constant Unicode_Char := 16#A08D#;
   Yi_Syllable_Nbyp                        : constant Unicode_Char := 16#A08E#;
   Yi_Syllable_Nbyrx                       : constant Unicode_Char := 16#A08F#;
   Yi_Syllable_Nbyr                        : constant Unicode_Char := 16#A090#;
   Yi_Syllable_Hmit                        : constant Unicode_Char := 16#A091#;
   Yi_Syllable_Hmix                        : constant Unicode_Char := 16#A092#;
   Yi_Syllable_Hmi                         : constant Unicode_Char := 16#A093#;
   Yi_Syllable_Hmip                        : constant Unicode_Char := 16#A094#;
   Yi_Syllable_Hmiex                       : constant Unicode_Char := 16#A095#;
   Yi_Syllable_Hmie                        : constant Unicode_Char := 16#A096#;
   Yi_Syllable_Hmiep                       : constant Unicode_Char := 16#A097#;
   Yi_Syllable_Hmat                        : constant Unicode_Char := 16#A098#;
   Yi_Syllable_Hmax                        : constant Unicode_Char := 16#A099#;
   Yi_Syllable_Hma                         : constant Unicode_Char := 16#A09A#;
   Yi_Syllable_Hmap                        : constant Unicode_Char := 16#A09B#;
   Yi_Syllable_Hmuox                       : constant Unicode_Char := 16#A09C#;
   Yi_Syllable_Hmuo                        : constant Unicode_Char := 16#A09D#;
   Yi_Syllable_Hmuop                       : constant Unicode_Char := 16#A09E#;
   Yi_Syllable_Hmot                        : constant Unicode_Char := 16#A09F#;
   Yi_Syllable_Hmox                        : constant Unicode_Char := 16#A0A0#;
   Yi_Syllable_Hmo                         : constant Unicode_Char := 16#A0A1#;
   Yi_Syllable_Hmop                        : constant Unicode_Char := 16#A0A2#;
   Yi_Syllable_Hmut                        : constant Unicode_Char := 16#A0A3#;
   Yi_Syllable_Hmux                        : constant Unicode_Char := 16#A0A4#;
   Yi_Syllable_Hmu                         : constant Unicode_Char := 16#A0A5#;
   Yi_Syllable_Hmup                        : constant Unicode_Char := 16#A0A6#;
   Yi_Syllable_Hmurx                       : constant Unicode_Char := 16#A0A7#;
   Yi_Syllable_Hmur                        : constant Unicode_Char := 16#A0A8#;
   Yi_Syllable_Hmyx                        : constant Unicode_Char := 16#A0A9#;
   Yi_Syllable_Hmy                         : constant Unicode_Char := 16#A0AA#;
   Yi_Syllable_Hmyp                        : constant Unicode_Char := 16#A0AB#;
   Yi_Syllable_Hmyrx                       : constant Unicode_Char := 16#A0AC#;
   Yi_Syllable_Hmyr                        : constant Unicode_Char := 16#A0AD#;
   Yi_Syllable_Mit                         : constant Unicode_Char := 16#A0AE#;
   Yi_Syllable_Mix                         : constant Unicode_Char := 16#A0AF#;
   Yi_Syllable_Mi                          : constant Unicode_Char := 16#A0B0#;
   Yi_Syllable_Mip                         : constant Unicode_Char := 16#A0B1#;
   Yi_Syllable_Miex                        : constant Unicode_Char := 16#A0B2#;
   Yi_Syllable_Mie                         : constant Unicode_Char := 16#A0B3#;
   Yi_Syllable_Miep                        : constant Unicode_Char := 16#A0B4#;
   Yi_Syllable_Mat                         : constant Unicode_Char := 16#A0B5#;
   Yi_Syllable_Max                         : constant Unicode_Char := 16#A0B6#;
   Yi_Syllable_Ma                          : constant Unicode_Char := 16#A0B7#;
   Yi_Syllable_Map                         : constant Unicode_Char := 16#A0B8#;
   Yi_Syllable_Muot                        : constant Unicode_Char := 16#A0B9#;
   Yi_Syllable_Muox                        : constant Unicode_Char := 16#A0BA#;
   Yi_Syllable_Muo                         : constant Unicode_Char := 16#A0BB#;
   Yi_Syllable_Muop                        : constant Unicode_Char := 16#A0BC#;
   Yi_Syllable_Mot                         : constant Unicode_Char := 16#A0BD#;
   Yi_Syllable_Mox                         : constant Unicode_Char := 16#A0BE#;
   Yi_Syllable_Mo                          : constant Unicode_Char := 16#A0BF#;
   Yi_Syllable_Mop                         : constant Unicode_Char := 16#A0C0#;
   Yi_Syllable_Mex                         : constant Unicode_Char := 16#A0C1#;
   Yi_Syllable_Me                          : constant Unicode_Char := 16#A0C2#;
   Yi_Syllable_Mut                         : constant Unicode_Char := 16#A0C3#;
   Yi_Syllable_Mux                         : constant Unicode_Char := 16#A0C4#;
   Yi_Syllable_Mu                          : constant Unicode_Char := 16#A0C5#;
   Yi_Syllable_Mup                         : constant Unicode_Char := 16#A0C6#;
   Yi_Syllable_Murx                        : constant Unicode_Char := 16#A0C7#;
   Yi_Syllable_Mur                         : constant Unicode_Char := 16#A0C8#;
   Yi_Syllable_Myt                         : constant Unicode_Char := 16#A0C9#;
   Yi_Syllable_Myx                         : constant Unicode_Char := 16#A0CA#;
   Yi_Syllable_My                          : constant Unicode_Char := 16#A0CB#;
   Yi_Syllable_Myp                         : constant Unicode_Char := 16#A0CC#;
   Yi_Syllable_Fit                         : constant Unicode_Char := 16#A0CD#;
   Yi_Syllable_Fix                         : constant Unicode_Char := 16#A0CE#;
   Yi_Syllable_Fi                          : constant Unicode_Char := 16#A0CF#;
   Yi_Syllable_Fip                         : constant Unicode_Char := 16#A0D0#;
   Yi_Syllable_Fat                         : constant Unicode_Char := 16#A0D1#;
   Yi_Syllable_Fax                         : constant Unicode_Char := 16#A0D2#;
   Yi_Syllable_Fa                          : constant Unicode_Char := 16#A0D3#;
   Yi_Syllable_Fap                         : constant Unicode_Char := 16#A0D4#;
   Yi_Syllable_Fox                         : constant Unicode_Char := 16#A0D5#;
   Yi_Syllable_Fo                          : constant Unicode_Char := 16#A0D6#;
   Yi_Syllable_Fop                         : constant Unicode_Char := 16#A0D7#;
   Yi_Syllable_Fut                         : constant Unicode_Char := 16#A0D8#;
   Yi_Syllable_Fux                         : constant Unicode_Char := 16#A0D9#;
   Yi_Syllable_Fu                          : constant Unicode_Char := 16#A0DA#;
   Yi_Syllable_Fup                         : constant Unicode_Char := 16#A0DB#;
   Yi_Syllable_Furx                        : constant Unicode_Char := 16#A0DC#;
   Yi_Syllable_Fur                         : constant Unicode_Char := 16#A0DD#;
   Yi_Syllable_Fyt                         : constant Unicode_Char := 16#A0DE#;
   Yi_Syllable_Fyx                         : constant Unicode_Char := 16#A0DF#;
   Yi_Syllable_Fy                          : constant Unicode_Char := 16#A0E0#;
   Yi_Syllable_Fyp                         : constant Unicode_Char := 16#A0E1#;
   Yi_Syllable_Vit                         : constant Unicode_Char := 16#A0E2#;
   Yi_Syllable_Vix                         : constant Unicode_Char := 16#A0E3#;
   Yi_Syllable_Vi                          : constant Unicode_Char := 16#A0E4#;
   Yi_Syllable_Vip                         : constant Unicode_Char := 16#A0E5#;
   Yi_Syllable_Viet                        : constant Unicode_Char := 16#A0E6#;
   Yi_Syllable_Viex                        : constant Unicode_Char := 16#A0E7#;
   Yi_Syllable_Vie                         : constant Unicode_Char := 16#A0E8#;
   Yi_Syllable_Viep                        : constant Unicode_Char := 16#A0E9#;
   Yi_Syllable_Vat                         : constant Unicode_Char := 16#A0EA#;
   Yi_Syllable_Vax                         : constant Unicode_Char := 16#A0EB#;
   Yi_Syllable_Va                          : constant Unicode_Char := 16#A0EC#;
   Yi_Syllable_Vap                         : constant Unicode_Char := 16#A0ED#;
   Yi_Syllable_Vot                         : constant Unicode_Char := 16#A0EE#;
   Yi_Syllable_Vox                         : constant Unicode_Char := 16#A0EF#;
   Yi_Syllable_Vo                          : constant Unicode_Char := 16#A0F0#;
   Yi_Syllable_Vop                         : constant Unicode_Char := 16#A0F1#;
   Yi_Syllable_Vex                         : constant Unicode_Char := 16#A0F2#;
   Yi_Syllable_Vep                         : constant Unicode_Char := 16#A0F3#;
   Yi_Syllable_Vut                         : constant Unicode_Char := 16#A0F4#;
   Yi_Syllable_Vux                         : constant Unicode_Char := 16#A0F5#;
   Yi_Syllable_Vu                          : constant Unicode_Char := 16#A0F6#;
   Yi_Syllable_Vup                         : constant Unicode_Char := 16#A0F7#;
   Yi_Syllable_Vurx                        : constant Unicode_Char := 16#A0F8#;
   Yi_Syllable_Vur                         : constant Unicode_Char := 16#A0F9#;
   Yi_Syllable_Vyt                         : constant Unicode_Char := 16#A0FA#;
   Yi_Syllable_Vyx                         : constant Unicode_Char := 16#A0FB#;
   Yi_Syllable_Vy                          : constant Unicode_Char := 16#A0FC#;
   Yi_Syllable_Vyp                         : constant Unicode_Char := 16#A0FD#;
   Yi_Syllable_Vyrx                        : constant Unicode_Char := 16#A0FE#;
   Yi_Syllable_Vyr                         : constant Unicode_Char := 16#A0FF#;
   Yi_Syllable_Dit                         : constant Unicode_Char := 16#A100#;
   Yi_Syllable_Dix                         : constant Unicode_Char := 16#A101#;
   Yi_Syllable_Di                          : constant Unicode_Char := 16#A102#;
   Yi_Syllable_Dip                         : constant Unicode_Char := 16#A103#;
   Yi_Syllable_Diex                        : constant Unicode_Char := 16#A104#;
   Yi_Syllable_Die                         : constant Unicode_Char := 16#A105#;
   Yi_Syllable_Diep                        : constant Unicode_Char := 16#A106#;
   Yi_Syllable_Dat                         : constant Unicode_Char := 16#A107#;
   Yi_Syllable_Dax                         : constant Unicode_Char := 16#A108#;
   Yi_Syllable_Da                          : constant Unicode_Char := 16#A109#;
   Yi_Syllable_Dap                         : constant Unicode_Char := 16#A10A#;
   Yi_Syllable_Duox                        : constant Unicode_Char := 16#A10B#;
   Yi_Syllable_Duo                         : constant Unicode_Char := 16#A10C#;
   Yi_Syllable_Dot                         : constant Unicode_Char := 16#A10D#;
   Yi_Syllable_Dox                         : constant Unicode_Char := 16#A10E#;
   Yi_Syllable_Do                          : constant Unicode_Char := 16#A10F#;
   Yi_Syllable_Dop                         : constant Unicode_Char := 16#A110#;
   Yi_Syllable_Dex                         : constant Unicode_Char := 16#A111#;
   Yi_Syllable_De                          : constant Unicode_Char := 16#A112#;
   Yi_Syllable_Dep                         : constant Unicode_Char := 16#A113#;
   Yi_Syllable_Dut                         : constant Unicode_Char := 16#A114#;
   Yi_Syllable_Dux                         : constant Unicode_Char := 16#A115#;
   Yi_Syllable_Du                          : constant Unicode_Char := 16#A116#;
   Yi_Syllable_Dup                         : constant Unicode_Char := 16#A117#;
   Yi_Syllable_Durx                        : constant Unicode_Char := 16#A118#;
   Yi_Syllable_Dur                         : constant Unicode_Char := 16#A119#;
   Yi_Syllable_Tit                         : constant Unicode_Char := 16#A11A#;
   Yi_Syllable_Tix                         : constant Unicode_Char := 16#A11B#;
   Yi_Syllable_Ti                          : constant Unicode_Char := 16#A11C#;
   Yi_Syllable_Tip                         : constant Unicode_Char := 16#A11D#;
   Yi_Syllable_Tiex                        : constant Unicode_Char := 16#A11E#;
   Yi_Syllable_Tie                         : constant Unicode_Char := 16#A11F#;
   Yi_Syllable_Tiep                        : constant Unicode_Char := 16#A120#;
   Yi_Syllable_Tat                         : constant Unicode_Char := 16#A121#;
   Yi_Syllable_Tax                         : constant Unicode_Char := 16#A122#;
   Yi_Syllable_Ta                          : constant Unicode_Char := 16#A123#;
   Yi_Syllable_Tap                         : constant Unicode_Char := 16#A124#;
   Yi_Syllable_Tuot                        : constant Unicode_Char := 16#A125#;
   Yi_Syllable_Tuox                        : constant Unicode_Char := 16#A126#;
   Yi_Syllable_Tuo                         : constant Unicode_Char := 16#A127#;
   Yi_Syllable_Tuop                        : constant Unicode_Char := 16#A128#;
   Yi_Syllable_Tot                         : constant Unicode_Char := 16#A129#;
   Yi_Syllable_Tox                         : constant Unicode_Char := 16#A12A#;
   Yi_Syllable_To                          : constant Unicode_Char := 16#A12B#;
   Yi_Syllable_Top                         : constant Unicode_Char := 16#A12C#;
   Yi_Syllable_Tex                         : constant Unicode_Char := 16#A12D#;
   Yi_Syllable_Te                          : constant Unicode_Char := 16#A12E#;
   Yi_Syllable_Tep                         : constant Unicode_Char := 16#A12F#;
   Yi_Syllable_Tut                         : constant Unicode_Char := 16#A130#;
   Yi_Syllable_Tux                         : constant Unicode_Char := 16#A131#;
   Yi_Syllable_Tu                          : constant Unicode_Char := 16#A132#;
   Yi_Syllable_Tup                         : constant Unicode_Char := 16#A133#;
   Yi_Syllable_Turx                        : constant Unicode_Char := 16#A134#;
   Yi_Syllable_Tur                         : constant Unicode_Char := 16#A135#;
   Yi_Syllable_Ddit                        : constant Unicode_Char := 16#A136#;
   Yi_Syllable_Ddix                        : constant Unicode_Char := 16#A137#;
   Yi_Syllable_Ddi                         : constant Unicode_Char := 16#A138#;
   Yi_Syllable_Ddip                        : constant Unicode_Char := 16#A139#;
   Yi_Syllable_Ddiex                       : constant Unicode_Char := 16#A13A#;
   Yi_Syllable_Ddie                        : constant Unicode_Char := 16#A13B#;
   Yi_Syllable_Ddiep                       : constant Unicode_Char := 16#A13C#;
   Yi_Syllable_Ddat                        : constant Unicode_Char := 16#A13D#;
   Yi_Syllable_Ddax                        : constant Unicode_Char := 16#A13E#;
   Yi_Syllable_Dda                         : constant Unicode_Char := 16#A13F#;
   Yi_Syllable_Ddap                        : constant Unicode_Char := 16#A140#;
   Yi_Syllable_Dduox                       : constant Unicode_Char := 16#A141#;
   Yi_Syllable_Dduo                        : constant Unicode_Char := 16#A142#;
   Yi_Syllable_Dduop                       : constant Unicode_Char := 16#A143#;
   Yi_Syllable_Ddot                        : constant Unicode_Char := 16#A144#;
   Yi_Syllable_Ddox                        : constant Unicode_Char := 16#A145#;
   Yi_Syllable_Ddo                         : constant Unicode_Char := 16#A146#;
   Yi_Syllable_Ddop                        : constant Unicode_Char := 16#A147#;
   Yi_Syllable_Ddex                        : constant Unicode_Char := 16#A148#;
   Yi_Syllable_Dde                         : constant Unicode_Char := 16#A149#;
   Yi_Syllable_Ddep                        : constant Unicode_Char := 16#A14A#;
   Yi_Syllable_Ddut                        : constant Unicode_Char := 16#A14B#;
   Yi_Syllable_Ddux                        : constant Unicode_Char := 16#A14C#;
   Yi_Syllable_Ddu                         : constant Unicode_Char := 16#A14D#;
   Yi_Syllable_Ddup                        : constant Unicode_Char := 16#A14E#;
   Yi_Syllable_Ddurx                       : constant Unicode_Char := 16#A14F#;
   Yi_Syllable_Ddur                        : constant Unicode_Char := 16#A150#;
   Yi_Syllable_Ndit                        : constant Unicode_Char := 16#A151#;
   Yi_Syllable_Ndix                        : constant Unicode_Char := 16#A152#;
   Yi_Syllable_Ndi                         : constant Unicode_Char := 16#A153#;
   Yi_Syllable_Ndip                        : constant Unicode_Char := 16#A154#;
   Yi_Syllable_Ndiex                       : constant Unicode_Char := 16#A155#;
   Yi_Syllable_Ndie                        : constant Unicode_Char := 16#A156#;
   Yi_Syllable_Ndat                        : constant Unicode_Char := 16#A157#;
   Yi_Syllable_Ndax                        : constant Unicode_Char := 16#A158#;
   Yi_Syllable_Nda                         : constant Unicode_Char := 16#A159#;
   Yi_Syllable_Ndap                        : constant Unicode_Char := 16#A15A#;
   Yi_Syllable_Ndot                        : constant Unicode_Char := 16#A15B#;
   Yi_Syllable_Ndox                        : constant Unicode_Char := 16#A15C#;
   Yi_Syllable_Ndo                         : constant Unicode_Char := 16#A15D#;
   Yi_Syllable_Ndop                        : constant Unicode_Char := 16#A15E#;
   Yi_Syllable_Ndex                        : constant Unicode_Char := 16#A15F#;
   Yi_Syllable_Nde                         : constant Unicode_Char := 16#A160#;
   Yi_Syllable_Ndep                        : constant Unicode_Char := 16#A161#;
   Yi_Syllable_Ndut                        : constant Unicode_Char := 16#A162#;
   Yi_Syllable_Ndux                        : constant Unicode_Char := 16#A163#;
   Yi_Syllable_Ndu                         : constant Unicode_Char := 16#A164#;
   Yi_Syllable_Ndup                        : constant Unicode_Char := 16#A165#;
   Yi_Syllable_Ndurx                       : constant Unicode_Char := 16#A166#;
   Yi_Syllable_Ndur                        : constant Unicode_Char := 16#A167#;
   Yi_Syllable_Hnit                        : constant Unicode_Char := 16#A168#;
   Yi_Syllable_Hnix                        : constant Unicode_Char := 16#A169#;
   Yi_Syllable_Hni                         : constant Unicode_Char := 16#A16A#;
   Yi_Syllable_Hnip                        : constant Unicode_Char := 16#A16B#;
   Yi_Syllable_Hniet                       : constant Unicode_Char := 16#A16C#;
   Yi_Syllable_Hniex                       : constant Unicode_Char := 16#A16D#;
   Yi_Syllable_Hnie                        : constant Unicode_Char := 16#A16E#;
   Yi_Syllable_Hniep                       : constant Unicode_Char := 16#A16F#;
   Yi_Syllable_Hnat                        : constant Unicode_Char := 16#A170#;
   Yi_Syllable_Hnax                        : constant Unicode_Char := 16#A171#;
   Yi_Syllable_Hna                         : constant Unicode_Char := 16#A172#;
   Yi_Syllable_Hnap                        : constant Unicode_Char := 16#A173#;
   Yi_Syllable_Hnuox                       : constant Unicode_Char := 16#A174#;
   Yi_Syllable_Hnuo                        : constant Unicode_Char := 16#A175#;
   Yi_Syllable_Hnot                        : constant Unicode_Char := 16#A176#;
   Yi_Syllable_Hnox                        : constant Unicode_Char := 16#A177#;
   Yi_Syllable_Hnop                        : constant Unicode_Char := 16#A178#;
   Yi_Syllable_Hnex                        : constant Unicode_Char := 16#A179#;
   Yi_Syllable_Hne                         : constant Unicode_Char := 16#A17A#;
   Yi_Syllable_Hnep                        : constant Unicode_Char := 16#A17B#;
   Yi_Syllable_Hnut                        : constant Unicode_Char := 16#A17C#;
   Yi_Syllable_Nit                         : constant Unicode_Char := 16#A17D#;
   Yi_Syllable_Nix                         : constant Unicode_Char := 16#A17E#;
   Yi_Syllable_Ni                          : constant Unicode_Char := 16#A17F#;
   Yi_Syllable_Nip                         : constant Unicode_Char := 16#A180#;
   Yi_Syllable_Niex                        : constant Unicode_Char := 16#A181#;
   Yi_Syllable_Nie                         : constant Unicode_Char := 16#A182#;
   Yi_Syllable_Niep                        : constant Unicode_Char := 16#A183#;
   Yi_Syllable_Nax                         : constant Unicode_Char := 16#A184#;
   Yi_Syllable_Na                          : constant Unicode_Char := 16#A185#;
   Yi_Syllable_Nap                         : constant Unicode_Char := 16#A186#;
   Yi_Syllable_Nuox                        : constant Unicode_Char := 16#A187#;
   Yi_Syllable_Nuo                         : constant Unicode_Char := 16#A188#;
   Yi_Syllable_Nuop                        : constant Unicode_Char := 16#A189#;
   Yi_Syllable_Not                         : constant Unicode_Char := 16#A18A#;
   Yi_Syllable_Nox                         : constant Unicode_Char := 16#A18B#;
   Yi_Syllable_No                          : constant Unicode_Char := 16#A18C#;
   Yi_Syllable_Nop                         : constant Unicode_Char := 16#A18D#;
   Yi_Syllable_Nex                         : constant Unicode_Char := 16#A18E#;
   Yi_Syllable_Ne                          : constant Unicode_Char := 16#A18F#;
   Yi_Syllable_Nep                         : constant Unicode_Char := 16#A190#;
   Yi_Syllable_Nut                         : constant Unicode_Char := 16#A191#;
   Yi_Syllable_Nux                         : constant Unicode_Char := 16#A192#;
   Yi_Syllable_Nu                          : constant Unicode_Char := 16#A193#;
   Yi_Syllable_Nup                         : constant Unicode_Char := 16#A194#;
   Yi_Syllable_Nurx                        : constant Unicode_Char := 16#A195#;
   Yi_Syllable_Nur                         : constant Unicode_Char := 16#A196#;
   Yi_Syllable_Hlit                        : constant Unicode_Char := 16#A197#;
   Yi_Syllable_Hlix                        : constant Unicode_Char := 16#A198#;
   Yi_Syllable_Hli                         : constant Unicode_Char := 16#A199#;
   Yi_Syllable_Hlip                        : constant Unicode_Char := 16#A19A#;
   Yi_Syllable_Hliex                       : constant Unicode_Char := 16#A19B#;
   Yi_Syllable_Hlie                        : constant Unicode_Char := 16#A19C#;
   Yi_Syllable_Hliep                       : constant Unicode_Char := 16#A19D#;
   Yi_Syllable_Hlat                        : constant Unicode_Char := 16#A19E#;
   Yi_Syllable_Hlax                        : constant Unicode_Char := 16#A19F#;
   Yi_Syllable_Hla                         : constant Unicode_Char := 16#A1A0#;
   Yi_Syllable_Hlap                        : constant Unicode_Char := 16#A1A1#;
   Yi_Syllable_Hluox                       : constant Unicode_Char := 16#A1A2#;
   Yi_Syllable_Hluo                        : constant Unicode_Char := 16#A1A3#;
   Yi_Syllable_Hluop                       : constant Unicode_Char := 16#A1A4#;
   Yi_Syllable_Hlox                        : constant Unicode_Char := 16#A1A5#;
   Yi_Syllable_Hlo                         : constant Unicode_Char := 16#A1A6#;
   Yi_Syllable_Hlop                        : constant Unicode_Char := 16#A1A7#;
   Yi_Syllable_Hlex                        : constant Unicode_Char := 16#A1A8#;
   Yi_Syllable_Hle                         : constant Unicode_Char := 16#A1A9#;
   Yi_Syllable_Hlep                        : constant Unicode_Char := 16#A1AA#;
   Yi_Syllable_Hlut                        : constant Unicode_Char := 16#A1AB#;
   Yi_Syllable_Hlux                        : constant Unicode_Char := 16#A1AC#;
   Yi_Syllable_Hlu                         : constant Unicode_Char := 16#A1AD#;
   Yi_Syllable_Hlup                        : constant Unicode_Char := 16#A1AE#;
   Yi_Syllable_Hlurx                       : constant Unicode_Char := 16#A1AF#;
   Yi_Syllable_Hlur                        : constant Unicode_Char := 16#A1B0#;
   Yi_Syllable_Hlyt                        : constant Unicode_Char := 16#A1B1#;
   Yi_Syllable_Hlyx                        : constant Unicode_Char := 16#A1B2#;
   Yi_Syllable_Hly                         : constant Unicode_Char := 16#A1B3#;
   Yi_Syllable_Hlyp                        : constant Unicode_Char := 16#A1B4#;
   Yi_Syllable_Hlyrx                       : constant Unicode_Char := 16#A1B5#;
   Yi_Syllable_Hlyr                        : constant Unicode_Char := 16#A1B6#;
   Yi_Syllable_Lit                         : constant Unicode_Char := 16#A1B7#;
   Yi_Syllable_Lix                         : constant Unicode_Char := 16#A1B8#;
   Yi_Syllable_Li                          : constant Unicode_Char := 16#A1B9#;
   Yi_Syllable_Lip                         : constant Unicode_Char := 16#A1BA#;
   Yi_Syllable_Liet                        : constant Unicode_Char := 16#A1BB#;
   Yi_Syllable_Liex                        : constant Unicode_Char := 16#A1BC#;
   Yi_Syllable_Lie                         : constant Unicode_Char := 16#A1BD#;
   Yi_Syllable_Liep                        : constant Unicode_Char := 16#A1BE#;
   Yi_Syllable_Lat                         : constant Unicode_Char := 16#A1BF#;
   Yi_Syllable_Lax                         : constant Unicode_Char := 16#A1C0#;
   Yi_Syllable_La                          : constant Unicode_Char := 16#A1C1#;
   Yi_Syllable_Lap                         : constant Unicode_Char := 16#A1C2#;
   Yi_Syllable_Luot                        : constant Unicode_Char := 16#A1C3#;
   Yi_Syllable_Luox                        : constant Unicode_Char := 16#A1C4#;
   Yi_Syllable_Luo                         : constant Unicode_Char := 16#A1C5#;
   Yi_Syllable_Luop                        : constant Unicode_Char := 16#A1C6#;
   Yi_Syllable_Lot                         : constant Unicode_Char := 16#A1C7#;
   Yi_Syllable_Lox                         : constant Unicode_Char := 16#A1C8#;
   Yi_Syllable_Lo                          : constant Unicode_Char := 16#A1C9#;
   Yi_Syllable_Lop                         : constant Unicode_Char := 16#A1CA#;
   Yi_Syllable_Lex                         : constant Unicode_Char := 16#A1CB#;
   Yi_Syllable_Le                          : constant Unicode_Char := 16#A1CC#;
   Yi_Syllable_Lep                         : constant Unicode_Char := 16#A1CD#;
   Yi_Syllable_Lut                         : constant Unicode_Char := 16#A1CE#;
   Yi_Syllable_Lux                         : constant Unicode_Char := 16#A1CF#;
   Yi_Syllable_Lu                          : constant Unicode_Char := 16#A1D0#;
   Yi_Syllable_Lup                         : constant Unicode_Char := 16#A1D1#;
   Yi_Syllable_Lurx                        : constant Unicode_Char := 16#A1D2#;
   Yi_Syllable_Lur                         : constant Unicode_Char := 16#A1D3#;
   Yi_Syllable_Lyt                         : constant Unicode_Char := 16#A1D4#;
   Yi_Syllable_Lyx                         : constant Unicode_Char := 16#A1D5#;
   Yi_Syllable_Ly                          : constant Unicode_Char := 16#A1D6#;
   Yi_Syllable_Lyp                         : constant Unicode_Char := 16#A1D7#;
   Yi_Syllable_Lyrx                        : constant Unicode_Char := 16#A1D8#;
   Yi_Syllable_Lyr                         : constant Unicode_Char := 16#A1D9#;
   Yi_Syllable_Git                         : constant Unicode_Char := 16#A1DA#;
   Yi_Syllable_Gix                         : constant Unicode_Char := 16#A1DB#;
   Yi_Syllable_Gi                          : constant Unicode_Char := 16#A1DC#;
   Yi_Syllable_Gip                         : constant Unicode_Char := 16#A1DD#;
   Yi_Syllable_Giet                        : constant Unicode_Char := 16#A1DE#;
   Yi_Syllable_Giex                        : constant Unicode_Char := 16#A1DF#;
   Yi_Syllable_Gie                         : constant Unicode_Char := 16#A1E0#;
   Yi_Syllable_Giep                        : constant Unicode_Char := 16#A1E1#;
   Yi_Syllable_Gat                         : constant Unicode_Char := 16#A1E2#;
   Yi_Syllable_Gax                         : constant Unicode_Char := 16#A1E3#;
   Yi_Syllable_Ga                          : constant Unicode_Char := 16#A1E4#;
   Yi_Syllable_Gap                         : constant Unicode_Char := 16#A1E5#;
   Yi_Syllable_Guot                        : constant Unicode_Char := 16#A1E6#;
   Yi_Syllable_Guox                        : constant Unicode_Char := 16#A1E7#;
   Yi_Syllable_Guo                         : constant Unicode_Char := 16#A1E8#;
   Yi_Syllable_Guop                        : constant Unicode_Char := 16#A1E9#;
   Yi_Syllable_Got                         : constant Unicode_Char := 16#A1EA#;
   Yi_Syllable_Gox                         : constant Unicode_Char := 16#A1EB#;
   Yi_Syllable_Go                          : constant Unicode_Char := 16#A1EC#;
   Yi_Syllable_Gop                         : constant Unicode_Char := 16#A1ED#;
   Yi_Syllable_Get                         : constant Unicode_Char := 16#A1EE#;
   Yi_Syllable_Gex                         : constant Unicode_Char := 16#A1EF#;
   Yi_Syllable_Ge                          : constant Unicode_Char := 16#A1F0#;
   Yi_Syllable_Gep                         : constant Unicode_Char := 16#A1F1#;
   Yi_Syllable_Gut                         : constant Unicode_Char := 16#A1F2#;
   Yi_Syllable_Gux                         : constant Unicode_Char := 16#A1F3#;
   Yi_Syllable_Gu                          : constant Unicode_Char := 16#A1F4#;
   Yi_Syllable_Gup                         : constant Unicode_Char := 16#A1F5#;
   Yi_Syllable_Gurx                        : constant Unicode_Char := 16#A1F6#;
   Yi_Syllable_Gur                         : constant Unicode_Char := 16#A1F7#;
   Yi_Syllable_Kit                         : constant Unicode_Char := 16#A1F8#;
   Yi_Syllable_Kix                         : constant Unicode_Char := 16#A1F9#;
   Yi_Syllable_Ki                          : constant Unicode_Char := 16#A1FA#;
   Yi_Syllable_Kip                         : constant Unicode_Char := 16#A1FB#;
   Yi_Syllable_Kiex                        : constant Unicode_Char := 16#A1FC#;
   Yi_Syllable_Kie                         : constant Unicode_Char := 16#A1FD#;
   Yi_Syllable_Kiep                        : constant Unicode_Char := 16#A1FE#;
   Yi_Syllable_Kat                         : constant Unicode_Char := 16#A1FF#;
   Yi_Syllable_Kax                         : constant Unicode_Char := 16#A200#;
   Yi_Syllable_Ka                          : constant Unicode_Char := 16#A201#;
   Yi_Syllable_Kap                         : constant Unicode_Char := 16#A202#;
   Yi_Syllable_Kuox                        : constant Unicode_Char := 16#A203#;
   Yi_Syllable_Kuo                         : constant Unicode_Char := 16#A204#;
   Yi_Syllable_Kuop                        : constant Unicode_Char := 16#A205#;
   Yi_Syllable_Kot                         : constant Unicode_Char := 16#A206#;
   Yi_Syllable_Kox                         : constant Unicode_Char := 16#A207#;
   Yi_Syllable_Ko                          : constant Unicode_Char := 16#A208#;
   Yi_Syllable_Kop                         : constant Unicode_Char := 16#A209#;
   Yi_Syllable_Ket                         : constant Unicode_Char := 16#A20A#;
   Yi_Syllable_Kex                         : constant Unicode_Char := 16#A20B#;
   Yi_Syllable_Ke                          : constant Unicode_Char := 16#A20C#;
   Yi_Syllable_Kep                         : constant Unicode_Char := 16#A20D#;
   Yi_Syllable_Kut                         : constant Unicode_Char := 16#A20E#;
   Yi_Syllable_Kux                         : constant Unicode_Char := 16#A20F#;
   Yi_Syllable_Ku                          : constant Unicode_Char := 16#A210#;
   Yi_Syllable_Kup                         : constant Unicode_Char := 16#A211#;
   Yi_Syllable_Kurx                        : constant Unicode_Char := 16#A212#;
   Yi_Syllable_Kur                         : constant Unicode_Char := 16#A213#;
   Yi_Syllable_Ggit                        : constant Unicode_Char := 16#A214#;
   Yi_Syllable_Ggix                        : constant Unicode_Char := 16#A215#;
   Yi_Syllable_Ggi                         : constant Unicode_Char := 16#A216#;
   Yi_Syllable_Ggiex                       : constant Unicode_Char := 16#A217#;
   Yi_Syllable_Ggie                        : constant Unicode_Char := 16#A218#;
   Yi_Syllable_Ggiep                       : constant Unicode_Char := 16#A219#;
   Yi_Syllable_Ggat                        : constant Unicode_Char := 16#A21A#;
   Yi_Syllable_Ggax                        : constant Unicode_Char := 16#A21B#;
   Yi_Syllable_Gga                         : constant Unicode_Char := 16#A21C#;
   Yi_Syllable_Ggap                        : constant Unicode_Char := 16#A21D#;
   Yi_Syllable_Gguot                       : constant Unicode_Char := 16#A21E#;
   Yi_Syllable_Gguox                       : constant Unicode_Char := 16#A21F#;
   Yi_Syllable_Gguo                        : constant Unicode_Char := 16#A220#;
   Yi_Syllable_Gguop                       : constant Unicode_Char := 16#A221#;
   Yi_Syllable_Ggot                        : constant Unicode_Char := 16#A222#;
   Yi_Syllable_Ggox                        : constant Unicode_Char := 16#A223#;
   Yi_Syllable_Ggo                         : constant Unicode_Char := 16#A224#;
   Yi_Syllable_Ggop                        : constant Unicode_Char := 16#A225#;
   Yi_Syllable_Gget                        : constant Unicode_Char := 16#A226#;
   Yi_Syllable_Ggex                        : constant Unicode_Char := 16#A227#;
   Yi_Syllable_Gge                         : constant Unicode_Char := 16#A228#;
   Yi_Syllable_Ggep                        : constant Unicode_Char := 16#A229#;
   Yi_Syllable_Ggut                        : constant Unicode_Char := 16#A22A#;
   Yi_Syllable_Ggux                        : constant Unicode_Char := 16#A22B#;
   Yi_Syllable_Ggu                         : constant Unicode_Char := 16#A22C#;
   Yi_Syllable_Ggup                        : constant Unicode_Char := 16#A22D#;
   Yi_Syllable_Ggurx                       : constant Unicode_Char := 16#A22E#;
   Yi_Syllable_Ggur                        : constant Unicode_Char := 16#A22F#;
   Yi_Syllable_Mgiex                       : constant Unicode_Char := 16#A230#;
   Yi_Syllable_Mgie                        : constant Unicode_Char := 16#A231#;
   Yi_Syllable_Mgat                        : constant Unicode_Char := 16#A232#;
   Yi_Syllable_Mgax                        : constant Unicode_Char := 16#A233#;
   Yi_Syllable_Mga                         : constant Unicode_Char := 16#A234#;
   Yi_Syllable_Mgap                        : constant Unicode_Char := 16#A235#;
   Yi_Syllable_Mguox                       : constant Unicode_Char := 16#A236#;
   Yi_Syllable_Mguo                        : constant Unicode_Char := 16#A237#;
   Yi_Syllable_Mguop                       : constant Unicode_Char := 16#A238#;
   Yi_Syllable_Mgot                        : constant Unicode_Char := 16#A239#;
   Yi_Syllable_Mgox                        : constant Unicode_Char := 16#A23A#;
   Yi_Syllable_Mgo                         : constant Unicode_Char := 16#A23B#;
   Yi_Syllable_Mgop                        : constant Unicode_Char := 16#A23C#;
   Yi_Syllable_Mgex                        : constant Unicode_Char := 16#A23D#;
   Yi_Syllable_Mge                         : constant Unicode_Char := 16#A23E#;
   Yi_Syllable_Mgep                        : constant Unicode_Char := 16#A23F#;
   Yi_Syllable_Mgut                        : constant Unicode_Char := 16#A240#;
   Yi_Syllable_Mgux                        : constant Unicode_Char := 16#A241#;
   Yi_Syllable_Mgu                         : constant Unicode_Char := 16#A242#;
   Yi_Syllable_Mgup                        : constant Unicode_Char := 16#A243#;
   Yi_Syllable_Mgurx                       : constant Unicode_Char := 16#A244#;
   Yi_Syllable_Mgur                        : constant Unicode_Char := 16#A245#;
   Yi_Syllable_Hxit                        : constant Unicode_Char := 16#A246#;
   Yi_Syllable_Hxix                        : constant Unicode_Char := 16#A247#;
   Yi_Syllable_Hxi                         : constant Unicode_Char := 16#A248#;
   Yi_Syllable_Hxip                        : constant Unicode_Char := 16#A249#;
   Yi_Syllable_Hxiet                       : constant Unicode_Char := 16#A24A#;
   Yi_Syllable_Hxiex                       : constant Unicode_Char := 16#A24B#;
   Yi_Syllable_Hxie                        : constant Unicode_Char := 16#A24C#;
   Yi_Syllable_Hxiep                       : constant Unicode_Char := 16#A24D#;
   Yi_Syllable_Hxat                        : constant Unicode_Char := 16#A24E#;
   Yi_Syllable_Hxax                        : constant Unicode_Char := 16#A24F#;
   Yi_Syllable_Hxa                         : constant Unicode_Char := 16#A250#;
   Yi_Syllable_Hxap                        : constant Unicode_Char := 16#A251#;
   Yi_Syllable_Hxuot                       : constant Unicode_Char := 16#A252#;
   Yi_Syllable_Hxuox                       : constant Unicode_Char := 16#A253#;
   Yi_Syllable_Hxuo                        : constant Unicode_Char := 16#A254#;
   Yi_Syllable_Hxuop                       : constant Unicode_Char := 16#A255#;
   Yi_Syllable_Hxot                        : constant Unicode_Char := 16#A256#;
   Yi_Syllable_Hxox                        : constant Unicode_Char := 16#A257#;
   Yi_Syllable_Hxo                         : constant Unicode_Char := 16#A258#;
   Yi_Syllable_Hxop                        : constant Unicode_Char := 16#A259#;
   Yi_Syllable_Hxex                        : constant Unicode_Char := 16#A25A#;
   Yi_Syllable_Hxe                         : constant Unicode_Char := 16#A25B#;
   Yi_Syllable_Hxep                        : constant Unicode_Char := 16#A25C#;
   Yi_Syllable_Ngiex                       : constant Unicode_Char := 16#A25D#;
   Yi_Syllable_Ngie                        : constant Unicode_Char := 16#A25E#;
   Yi_Syllable_Ngiep                       : constant Unicode_Char := 16#A25F#;
   Yi_Syllable_Ngat                        : constant Unicode_Char := 16#A260#;
   Yi_Syllable_Ngax                        : constant Unicode_Char := 16#A261#;
   Yi_Syllable_Nga                         : constant Unicode_Char := 16#A262#;
   Yi_Syllable_Ngap                        : constant Unicode_Char := 16#A263#;
   Yi_Syllable_Nguot                       : constant Unicode_Char := 16#A264#;
   Yi_Syllable_Nguox                       : constant Unicode_Char := 16#A265#;
   Yi_Syllable_Nguo                        : constant Unicode_Char := 16#A266#;
   Yi_Syllable_Ngot                        : constant Unicode_Char := 16#A267#;
   Yi_Syllable_Ngox                        : constant Unicode_Char := 16#A268#;
   Yi_Syllable_Ngo                         : constant Unicode_Char := 16#A269#;
   Yi_Syllable_Ngop                        : constant Unicode_Char := 16#A26A#;
   Yi_Syllable_Ngex                        : constant Unicode_Char := 16#A26B#;
   Yi_Syllable_Nge                         : constant Unicode_Char := 16#A26C#;
   Yi_Syllable_Ngep                        : constant Unicode_Char := 16#A26D#;
   Yi_Syllable_Hit                         : constant Unicode_Char := 16#A26E#;
   Yi_Syllable_Hiex                        : constant Unicode_Char := 16#A26F#;
   Yi_Syllable_Hie                         : constant Unicode_Char := 16#A270#;
   Yi_Syllable_Hat                         : constant Unicode_Char := 16#A271#;
   Yi_Syllable_Hax                         : constant Unicode_Char := 16#A272#;
   Yi_Syllable_Ha                          : constant Unicode_Char := 16#A273#;
   Yi_Syllable_Hap                         : constant Unicode_Char := 16#A274#;
   Yi_Syllable_Huot                        : constant Unicode_Char := 16#A275#;
   Yi_Syllable_Huox                        : constant Unicode_Char := 16#A276#;
   Yi_Syllable_Huo                         : constant Unicode_Char := 16#A277#;
   Yi_Syllable_Huop                        : constant Unicode_Char := 16#A278#;
   Yi_Syllable_Hot                         : constant Unicode_Char := 16#A279#;
   Yi_Syllable_Hox                         : constant Unicode_Char := 16#A27A#;
   Yi_Syllable_Ho                          : constant Unicode_Char := 16#A27B#;
   Yi_Syllable_Hop                         : constant Unicode_Char := 16#A27C#;
   Yi_Syllable_Hex                         : constant Unicode_Char := 16#A27D#;
   Yi_Syllable_He                          : constant Unicode_Char := 16#A27E#;
   Yi_Syllable_Hep                         : constant Unicode_Char := 16#A27F#;
   Yi_Syllable_Wat                         : constant Unicode_Char := 16#A280#;
   Yi_Syllable_Wax                         : constant Unicode_Char := 16#A281#;
   Yi_Syllable_Wa                          : constant Unicode_Char := 16#A282#;
   Yi_Syllable_Wap                         : constant Unicode_Char := 16#A283#;
   Yi_Syllable_Wuox                        : constant Unicode_Char := 16#A284#;
   Yi_Syllable_Wuo                         : constant Unicode_Char := 16#A285#;
   Yi_Syllable_Wuop                        : constant Unicode_Char := 16#A286#;
   Yi_Syllable_Wox                         : constant Unicode_Char := 16#A287#;
   Yi_Syllable_Wo                          : constant Unicode_Char := 16#A288#;
   Yi_Syllable_Wop                         : constant Unicode_Char := 16#A289#;
   Yi_Syllable_Wex                         : constant Unicode_Char := 16#A28A#;
   Yi_Syllable_We                          : constant Unicode_Char := 16#A28B#;
   Yi_Syllable_Wep                         : constant Unicode_Char := 16#A28C#;
   Yi_Syllable_Zit                         : constant Unicode_Char := 16#A28D#;
   Yi_Syllable_Zix                         : constant Unicode_Char := 16#A28E#;
   Yi_Syllable_Zi                          : constant Unicode_Char := 16#A28F#;
   Yi_Syllable_Zip                         : constant Unicode_Char := 16#A290#;
   Yi_Syllable_Ziex                        : constant Unicode_Char := 16#A291#;
   Yi_Syllable_Zie                         : constant Unicode_Char := 16#A292#;
   Yi_Syllable_Ziep                        : constant Unicode_Char := 16#A293#;
   Yi_Syllable_Zat                         : constant Unicode_Char := 16#A294#;
   Yi_Syllable_Zax                         : constant Unicode_Char := 16#A295#;
   Yi_Syllable_Za                          : constant Unicode_Char := 16#A296#;
   Yi_Syllable_Zap                         : constant Unicode_Char := 16#A297#;
   Yi_Syllable_Zuox                        : constant Unicode_Char := 16#A298#;
   Yi_Syllable_Zuo                         : constant Unicode_Char := 16#A299#;
   Yi_Syllable_Zuop                        : constant Unicode_Char := 16#A29A#;
   Yi_Syllable_Zot                         : constant Unicode_Char := 16#A29B#;
   Yi_Syllable_Zox                         : constant Unicode_Char := 16#A29C#;
   Yi_Syllable_Zo                          : constant Unicode_Char := 16#A29D#;
   Yi_Syllable_Zop                         : constant Unicode_Char := 16#A29E#;
   Yi_Syllable_Zex                         : constant Unicode_Char := 16#A29F#;
   Yi_Syllable_Ze                          : constant Unicode_Char := 16#A2A0#;
   Yi_Syllable_Zep                         : constant Unicode_Char := 16#A2A1#;
   Yi_Syllable_Zut                         : constant Unicode_Char := 16#A2A2#;
   Yi_Syllable_Zux                         : constant Unicode_Char := 16#A2A3#;
   Yi_Syllable_Zu                          : constant Unicode_Char := 16#A2A4#;
   Yi_Syllable_Zup                         : constant Unicode_Char := 16#A2A5#;
   Yi_Syllable_Zurx                        : constant Unicode_Char := 16#A2A6#;
   Yi_Syllable_Zur                         : constant Unicode_Char := 16#A2A7#;
   Yi_Syllable_Zyt                         : constant Unicode_Char := 16#A2A8#;
   Yi_Syllable_Zyx                         : constant Unicode_Char := 16#A2A9#;
   Yi_Syllable_Zy                          : constant Unicode_Char := 16#A2AA#;
   Yi_Syllable_Zyp                         : constant Unicode_Char := 16#A2AB#;
   Yi_Syllable_Zyrx                        : constant Unicode_Char := 16#A2AC#;
   Yi_Syllable_Zyr                         : constant Unicode_Char := 16#A2AD#;
   Yi_Syllable_Cit                         : constant Unicode_Char := 16#A2AE#;
   Yi_Syllable_Cix                         : constant Unicode_Char := 16#A2AF#;
   Yi_Syllable_Ci                          : constant Unicode_Char := 16#A2B0#;
   Yi_Syllable_Cip                         : constant Unicode_Char := 16#A2B1#;
   Yi_Syllable_Ciet                        : constant Unicode_Char := 16#A2B2#;
   Yi_Syllable_Ciex                        : constant Unicode_Char := 16#A2B3#;
   Yi_Syllable_Cie                         : constant Unicode_Char := 16#A2B4#;
   Yi_Syllable_Ciep                        : constant Unicode_Char := 16#A2B5#;
   Yi_Syllable_Cat                         : constant Unicode_Char := 16#A2B6#;
   Yi_Syllable_Cax                         : constant Unicode_Char := 16#A2B7#;
   Yi_Syllable_Ca                          : constant Unicode_Char := 16#A2B8#;
   Yi_Syllable_Cap                         : constant Unicode_Char := 16#A2B9#;
   Yi_Syllable_Cuox                        : constant Unicode_Char := 16#A2BA#;
   Yi_Syllable_Cuo                         : constant Unicode_Char := 16#A2BB#;
   Yi_Syllable_Cuop                        : constant Unicode_Char := 16#A2BC#;
   Yi_Syllable_Cot                         : constant Unicode_Char := 16#A2BD#;
   Yi_Syllable_Cox                         : constant Unicode_Char := 16#A2BE#;
   Yi_Syllable_Co                          : constant Unicode_Char := 16#A2BF#;
   Yi_Syllable_Cop                         : constant Unicode_Char := 16#A2C0#;
   Yi_Syllable_Cex                         : constant Unicode_Char := 16#A2C1#;
   Yi_Syllable_Ce                          : constant Unicode_Char := 16#A2C2#;
   Yi_Syllable_Cep                         : constant Unicode_Char := 16#A2C3#;
   Yi_Syllable_Cut                         : constant Unicode_Char := 16#A2C4#;
   Yi_Syllable_Cux                         : constant Unicode_Char := 16#A2C5#;
   Yi_Syllable_Cu                          : constant Unicode_Char := 16#A2C6#;
   Yi_Syllable_Cup                         : constant Unicode_Char := 16#A2C7#;
   Yi_Syllable_Curx                        : constant Unicode_Char := 16#A2C8#;
   Yi_Syllable_Cur                         : constant Unicode_Char := 16#A2C9#;
   Yi_Syllable_Cyt                         : constant Unicode_Char := 16#A2CA#;
   Yi_Syllable_Cyx                         : constant Unicode_Char := 16#A2CB#;
   Yi_Syllable_Cy                          : constant Unicode_Char := 16#A2CC#;
   Yi_Syllable_Cyp                         : constant Unicode_Char := 16#A2CD#;
   Yi_Syllable_Cyrx                        : constant Unicode_Char := 16#A2CE#;
   Yi_Syllable_Cyr                         : constant Unicode_Char := 16#A2CF#;
   Yi_Syllable_Zzit                        : constant Unicode_Char := 16#A2D0#;
   Yi_Syllable_Zzix                        : constant Unicode_Char := 16#A2D1#;
   Yi_Syllable_Zzi                         : constant Unicode_Char := 16#A2D2#;
   Yi_Syllable_Zzip                        : constant Unicode_Char := 16#A2D3#;
   Yi_Syllable_Zziet                       : constant Unicode_Char := 16#A2D4#;
   Yi_Syllable_Zziex                       : constant Unicode_Char := 16#A2D5#;
   Yi_Syllable_Zzie                        : constant Unicode_Char := 16#A2D6#;
   Yi_Syllable_Zziep                       : constant Unicode_Char := 16#A2D7#;
   Yi_Syllable_Zzat                        : constant Unicode_Char := 16#A2D8#;
   Yi_Syllable_Zzax                        : constant Unicode_Char := 16#A2D9#;
   Yi_Syllable_Zza                         : constant Unicode_Char := 16#A2DA#;
   Yi_Syllable_Zzap                        : constant Unicode_Char := 16#A2DB#;
   Yi_Syllable_Zzox                        : constant Unicode_Char := 16#A2DC#;
   Yi_Syllable_Zzo                         : constant Unicode_Char := 16#A2DD#;
   Yi_Syllable_Zzop                        : constant Unicode_Char := 16#A2DE#;
   Yi_Syllable_Zzex                        : constant Unicode_Char := 16#A2DF#;
   Yi_Syllable_Zze                         : constant Unicode_Char := 16#A2E0#;
   Yi_Syllable_Zzep                        : constant Unicode_Char := 16#A2E1#;
   Yi_Syllable_Zzux                        : constant Unicode_Char := 16#A2E2#;
   Yi_Syllable_Zzu                         : constant Unicode_Char := 16#A2E3#;
   Yi_Syllable_Zzup                        : constant Unicode_Char := 16#A2E4#;
   Yi_Syllable_Zzurx                       : constant Unicode_Char := 16#A2E5#;
   Yi_Syllable_Zzur                        : constant Unicode_Char := 16#A2E6#;
   Yi_Syllable_Zzyt                        : constant Unicode_Char := 16#A2E7#;
   Yi_Syllable_Zzyx                        : constant Unicode_Char := 16#A2E8#;
   Yi_Syllable_Zzy                         : constant Unicode_Char := 16#A2E9#;
   Yi_Syllable_Zzyp                        : constant Unicode_Char := 16#A2EA#;
   Yi_Syllable_Zzyrx                       : constant Unicode_Char := 16#A2EB#;
   Yi_Syllable_Zzyr                        : constant Unicode_Char := 16#A2EC#;
   Yi_Syllable_Nzit                        : constant Unicode_Char := 16#A2ED#;
   Yi_Syllable_Nzix                        : constant Unicode_Char := 16#A2EE#;
   Yi_Syllable_Nzi                         : constant Unicode_Char := 16#A2EF#;
   Yi_Syllable_Nzip                        : constant Unicode_Char := 16#A2F0#;
   Yi_Syllable_Nziex                       : constant Unicode_Char := 16#A2F1#;
   Yi_Syllable_Nzie                        : constant Unicode_Char := 16#A2F2#;
   Yi_Syllable_Nziep                       : constant Unicode_Char := 16#A2F3#;
   Yi_Syllable_Nzat                        : constant Unicode_Char := 16#A2F4#;
   Yi_Syllable_Nzax                        : constant Unicode_Char := 16#A2F5#;
   Yi_Syllable_Nza                         : constant Unicode_Char := 16#A2F6#;
   Yi_Syllable_Nzap                        : constant Unicode_Char := 16#A2F7#;
   Yi_Syllable_Nzuox                       : constant Unicode_Char := 16#A2F8#;
   Yi_Syllable_Nzuo                        : constant Unicode_Char := 16#A2F9#;
   Yi_Syllable_Nzox                        : constant Unicode_Char := 16#A2FA#;
   Yi_Syllable_Nzop                        : constant Unicode_Char := 16#A2FB#;
   Yi_Syllable_Nzex                        : constant Unicode_Char := 16#A2FC#;
   Yi_Syllable_Nze                         : constant Unicode_Char := 16#A2FD#;
   Yi_Syllable_Nzux                        : constant Unicode_Char := 16#A2FE#;
   Yi_Syllable_Nzu                         : constant Unicode_Char := 16#A2FF#;
   Yi_Syllable_Nzup                        : constant Unicode_Char := 16#A300#;
   Yi_Syllable_Nzurx                       : constant Unicode_Char := 16#A301#;
   Yi_Syllable_Nzur                        : constant Unicode_Char := 16#A302#;
   Yi_Syllable_Nzyt                        : constant Unicode_Char := 16#A303#;
   Yi_Syllable_Nzyx                        : constant Unicode_Char := 16#A304#;
   Yi_Syllable_Nzy                         : constant Unicode_Char := 16#A305#;
   Yi_Syllable_Nzyp                        : constant Unicode_Char := 16#A306#;
   Yi_Syllable_Nzyrx                       : constant Unicode_Char := 16#A307#;
   Yi_Syllable_Nzyr                        : constant Unicode_Char := 16#A308#;
   Yi_Syllable_Sit                         : constant Unicode_Char := 16#A309#;
   Yi_Syllable_Six                         : constant Unicode_Char := 16#A30A#;
   Yi_Syllable_Si                          : constant Unicode_Char := 16#A30B#;
   Yi_Syllable_Sip                         : constant Unicode_Char := 16#A30C#;
   Yi_Syllable_Siex                        : constant Unicode_Char := 16#A30D#;
   Yi_Syllable_Sie                         : constant Unicode_Char := 16#A30E#;
   Yi_Syllable_Siep                        : constant Unicode_Char := 16#A30F#;
   Yi_Syllable_Sat                         : constant Unicode_Char := 16#A310#;
   Yi_Syllable_Sax                         : constant Unicode_Char := 16#A311#;
   Yi_Syllable_Sa                          : constant Unicode_Char := 16#A312#;
   Yi_Syllable_Sap                         : constant Unicode_Char := 16#A313#;
   Yi_Syllable_Suox                        : constant Unicode_Char := 16#A314#;
   Yi_Syllable_Suo                         : constant Unicode_Char := 16#A315#;
   Yi_Syllable_Suop                        : constant Unicode_Char := 16#A316#;
   Yi_Syllable_Sot                         : constant Unicode_Char := 16#A317#;
   Yi_Syllable_Sox                         : constant Unicode_Char := 16#A318#;
   Yi_Syllable_So                          : constant Unicode_Char := 16#A319#;
   Yi_Syllable_Sop                         : constant Unicode_Char := 16#A31A#;
   Yi_Syllable_Sex                         : constant Unicode_Char := 16#A31B#;
   Yi_Syllable_Se                          : constant Unicode_Char := 16#A31C#;
   Yi_Syllable_Sep                         : constant Unicode_Char := 16#A31D#;
   Yi_Syllable_Sut                         : constant Unicode_Char := 16#A31E#;
   Yi_Syllable_Sux                         : constant Unicode_Char := 16#A31F#;
   Yi_Syllable_Su                          : constant Unicode_Char := 16#A320#;
   Yi_Syllable_Sup                         : constant Unicode_Char := 16#A321#;
   Yi_Syllable_Surx                        : constant Unicode_Char := 16#A322#;
   Yi_Syllable_Sur                         : constant Unicode_Char := 16#A323#;
   Yi_Syllable_Syt                         : constant Unicode_Char := 16#A324#;
   Yi_Syllable_Syx                         : constant Unicode_Char := 16#A325#;
   Yi_Syllable_Sy                          : constant Unicode_Char := 16#A326#;
   Yi_Syllable_Syp                         : constant Unicode_Char := 16#A327#;
   Yi_Syllable_Syrx                        : constant Unicode_Char := 16#A328#;
   Yi_Syllable_Syr                         : constant Unicode_Char := 16#A329#;
   Yi_Syllable_Ssit                        : constant Unicode_Char := 16#A32A#;
   Yi_Syllable_Ssix                        : constant Unicode_Char := 16#A32B#;
   Yi_Syllable_Ssi                         : constant Unicode_Char := 16#A32C#;
   Yi_Syllable_Ssip                        : constant Unicode_Char := 16#A32D#;
   Yi_Syllable_Ssiex                       : constant Unicode_Char := 16#A32E#;
   Yi_Syllable_Ssie                        : constant Unicode_Char := 16#A32F#;
   Yi_Syllable_Ssiep                       : constant Unicode_Char := 16#A330#;
   Yi_Syllable_Ssat                        : constant Unicode_Char := 16#A331#;
   Yi_Syllable_Ssax                        : constant Unicode_Char := 16#A332#;
   Yi_Syllable_Ssa                         : constant Unicode_Char := 16#A333#;
   Yi_Syllable_Ssap                        : constant Unicode_Char := 16#A334#;
   Yi_Syllable_Ssot                        : constant Unicode_Char := 16#A335#;
   Yi_Syllable_Ssox                        : constant Unicode_Char := 16#A336#;
   Yi_Syllable_Sso                         : constant Unicode_Char := 16#A337#;
   Yi_Syllable_Ssop                        : constant Unicode_Char := 16#A338#;
   Yi_Syllable_Ssex                        : constant Unicode_Char := 16#A339#;
   Yi_Syllable_Sse                         : constant Unicode_Char := 16#A33A#;
   Yi_Syllable_Ssep                        : constant Unicode_Char := 16#A33B#;
   Yi_Syllable_Ssut                        : constant Unicode_Char := 16#A33C#;
   Yi_Syllable_Ssux                        : constant Unicode_Char := 16#A33D#;
   Yi_Syllable_Ssu                         : constant Unicode_Char := 16#A33E#;
   Yi_Syllable_Ssup                        : constant Unicode_Char := 16#A33F#;
   Yi_Syllable_Ssyt                        : constant Unicode_Char := 16#A340#;
   Yi_Syllable_Ssyx                        : constant Unicode_Char := 16#A341#;
   Yi_Syllable_Ssy                         : constant Unicode_Char := 16#A342#;
   Yi_Syllable_Ssyp                        : constant Unicode_Char := 16#A343#;
   Yi_Syllable_Ssyrx                       : constant Unicode_Char := 16#A344#;
   Yi_Syllable_Ssyr                        : constant Unicode_Char := 16#A345#;
   Yi_Syllable_Zhat                        : constant Unicode_Char := 16#A346#;
   Yi_Syllable_Zhax                        : constant Unicode_Char := 16#A347#;
   Yi_Syllable_Zha                         : constant Unicode_Char := 16#A348#;
   Yi_Syllable_Zhap                        : constant Unicode_Char := 16#A349#;
   Yi_Syllable_Zhuox                       : constant Unicode_Char := 16#A34A#;
   Yi_Syllable_Zhuo                        : constant Unicode_Char := 16#A34B#;
   Yi_Syllable_Zhuop                       : constant Unicode_Char := 16#A34C#;
   Yi_Syllable_Zhot                        : constant Unicode_Char := 16#A34D#;
   Yi_Syllable_Zhox                        : constant Unicode_Char := 16#A34E#;
   Yi_Syllable_Zho                         : constant Unicode_Char := 16#A34F#;
   Yi_Syllable_Zhop                        : constant Unicode_Char := 16#A350#;
   Yi_Syllable_Zhet                        : constant Unicode_Char := 16#A351#;
   Yi_Syllable_Zhex                        : constant Unicode_Char := 16#A352#;
   Yi_Syllable_Zhe                         : constant Unicode_Char := 16#A353#;
   Yi_Syllable_Zhep                        : constant Unicode_Char := 16#A354#;
   Yi_Syllable_Zhut                        : constant Unicode_Char := 16#A355#;
   Yi_Syllable_Zhux                        : constant Unicode_Char := 16#A356#;
   Yi_Syllable_Zhu                         : constant Unicode_Char := 16#A357#;
   Yi_Syllable_Zhup                        : constant Unicode_Char := 16#A358#;
   Yi_Syllable_Zhurx                       : constant Unicode_Char := 16#A359#;
   Yi_Syllable_Zhur                        : constant Unicode_Char := 16#A35A#;
   Yi_Syllable_Zhyt                        : constant Unicode_Char := 16#A35B#;
   Yi_Syllable_Zhyx                        : constant Unicode_Char := 16#A35C#;
   Yi_Syllable_Zhy                         : constant Unicode_Char := 16#A35D#;
   Yi_Syllable_Zhyp                        : constant Unicode_Char := 16#A35E#;
   Yi_Syllable_Zhyrx                       : constant Unicode_Char := 16#A35F#;
   Yi_Syllable_Zhyr                        : constant Unicode_Char := 16#A360#;
   Yi_Syllable_Chat                        : constant Unicode_Char := 16#A361#;
   Yi_Syllable_Chax                        : constant Unicode_Char := 16#A362#;
   Yi_Syllable_Cha                         : constant Unicode_Char := 16#A363#;
   Yi_Syllable_Chap                        : constant Unicode_Char := 16#A364#;
   Yi_Syllable_Chuot                       : constant Unicode_Char := 16#A365#;
   Yi_Syllable_Chuox                       : constant Unicode_Char := 16#A366#;
   Yi_Syllable_Chuo                        : constant Unicode_Char := 16#A367#;
   Yi_Syllable_Chuop                       : constant Unicode_Char := 16#A368#;
   Yi_Syllable_Chot                        : constant Unicode_Char := 16#A369#;
   Yi_Syllable_Chox                        : constant Unicode_Char := 16#A36A#;
   Yi_Syllable_Cho                         : constant Unicode_Char := 16#A36B#;
   Yi_Syllable_Chop                        : constant Unicode_Char := 16#A36C#;
   Yi_Syllable_Chet                        : constant Unicode_Char := 16#A36D#;
   Yi_Syllable_Chex                        : constant Unicode_Char := 16#A36E#;
   Yi_Syllable_Che                         : constant Unicode_Char := 16#A36F#;
   Yi_Syllable_Chep                        : constant Unicode_Char := 16#A370#;
   Yi_Syllable_Chux                        : constant Unicode_Char := 16#A371#;
   Yi_Syllable_Chu                         : constant Unicode_Char := 16#A372#;
   Yi_Syllable_Chup                        : constant Unicode_Char := 16#A373#;
   Yi_Syllable_Churx                       : constant Unicode_Char := 16#A374#;
   Yi_Syllable_Chur                        : constant Unicode_Char := 16#A375#;
   Yi_Syllable_Chyt                        : constant Unicode_Char := 16#A376#;
   Yi_Syllable_Chyx                        : constant Unicode_Char := 16#A377#;
   Yi_Syllable_Chy                         : constant Unicode_Char := 16#A378#;
   Yi_Syllable_Chyp                        : constant Unicode_Char := 16#A379#;
   Yi_Syllable_Chyrx                       : constant Unicode_Char := 16#A37A#;
   Yi_Syllable_Chyr                        : constant Unicode_Char := 16#A37B#;
   Yi_Syllable_Rrax                        : constant Unicode_Char := 16#A37C#;
   Yi_Syllable_Rra                         : constant Unicode_Char := 16#A37D#;
   Yi_Syllable_Rruox                       : constant Unicode_Char := 16#A37E#;
   Yi_Syllable_Rruo                        : constant Unicode_Char := 16#A37F#;
   Yi_Syllable_Rrot                        : constant Unicode_Char := 16#A380#;
   Yi_Syllable_Rrox                        : constant Unicode_Char := 16#A381#;
   Yi_Syllable_Rro                         : constant Unicode_Char := 16#A382#;
   Yi_Syllable_Rrop                        : constant Unicode_Char := 16#A383#;
   Yi_Syllable_Rret                        : constant Unicode_Char := 16#A384#;
   Yi_Syllable_Rrex                        : constant Unicode_Char := 16#A385#;
   Yi_Syllable_Rre                         : constant Unicode_Char := 16#A386#;
   Yi_Syllable_Rrep                        : constant Unicode_Char := 16#A387#;
   Yi_Syllable_Rrut                        : constant Unicode_Char := 16#A388#;
   Yi_Syllable_Rrux                        : constant Unicode_Char := 16#A389#;
   Yi_Syllable_Rru                         : constant Unicode_Char := 16#A38A#;
   Yi_Syllable_Rrup                        : constant Unicode_Char := 16#A38B#;
   Yi_Syllable_Rrurx                       : constant Unicode_Char := 16#A38C#;
   Yi_Syllable_Rrur                        : constant Unicode_Char := 16#A38D#;
   Yi_Syllable_Rryt                        : constant Unicode_Char := 16#A38E#;
   Yi_Syllable_Rryx                        : constant Unicode_Char := 16#A38F#;
   Yi_Syllable_Rry                         : constant Unicode_Char := 16#A390#;
   Yi_Syllable_Rryp                        : constant Unicode_Char := 16#A391#;
   Yi_Syllable_Rryrx                       : constant Unicode_Char := 16#A392#;
   Yi_Syllable_Rryr                        : constant Unicode_Char := 16#A393#;
   Yi_Syllable_Nrat                        : constant Unicode_Char := 16#A394#;
   Yi_Syllable_Nrax                        : constant Unicode_Char := 16#A395#;
   Yi_Syllable_Nra                         : constant Unicode_Char := 16#A396#;
   Yi_Syllable_Nrap                        : constant Unicode_Char := 16#A397#;
   Yi_Syllable_Nrox                        : constant Unicode_Char := 16#A398#;
   Yi_Syllable_Nro                         : constant Unicode_Char := 16#A399#;
   Yi_Syllable_Nrop                        : constant Unicode_Char := 16#A39A#;
   Yi_Syllable_Nret                        : constant Unicode_Char := 16#A39B#;
   Yi_Syllable_Nrex                        : constant Unicode_Char := 16#A39C#;
   Yi_Syllable_Nre                         : constant Unicode_Char := 16#A39D#;
   Yi_Syllable_Nrep                        : constant Unicode_Char := 16#A39E#;
   Yi_Syllable_Nrut                        : constant Unicode_Char := 16#A39F#;
   Yi_Syllable_Nrux                        : constant Unicode_Char := 16#A3A0#;
   Yi_Syllable_Nru                         : constant Unicode_Char := 16#A3A1#;
   Yi_Syllable_Nrup                        : constant Unicode_Char := 16#A3A2#;
   Yi_Syllable_Nrurx                       : constant Unicode_Char := 16#A3A3#;
   Yi_Syllable_Nrur                        : constant Unicode_Char := 16#A3A4#;
   Yi_Syllable_Nryt                        : constant Unicode_Char := 16#A3A5#;
   Yi_Syllable_Nryx                        : constant Unicode_Char := 16#A3A6#;
   Yi_Syllable_Nry                         : constant Unicode_Char := 16#A3A7#;
   Yi_Syllable_Nryp                        : constant Unicode_Char := 16#A3A8#;
   Yi_Syllable_Nryrx                       : constant Unicode_Char := 16#A3A9#;
   Yi_Syllable_Nryr                        : constant Unicode_Char := 16#A3AA#;
   Yi_Syllable_Shat                        : constant Unicode_Char := 16#A3AB#;
   Yi_Syllable_Shax                        : constant Unicode_Char := 16#A3AC#;
   Yi_Syllable_Sha                         : constant Unicode_Char := 16#A3AD#;
   Yi_Syllable_Shap                        : constant Unicode_Char := 16#A3AE#;
   Yi_Syllable_Shuox                       : constant Unicode_Char := 16#A3AF#;
   Yi_Syllable_Shuo                        : constant Unicode_Char := 16#A3B0#;
   Yi_Syllable_Shuop                       : constant Unicode_Char := 16#A3B1#;
   Yi_Syllable_Shot                        : constant Unicode_Char := 16#A3B2#;
   Yi_Syllable_Shox                        : constant Unicode_Char := 16#A3B3#;
   Yi_Syllable_Sho                         : constant Unicode_Char := 16#A3B4#;
   Yi_Syllable_Shop                        : constant Unicode_Char := 16#A3B5#;
   Yi_Syllable_Shet                        : constant Unicode_Char := 16#A3B6#;
   Yi_Syllable_Shex                        : constant Unicode_Char := 16#A3B7#;
   Yi_Syllable_She                         : constant Unicode_Char := 16#A3B8#;
   Yi_Syllable_Shep                        : constant Unicode_Char := 16#A3B9#;
   Yi_Syllable_Shut                        : constant Unicode_Char := 16#A3BA#;
   Yi_Syllable_Shux                        : constant Unicode_Char := 16#A3BB#;
   Yi_Syllable_Shu                         : constant Unicode_Char := 16#A3BC#;
   Yi_Syllable_Shup                        : constant Unicode_Char := 16#A3BD#;
   Yi_Syllable_Shurx                       : constant Unicode_Char := 16#A3BE#;
   Yi_Syllable_Shur                        : constant Unicode_Char := 16#A3BF#;
   Yi_Syllable_Shyt                        : constant Unicode_Char := 16#A3C0#;
   Yi_Syllable_Shyx                        : constant Unicode_Char := 16#A3C1#;
   Yi_Syllable_Shy                         : constant Unicode_Char := 16#A3C2#;
   Yi_Syllable_Shyp                        : constant Unicode_Char := 16#A3C3#;
   Yi_Syllable_Shyrx                       : constant Unicode_Char := 16#A3C4#;
   Yi_Syllable_Shyr                        : constant Unicode_Char := 16#A3C5#;
   Yi_Syllable_Rat                         : constant Unicode_Char := 16#A3C6#;
   Yi_Syllable_Rax                         : constant Unicode_Char := 16#A3C7#;
   Yi_Syllable_Ra                          : constant Unicode_Char := 16#A3C8#;
   Yi_Syllable_Rap                         : constant Unicode_Char := 16#A3C9#;
   Yi_Syllable_Ruox                        : constant Unicode_Char := 16#A3CA#;
   Yi_Syllable_Ruo                         : constant Unicode_Char := 16#A3CB#;
   Yi_Syllable_Ruop                        : constant Unicode_Char := 16#A3CC#;
   Yi_Syllable_Rot                         : constant Unicode_Char := 16#A3CD#;
   Yi_Syllable_Rox                         : constant Unicode_Char := 16#A3CE#;
   Yi_Syllable_Ro                          : constant Unicode_Char := 16#A3CF#;
   Yi_Syllable_Rop                         : constant Unicode_Char := 16#A3D0#;
   Yi_Syllable_Rex                         : constant Unicode_Char := 16#A3D1#;
   Yi_Syllable_Re                          : constant Unicode_Char := 16#A3D2#;
   Yi_Syllable_Rep                         : constant Unicode_Char := 16#A3D3#;
   Yi_Syllable_Rut                         : constant Unicode_Char := 16#A3D4#;
   Yi_Syllable_Rux                         : constant Unicode_Char := 16#A3D5#;
   Yi_Syllable_Ru                          : constant Unicode_Char := 16#A3D6#;
   Yi_Syllable_Rup                         : constant Unicode_Char := 16#A3D7#;
   Yi_Syllable_Rurx                        : constant Unicode_Char := 16#A3D8#;
   Yi_Syllable_Rur                         : constant Unicode_Char := 16#A3D9#;
   Yi_Syllable_Ryt                         : constant Unicode_Char := 16#A3DA#;
   Yi_Syllable_Ryx                         : constant Unicode_Char := 16#A3DB#;
   Yi_Syllable_Ry                          : constant Unicode_Char := 16#A3DC#;
   Yi_Syllable_Ryp                         : constant Unicode_Char := 16#A3DD#;
   Yi_Syllable_Ryrx                        : constant Unicode_Char := 16#A3DE#;
   Yi_Syllable_Ryr                         : constant Unicode_Char := 16#A3DF#;
   Yi_Syllable_Jit                         : constant Unicode_Char := 16#A3E0#;
   Yi_Syllable_Jix                         : constant Unicode_Char := 16#A3E1#;
   Yi_Syllable_Ji                          : constant Unicode_Char := 16#A3E2#;
   Yi_Syllable_Jip                         : constant Unicode_Char := 16#A3E3#;
   Yi_Syllable_Jiet                        : constant Unicode_Char := 16#A3E4#;
   Yi_Syllable_Jiex                        : constant Unicode_Char := 16#A3E5#;
   Yi_Syllable_Jie                         : constant Unicode_Char := 16#A3E6#;
   Yi_Syllable_Jiep                        : constant Unicode_Char := 16#A3E7#;
   Yi_Syllable_Juot                        : constant Unicode_Char := 16#A3E8#;
   Yi_Syllable_Juox                        : constant Unicode_Char := 16#A3E9#;
   Yi_Syllable_Juo                         : constant Unicode_Char := 16#A3EA#;
   Yi_Syllable_Juop                        : constant Unicode_Char := 16#A3EB#;
   Yi_Syllable_Jot                         : constant Unicode_Char := 16#A3EC#;
   Yi_Syllable_Jox                         : constant Unicode_Char := 16#A3ED#;
   Yi_Syllable_Jo                          : constant Unicode_Char := 16#A3EE#;
   Yi_Syllable_Jop                         : constant Unicode_Char := 16#A3EF#;
   Yi_Syllable_Jut                         : constant Unicode_Char := 16#A3F0#;
   Yi_Syllable_Jux                         : constant Unicode_Char := 16#A3F1#;
   Yi_Syllable_Ju                          : constant Unicode_Char := 16#A3F2#;
   Yi_Syllable_Jup                         : constant Unicode_Char := 16#A3F3#;
   Yi_Syllable_Jurx                        : constant Unicode_Char := 16#A3F4#;
   Yi_Syllable_Jur                         : constant Unicode_Char := 16#A3F5#;
   Yi_Syllable_Jyt                         : constant Unicode_Char := 16#A3F6#;
   Yi_Syllable_Jyx                         : constant Unicode_Char := 16#A3F7#;
   Yi_Syllable_Jy                          : constant Unicode_Char := 16#A3F8#;
   Yi_Syllable_Jyp                         : constant Unicode_Char := 16#A3F9#;
   Yi_Syllable_Jyrx                        : constant Unicode_Char := 16#A3FA#;
   Yi_Syllable_Jyr                         : constant Unicode_Char := 16#A3FB#;
   Yi_Syllable_Qit                         : constant Unicode_Char := 16#A3FC#;
   Yi_Syllable_Qix                         : constant Unicode_Char := 16#A3FD#;
   Yi_Syllable_Qi                          : constant Unicode_Char := 16#A3FE#;
   Yi_Syllable_Qip                         : constant Unicode_Char := 16#A3FF#;
   Yi_Syllable_Qiet                        : constant Unicode_Char := 16#A400#;
   Yi_Syllable_Qiex                        : constant Unicode_Char := 16#A401#;
   Yi_Syllable_Qie                         : constant Unicode_Char := 16#A402#;
   Yi_Syllable_Qiep                        : constant Unicode_Char := 16#A403#;
   Yi_Syllable_Quot                        : constant Unicode_Char := 16#A404#;
   Yi_Syllable_Quox                        : constant Unicode_Char := 16#A405#;
   Yi_Syllable_Quo                         : constant Unicode_Char := 16#A406#;
   Yi_Syllable_Quop                        : constant Unicode_Char := 16#A407#;
   Yi_Syllable_Qot                         : constant Unicode_Char := 16#A408#;
   Yi_Syllable_Qox                         : constant Unicode_Char := 16#A409#;
   Yi_Syllable_Qo                          : constant Unicode_Char := 16#A40A#;
   Yi_Syllable_Qop                         : constant Unicode_Char := 16#A40B#;
   Yi_Syllable_Qut                         : constant Unicode_Char := 16#A40C#;
   Yi_Syllable_Qux                         : constant Unicode_Char := 16#A40D#;
   Yi_Syllable_Qu                          : constant Unicode_Char := 16#A40E#;
   Yi_Syllable_Qup                         : constant Unicode_Char := 16#A40F#;
   Yi_Syllable_Qurx                        : constant Unicode_Char := 16#A410#;
   Yi_Syllable_Qur                         : constant Unicode_Char := 16#A411#;
   Yi_Syllable_Qyt                         : constant Unicode_Char := 16#A412#;
   Yi_Syllable_Qyx                         : constant Unicode_Char := 16#A413#;
   Yi_Syllable_Qy                          : constant Unicode_Char := 16#A414#;
   Yi_Syllable_Qyp                         : constant Unicode_Char := 16#A415#;
   Yi_Syllable_Qyrx                        : constant Unicode_Char := 16#A416#;
   Yi_Syllable_Qyr                         : constant Unicode_Char := 16#A417#;
   Yi_Syllable_Jjit                        : constant Unicode_Char := 16#A418#;
   Yi_Syllable_Jjix                        : constant Unicode_Char := 16#A419#;
   Yi_Syllable_Jji                         : constant Unicode_Char := 16#A41A#;
   Yi_Syllable_Jjip                        : constant Unicode_Char := 16#A41B#;
   Yi_Syllable_Jjiet                       : constant Unicode_Char := 16#A41C#;
   Yi_Syllable_Jjiex                       : constant Unicode_Char := 16#A41D#;
   Yi_Syllable_Jjie                        : constant Unicode_Char := 16#A41E#;
   Yi_Syllable_Jjiep                       : constant Unicode_Char := 16#A41F#;
   Yi_Syllable_Jjuox                       : constant Unicode_Char := 16#A420#;
   Yi_Syllable_Jjuo                        : constant Unicode_Char := 16#A421#;
   Yi_Syllable_Jjuop                       : constant Unicode_Char := 16#A422#;
   Yi_Syllable_Jjot                        : constant Unicode_Char := 16#A423#;
   Yi_Syllable_Jjox                        : constant Unicode_Char := 16#A424#;
   Yi_Syllable_Jjo                         : constant Unicode_Char := 16#A425#;
   Yi_Syllable_Jjop                        : constant Unicode_Char := 16#A426#;
   Yi_Syllable_Jjut                        : constant Unicode_Char := 16#A427#;
   Yi_Syllable_Jjux                        : constant Unicode_Char := 16#A428#;
   Yi_Syllable_Jju                         : constant Unicode_Char := 16#A429#;
   Yi_Syllable_Jjup                        : constant Unicode_Char := 16#A42A#;
   Yi_Syllable_Jjurx                       : constant Unicode_Char := 16#A42B#;
   Yi_Syllable_Jjur                        : constant Unicode_Char := 16#A42C#;
   Yi_Syllable_Jjyt                        : constant Unicode_Char := 16#A42D#;
   Yi_Syllable_Jjyx                        : constant Unicode_Char := 16#A42E#;
   Yi_Syllable_Jjy                         : constant Unicode_Char := 16#A42F#;
   Yi_Syllable_Jjyp                        : constant Unicode_Char := 16#A430#;
   Yi_Syllable_Njit                        : constant Unicode_Char := 16#A431#;
   Yi_Syllable_Njix                        : constant Unicode_Char := 16#A432#;
   Yi_Syllable_Nji                         : constant Unicode_Char := 16#A433#;
   Yi_Syllable_Njip                        : constant Unicode_Char := 16#A434#;
   Yi_Syllable_Njiet                       : constant Unicode_Char := 16#A435#;
   Yi_Syllable_Njiex                       : constant Unicode_Char := 16#A436#;
   Yi_Syllable_Njie                        : constant Unicode_Char := 16#A437#;
   Yi_Syllable_Njiep                       : constant Unicode_Char := 16#A438#;
   Yi_Syllable_Njuox                       : constant Unicode_Char := 16#A439#;
   Yi_Syllable_Njuo                        : constant Unicode_Char := 16#A43A#;
   Yi_Syllable_Njot                        : constant Unicode_Char := 16#A43B#;
   Yi_Syllable_Njox                        : constant Unicode_Char := 16#A43C#;
   Yi_Syllable_Njo                         : constant Unicode_Char := 16#A43D#;
   Yi_Syllable_Njop                        : constant Unicode_Char := 16#A43E#;
   Yi_Syllable_Njux                        : constant Unicode_Char := 16#A43F#;
   Yi_Syllable_Nju                         : constant Unicode_Char := 16#A440#;
   Yi_Syllable_Njup                        : constant Unicode_Char := 16#A441#;
   Yi_Syllable_Njurx                       : constant Unicode_Char := 16#A442#;
   Yi_Syllable_Njur                        : constant Unicode_Char := 16#A443#;
   Yi_Syllable_Njyt                        : constant Unicode_Char := 16#A444#;
   Yi_Syllable_Njyx                        : constant Unicode_Char := 16#A445#;
   Yi_Syllable_Njy                         : constant Unicode_Char := 16#A446#;
   Yi_Syllable_Njyp                        : constant Unicode_Char := 16#A447#;
   Yi_Syllable_Njyrx                       : constant Unicode_Char := 16#A448#;
   Yi_Syllable_Njyr                        : constant Unicode_Char := 16#A449#;
   Yi_Syllable_Nyit                        : constant Unicode_Char := 16#A44A#;
   Yi_Syllable_Nyix                        : constant Unicode_Char := 16#A44B#;
   Yi_Syllable_Nyi                         : constant Unicode_Char := 16#A44C#;
   Yi_Syllable_Nyip                        : constant Unicode_Char := 16#A44D#;
   Yi_Syllable_Nyiet                       : constant Unicode_Char := 16#A44E#;
   Yi_Syllable_Nyiex                       : constant Unicode_Char := 16#A44F#;
   Yi_Syllable_Nyie                        : constant Unicode_Char := 16#A450#;
   Yi_Syllable_Nyiep                       : constant Unicode_Char := 16#A451#;
   Yi_Syllable_Nyuox                       : constant Unicode_Char := 16#A452#;
   Yi_Syllable_Nyuo                        : constant Unicode_Char := 16#A453#;
   Yi_Syllable_Nyuop                       : constant Unicode_Char := 16#A454#;
   Yi_Syllable_Nyot                        : constant Unicode_Char := 16#A455#;
   Yi_Syllable_Nyox                        : constant Unicode_Char := 16#A456#;
   Yi_Syllable_Nyo                         : constant Unicode_Char := 16#A457#;
   Yi_Syllable_Nyop                        : constant Unicode_Char := 16#A458#;
   Yi_Syllable_Nyut                        : constant Unicode_Char := 16#A459#;
   Yi_Syllable_Nyux                        : constant Unicode_Char := 16#A45A#;
   Yi_Syllable_Nyu                         : constant Unicode_Char := 16#A45B#;
   Yi_Syllable_Nyup                        : constant Unicode_Char := 16#A45C#;
   Yi_Syllable_Xit                         : constant Unicode_Char := 16#A45D#;
   Yi_Syllable_Xix                         : constant Unicode_Char := 16#A45E#;
   Yi_Syllable_Xi                          : constant Unicode_Char := 16#A45F#;
   Yi_Syllable_Xip                         : constant Unicode_Char := 16#A460#;
   Yi_Syllable_Xiet                        : constant Unicode_Char := 16#A461#;
   Yi_Syllable_Xiex                        : constant Unicode_Char := 16#A462#;
   Yi_Syllable_Xie                         : constant Unicode_Char := 16#A463#;
   Yi_Syllable_Xiep                        : constant Unicode_Char := 16#A464#;
   Yi_Syllable_Xuox                        : constant Unicode_Char := 16#A465#;
   Yi_Syllable_Xuo                         : constant Unicode_Char := 16#A466#;
   Yi_Syllable_Xot                         : constant Unicode_Char := 16#A467#;
   Yi_Syllable_Xox                         : constant Unicode_Char := 16#A468#;
   Yi_Syllable_Xo                          : constant Unicode_Char := 16#A469#;
   Yi_Syllable_Xop                         : constant Unicode_Char := 16#A46A#;
   Yi_Syllable_Xyt                         : constant Unicode_Char := 16#A46B#;
   Yi_Syllable_Xyx                         : constant Unicode_Char := 16#A46C#;
   Yi_Syllable_Xy                          : constant Unicode_Char := 16#A46D#;
   Yi_Syllable_Xyp                         : constant Unicode_Char := 16#A46E#;
   Yi_Syllable_Xyrx                        : constant Unicode_Char := 16#A46F#;
   Yi_Syllable_Xyr                         : constant Unicode_Char := 16#A470#;
   Yi_Syllable_Yit                         : constant Unicode_Char := 16#A471#;
   Yi_Syllable_Yix                         : constant Unicode_Char := 16#A472#;
   Yi_Syllable_Yi                          : constant Unicode_Char := 16#A473#;
   Yi_Syllable_Yip                         : constant Unicode_Char := 16#A474#;
   Yi_Syllable_Yiet                        : constant Unicode_Char := 16#A475#;
   Yi_Syllable_Yiex                        : constant Unicode_Char := 16#A476#;
   Yi_Syllable_Yie                         : constant Unicode_Char := 16#A477#;
   Yi_Syllable_Yiep                        : constant Unicode_Char := 16#A478#;
   Yi_Syllable_Yuot                        : constant Unicode_Char := 16#A479#;
   Yi_Syllable_Yuox                        : constant Unicode_Char := 16#A47A#;
   Yi_Syllable_Yuo                         : constant Unicode_Char := 16#A47B#;
   Yi_Syllable_Yuop                        : constant Unicode_Char := 16#A47C#;
   Yi_Syllable_Yot                         : constant Unicode_Char := 16#A47D#;
   Yi_Syllable_Yox                         : constant Unicode_Char := 16#A47E#;
   Yi_Syllable_Yo                          : constant Unicode_Char := 16#A47F#;
   Yi_Syllable_Yop                         : constant Unicode_Char := 16#A480#;
   Yi_Syllable_Yut                         : constant Unicode_Char := 16#A481#;
   Yi_Syllable_Yux                         : constant Unicode_Char := 16#A482#;
   Yi_Syllable_Yu                          : constant Unicode_Char := 16#A483#;
   Yi_Syllable_Yup                         : constant Unicode_Char := 16#A484#;
   Yi_Syllable_Yurx                        : constant Unicode_Char := 16#A485#;
   Yi_Syllable_Yur                         : constant Unicode_Char := 16#A486#;
   Yi_Syllable_Yyt                         : constant Unicode_Char := 16#A487#;
   Yi_Syllable_Yyx                         : constant Unicode_Char := 16#A488#;
   Yi_Syllable_Yy                          : constant Unicode_Char := 16#A489#;
   Yi_Syllable_Yyp                         : constant Unicode_Char := 16#A48A#;
   Yi_Syllable_Yyrx                        : constant Unicode_Char := 16#A48B#;
   Yi_Syllable_Yyr                         : constant Unicode_Char := 16#A48C#;
end Unicode.Names.Yi_Syllables;
