--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Phonetic_Extensions is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Latin_Letter_Small_Capital_A            : constant Unicode_Char := 16#1D00#;
   Latin_Letter_Small_Capital_Ae           : constant Unicode_Char := 16#1D01#;
   Latin_Small_Letter_Turned_Ae            : constant Unicode_Char := 16#1D02#;
   Latin_Letter_Small_Capital_Barred_B     : constant Unicode_Char := 16#1D03#;
   Latin_Letter_Small_Capital_C            : constant Unicode_Char := 16#1D04#;
   Latin_Letter_Small_Capital_D            : constant Unicode_Char := 16#1D05#;
   Latin_Letter_Small_Capital_Eth          : constant Unicode_Char := 16#1D06#;
   Latin_Letter_Small_Capital_E            : constant Unicode_Char := 16#1D07#;
   Latin_Small_Letter_Turned_Open_E        : constant Unicode_Char := 16#1D08#;
   Latin_Small_Letter_Turned_I             : constant Unicode_Char := 16#1D09#;
   Latin_Letter_Small_Capital_J            : constant Unicode_Char := 16#1D0A#;
   Latin_Letter_Small_Capital_K            : constant Unicode_Char := 16#1D0B#;
   Latin_Letter_Small_Capital_L_With_Stroke :
      constant Unicode_Char := 16#1D0C#;
   Latin_Letter_Small_Capital_M            : constant Unicode_Char := 16#1D0D#;
   Latin_Letter_Small_Capital_Reversed_N   : constant Unicode_Char := 16#1D0E#;
   Latin_Letter_Small_Capital_O            : constant Unicode_Char := 16#1D0F#;
   Latin_Letter_Small_Capital_Open_O       : constant Unicode_Char := 16#1D10#;
   Latin_Small_Letter_Sideways_O           : constant Unicode_Char := 16#1D11#;
   Latin_Small_Letter_Sideways_Open_O      : constant Unicode_Char := 16#1D12#;
   Latin_Small_Letter_Sideways_O_With_Stroke :
      constant Unicode_Char := 16#1D13#;
   Latin_Small_Letter_Turned_Oe            : constant Unicode_Char := 16#1D14#;
   Latin_Letter_Small_Capital_Ou           : constant Unicode_Char := 16#1D15#;
   Latin_Small_Letter_Top_Half_O           : constant Unicode_Char := 16#1D16#;
   Latin_Small_Letter_Bottom_Half_O        : constant Unicode_Char := 16#1D17#;
   Latin_Letter_Small_Capital_P            : constant Unicode_Char := 16#1D18#;
   Latin_Letter_Small_Capital_Reversed_R   : constant Unicode_Char := 16#1D19#;
   Latin_Letter_Small_Capital_Turned_R     : constant Unicode_Char := 16#1D1A#;
   Latin_Letter_Small_Capital_T            : constant Unicode_Char := 16#1D1B#;
   Latin_Letter_Small_Capital_U            : constant Unicode_Char := 16#1D1C#;
   Latin_Small_Letter_Sideways_U           : constant Unicode_Char := 16#1D1D#;
   Latin_Small_Letter_Sideways_Diaeresized_U :
      constant Unicode_Char := 16#1D1E#;
   Latin_Small_Letter_Sideways_Turned_M    : constant Unicode_Char := 16#1D1F#;
   Latin_Letter_Small_Capital_V            : constant Unicode_Char := 16#1D20#;
   Latin_Letter_Small_Capital_W            : constant Unicode_Char := 16#1D21#;
   Latin_Letter_Small_Capital_Z            : constant Unicode_Char := 16#1D22#;
   Latin_Letter_Small_Capital_Ezh          : constant Unicode_Char := 16#1D23#;
   Latin_Letter_Voiced_Laryngeal_Spirant   : constant Unicode_Char := 16#1D24#;
   Latin_Letter_Ain                        : constant Unicode_Char := 16#1D25#;
   Greek_Letter_Small_Capital_Gamma        : constant Unicode_Char := 16#1D26#;
   Greek_Letter_Small_Capital_Lamda        : constant Unicode_Char := 16#1D27#;
   Greek_Letter_Small_Capital_Pi           : constant Unicode_Char := 16#1D28#;
   Greek_Letter_Small_Capital_Rho          : constant Unicode_Char := 16#1D29#;
   Greek_Letter_Small_Capital_Psi          : constant Unicode_Char := 16#1D2A#;
   Cyrillic_Letter_Small_Capital_El        : constant Unicode_Char := 16#1D2B#;
   Modifier_Letter_Capital_A               : constant Unicode_Char := 16#1D2C#;
   Modifier_Letter_Capital_Ae              : constant Unicode_Char := 16#1D2D#;
   Modifier_Letter_Capital_B               : constant Unicode_Char := 16#1D2E#;
   Modifier_Letter_Capital_Barred_B        : constant Unicode_Char := 16#1D2F#;
   Modifier_Letter_Capital_D               : constant Unicode_Char := 16#1D30#;
   Modifier_Letter_Capital_E               : constant Unicode_Char := 16#1D31#;
   Modifier_Letter_Capital_Reversed_E      : constant Unicode_Char := 16#1D32#;
   Modifier_Letter_Capital_G               : constant Unicode_Char := 16#1D33#;
   Modifier_Letter_Capital_H               : constant Unicode_Char := 16#1D34#;
   Modifier_Letter_Capital_I               : constant Unicode_Char := 16#1D35#;
   Modifier_Letter_Capital_J               : constant Unicode_Char := 16#1D36#;
   Modifier_Letter_Capital_K               : constant Unicode_Char := 16#1D37#;
   Modifier_Letter_Capital_L               : constant Unicode_Char := 16#1D38#;
   Modifier_Letter_Capital_M               : constant Unicode_Char := 16#1D39#;
   Modifier_Letter_Capital_N               : constant Unicode_Char := 16#1D3A#;
   Modifier_Letter_Capital_Reversed_N      : constant Unicode_Char := 16#1D3B#;
   Modifier_Letter_Capital_O               : constant Unicode_Char := 16#1D3C#;
   Modifier_Letter_Capital_Ou              : constant Unicode_Char := 16#1D3D#;
   Modifier_Letter_Capital_P               : constant Unicode_Char := 16#1D3E#;
   Modifier_Letter_Capital_R               : constant Unicode_Char := 16#1D3F#;
   Modifier_Letter_Capital_T               : constant Unicode_Char := 16#1D40#;
   Modifier_Letter_Capital_U               : constant Unicode_Char := 16#1D41#;
   Modifier_Letter_Capital_W               : constant Unicode_Char := 16#1D42#;
   Modifier_Letter_Small_A                 : constant Unicode_Char := 16#1D43#;
   Modifier_Letter_Small_Turned_A          : constant Unicode_Char := 16#1D44#;
   Modifier_Letter_Small_Alpha             : constant Unicode_Char := 16#1D45#;
   Modifier_Letter_Small_Turned_Ae         : constant Unicode_Char := 16#1D46#;
   Modifier_Letter_Small_B                 : constant Unicode_Char := 16#1D47#;
   Modifier_Letter_Small_D                 : constant Unicode_Char := 16#1D48#;
   Modifier_Letter_Small_E                 : constant Unicode_Char := 16#1D49#;
   Modifier_Letter_Small_Schwa             : constant Unicode_Char := 16#1D4A#;
   Modifier_Letter_Small_Open_E            : constant Unicode_Char := 16#1D4B#;
   Modifier_Letter_Small_Turned_Open_E     : constant Unicode_Char := 16#1D4C#;
   Modifier_Letter_Small_G                 : constant Unicode_Char := 16#1D4D#;
   Modifier_Letter_Small_Turned_I          : constant Unicode_Char := 16#1D4E#;
   Modifier_Letter_Small_K                 : constant Unicode_Char := 16#1D4F#;
   Modifier_Letter_Small_M                 : constant Unicode_Char := 16#1D50#;
   Modifier_Letter_Small_Eng               : constant Unicode_Char := 16#1D51#;
   Modifier_Letter_Small_O                 : constant Unicode_Char := 16#1D52#;
   Modifier_Letter_Small_Open_O            : constant Unicode_Char := 16#1D53#;
   Modifier_Letter_Small_Top_Half_O        : constant Unicode_Char := 16#1D54#;
   Modifier_Letter_Small_Bottom_Half_O     : constant Unicode_Char := 16#1D55#;
   Modifier_Letter_Small_P                 : constant Unicode_Char := 16#1D56#;
   Modifier_Letter_Small_T                 : constant Unicode_Char := 16#1D57#;
   Modifier_Letter_Small_U                 : constant Unicode_Char := 16#1D58#;
   Modifier_Letter_Small_Sideways_U        : constant Unicode_Char := 16#1D59#;
   Modifier_Letter_Small_Turned_M          : constant Unicode_Char := 16#1D5A#;
   Modifier_Letter_Small_V                 : constant Unicode_Char := 16#1D5B#;
   Modifier_Letter_Small_Ain               : constant Unicode_Char := 16#1D5C#;
   Modifier_Letter_Small_Beta              : constant Unicode_Char := 16#1D5D#;
   Modifier_Letter_Small_Greek_Gamma       : constant Unicode_Char := 16#1D5E#;
   Modifier_Letter_Small_Delta             : constant Unicode_Char := 16#1D5F#;
   Modifier_Letter_Small_Greek_Phi         : constant Unicode_Char := 16#1D60#;
   Modifier_Letter_Small_Chi               : constant Unicode_Char := 16#1D61#;
   Latin_Subscript_Small_Letter_I          : constant Unicode_Char := 16#1D62#;
   Latin_Subscript_Small_Letter_R          : constant Unicode_Char := 16#1D63#;
   Latin_Subscript_Small_Letter_U          : constant Unicode_Char := 16#1D64#;
   Latin_Subscript_Small_Letter_V          : constant Unicode_Char := 16#1D65#;
   Greek_Subscript_Small_Letter_Beta       : constant Unicode_Char := 16#1D66#;
   Greek_Subscript_Small_Letter_Gamma      : constant Unicode_Char := 16#1D67#;
   Greek_Subscript_Small_Letter_Rho        : constant Unicode_Char := 16#1D68#;
   Greek_Subscript_Small_Letter_Phi        : constant Unicode_Char := 16#1D69#;
   Greek_Subscript_Small_Letter_Chi        : constant Unicode_Char := 16#1D6A#;
   Latin_Small_Letter_Ue                   : constant Unicode_Char := 16#1D6B#;
   Latin_Small_Letter_B_With_Middle_Tilde  : constant Unicode_Char := 16#1D6C#;
   Latin_Small_Letter_D_With_Middle_Tilde  : constant Unicode_Char := 16#1D6D#;
   Latin_Small_Letter_F_With_Middle_Tilde  : constant Unicode_Char := 16#1D6E#;
   Latin_Small_Letter_M_With_Middle_Tilde  : constant Unicode_Char := 16#1D6F#;
   Latin_Small_Letter_N_With_Middle_Tilde  : constant Unicode_Char := 16#1D70#;
   Latin_Small_Letter_P_With_Middle_Tilde  : constant Unicode_Char := 16#1D71#;
   Latin_Small_Letter_R_With_Middle_Tilde  : constant Unicode_Char := 16#1D72#;
   Latin_Small_Letter_R_With_Fishhook_And_Middle_Tilde :
      constant Unicode_Char := 16#1D73#;
   Latin_Small_Letter_S_With_Middle_Tilde  : constant Unicode_Char := 16#1D74#;
   Latin_Small_Letter_T_With_Middle_Tilde  : constant Unicode_Char := 16#1D75#;
   Latin_Small_Letter_Z_With_Middle_Tilde  : constant Unicode_Char := 16#1D76#;
   Latin_Small_Letter_Turned_G             : constant Unicode_Char := 16#1D77#;
   Modifier_Letter_Cyrillic_En             : constant Unicode_Char := 16#1D78#;
   Latin_Small_Letter_Insular_G            : constant Unicode_Char := 16#1D79#;
   Latin_Small_Letter_Th_With_Strikethrough :
      constant Unicode_Char := 16#1D7A#;
   Latin_Small_Capital_Letter_I_With_Stroke :
      constant Unicode_Char := 16#1D7B#;
   Latin_Small_Letter_Iota_With_Stroke     : constant Unicode_Char := 16#1D7C#;
   Latin_Small_Letter_P_With_Stroke        : constant Unicode_Char := 16#1D7D#;
   Latin_Small_Capital_Letter_U_With_Stroke :
      constant Unicode_Char := 16#1D7E#;
   Latin_Small_Letter_Upsilon_With_Stroke  : constant Unicode_Char := 16#1D7F#;
end Unicode.Names.Phonetic_Extensions;
