--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Meetei_Mayek is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Meetei_Mayek_Letter_Kok                 : constant Unicode_Char := 16#ABC0#;
   Meetei_Mayek_Letter_Sam                 : constant Unicode_Char := 16#ABC1#;
   Meetei_Mayek_Letter_Lai                 : constant Unicode_Char := 16#ABC2#;
   Meetei_Mayek_Letter_Mit                 : constant Unicode_Char := 16#ABC3#;
   Meetei_Mayek_Letter_Pa                  : constant Unicode_Char := 16#ABC4#;
   Meetei_Mayek_Letter_Na                  : constant Unicode_Char := 16#ABC5#;
   Meetei_Mayek_Letter_Chil                : constant Unicode_Char := 16#ABC6#;
   Meetei_Mayek_Letter_Til                 : constant Unicode_Char := 16#ABC7#;
   Meetei_Mayek_Letter_Khou                : constant Unicode_Char := 16#ABC8#;
   Meetei_Mayek_Letter_Ngou                : constant Unicode_Char := 16#ABC9#;
   Meetei_Mayek_Letter_Thou                : constant Unicode_Char := 16#ABCA#;
   Meetei_Mayek_Letter_Wai                 : constant Unicode_Char := 16#ABCB#;
   Meetei_Mayek_Letter_Yang                : constant Unicode_Char := 16#ABCC#;
   Meetei_Mayek_Letter_Huk                 : constant Unicode_Char := 16#ABCD#;
   Meetei_Mayek_Letter_Un                  : constant Unicode_Char := 16#ABCE#;
   Meetei_Mayek_Letter_I                   : constant Unicode_Char := 16#ABCF#;
   Meetei_Mayek_Letter_Pham                : constant Unicode_Char := 16#ABD0#;
   Meetei_Mayek_Letter_Atiya               : constant Unicode_Char := 16#ABD1#;
   Meetei_Mayek_Letter_Gok                 : constant Unicode_Char := 16#ABD2#;
   Meetei_Mayek_Letter_Jham                : constant Unicode_Char := 16#ABD3#;
   Meetei_Mayek_Letter_Rai                 : constant Unicode_Char := 16#ABD4#;
   Meetei_Mayek_Letter_Ba                  : constant Unicode_Char := 16#ABD5#;
   Meetei_Mayek_Letter_Jil                 : constant Unicode_Char := 16#ABD6#;
   Meetei_Mayek_Letter_Dil                 : constant Unicode_Char := 16#ABD7#;
   Meetei_Mayek_Letter_Ghou                : constant Unicode_Char := 16#ABD8#;
   Meetei_Mayek_Letter_Dhou                : constant Unicode_Char := 16#ABD9#;
   Meetei_Mayek_Letter_Bham                : constant Unicode_Char := 16#ABDA#;
   Meetei_Mayek_Letter_Kok_Lonsum          : constant Unicode_Char := 16#ABDB#;
   Meetei_Mayek_Letter_Lai_Lonsum          : constant Unicode_Char := 16#ABDC#;
   Meetei_Mayek_Letter_Mit_Lonsum          : constant Unicode_Char := 16#ABDD#;
   Meetei_Mayek_Letter_Pa_Lonsum           : constant Unicode_Char := 16#ABDE#;
   Meetei_Mayek_Letter_Na_Lonsum           : constant Unicode_Char := 16#ABDF#;
   Meetei_Mayek_Letter_Til_Lonsum          : constant Unicode_Char := 16#ABE0#;
   Meetei_Mayek_Letter_Ngou_Lonsum         : constant Unicode_Char := 16#ABE1#;
   Meetei_Mayek_Letter_I_Lonsum            : constant Unicode_Char := 16#ABE2#;
   Meetei_Mayek_Vowel_Sign_Onap            : constant Unicode_Char := 16#ABE3#;
   Meetei_Mayek_Vowel_Sign_Inap            : constant Unicode_Char := 16#ABE4#;
   Meetei_Mayek_Vowel_Sign_Anap            : constant Unicode_Char := 16#ABE5#;
   Meetei_Mayek_Vowel_Sign_Yenap           : constant Unicode_Char := 16#ABE6#;
   Meetei_Mayek_Vowel_Sign_Sounap          : constant Unicode_Char := 16#ABE7#;
   Meetei_Mayek_Vowel_Sign_Unap            : constant Unicode_Char := 16#ABE8#;
   Meetei_Mayek_Vowel_Sign_Cheinap         : constant Unicode_Char := 16#ABE9#;
   Meetei_Mayek_Vowel_Sign_Nung            : constant Unicode_Char := 16#ABEA#;
   Meetei_Mayek_Cheikhei                   : constant Unicode_Char := 16#ABEB#;
   Meetei_Mayek_Lum_Iyek                   : constant Unicode_Char := 16#ABEC#;
   Meetei_Mayek_Apun_Iyek                  : constant Unicode_Char := 16#ABED#;
   Meetei_Mayek_Digit_Zero                 : constant Unicode_Char := 16#ABF0#;
   Meetei_Mayek_Digit_One                  : constant Unicode_Char := 16#ABF1#;
   Meetei_Mayek_Digit_Two                  : constant Unicode_Char := 16#ABF2#;
   Meetei_Mayek_Digit_Three                : constant Unicode_Char := 16#ABF3#;
   Meetei_Mayek_Digit_Four                 : constant Unicode_Char := 16#ABF4#;
   Meetei_Mayek_Digit_Five                 : constant Unicode_Char := 16#ABF5#;
   Meetei_Mayek_Digit_Six                  : constant Unicode_Char := 16#ABF6#;
   Meetei_Mayek_Digit_Seven                : constant Unicode_Char := 16#ABF7#;
   Meetei_Mayek_Digit_Eight                : constant Unicode_Char := 16#ABF8#;
   Meetei_Mayek_Digit_Nine                 : constant Unicode_Char := 16#ABF9#;
end Unicode.Names.Meetei_Mayek;
