--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Misc_Symbols_Pictographs is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cyclone                                 :
      constant Unicode_Char := 16#1F300#;
   Foggy                                   :
      constant Unicode_Char := 16#1F301#;
   Closed_Umbrella                         :
      constant Unicode_Char := 16#1F302#;
   Night_With_Stars                        :
      constant Unicode_Char := 16#1F303#;
   Sunrise_Over_Mountains                  :
      constant Unicode_Char := 16#1F304#;
   Sunrise                                 :
      constant Unicode_Char := 16#1F305#;
   Cityscape_At_Dusk                       :
      constant Unicode_Char := 16#1F306#;
   Sunset_Over_Buildings                   :
      constant Unicode_Char := 16#1F307#;
   Rainbow                                 :
      constant Unicode_Char := 16#1F308#;
   Bridge_At_Night                         :
      constant Unicode_Char := 16#1F309#;
   Water_Wave                              :
      constant Unicode_Char := 16#1F30A#;
   Volcano                                 :
      constant Unicode_Char := 16#1F30B#;
   Milky_Way                               :
      constant Unicode_Char := 16#1F30C#;
   Earth_Globe_Europe_Africa               :
      constant Unicode_Char := 16#1F30D#;
   Earth_Globe_Americas                    :
      constant Unicode_Char := 16#1F30E#;
   Earth_Globe_Asia_Australia              :
      constant Unicode_Char := 16#1F30F#;
   Globe_With_Meridians                    :
      constant Unicode_Char := 16#1F310#;
   New_Moon_Symbol                         :
      constant Unicode_Char := 16#1F311#;
   Waxing_Crescent_Moon_Symbol             :
      constant Unicode_Char := 16#1F312#;
   First_Quarter_Moon_Symbol               :
      constant Unicode_Char := 16#1F313#;
   Waxing_Gibbous_Moon_Symbol              :
      constant Unicode_Char := 16#1F314#;
   Full_Moon_Symbol                        :
      constant Unicode_Char := 16#1F315#;
   Waning_Gibbous_Moon_Symbol              :
      constant Unicode_Char := 16#1F316#;
   Last_Quarter_Moon_Symbol                :
      constant Unicode_Char := 16#1F317#;
   Waning_Crescent_Moon_Symbol             :
      constant Unicode_Char := 16#1F318#;
   Crescent_Moon                           :
      constant Unicode_Char := 16#1F319#;
   New_Moon_With_Face                      :
      constant Unicode_Char := 16#1F31A#;
   First_Quarter_Moon_With_Face            :
      constant Unicode_Char := 16#1F31B#;
   Last_Quarter_Moon_With_Face             :
      constant Unicode_Char := 16#1F31C#;
   Full_Moon_With_Face                     :
      constant Unicode_Char := 16#1F31D#;
   Sun_With_Face                           :
      constant Unicode_Char := 16#1F31E#;
   Glowing_Star                            :
      constant Unicode_Char := 16#1F31F#;
   Shooting_Star                           :
      constant Unicode_Char := 16#1F320#;
   Thermometer                             :
      constant Unicode_Char := 16#1F321#;
   Black_Droplet                           :
      constant Unicode_Char := 16#1F322#;
   White_Sun                               :
      constant Unicode_Char := 16#1F323#;
   White_Sun_With_Small_Cloud              :
      constant Unicode_Char := 16#1F324#;
   White_Sun_Behind_Cloud                  :
      constant Unicode_Char := 16#1F325#;
   White_Sun_Behind_Cloud_With_Rain        :
      constant Unicode_Char := 16#1F326#;
   Cloud_With_Rain                         :
      constant Unicode_Char := 16#1F327#;
   Cloud_With_Snow                         :
      constant Unicode_Char := 16#1F328#;
   Cloud_With_Lightning                    :
      constant Unicode_Char := 16#1F329#;
   Cloud_With_Tornado                      :
      constant Unicode_Char := 16#1F32A#;
   Fog                                     :
      constant Unicode_Char := 16#1F32B#;
   Wind_Blowing_Face                       :
      constant Unicode_Char := 16#1F32C#;
   Hot_Dog                                 :
      constant Unicode_Char := 16#1F32D#;
   Taco                                    :
      constant Unicode_Char := 16#1F32E#;
   Burrito                                 :
      constant Unicode_Char := 16#1F32F#;
   Chestnut                                :
      constant Unicode_Char := 16#1F330#;
   Seedling                                :
      constant Unicode_Char := 16#1F331#;
   Evergreen_Tree                          :
      constant Unicode_Char := 16#1F332#;
   Deciduous_Tree                          :
      constant Unicode_Char := 16#1F333#;
   Palm_Tree                               :
      constant Unicode_Char := 16#1F334#;
   Cactus                                  :
      constant Unicode_Char := 16#1F335#;
   Hot_Pepper                              :
      constant Unicode_Char := 16#1F336#;
   Tulip                                   :
      constant Unicode_Char := 16#1F337#;
   Cherry_Blossom                          :
      constant Unicode_Char := 16#1F338#;
   Rose                                    :
      constant Unicode_Char := 16#1F339#;
   Hibiscus                                :
      constant Unicode_Char := 16#1F33A#;
   Sunflower                               :
      constant Unicode_Char := 16#1F33B#;
   Blossom                                 :
      constant Unicode_Char := 16#1F33C#;
   Ear_Of_Maize                            :
      constant Unicode_Char := 16#1F33D#;
   Ear_Of_Rice                             :
      constant Unicode_Char := 16#1F33E#;
   Herb                                    :
      constant Unicode_Char := 16#1F33F#;
   Four_Leaf_Clover                        :
      constant Unicode_Char := 16#1F340#;
   Maple_Leaf                              :
      constant Unicode_Char := 16#1F341#;
   Fallen_Leaf                             :
      constant Unicode_Char := 16#1F342#;
   Leaf_Fluttering_In_Wind                 :
      constant Unicode_Char := 16#1F343#;
   Mushroom                                :
      constant Unicode_Char := 16#1F344#;
   Tomato                                  :
      constant Unicode_Char := 16#1F345#;
   Aubergine                               :
      constant Unicode_Char := 16#1F346#;
   Grapes                                  :
      constant Unicode_Char := 16#1F347#;
   Melon                                   :
      constant Unicode_Char := 16#1F348#;
   Watermelon                              :
      constant Unicode_Char := 16#1F349#;
   Tangerine                               :
      constant Unicode_Char := 16#1F34A#;
   Lemon                                   :
      constant Unicode_Char := 16#1F34B#;
   Banana                                  :
      constant Unicode_Char := 16#1F34C#;
   Pineapple                               :
      constant Unicode_Char := 16#1F34D#;
   Red_Apple                               :
      constant Unicode_Char := 16#1F34E#;
   Green_Apple                             :
      constant Unicode_Char := 16#1F34F#;
   Pear                                    :
      constant Unicode_Char := 16#1F350#;
   Peach                                   :
      constant Unicode_Char := 16#1F351#;
   Cherries                                :
      constant Unicode_Char := 16#1F352#;
   Strawberry                              :
      constant Unicode_Char := 16#1F353#;
   Hamburger                               :
      constant Unicode_Char := 16#1F354#;
   Slice_Of_Pizza                          :
      constant Unicode_Char := 16#1F355#;
   Meat_On_Bone                            :
      constant Unicode_Char := 16#1F356#;
   Poultry_Leg                             :
      constant Unicode_Char := 16#1F357#;
   Rice_Cracker                            :
      constant Unicode_Char := 16#1F358#;
   Rice_Ball                               :
      constant Unicode_Char := 16#1F359#;
   Cooked_Rice                             :
      constant Unicode_Char := 16#1F35A#;
   Curry_And_Rice                          :
      constant Unicode_Char := 16#1F35B#;
   Steaming_Bowl                           :
      constant Unicode_Char := 16#1F35C#;
   Spaghetti                               :
      constant Unicode_Char := 16#1F35D#;
   Bread                                   :
      constant Unicode_Char := 16#1F35E#;
   French_Fries                            :
      constant Unicode_Char := 16#1F35F#;
   Roasted_Sweet_Potato                    :
      constant Unicode_Char := 16#1F360#;
   Dango                                   :
      constant Unicode_Char := 16#1F361#;
   Oden                                    :
      constant Unicode_Char := 16#1F362#;
   Sushi                                   :
      constant Unicode_Char := 16#1F363#;
   Fried_Shrimp                            :
      constant Unicode_Char := 16#1F364#;
   Fish_Cake_With_Swirl_Design             :
      constant Unicode_Char := 16#1F365#;
   Soft_Ice_Cream                          :
      constant Unicode_Char := 16#1F366#;
   Shaved_Ice                              :
      constant Unicode_Char := 16#1F367#;
   Ice_Cream                               :
      constant Unicode_Char := 16#1F368#;
   Doughnut                                :
      constant Unicode_Char := 16#1F369#;
   Cookie                                  :
      constant Unicode_Char := 16#1F36A#;
   Chocolate_Bar                           :
      constant Unicode_Char := 16#1F36B#;
   Candy                                   :
      constant Unicode_Char := 16#1F36C#;
   Lollipop                                :
      constant Unicode_Char := 16#1F36D#;
   Custard                                 :
      constant Unicode_Char := 16#1F36E#;
   Honey_Pot                               :
      constant Unicode_Char := 16#1F36F#;
   Shortcake                               :
      constant Unicode_Char := 16#1F370#;
   Bento_Box                               :
      constant Unicode_Char := 16#1F371#;
   Pot_Of_Food                             :
      constant Unicode_Char := 16#1F372#;
   Cooking                                 :
      constant Unicode_Char := 16#1F373#;
   Fork_And_Knife                          :
      constant Unicode_Char := 16#1F374#;
   Teacup_Without_Handle                   :
      constant Unicode_Char := 16#1F375#;
   Sake_Bottle_And_Cup                     :
      constant Unicode_Char := 16#1F376#;
   Wine_Glass                              :
      constant Unicode_Char := 16#1F377#;
   Cocktail_Glass                          :
      constant Unicode_Char := 16#1F378#;
   Tropical_Drink                          :
      constant Unicode_Char := 16#1F379#;
   Beer_Mug                                :
      constant Unicode_Char := 16#1F37A#;
   Clinking_Beer_Mugs                      :
      constant Unicode_Char := 16#1F37B#;
   Baby_Bottle                             :
      constant Unicode_Char := 16#1F37C#;
   Fork_And_Knife_With_Plate               :
      constant Unicode_Char := 16#1F37D#;
   Bottle_With_Popping_Cork                :
      constant Unicode_Char := 16#1F37E#;
   Popcorn                                 :
      constant Unicode_Char := 16#1F37F#;
   Ribbon                                  :
      constant Unicode_Char := 16#1F380#;
   Wrapped_Present                         :
      constant Unicode_Char := 16#1F381#;
   Birthday_Cake                           :
      constant Unicode_Char := 16#1F382#;
   Jack_O_Lantern                          :
      constant Unicode_Char := 16#1F383#;
   Christmas_Tree                          :
      constant Unicode_Char := 16#1F384#;
   Father_Christmas                        :
      constant Unicode_Char := 16#1F385#;
   Fireworks                               :
      constant Unicode_Char := 16#1F386#;
   Firework_Sparkler                       :
      constant Unicode_Char := 16#1F387#;
   Balloon                                 :
      constant Unicode_Char := 16#1F388#;
   Party_Popper                            :
      constant Unicode_Char := 16#1F389#;
   Confetti_Ball                           :
      constant Unicode_Char := 16#1F38A#;
   Tanabata_Tree                           :
      constant Unicode_Char := 16#1F38B#;
   Crossed_Flags                           :
      constant Unicode_Char := 16#1F38C#;
   Pine_Decoration                         :
      constant Unicode_Char := 16#1F38D#;
   Japanese_Dolls                          :
      constant Unicode_Char := 16#1F38E#;
   Carp_Streamer                           :
      constant Unicode_Char := 16#1F38F#;
   Wind_Chime                              :
      constant Unicode_Char := 16#1F390#;
   Moon_Viewing_Ceremony                   :
      constant Unicode_Char := 16#1F391#;
   School_Satchel                          :
      constant Unicode_Char := 16#1F392#;
   Graduation_Cap                          :
      constant Unicode_Char := 16#1F393#;
   Heart_With_Tip_On_The_Left              :
      constant Unicode_Char := 16#1F394#;
   Bouquet_Of_Flowers                      :
      constant Unicode_Char := 16#1F395#;
   Military_Medal                          :
      constant Unicode_Char := 16#1F396#;
   Reminder_Ribbon                         :
      constant Unicode_Char := 16#1F397#;
   Musical_Keyboard_With_Jacks             :
      constant Unicode_Char := 16#1F398#;
   Studio_Microphone                       :
      constant Unicode_Char := 16#1F399#;
   Level_Slider                            :
      constant Unicode_Char := 16#1F39A#;
   Control_Knobs                           :
      constant Unicode_Char := 16#1F39B#;
   Beamed_Ascending_Musical_Notes          :
      constant Unicode_Char := 16#1F39C#;
   Beamed_Descending_Musical_Notes         :
      constant Unicode_Char := 16#1F39D#;
   Film_Frames                             :
      constant Unicode_Char := 16#1F39E#;
   Admission_Tickets                       :
      constant Unicode_Char := 16#1F39F#;
   Carousel_Horse                          :
      constant Unicode_Char := 16#1F3A0#;
   Ferris_Wheel                            :
      constant Unicode_Char := 16#1F3A1#;
   Roller_Coaster                          :
      constant Unicode_Char := 16#1F3A2#;
   Fishing_Pole_And_Fish                   :
      constant Unicode_Char := 16#1F3A3#;
   Microphone                              :
      constant Unicode_Char := 16#1F3A4#;
   Movie_Camera                            :
      constant Unicode_Char := 16#1F3A5#;
   Cinema                                  :
      constant Unicode_Char := 16#1F3A6#;
   Headphone                               :
      constant Unicode_Char := 16#1F3A7#;
   Artist_Palette                          :
      constant Unicode_Char := 16#1F3A8#;
   Top_Hat                                 :
      constant Unicode_Char := 16#1F3A9#;
   Circus_Tent                             :
      constant Unicode_Char := 16#1F3AA#;
   Ticket                                  :
      constant Unicode_Char := 16#1F3AB#;
   Clapper_Board                           :
      constant Unicode_Char := 16#1F3AC#;
   Performing_Arts                         :
      constant Unicode_Char := 16#1F3AD#;
   Video_Game                              :
      constant Unicode_Char := 16#1F3AE#;
   Direct_Hit                              :
      constant Unicode_Char := 16#1F3AF#;
   Slot_Machine                            :
      constant Unicode_Char := 16#1F3B0#;
   Billiards                               :
      constant Unicode_Char := 16#1F3B1#;
   Game_Die                                :
      constant Unicode_Char := 16#1F3B2#;
   Bowling                                 :
      constant Unicode_Char := 16#1F3B3#;
   Flower_Playing_Cards                    :
      constant Unicode_Char := 16#1F3B4#;
   Musical_Note                            :
      constant Unicode_Char := 16#1F3B5#;
   Multiple_Musical_Notes                  :
      constant Unicode_Char := 16#1F3B6#;
   Saxophone                               :
      constant Unicode_Char := 16#1F3B7#;
   Guitar                                  :
      constant Unicode_Char := 16#1F3B8#;
   Musical_Keyboard                        :
      constant Unicode_Char := 16#1F3B9#;
   Trumpet                                 :
      constant Unicode_Char := 16#1F3BA#;
   Violin                                  :
      constant Unicode_Char := 16#1F3BB#;
   Musical_Score                           :
      constant Unicode_Char := 16#1F3BC#;
   Running_Shirt_With_Sash                 :
      constant Unicode_Char := 16#1F3BD#;
   Tennis_Racquet_And_Ball                 :
      constant Unicode_Char := 16#1F3BE#;
   Ski_And_Ski_Boot                        :
      constant Unicode_Char := 16#1F3BF#;
   Basketball_And_Hoop                     :
      constant Unicode_Char := 16#1F3C0#;
   Chequered_Flag                          :
      constant Unicode_Char := 16#1F3C1#;
   Snowboarder                             :
      constant Unicode_Char := 16#1F3C2#;
   Runner                                  :
      constant Unicode_Char := 16#1F3C3#;
   Surfer                                  :
      constant Unicode_Char := 16#1F3C4#;
   Sports_Medal                            :
      constant Unicode_Char := 16#1F3C5#;
   Trophy                                  :
      constant Unicode_Char := 16#1F3C6#;
   Horse_Racing                            :
      constant Unicode_Char := 16#1F3C7#;
   American_Football                       :
      constant Unicode_Char := 16#1F3C8#;
   Rugby_Football                          :
      constant Unicode_Char := 16#1F3C9#;
   Swimmer                                 :
      constant Unicode_Char := 16#1F3CA#;
   Weight_Lifter                           :
      constant Unicode_Char := 16#1F3CB#;
   Golfer                                  :
      constant Unicode_Char := 16#1F3CC#;
   Racing_Motorcycle                       :
      constant Unicode_Char := 16#1F3CD#;
   Racing_Car                              :
      constant Unicode_Char := 16#1F3CE#;
   Cricket_Bat_And_Ball                    :
      constant Unicode_Char := 16#1F3CF#;
   Volleyball                              :
      constant Unicode_Char := 16#1F3D0#;
   Field_Hockey_Stick_And_Ball             :
      constant Unicode_Char := 16#1F3D1#;
   Ice_Hockey_Stick_And_Puck               :
      constant Unicode_Char := 16#1F3D2#;
   Table_Tennis_Paddle_And_Ball            :
      constant Unicode_Char := 16#1F3D3#;
   Snow_Capped_Mountain                    :
      constant Unicode_Char := 16#1F3D4#;
   Camping                                 :
      constant Unicode_Char := 16#1F3D5#;
   Beach_With_Umbrella                     :
      constant Unicode_Char := 16#1F3D6#;
   Building_Construction                   :
      constant Unicode_Char := 16#1F3D7#;
   House_Buildings                         :
      constant Unicode_Char := 16#1F3D8#;
   Cityscape                               :
      constant Unicode_Char := 16#1F3D9#;
   Derelict_House_Building                 :
      constant Unicode_Char := 16#1F3DA#;
   Classical_Building                      :
      constant Unicode_Char := 16#1F3DB#;
   Desert                                  :
      constant Unicode_Char := 16#1F3DC#;
   Desert_Island                           :
      constant Unicode_Char := 16#1F3DD#;
   National_Park                           :
      constant Unicode_Char := 16#1F3DE#;
   Stadium                                 :
      constant Unicode_Char := 16#1F3DF#;
   House_Building                          :
      constant Unicode_Char := 16#1F3E0#;
   House_With_Garden                       :
      constant Unicode_Char := 16#1F3E1#;
   Office_Building                         :
      constant Unicode_Char := 16#1F3E2#;
   Japanese_Post_Office                    :
      constant Unicode_Char := 16#1F3E3#;
   European_Post_Office                    :
      constant Unicode_Char := 16#1F3E4#;
   Hospital                                :
      constant Unicode_Char := 16#1F3E5#;
   Bank                                    :
      constant Unicode_Char := 16#1F3E6#;
   Automated_Teller_Machine                :
      constant Unicode_Char := 16#1F3E7#;
   Hotel                                   :
      constant Unicode_Char := 16#1F3E8#;
   Love_Hotel                              :
      constant Unicode_Char := 16#1F3E9#;
   Convenience_Store                       :
      constant Unicode_Char := 16#1F3EA#;
   School                                  :
      constant Unicode_Char := 16#1F3EB#;
   Department_Store                        :
      constant Unicode_Char := 16#1F3EC#;
   Factory                                 :
      constant Unicode_Char := 16#1F3ED#;
   Izakaya_Lantern                         :
      constant Unicode_Char := 16#1F3EE#;
   Japanese_Castle                         :
      constant Unicode_Char := 16#1F3EF#;
   European_Castle                         :
      constant Unicode_Char := 16#1F3F0#;
   White_Pennant                           :
      constant Unicode_Char := 16#1F3F1#;
   Black_Pennant                           :
      constant Unicode_Char := 16#1F3F2#;
   Waving_White_Flag                       :
      constant Unicode_Char := 16#1F3F3#;
   Waving_Black_Flag                       :
      constant Unicode_Char := 16#1F3F4#;
   Rosette                                 :
      constant Unicode_Char := 16#1F3F5#;
   Black_Rosette                           :
      constant Unicode_Char := 16#1F3F6#;
   Label                                   :
      constant Unicode_Char := 16#1F3F7#;
   Badminton_Racquet_And_Shuttlecock       :
      constant Unicode_Char := 16#1F3F8#;
   Bow_And_Arrow                           :
      constant Unicode_Char := 16#1F3F9#;
   Amphora                                 :
      constant Unicode_Char := 16#1F3FA#;
   Emoji_Modifier_Fitzpatrick_Type_1_2     :
      constant Unicode_Char := 16#1F3FB#;
   Emoji_Modifier_Fitzpatrick_Type_3       :
      constant Unicode_Char := 16#1F3FC#;
   Emoji_Modifier_Fitzpatrick_Type_4       :
      constant Unicode_Char := 16#1F3FD#;
   Emoji_Modifier_Fitzpatrick_Type_5       :
      constant Unicode_Char := 16#1F3FE#;
   Emoji_Modifier_Fitzpatrick_Type_6       :
      constant Unicode_Char := 16#1F3FF#;
   Rat                                     :
      constant Unicode_Char := 16#1F400#;
   Mouse                                   :
      constant Unicode_Char := 16#1F401#;
   Ox                                      :
      constant Unicode_Char := 16#1F402#;
   Water_Buffalo                           :
      constant Unicode_Char := 16#1F403#;
   Cow                                     :
      constant Unicode_Char := 16#1F404#;
   Tiger                                   :
      constant Unicode_Char := 16#1F405#;
   Leopard                                 :
      constant Unicode_Char := 16#1F406#;
   Rabbit                                  :
      constant Unicode_Char := 16#1F407#;
   Cat                                     :
      constant Unicode_Char := 16#1F408#;
   Dragon                                  :
      constant Unicode_Char := 16#1F409#;
   Crocodile                               :
      constant Unicode_Char := 16#1F40A#;
   Whale                                   :
      constant Unicode_Char := 16#1F40B#;
   Snail                                   :
      constant Unicode_Char := 16#1F40C#;
   Snake                                   :
      constant Unicode_Char := 16#1F40D#;
   Horse                                   :
      constant Unicode_Char := 16#1F40E#;
   Ram                                     :
      constant Unicode_Char := 16#1F40F#;
   Goat                                    :
      constant Unicode_Char := 16#1F410#;
   Sheep                                   :
      constant Unicode_Char := 16#1F411#;
   Monkey                                  :
      constant Unicode_Char := 16#1F412#;
   Rooster                                 :
      constant Unicode_Char := 16#1F413#;
   Chicken                                 :
      constant Unicode_Char := 16#1F414#;
   Dog                                     :
      constant Unicode_Char := 16#1F415#;
   Pig                                     :
      constant Unicode_Char := 16#1F416#;
   Boar                                    :
      constant Unicode_Char := 16#1F417#;
   Elephant                                :
      constant Unicode_Char := 16#1F418#;
   Octopus                                 :
      constant Unicode_Char := 16#1F419#;
   Spiral_Shell                            :
      constant Unicode_Char := 16#1F41A#;
   Bug                                     :
      constant Unicode_Char := 16#1F41B#;
   Ant                                     :
      constant Unicode_Char := 16#1F41C#;
   Honeybee                                :
      constant Unicode_Char := 16#1F41D#;
   Lady_Beetle                             :
      constant Unicode_Char := 16#1F41E#;
   Fish                                    :
      constant Unicode_Char := 16#1F41F#;
   Tropical_Fish                           :
      constant Unicode_Char := 16#1F420#;
   Blowfish                                :
      constant Unicode_Char := 16#1F421#;
   Turtle                                  :
      constant Unicode_Char := 16#1F422#;
   Hatching_Chick                          :
      constant Unicode_Char := 16#1F423#;
   Baby_Chick                              :
      constant Unicode_Char := 16#1F424#;
   Front_Facing_Baby_Chick                 :
      constant Unicode_Char := 16#1F425#;
   Bird                                    :
      constant Unicode_Char := 16#1F426#;
   Penguin                                 :
      constant Unicode_Char := 16#1F427#;
   Koala                                   :
      constant Unicode_Char := 16#1F428#;
   Poodle                                  :
      constant Unicode_Char := 16#1F429#;
   Dromedary_Camel                         :
      constant Unicode_Char := 16#1F42A#;
   Bactrian_Camel                          :
      constant Unicode_Char := 16#1F42B#;
   Dolphin                                 :
      constant Unicode_Char := 16#1F42C#;
   Mouse_Face                              :
      constant Unicode_Char := 16#1F42D#;
   Cow_Face                                :
      constant Unicode_Char := 16#1F42E#;
   Tiger_Face                              :
      constant Unicode_Char := 16#1F42F#;
   Rabbit_Face                             :
      constant Unicode_Char := 16#1F430#;
   Cat_Face                                :
      constant Unicode_Char := 16#1F431#;
   Dragon_Face                             :
      constant Unicode_Char := 16#1F432#;
   Spouting_Whale                          :
      constant Unicode_Char := 16#1F433#;
   Horse_Face                              :
      constant Unicode_Char := 16#1F434#;
   Monkey_Face                             :
      constant Unicode_Char := 16#1F435#;
   Dog_Face                                :
      constant Unicode_Char := 16#1F436#;
   Pig_Face                                :
      constant Unicode_Char := 16#1F437#;
   Frog_Face                               :
      constant Unicode_Char := 16#1F438#;
   Hamster_Face                            :
      constant Unicode_Char := 16#1F439#;
   Wolf_Face                               :
      constant Unicode_Char := 16#1F43A#;
   Bear_Face                               :
      constant Unicode_Char := 16#1F43B#;
   Panda_Face                              :
      constant Unicode_Char := 16#1F43C#;
   Pig_Nose                                :
      constant Unicode_Char := 16#1F43D#;
   Paw_Prints                              :
      constant Unicode_Char := 16#1F43E#;
   Chipmunk                                :
      constant Unicode_Char := 16#1F43F#;
   Eyes                                    :
      constant Unicode_Char := 16#1F440#;
   Eye                                     :
      constant Unicode_Char := 16#1F441#;
   Ear                                     :
      constant Unicode_Char := 16#1F442#;
   Nose                                    :
      constant Unicode_Char := 16#1F443#;
   Mouth                                   :
      constant Unicode_Char := 16#1F444#;
   Tongue                                  :
      constant Unicode_Char := 16#1F445#;
   White_Up_Pointing_Backhand_Index        :
      constant Unicode_Char := 16#1F446#;
   White_Down_Pointing_Backhand_Index      :
      constant Unicode_Char := 16#1F447#;
   White_Left_Pointing_Backhand_Index      :
      constant Unicode_Char := 16#1F448#;
   White_Right_Pointing_Backhand_Index     :
      constant Unicode_Char := 16#1F449#;
   Fisted_Hand_Sign                        :
      constant Unicode_Char := 16#1F44A#;
   Waving_Hand_Sign                        :
      constant Unicode_Char := 16#1F44B#;
   Ok_Hand_Sign                            :
      constant Unicode_Char := 16#1F44C#;
   Thumbs_Up_Sign                          :
      constant Unicode_Char := 16#1F44D#;
   Thumbs_Down_Sign                        :
      constant Unicode_Char := 16#1F44E#;
   Clapping_Hands_Sign                     :
      constant Unicode_Char := 16#1F44F#;
   Open_Hands_Sign                         :
      constant Unicode_Char := 16#1F450#;
   Crown                                   :
      constant Unicode_Char := 16#1F451#;
   Womans_Hat                              :
      constant Unicode_Char := 16#1F452#;
   Eyeglasses                              :
      constant Unicode_Char := 16#1F453#;
   Necktie                                 :
      constant Unicode_Char := 16#1F454#;
   T_Shirt                                 :
      constant Unicode_Char := 16#1F455#;
   Jeans                                   :
      constant Unicode_Char := 16#1F456#;
   Dress                                   :
      constant Unicode_Char := 16#1F457#;
   Kimono                                  :
      constant Unicode_Char := 16#1F458#;
   Bikini                                  :
      constant Unicode_Char := 16#1F459#;
   Womans_Clothes                          :
      constant Unicode_Char := 16#1F45A#;
   Purse                                   :
      constant Unicode_Char := 16#1F45B#;
   Handbag                                 :
      constant Unicode_Char := 16#1F45C#;
   Pouch                                   :
      constant Unicode_Char := 16#1F45D#;
   Mans_Shoe                               :
      constant Unicode_Char := 16#1F45E#;
   Athletic_Shoe                           :
      constant Unicode_Char := 16#1F45F#;
   High_Heeled_Shoe                        :
      constant Unicode_Char := 16#1F460#;
   Womans_Sandal                           :
      constant Unicode_Char := 16#1F461#;
   Womans_Boots                            :
      constant Unicode_Char := 16#1F462#;
   Footprints                              :
      constant Unicode_Char := 16#1F463#;
   Bust_In_Silhouette                      :
      constant Unicode_Char := 16#1F464#;
   Busts_In_Silhouette                     :
      constant Unicode_Char := 16#1F465#;
   Boy                                     :
      constant Unicode_Char := 16#1F466#;
   Girl                                    :
      constant Unicode_Char := 16#1F467#;
   Man                                     :
      constant Unicode_Char := 16#1F468#;
   Woman                                   :
      constant Unicode_Char := 16#1F469#;
   Family                                  :
      constant Unicode_Char := 16#1F46A#;
   Man_And_Woman_Holding_Hands             :
      constant Unicode_Char := 16#1F46B#;
   Two_Men_Holding_Hands                   :
      constant Unicode_Char := 16#1F46C#;
   Two_Women_Holding_Hands                 :
      constant Unicode_Char := 16#1F46D#;
   Police_Officer                          :
      constant Unicode_Char := 16#1F46E#;
   Woman_With_Bunny_Ears                   :
      constant Unicode_Char := 16#1F46F#;
   Bride_With_Veil                         :
      constant Unicode_Char := 16#1F470#;
   Person_With_Blond_Hair                  :
      constant Unicode_Char := 16#1F471#;
   Man_With_Gua_Pi_Mao                     :
      constant Unicode_Char := 16#1F472#;
   Man_With_Turban                         :
      constant Unicode_Char := 16#1F473#;
   Older_Man                               :
      constant Unicode_Char := 16#1F474#;
   Older_Woman                             :
      constant Unicode_Char := 16#1F475#;
   Baby                                    :
      constant Unicode_Char := 16#1F476#;
   Construction_Worker                     :
      constant Unicode_Char := 16#1F477#;
   Princess                                :
      constant Unicode_Char := 16#1F478#;
   Japanese_Ogre                           :
      constant Unicode_Char := 16#1F479#;
   Japanese_Goblin                         :
      constant Unicode_Char := 16#1F47A#;
   Ghost                                   :
      constant Unicode_Char := 16#1F47B#;
   Baby_Angel                              :
      constant Unicode_Char := 16#1F47C#;
   Extraterrestrial_Alien                  :
      constant Unicode_Char := 16#1F47D#;
   Alien_Monster                           :
      constant Unicode_Char := 16#1F47E#;
   Imp                                     :
      constant Unicode_Char := 16#1F47F#;
   Skull                                   :
      constant Unicode_Char := 16#1F480#;
   Information_Desk_Person                 :
      constant Unicode_Char := 16#1F481#;
   Guardsman                               :
      constant Unicode_Char := 16#1F482#;
   Dancer                                  :
      constant Unicode_Char := 16#1F483#;
   Lipstick                                :
      constant Unicode_Char := 16#1F484#;
   Nail_Polish                             :
      constant Unicode_Char := 16#1F485#;
   Face_Massage                            :
      constant Unicode_Char := 16#1F486#;
   Haircut                                 :
      constant Unicode_Char := 16#1F487#;
   Barber_Pole                             :
      constant Unicode_Char := 16#1F488#;
   Syringe                                 :
      constant Unicode_Char := 16#1F489#;
   Pill                                    :
      constant Unicode_Char := 16#1F48A#;
   Kiss_Mark                               :
      constant Unicode_Char := 16#1F48B#;
   Love_Letter                             :
      constant Unicode_Char := 16#1F48C#;
   Ring                                    :
      constant Unicode_Char := 16#1F48D#;
   Gem_Stone                               :
      constant Unicode_Char := 16#1F48E#;
   Kiss                                    :
      constant Unicode_Char := 16#1F48F#;
   Bouquet                                 :
      constant Unicode_Char := 16#1F490#;
   Couple_With_Heart                       :
      constant Unicode_Char := 16#1F491#;
   Wedding                                 :
      constant Unicode_Char := 16#1F492#;
   Beating_Heart                           :
      constant Unicode_Char := 16#1F493#;
   Broken_Heart                            :
      constant Unicode_Char := 16#1F494#;
   Two_Hearts                              :
      constant Unicode_Char := 16#1F495#;
   Sparkling_Heart                         :
      constant Unicode_Char := 16#1F496#;
   Growing_Heart                           :
      constant Unicode_Char := 16#1F497#;
   Heart_With_Arrow                        :
      constant Unicode_Char := 16#1F498#;
   Blue_Heart                              :
      constant Unicode_Char := 16#1F499#;
   Green_Heart                             :
      constant Unicode_Char := 16#1F49A#;
   Yellow_Heart                            :
      constant Unicode_Char := 16#1F49B#;
   Purple_Heart                            :
      constant Unicode_Char := 16#1F49C#;
   Heart_With_Ribbon                       :
      constant Unicode_Char := 16#1F49D#;
   Revolving_Hearts                        :
      constant Unicode_Char := 16#1F49E#;
   Heart_Decoration                        :
      constant Unicode_Char := 16#1F49F#;
   Diamond_Shape_With_A_Dot_Inside         :
      constant Unicode_Char := 16#1F4A0#;
   Electric_Light_Bulb                     :
      constant Unicode_Char := 16#1F4A1#;
   Anger_Symbol                            :
      constant Unicode_Char := 16#1F4A2#;
   Bomb                                    :
      constant Unicode_Char := 16#1F4A3#;
   Sleeping_Symbol                         :
      constant Unicode_Char := 16#1F4A4#;
   Collision_Symbol                        :
      constant Unicode_Char := 16#1F4A5#;
   Splashing_Sweat_Symbol                  :
      constant Unicode_Char := 16#1F4A6#;
   Droplet                                 :
      constant Unicode_Char := 16#1F4A7#;
   Dash_Symbol                             :
      constant Unicode_Char := 16#1F4A8#;
   Pile_Of_Poo                             :
      constant Unicode_Char := 16#1F4A9#;
   Flexed_Biceps                           :
      constant Unicode_Char := 16#1F4AA#;
   Dizzy_Symbol                            :
      constant Unicode_Char := 16#1F4AB#;
   Speech_Balloon                          :
      constant Unicode_Char := 16#1F4AC#;
   Thought_Balloon                         :
      constant Unicode_Char := 16#1F4AD#;
   White_Flower                            :
      constant Unicode_Char := 16#1F4AE#;
   Hundred_Points_Symbol                   :
      constant Unicode_Char := 16#1F4AF#;
   Money_Bag                               :
      constant Unicode_Char := 16#1F4B0#;
   Currency_Exchange                       :
      constant Unicode_Char := 16#1F4B1#;
   Heavy_Dollar_Sign                       :
      constant Unicode_Char := 16#1F4B2#;
   Credit_Card                             :
      constant Unicode_Char := 16#1F4B3#;
   Banknote_With_Yen_Sign                  :
      constant Unicode_Char := 16#1F4B4#;
   Banknote_With_Dollar_Sign               :
      constant Unicode_Char := 16#1F4B5#;
   Banknote_With_Euro_Sign                 :
      constant Unicode_Char := 16#1F4B6#;
   Banknote_With_Pound_Sign                :
      constant Unicode_Char := 16#1F4B7#;
   Money_With_Wings                        :
      constant Unicode_Char := 16#1F4B8#;
   Chart_With_Upwards_Trend_And_Yen_Sign   :
      constant Unicode_Char := 16#1F4B9#;
   Seat                                    :
      constant Unicode_Char := 16#1F4BA#;
   Personal_Computer                       :
      constant Unicode_Char := 16#1F4BB#;
   Briefcase                               :
      constant Unicode_Char := 16#1F4BC#;
   Minidisc                                :
      constant Unicode_Char := 16#1F4BD#;
   Floppy_Disk                             :
      constant Unicode_Char := 16#1F4BE#;
   Optical_Disc                            :
      constant Unicode_Char := 16#1F4BF#;
   Dvd                                     :
      constant Unicode_Char := 16#1F4C0#;
   File_Folder                             :
      constant Unicode_Char := 16#1F4C1#;
   Open_File_Folder                        :
      constant Unicode_Char := 16#1F4C2#;
   Page_With_Curl                          :
      constant Unicode_Char := 16#1F4C3#;
   Page_Facing_Up                          :
      constant Unicode_Char := 16#1F4C4#;
   Calendar                                :
      constant Unicode_Char := 16#1F4C5#;
   Tear_Off_Calendar                       :
      constant Unicode_Char := 16#1F4C6#;
   Card_Index                              :
      constant Unicode_Char := 16#1F4C7#;
   Chart_With_Upwards_Trend                :
      constant Unicode_Char := 16#1F4C8#;
   Chart_With_Downwards_Trend              :
      constant Unicode_Char := 16#1F4C9#;
   Bar_Chart                               :
      constant Unicode_Char := 16#1F4CA#;
   Clipboard                               :
      constant Unicode_Char := 16#1F4CB#;
   Pushpin                                 :
      constant Unicode_Char := 16#1F4CC#;
   Round_Pushpin                           :
      constant Unicode_Char := 16#1F4CD#;
   Paperclip                               :
      constant Unicode_Char := 16#1F4CE#;
   Straight_Ruler                          :
      constant Unicode_Char := 16#1F4CF#;
   Triangular_Ruler                        :
      constant Unicode_Char := 16#1F4D0#;
   Bookmark_Tabs                           :
      constant Unicode_Char := 16#1F4D1#;
   Ledger                                  :
      constant Unicode_Char := 16#1F4D2#;
   Notebook                                :
      constant Unicode_Char := 16#1F4D3#;
   Notebook_With_Decorative_Cover          :
      constant Unicode_Char := 16#1F4D4#;
   Closed_Book                             :
      constant Unicode_Char := 16#1F4D5#;
   Open_Book                               :
      constant Unicode_Char := 16#1F4D6#;
   Green_Book                              :
      constant Unicode_Char := 16#1F4D7#;
   Blue_Book                               :
      constant Unicode_Char := 16#1F4D8#;
   Orange_Book                             :
      constant Unicode_Char := 16#1F4D9#;
   Books                                   :
      constant Unicode_Char := 16#1F4DA#;
   Name_Badge                              :
      constant Unicode_Char := 16#1F4DB#;
   Scroll                                  :
      constant Unicode_Char := 16#1F4DC#;
   Memo                                    :
      constant Unicode_Char := 16#1F4DD#;
   Telephone_Receiver                      :
      constant Unicode_Char := 16#1F4DE#;
   Pager                                   :
      constant Unicode_Char := 16#1F4DF#;
   Fax_Machine                             :
      constant Unicode_Char := 16#1F4E0#;
   Satellite_Antenna                       :
      constant Unicode_Char := 16#1F4E1#;
   Public_Address_Loudspeaker              :
      constant Unicode_Char := 16#1F4E2#;
   Cheering_Megaphone                      :
      constant Unicode_Char := 16#1F4E3#;
   Outbox_Tray                             :
      constant Unicode_Char := 16#1F4E4#;
   Inbox_Tray                              :
      constant Unicode_Char := 16#1F4E5#;
   --  Real Unicode name is PACKAGE
   Unicode_Package                         :
      constant Unicode_Char := 16#1F4E6#;
   E_Mail_Symbol                           :
      constant Unicode_Char := 16#1F4E7#;
   Incoming_Envelope                       :
      constant Unicode_Char := 16#1F4E8#;
   Envelope_With_Downwards_Arrow_Above     :
      constant Unicode_Char := 16#1F4E9#;
   Closed_Mailbox_With_Lowered_Flag        :
      constant Unicode_Char := 16#1F4EA#;
   Closed_Mailbox_With_Raised_Flag         :
      constant Unicode_Char := 16#1F4EB#;
   Open_Mailbox_With_Raised_Flag           :
      constant Unicode_Char := 16#1F4EC#;
   Open_Mailbox_With_Lowered_Flag          :
      constant Unicode_Char := 16#1F4ED#;
   Postbox                                 :
      constant Unicode_Char := 16#1F4EE#;
   Postal_Horn                             :
      constant Unicode_Char := 16#1F4EF#;
   Newspaper                               :
      constant Unicode_Char := 16#1F4F0#;
   Mobile_Phone                            :
      constant Unicode_Char := 16#1F4F1#;
   Mobile_Phone_With_Rightwards_Arrow_At_Left :
      constant Unicode_Char := 16#1F4F2#;
   Vibration_Mode                          :
      constant Unicode_Char := 16#1F4F3#;
   Mobile_Phone_Off                        :
      constant Unicode_Char := 16#1F4F4#;
   No_Mobile_Phones                        :
      constant Unicode_Char := 16#1F4F5#;
   Antenna_With_Bars                       :
      constant Unicode_Char := 16#1F4F6#;
   Camera                                  :
      constant Unicode_Char := 16#1F4F7#;
   Camera_With_Flash                       :
      constant Unicode_Char := 16#1F4F8#;
   Video_Camera                            :
      constant Unicode_Char := 16#1F4F9#;
   Television                              :
      constant Unicode_Char := 16#1F4FA#;
   Radio                                   :
      constant Unicode_Char := 16#1F4FB#;
   Videocassette                           :
      constant Unicode_Char := 16#1F4FC#;
   Film_Projector                          :
      constant Unicode_Char := 16#1F4FD#;
   Portable_Stereo                         :
      constant Unicode_Char := 16#1F4FE#;
   Prayer_Beads                            :
      constant Unicode_Char := 16#1F4FF#;
   Twisted_Rightwards_Arrows               :
      constant Unicode_Char := 16#1F500#;
   Clockwise_Rightwards_And_Leftwards_Open_Circle_Arrows :
      constant Unicode_Char := 16#1F501#;
   Clockwise_Rightwards_And_Leftwards_Open_Circle_Arrows_With_Circled_One_Overlay :
      constant Unicode_Char := 16#1F502#;
   Clockwise_Downwards_And_Upwards_Open_Circle_Arrows :
      constant Unicode_Char := 16#1F503#;
   Anticlockwise_Downwards_And_Upwards_Open_Circle_Arrows :
      constant Unicode_Char := 16#1F504#;
   Low_Brightness_Symbol                   :
      constant Unicode_Char := 16#1F505#;
   High_Brightness_Symbol                  :
      constant Unicode_Char := 16#1F506#;
   Speaker_With_Cancellation_Stroke        :
      constant Unicode_Char := 16#1F507#;
   Speaker                                 :
      constant Unicode_Char := 16#1F508#;
   Speaker_With_One_Sound_Wave             :
      constant Unicode_Char := 16#1F509#;
   Speaker_With_Three_Sound_Waves          :
      constant Unicode_Char := 16#1F50A#;
   Battery                                 :
      constant Unicode_Char := 16#1F50B#;
   Electric_Plug                           :
      constant Unicode_Char := 16#1F50C#;
   Left_Pointing_Magnifying_Glass          :
      constant Unicode_Char := 16#1F50D#;
   Right_Pointing_Magnifying_Glass         :
      constant Unicode_Char := 16#1F50E#;
   Lock_With_Ink_Pen                       :
      constant Unicode_Char := 16#1F50F#;
   Closed_Lock_With_Key                    :
      constant Unicode_Char := 16#1F510#;
   Key                                     :
      constant Unicode_Char := 16#1F511#;
   Lock                                    :
      constant Unicode_Char := 16#1F512#;
   Open_Lock                               :
      constant Unicode_Char := 16#1F513#;
   Bell                                    :
      constant Unicode_Char := 16#1F514#;
   Bell_With_Cancellation_Stroke           :
      constant Unicode_Char := 16#1F515#;
   Bookmark                                :
      constant Unicode_Char := 16#1F516#;
   Link_Symbol                             :
      constant Unicode_Char := 16#1F517#;
   Radio_Button                            :
      constant Unicode_Char := 16#1F518#;
   Back_With_Leftwards_Arrow_Above         :
      constant Unicode_Char := 16#1F519#;
   End_With_Leftwards_Arrow_Above          :
      constant Unicode_Char := 16#1F51A#;
   On_With_Exclamation_Mark_With_Left_Right_Arrow_Above :
      constant Unicode_Char := 16#1F51B#;
   Soon_With_Rightwards_Arrow_Above        :
      constant Unicode_Char := 16#1F51C#;
   Top_With_Upwards_Arrow_Above            :
      constant Unicode_Char := 16#1F51D#;
   No_One_Under_Eighteen_Symbol            :
      constant Unicode_Char := 16#1F51E#;
   Keycap_Ten                              :
      constant Unicode_Char := 16#1F51F#;
   Input_Symbol_For_Latin_Capital_Letters  :
      constant Unicode_Char := 16#1F520#;
   Input_Symbol_For_Latin_Small_Letters    :
      constant Unicode_Char := 16#1F521#;
   Input_Symbol_For_Numbers                :
      constant Unicode_Char := 16#1F522#;
   Input_Symbol_For_Symbols                :
      constant Unicode_Char := 16#1F523#;
   Input_Symbol_For_Latin_Letters          :
      constant Unicode_Char := 16#1F524#;
   Fire                                    :
      constant Unicode_Char := 16#1F525#;
   Electric_Torch                          :
      constant Unicode_Char := 16#1F526#;
   Wrench                                  :
      constant Unicode_Char := 16#1F527#;
   Hammer                                  :
      constant Unicode_Char := 16#1F528#;
   Nut_And_Bolt                            :
      constant Unicode_Char := 16#1F529#;
   Hocho                                   :
      constant Unicode_Char := 16#1F52A#;
   Pistol                                  :
      constant Unicode_Char := 16#1F52B#;
   Microscope                              :
      constant Unicode_Char := 16#1F52C#;
   Telescope                               :
      constant Unicode_Char := 16#1F52D#;
   Crystal_Ball                            :
      constant Unicode_Char := 16#1F52E#;
   Six_Pointed_Star_With_Middle_Dot        :
      constant Unicode_Char := 16#1F52F#;
   Japanese_Symbol_For_Beginner            :
      constant Unicode_Char := 16#1F530#;
   Trident_Emblem                          :
      constant Unicode_Char := 16#1F531#;
   Black_Square_Button                     :
      constant Unicode_Char := 16#1F532#;
   White_Square_Button                     :
      constant Unicode_Char := 16#1F533#;
   Large_Red_Circle                        :
      constant Unicode_Char := 16#1F534#;
   Large_Blue_Circle                       :
      constant Unicode_Char := 16#1F535#;
   Large_Orange_Diamond                    :
      constant Unicode_Char := 16#1F536#;
   Large_Blue_Diamond                      :
      constant Unicode_Char := 16#1F537#;
   Small_Orange_Diamond                    :
      constant Unicode_Char := 16#1F538#;
   Small_Blue_Diamond                      :
      constant Unicode_Char := 16#1F539#;
   Up_Pointing_Red_Triangle                :
      constant Unicode_Char := 16#1F53A#;
   Down_Pointing_Red_Triangle              :
      constant Unicode_Char := 16#1F53B#;
   Up_Pointing_Small_Red_Triangle          :
      constant Unicode_Char := 16#1F53C#;
   Down_Pointing_Small_Red_Triangle        :
      constant Unicode_Char := 16#1F53D#;
   Lower_Right_Shadowed_White_Circle       :
      constant Unicode_Char := 16#1F53E#;
   Upper_Right_Shadowed_White_Circle       :
      constant Unicode_Char := 16#1F53F#;
   Circled_Cross_Pommee                    :
      constant Unicode_Char := 16#1F540#;
   Cross_Pommee_With_Half_Circle_Below     :
      constant Unicode_Char := 16#1F541#;
   Cross_Pommee                            :
      constant Unicode_Char := 16#1F542#;
   Notched_Left_Semicircle_With_Three_Dots :
      constant Unicode_Char := 16#1F543#;
   Notched_Right_Semicircle_With_Three_Dots :
      constant Unicode_Char := 16#1F544#;
   Symbol_For_Marks_Chapter                :
      constant Unicode_Char := 16#1F545#;
   White_Latin_Cross                       :
      constant Unicode_Char := 16#1F546#;
   Heavy_Latin_Cross                       :
      constant Unicode_Char := 16#1F547#;
   Celtic_Cross                            :
      constant Unicode_Char := 16#1F548#;
   Om_Symbol                               :
      constant Unicode_Char := 16#1F549#;
   Dove_Of_Peace                           :
      constant Unicode_Char := 16#1F54A#;
   Kaaba                                   :
      constant Unicode_Char := 16#1F54B#;
   Mosque                                  :
      constant Unicode_Char := 16#1F54C#;
   Synagogue                               :
      constant Unicode_Char := 16#1F54D#;
   Menorah_With_Nine_Branches              :
      constant Unicode_Char := 16#1F54E#;
   Bowl_Of_Hygieia                         :
      constant Unicode_Char := 16#1F54F#;
   Clock_Face_One_Oclock                   :
      constant Unicode_Char := 16#1F550#;
   Clock_Face_Two_Oclock                   :
      constant Unicode_Char := 16#1F551#;
   Clock_Face_Three_Oclock                 :
      constant Unicode_Char := 16#1F552#;
   Clock_Face_Four_Oclock                  :
      constant Unicode_Char := 16#1F553#;
   Clock_Face_Five_Oclock                  :
      constant Unicode_Char := 16#1F554#;
   Clock_Face_Six_Oclock                   :
      constant Unicode_Char := 16#1F555#;
   Clock_Face_Seven_Oclock                 :
      constant Unicode_Char := 16#1F556#;
   Clock_Face_Eight_Oclock                 :
      constant Unicode_Char := 16#1F557#;
   Clock_Face_Nine_Oclock                  :
      constant Unicode_Char := 16#1F558#;
   Clock_Face_Ten_Oclock                   :
      constant Unicode_Char := 16#1F559#;
   Clock_Face_Eleven_Oclock                :
      constant Unicode_Char := 16#1F55A#;
   Clock_Face_Twelve_Oclock                :
      constant Unicode_Char := 16#1F55B#;
   Clock_Face_One_Thirty                   :
      constant Unicode_Char := 16#1F55C#;
   Clock_Face_Two_Thirty                   :
      constant Unicode_Char := 16#1F55D#;
   Clock_Face_Three_Thirty                 :
      constant Unicode_Char := 16#1F55E#;
   Clock_Face_Four_Thirty                  :
      constant Unicode_Char := 16#1F55F#;
   Clock_Face_Five_Thirty                  :
      constant Unicode_Char := 16#1F560#;
   Clock_Face_Six_Thirty                   :
      constant Unicode_Char := 16#1F561#;
   Clock_Face_Seven_Thirty                 :
      constant Unicode_Char := 16#1F562#;
   Clock_Face_Eight_Thirty                 :
      constant Unicode_Char := 16#1F563#;
   Clock_Face_Nine_Thirty                  :
      constant Unicode_Char := 16#1F564#;
   Clock_Face_Ten_Thirty                   :
      constant Unicode_Char := 16#1F565#;
   Clock_Face_Eleven_Thirty                :
      constant Unicode_Char := 16#1F566#;
   Clock_Face_Twelve_Thirty                :
      constant Unicode_Char := 16#1F567#;
   Right_Speaker                           :
      constant Unicode_Char := 16#1F568#;
   Right_Speaker_With_One_Sound_Wave       :
      constant Unicode_Char := 16#1F569#;
   Right_Speaker_With_Three_Sound_Waves    :
      constant Unicode_Char := 16#1F56A#;
   Bullhorn                                :
      constant Unicode_Char := 16#1F56B#;
   Bullhorn_With_Sound_Waves               :
      constant Unicode_Char := 16#1F56C#;
   Ringing_Bell                            :
      constant Unicode_Char := 16#1F56D#;
   Book                                    :
      constant Unicode_Char := 16#1F56E#;
   Candle                                  :
      constant Unicode_Char := 16#1F56F#;
   Mantelpiece_Clock                       :
      constant Unicode_Char := 16#1F570#;
   Black_Skull_And_Crossbones              :
      constant Unicode_Char := 16#1F571#;
   No_Piracy                               :
      constant Unicode_Char := 16#1F572#;
   Hole                                    :
      constant Unicode_Char := 16#1F573#;
   Man_In_Business_Suit_Levitating         :
      constant Unicode_Char := 16#1F574#;
   Sleuth_Or_Spy                           :
      constant Unicode_Char := 16#1F575#;
   Dark_Sunglasses                         :
      constant Unicode_Char := 16#1F576#;
   Spider                                  :
      constant Unicode_Char := 16#1F577#;
   Spider_Web                              :
      constant Unicode_Char := 16#1F578#;
   Joystick                                :
      constant Unicode_Char := 16#1F579#;
   Left_Hand_Telephone_Receiver            :
      constant Unicode_Char := 16#1F57B#;
   Telephone_Receiver_With_Page            :
      constant Unicode_Char := 16#1F57C#;
   Right_Hand_Telephone_Receiver           :
      constant Unicode_Char := 16#1F57D#;
   White_Touchtone_Telephone               :
      constant Unicode_Char := 16#1F57E#;
   Black_Touchtone_Telephone               :
      constant Unicode_Char := 16#1F57F#;
   Telephone_On_Top_Of_Modem               :
      constant Unicode_Char := 16#1F580#;
   Clamshell_Mobile_Phone                  :
      constant Unicode_Char := 16#1F581#;
   Back_Of_Envelope                        :
      constant Unicode_Char := 16#1F582#;
   Stamped_Envelope                        :
      constant Unicode_Char := 16#1F583#;
   Envelope_With_Lightning                 :
      constant Unicode_Char := 16#1F584#;
   Flying_Envelope                         :
      constant Unicode_Char := 16#1F585#;
   Pen_Over_Stamped_Envelope               :
      constant Unicode_Char := 16#1F586#;
   Linked_Paperclips                       :
      constant Unicode_Char := 16#1F587#;
   Black_Pushpin                           :
      constant Unicode_Char := 16#1F588#;
   Lower_Left_Pencil                       :
      constant Unicode_Char := 16#1F589#;
   Lower_Left_Ballpoint_Pen                :
      constant Unicode_Char := 16#1F58A#;
   Lower_Left_Fountain_Pen                 :
      constant Unicode_Char := 16#1F58B#;
   Lower_Left_Paintbrush                   :
      constant Unicode_Char := 16#1F58C#;
   Lower_Left_Crayon                       :
      constant Unicode_Char := 16#1F58D#;
   Left_Writing_Hand                       :
      constant Unicode_Char := 16#1F58E#;
   Turned_Ok_Hand_Sign                     :
      constant Unicode_Char := 16#1F58F#;
   Raised_Hand_With_Fingers_Splayed        :
      constant Unicode_Char := 16#1F590#;
   Reversed_Raised_Hand_With_Fingers_Splayed :
      constant Unicode_Char := 16#1F591#;
   Reversed_Thumbs_Up_Sign                 :
      constant Unicode_Char := 16#1F592#;
   Reversed_Thumbs_Down_Sign               :
      constant Unicode_Char := 16#1F593#;
   Reversed_Victory_Hand                   :
      constant Unicode_Char := 16#1F594#;
   Reversed_Hand_With_Middle_Finger_Extended :
      constant Unicode_Char := 16#1F595#;
   Raised_Hand_With_Part_Between_Middle_And_Ring_Fingers :
      constant Unicode_Char := 16#1F596#;
   White_Down_Pointing_Left_Hand_Index     :
      constant Unicode_Char := 16#1F597#;
   Sideways_White_Left_Pointing_Index      :
      constant Unicode_Char := 16#1F598#;
   Sideways_White_Right_Pointing_Index     :
      constant Unicode_Char := 16#1F599#;
   Sideways_Black_Left_Pointing_Index      :
      constant Unicode_Char := 16#1F59A#;
   Sideways_Black_Right_Pointing_Index     :
      constant Unicode_Char := 16#1F59B#;
   Black_Left_Pointing_Backhand_Index      :
      constant Unicode_Char := 16#1F59C#;
   Black_Right_Pointing_Backhand_Index     :
      constant Unicode_Char := 16#1F59D#;
   Sideways_White_Up_Pointing_Index        :
      constant Unicode_Char := 16#1F59E#;
   Sideways_White_Down_Pointing_Index      :
      constant Unicode_Char := 16#1F59F#;
   Sideways_Black_Up_Pointing_Index        :
      constant Unicode_Char := 16#1F5A0#;
   Sideways_Black_Down_Pointing_Index      :
      constant Unicode_Char := 16#1F5A1#;
   Black_Up_Pointing_Backhand_Index        :
      constant Unicode_Char := 16#1F5A2#;
   Black_Down_Pointing_Backhand_Index      :
      constant Unicode_Char := 16#1F5A3#;
   Desktop_Computer                        :
      constant Unicode_Char := 16#1F5A5#;
   Keyboard_And_Mouse                      :
      constant Unicode_Char := 16#1F5A6#;
   Three_Networked_Computers               :
      constant Unicode_Char := 16#1F5A7#;
   Printer                                 :
      constant Unicode_Char := 16#1F5A8#;
   Pocket_Calculator                       :
      constant Unicode_Char := 16#1F5A9#;
   Black_Hard_Shell_Floppy_Disk            :
      constant Unicode_Char := 16#1F5AA#;
   White_Hard_Shell_Floppy_Disk            :
      constant Unicode_Char := 16#1F5AB#;
   Soft_Shell_Floppy_Disk                  :
      constant Unicode_Char := 16#1F5AC#;
   Tape_Cartridge                          :
      constant Unicode_Char := 16#1F5AD#;
   Wired_Keyboard                          :
      constant Unicode_Char := 16#1F5AE#;
   One_Button_Mouse                        :
      constant Unicode_Char := 16#1F5AF#;
   Two_Button_Mouse                        :
      constant Unicode_Char := 16#1F5B0#;
   Three_Button_Mouse                      :
      constant Unicode_Char := 16#1F5B1#;
   Trackball                               :
      constant Unicode_Char := 16#1F5B2#;
   Old_Personal_Computer                   :
      constant Unicode_Char := 16#1F5B3#;
   Hard_Disk                               :
      constant Unicode_Char := 16#1F5B4#;
   Screen                                  :
      constant Unicode_Char := 16#1F5B5#;
   Printer_Icon                            :
      constant Unicode_Char := 16#1F5B6#;
   Fax_Icon                                :
      constant Unicode_Char := 16#1F5B7#;
   Optical_Disc_Icon                       :
      constant Unicode_Char := 16#1F5B8#;
   Document_With_Text                      :
      constant Unicode_Char := 16#1F5B9#;
   Document_With_Text_And_Picture          :
      constant Unicode_Char := 16#1F5BA#;
   Document_With_Picture                   :
      constant Unicode_Char := 16#1F5BB#;
   Frame_With_Picture                      :
      constant Unicode_Char := 16#1F5BC#;
   Frame_With_Tiles                        :
      constant Unicode_Char := 16#1F5BD#;
   Frame_With_An_X                         :
      constant Unicode_Char := 16#1F5BE#;
   Black_Folder                            :
      constant Unicode_Char := 16#1F5BF#;
   Folder                                  :
      constant Unicode_Char := 16#1F5C0#;
   Open_Folder                             :
      constant Unicode_Char := 16#1F5C1#;
   Card_Index_Dividers                     :
      constant Unicode_Char := 16#1F5C2#;
   Card_File_Box                           :
      constant Unicode_Char := 16#1F5C3#;
   File_Cabinet                            :
      constant Unicode_Char := 16#1F5C4#;
   Empty_Note                              :
      constant Unicode_Char := 16#1F5C5#;
   Empty_Note_Page                         :
      constant Unicode_Char := 16#1F5C6#;
   Empty_Note_Pad                          :
      constant Unicode_Char := 16#1F5C7#;
   Note                                    :
      constant Unicode_Char := 16#1F5C8#;
   Note_Page                               :
      constant Unicode_Char := 16#1F5C9#;
   Note_Pad                                :
      constant Unicode_Char := 16#1F5CA#;
   Empty_Document                          :
      constant Unicode_Char := 16#1F5CB#;
   Empty_Page                              :
      constant Unicode_Char := 16#1F5CC#;
   Empty_Pages                             :
      constant Unicode_Char := 16#1F5CD#;
   Document                                :
      constant Unicode_Char := 16#1F5CE#;
   Page                                    :
      constant Unicode_Char := 16#1F5CF#;
   Pages                                   :
      constant Unicode_Char := 16#1F5D0#;
   Wastebasket                             :
      constant Unicode_Char := 16#1F5D1#;
   Spiral_Note_Pad                         :
      constant Unicode_Char := 16#1F5D2#;
   Spiral_Calendar_Pad                     :
      constant Unicode_Char := 16#1F5D3#;
   Desktop_Window                          :
      constant Unicode_Char := 16#1F5D4#;
   Minimize                                :
      constant Unicode_Char := 16#1F5D5#;
   Maximize                                :
      constant Unicode_Char := 16#1F5D6#;
   Overlap                                 :
      constant Unicode_Char := 16#1F5D7#;
   Clockwise_Right_And_Left_Semicircle_Arrows :
      constant Unicode_Char := 16#1F5D8#;
   Cancellation_X                          :
      constant Unicode_Char := 16#1F5D9#;
   Increase_Font_Size_Symbol               :
      constant Unicode_Char := 16#1F5DA#;
   Decrease_Font_Size_Symbol               :
      constant Unicode_Char := 16#1F5DB#;
   Compression                             :
      constant Unicode_Char := 16#1F5DC#;
   Old_Key                                 :
      constant Unicode_Char := 16#1F5DD#;
   Rolled_Up_Newspaper                     :
      constant Unicode_Char := 16#1F5DE#;
   Page_With_Circled_Text                  :
      constant Unicode_Char := 16#1F5DF#;
   Stock_Chart                             :
      constant Unicode_Char := 16#1F5E0#;
   Dagger_Knife                            :
      constant Unicode_Char := 16#1F5E1#;
   Lips                                    :
      constant Unicode_Char := 16#1F5E2#;
   Speaking_Head_In_Silhouette             :
      constant Unicode_Char := 16#1F5E3#;
   Three_Rays_Above                        :
      constant Unicode_Char := 16#1F5E4#;
   Three_Rays_Below                        :
      constant Unicode_Char := 16#1F5E5#;
   Three_Rays_Left                         :
      constant Unicode_Char := 16#1F5E6#;
   Three_Rays_Right                        :
      constant Unicode_Char := 16#1F5E7#;
   Left_Speech_Bubble                      :
      constant Unicode_Char := 16#1F5E8#;
   Right_Speech_Bubble                     :
      constant Unicode_Char := 16#1F5E9#;
   Two_Speech_Bubbles                      :
      constant Unicode_Char := 16#1F5EA#;
   Three_Speech_Bubbles                    :
      constant Unicode_Char := 16#1F5EB#;
   Left_Thought_Bubble                     :
      constant Unicode_Char := 16#1F5EC#;
   Right_Thought_Bubble                    :
      constant Unicode_Char := 16#1F5ED#;
   Left_Anger_Bubble                       :
      constant Unicode_Char := 16#1F5EE#;
   Right_Anger_Bubble                      :
      constant Unicode_Char := 16#1F5EF#;
   Mood_Bubble                             :
      constant Unicode_Char := 16#1F5F0#;
   Lightning_Mood_Bubble                   :
      constant Unicode_Char := 16#1F5F1#;
   Lightning_Mood                          :
      constant Unicode_Char := 16#1F5F2#;
   Ballot_Box_With_Ballot                  :
      constant Unicode_Char := 16#1F5F3#;
   Ballot_Script_X                         :
      constant Unicode_Char := 16#1F5F4#;
   Ballot_Box_With_Script_X                :
      constant Unicode_Char := 16#1F5F5#;
   Ballot_Bold_Script_X                    :
      constant Unicode_Char := 16#1F5F6#;
   Ballot_Box_With_Bold_Script_X           :
      constant Unicode_Char := 16#1F5F7#;
   Light_Check_Mark                        :
      constant Unicode_Char := 16#1F5F8#;
   Ballot_Box_With_Bold_Check              :
      constant Unicode_Char := 16#1F5F9#;
   World_Map                               :
      constant Unicode_Char := 16#1F5FA#;
   Mount_Fuji                              :
      constant Unicode_Char := 16#1F5FB#;
   Tokyo_Tower                             :
      constant Unicode_Char := 16#1F5FC#;
   Statue_Of_Liberty                       :
      constant Unicode_Char := 16#1F5FD#;
   Silhouette_Of_Japan                     :
      constant Unicode_Char := 16#1F5FE#;
   Moyai                                   :
      constant Unicode_Char := 16#1F5FF#;
end Unicode.Names.Misc_Symbols_Pictographs;
