--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Inscriptional_Parthian is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Inscriptional_Parthian_Letter_Aleph     :
      constant Unicode_Char := 16#10B40#;
   Inscriptional_Parthian_Letter_Beth      :
      constant Unicode_Char := 16#10B41#;
   Inscriptional_Parthian_Letter_Gimel     :
      constant Unicode_Char := 16#10B42#;
   Inscriptional_Parthian_Letter_Daleth    :
      constant Unicode_Char := 16#10B43#;
   Inscriptional_Parthian_Letter_He        :
      constant Unicode_Char := 16#10B44#;
   Inscriptional_Parthian_Letter_Waw       :
      constant Unicode_Char := 16#10B45#;
   Inscriptional_Parthian_Letter_Zayin     :
      constant Unicode_Char := 16#10B46#;
   Inscriptional_Parthian_Letter_Heth      :
      constant Unicode_Char := 16#10B47#;
   Inscriptional_Parthian_Letter_Teth      :
      constant Unicode_Char := 16#10B48#;
   Inscriptional_Parthian_Letter_Yodh      :
      constant Unicode_Char := 16#10B49#;
   Inscriptional_Parthian_Letter_Kaph      :
      constant Unicode_Char := 16#10B4A#;
   Inscriptional_Parthian_Letter_Lamedh    :
      constant Unicode_Char := 16#10B4B#;
   Inscriptional_Parthian_Letter_Mem       :
      constant Unicode_Char := 16#10B4C#;
   Inscriptional_Parthian_Letter_Nun       :
      constant Unicode_Char := 16#10B4D#;
   Inscriptional_Parthian_Letter_Samekh    :
      constant Unicode_Char := 16#10B4E#;
   Inscriptional_Parthian_Letter_Ayin      :
      constant Unicode_Char := 16#10B4F#;
   Inscriptional_Parthian_Letter_Pe        :
      constant Unicode_Char := 16#10B50#;
   Inscriptional_Parthian_Letter_Sadhe     :
      constant Unicode_Char := 16#10B51#;
   Inscriptional_Parthian_Letter_Qoph      :
      constant Unicode_Char := 16#10B52#;
   Inscriptional_Parthian_Letter_Resh      :
      constant Unicode_Char := 16#10B53#;
   Inscriptional_Parthian_Letter_Shin      :
      constant Unicode_Char := 16#10B54#;
   Inscriptional_Parthian_Letter_Taw       :
      constant Unicode_Char := 16#10B55#;
   Inscriptional_Parthian_Number_One       :
      constant Unicode_Char := 16#10B58#;
   Inscriptional_Parthian_Number_Two       :
      constant Unicode_Char := 16#10B59#;
   Inscriptional_Parthian_Number_Three     :
      constant Unicode_Char := 16#10B5A#;
   Inscriptional_Parthian_Number_Four      :
      constant Unicode_Char := 16#10B5B#;
   Inscriptional_Parthian_Number_Ten       :
      constant Unicode_Char := 16#10B5C#;
   Inscriptional_Parthian_Number_Twenty    :
      constant Unicode_Char := 16#10B5D#;
   Inscriptional_Parthian_Number_One_Hundred :
      constant Unicode_Char := 16#10B5E#;
   Inscriptional_Parthian_Number_One_Thousand :
      constant Unicode_Char := 16#10B5F#;
end Unicode.Names.Inscriptional_Parthian;
