--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Tai_Tham is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Tai_Tham_Letter_High_Ka                 : constant Unicode_Char := 16#1A20#;
   Tai_Tham_Letter_High_Kha                : constant Unicode_Char := 16#1A21#;
   Tai_Tham_Letter_High_Kxa                : constant Unicode_Char := 16#1A22#;
   Tai_Tham_Letter_Low_Ka                  : constant Unicode_Char := 16#1A23#;
   Tai_Tham_Letter_Low_Kxa                 : constant Unicode_Char := 16#1A24#;
   Tai_Tham_Letter_Low_Kha                 : constant Unicode_Char := 16#1A25#;
   Tai_Tham_Letter_Nga                     : constant Unicode_Char := 16#1A26#;
   Tai_Tham_Letter_High_Ca                 : constant Unicode_Char := 16#1A27#;
   Tai_Tham_Letter_High_Cha                : constant Unicode_Char := 16#1A28#;
   Tai_Tham_Letter_Low_Ca                  : constant Unicode_Char := 16#1A29#;
   Tai_Tham_Letter_Low_Sa                  : constant Unicode_Char := 16#1A2A#;
   Tai_Tham_Letter_Low_Cha                 : constant Unicode_Char := 16#1A2B#;
   Tai_Tham_Letter_Nya                     : constant Unicode_Char := 16#1A2C#;
   Tai_Tham_Letter_Rata                    : constant Unicode_Char := 16#1A2D#;
   Tai_Tham_Letter_High_Ratha              : constant Unicode_Char := 16#1A2E#;
   Tai_Tham_Letter_Da                      : constant Unicode_Char := 16#1A2F#;
   Tai_Tham_Letter_Low_Ratha               : constant Unicode_Char := 16#1A30#;
   Tai_Tham_Letter_Rana                    : constant Unicode_Char := 16#1A31#;
   Tai_Tham_Letter_High_Ta                 : constant Unicode_Char := 16#1A32#;
   Tai_Tham_Letter_High_Tha                : constant Unicode_Char := 16#1A33#;
   Tai_Tham_Letter_Low_Ta                  : constant Unicode_Char := 16#1A34#;
   Tai_Tham_Letter_Low_Tha                 : constant Unicode_Char := 16#1A35#;
   Tai_Tham_Letter_Na                      : constant Unicode_Char := 16#1A36#;
   Tai_Tham_Letter_Ba                      : constant Unicode_Char := 16#1A37#;
   Tai_Tham_Letter_High_Pa                 : constant Unicode_Char := 16#1A38#;
   Tai_Tham_Letter_High_Pha                : constant Unicode_Char := 16#1A39#;
   Tai_Tham_Letter_High_Fa                 : constant Unicode_Char := 16#1A3A#;
   Tai_Tham_Letter_Low_Pa                  : constant Unicode_Char := 16#1A3B#;
   Tai_Tham_Letter_Low_Fa                  : constant Unicode_Char := 16#1A3C#;
   Tai_Tham_Letter_Low_Pha                 : constant Unicode_Char := 16#1A3D#;
   Tai_Tham_Letter_Ma                      : constant Unicode_Char := 16#1A3E#;
   Tai_Tham_Letter_Low_Ya                  : constant Unicode_Char := 16#1A3F#;
   Tai_Tham_Letter_High_Ya                 : constant Unicode_Char := 16#1A40#;
   Tai_Tham_Letter_Ra                      : constant Unicode_Char := 16#1A41#;
   Tai_Tham_Letter_Rue                     : constant Unicode_Char := 16#1A42#;
   Tai_Tham_Letter_La                      : constant Unicode_Char := 16#1A43#;
   Tai_Tham_Letter_Lue                     : constant Unicode_Char := 16#1A44#;
   Tai_Tham_Letter_Wa                      : constant Unicode_Char := 16#1A45#;
   Tai_Tham_Letter_High_Sha                : constant Unicode_Char := 16#1A46#;
   Tai_Tham_Letter_High_Ssa                : constant Unicode_Char := 16#1A47#;
   Tai_Tham_Letter_High_Sa                 : constant Unicode_Char := 16#1A48#;
   Tai_Tham_Letter_High_Ha                 : constant Unicode_Char := 16#1A49#;
   Tai_Tham_Letter_Lla                     : constant Unicode_Char := 16#1A4A#;
   Tai_Tham_Letter_A                       : constant Unicode_Char := 16#1A4B#;
   Tai_Tham_Letter_Low_Ha                  : constant Unicode_Char := 16#1A4C#;
   Tai_Tham_Letter_I                       : constant Unicode_Char := 16#1A4D#;
   Tai_Tham_Letter_Ii                      : constant Unicode_Char := 16#1A4E#;
   Tai_Tham_Letter_U                       : constant Unicode_Char := 16#1A4F#;
   Tai_Tham_Letter_Uu                      : constant Unicode_Char := 16#1A50#;
   Tai_Tham_Letter_Ee                      : constant Unicode_Char := 16#1A51#;
   Tai_Tham_Letter_Oo                      : constant Unicode_Char := 16#1A52#;
   Tai_Tham_Letter_Lae                     : constant Unicode_Char := 16#1A53#;
   Tai_Tham_Letter_Great_Sa                : constant Unicode_Char := 16#1A54#;
   Tai_Tham_Consonant_Sign_Medial_Ra       : constant Unicode_Char := 16#1A55#;
   Tai_Tham_Consonant_Sign_Medial_La       : constant Unicode_Char := 16#1A56#;
   Tai_Tham_Consonant_Sign_La_Tang_Lai     : constant Unicode_Char := 16#1A57#;
   Tai_Tham_Sign_Mai_Kang_Lai              : constant Unicode_Char := 16#1A58#;
   Tai_Tham_Consonant_Sign_Final_Nga       : constant Unicode_Char := 16#1A59#;
   Tai_Tham_Consonant_Sign_Low_Pa          : constant Unicode_Char := 16#1A5A#;
   Tai_Tham_Consonant_Sign_High_Ratha_Or_Low_Pa :
      constant Unicode_Char := 16#1A5B#;
   Tai_Tham_Consonant_Sign_Ma              : constant Unicode_Char := 16#1A5C#;
   Tai_Tham_Consonant_Sign_Ba              : constant Unicode_Char := 16#1A5D#;
   Tai_Tham_Consonant_Sign_Sa              : constant Unicode_Char := 16#1A5E#;
   Tai_Tham_Sign_Sakot                     : constant Unicode_Char := 16#1A60#;
   Tai_Tham_Vowel_Sign_A                   : constant Unicode_Char := 16#1A61#;
   Tai_Tham_Vowel_Sign_Mai_Sat             : constant Unicode_Char := 16#1A62#;
   Tai_Tham_Vowel_Sign_Aa                  : constant Unicode_Char := 16#1A63#;
   Tai_Tham_Vowel_Sign_Tall_Aa             : constant Unicode_Char := 16#1A64#;
   Tai_Tham_Vowel_Sign_I                   : constant Unicode_Char := 16#1A65#;
   Tai_Tham_Vowel_Sign_Ii                  : constant Unicode_Char := 16#1A66#;
   Tai_Tham_Vowel_Sign_Ue                  : constant Unicode_Char := 16#1A67#;
   Tai_Tham_Vowel_Sign_Uue                 : constant Unicode_Char := 16#1A68#;
   Tai_Tham_Vowel_Sign_U                   : constant Unicode_Char := 16#1A69#;
   Tai_Tham_Vowel_Sign_Uu                  : constant Unicode_Char := 16#1A6A#;
   Tai_Tham_Vowel_Sign_O                   : constant Unicode_Char := 16#1A6B#;
   Tai_Tham_Vowel_Sign_Oa_Below            : constant Unicode_Char := 16#1A6C#;
   Tai_Tham_Vowel_Sign_Oy                  : constant Unicode_Char := 16#1A6D#;
   Tai_Tham_Vowel_Sign_E                   : constant Unicode_Char := 16#1A6E#;
   Tai_Tham_Vowel_Sign_Ae                  : constant Unicode_Char := 16#1A6F#;
   Tai_Tham_Vowel_Sign_Oo                  : constant Unicode_Char := 16#1A70#;
   Tai_Tham_Vowel_Sign_Ai                  : constant Unicode_Char := 16#1A71#;
   Tai_Tham_Vowel_Sign_Tham_Ai             : constant Unicode_Char := 16#1A72#;
   Tai_Tham_Vowel_Sign_Oa_Above            : constant Unicode_Char := 16#1A73#;
   Tai_Tham_Sign_Mai_Kang                  : constant Unicode_Char := 16#1A74#;
   Tai_Tham_Sign_Tone_1                    : constant Unicode_Char := 16#1A75#;
   Tai_Tham_Sign_Tone_2                    : constant Unicode_Char := 16#1A76#;
   Tai_Tham_Sign_Khuen_Tone_3              : constant Unicode_Char := 16#1A77#;
   Tai_Tham_Sign_Khuen_Tone_4              : constant Unicode_Char := 16#1A78#;
   Tai_Tham_Sign_Khuen_Tone_5              : constant Unicode_Char := 16#1A79#;
   Tai_Tham_Sign_Ra_Haam                   : constant Unicode_Char := 16#1A7A#;
   Tai_Tham_Sign_Mai_Sam                   : constant Unicode_Char := 16#1A7B#;
   Tai_Tham_Sign_Khuen_Lue_Karan           : constant Unicode_Char := 16#1A7C#;
   Tai_Tham_Combining_Cryptogrammic_Dot    : constant Unicode_Char := 16#1A7F#;
   Tai_Tham_Hora_Digit_Zero                : constant Unicode_Char := 16#1A80#;
   Tai_Tham_Hora_Digit_One                 : constant Unicode_Char := 16#1A81#;
   Tai_Tham_Hora_Digit_Two                 : constant Unicode_Char := 16#1A82#;
   Tai_Tham_Hora_Digit_Three               : constant Unicode_Char := 16#1A83#;
   Tai_Tham_Hora_Digit_Four                : constant Unicode_Char := 16#1A84#;
   Tai_Tham_Hora_Digit_Five                : constant Unicode_Char := 16#1A85#;
   Tai_Tham_Hora_Digit_Six                 : constant Unicode_Char := 16#1A86#;
   Tai_Tham_Hora_Digit_Seven               : constant Unicode_Char := 16#1A87#;
   Tai_Tham_Hora_Digit_Eight               : constant Unicode_Char := 16#1A88#;
   Tai_Tham_Hora_Digit_Nine                : constant Unicode_Char := 16#1A89#;
   Tai_Tham_Tham_Digit_Zero                : constant Unicode_Char := 16#1A90#;
   Tai_Tham_Tham_Digit_One                 : constant Unicode_Char := 16#1A91#;
   Tai_Tham_Tham_Digit_Two                 : constant Unicode_Char := 16#1A92#;
   Tai_Tham_Tham_Digit_Three               : constant Unicode_Char := 16#1A93#;
   Tai_Tham_Tham_Digit_Four                : constant Unicode_Char := 16#1A94#;
   Tai_Tham_Tham_Digit_Five                : constant Unicode_Char := 16#1A95#;
   Tai_Tham_Tham_Digit_Six                 : constant Unicode_Char := 16#1A96#;
   Tai_Tham_Tham_Digit_Seven               : constant Unicode_Char := 16#1A97#;
   Tai_Tham_Tham_Digit_Eight               : constant Unicode_Char := 16#1A98#;
   Tai_Tham_Tham_Digit_Nine                : constant Unicode_Char := 16#1A99#;
   Tai_Tham_Sign_Wiang                     : constant Unicode_Char := 16#1AA0#;
   Tai_Tham_Sign_Wiangwaak                 : constant Unicode_Char := 16#1AA1#;
   Tai_Tham_Sign_Sawan                     : constant Unicode_Char := 16#1AA2#;
   Tai_Tham_Sign_Keow                      : constant Unicode_Char := 16#1AA3#;
   Tai_Tham_Sign_Hoy                       : constant Unicode_Char := 16#1AA4#;
   Tai_Tham_Sign_Dokmai                    : constant Unicode_Char := 16#1AA5#;
   Tai_Tham_Sign_Reversed_Rotated_Rana     : constant Unicode_Char := 16#1AA6#;
   Tai_Tham_Sign_Mai_Yamok                 : constant Unicode_Char := 16#1AA7#;
   Tai_Tham_Sign_Kaan                      : constant Unicode_Char := 16#1AA8#;
   Tai_Tham_Sign_Kaankuu                   : constant Unicode_Char := 16#1AA9#;
   Tai_Tham_Sign_Satkaan                   : constant Unicode_Char := 16#1AAA#;
   Tai_Tham_Sign_Satkaankuu                : constant Unicode_Char := 16#1AAB#;
   Tai_Tham_Sign_Hang                      : constant Unicode_Char := 16#1AAC#;
   Tai_Tham_Sign_Caang                     : constant Unicode_Char := 16#1AAD#;
end Unicode.Names.Tai_Tham;
