--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Linear_B_Ideograms is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Linear_B_Ideogram_B100_Man              :
      constant Unicode_Char := 16#10080#;
   Linear_B_Ideogram_B102_Woman            :
      constant Unicode_Char := 16#10081#;
   Linear_B_Ideogram_B104_Deer             :
      constant Unicode_Char := 16#10082#;
   Linear_B_Ideogram_B105_Equid            :
      constant Unicode_Char := 16#10083#;
   Linear_B_Ideogram_B105f_Mare            :
      constant Unicode_Char := 16#10084#;
   Linear_B_Ideogram_B105m_Stallion        :
      constant Unicode_Char := 16#10085#;
   Linear_B_Ideogram_B106f_Ewe             :
      constant Unicode_Char := 16#10086#;
   Linear_B_Ideogram_B106m_Ram             :
      constant Unicode_Char := 16#10087#;
   Linear_B_Ideogram_B107f_She_Goat        :
      constant Unicode_Char := 16#10088#;
   Linear_B_Ideogram_B107m_He_Goat         :
      constant Unicode_Char := 16#10089#;
   Linear_B_Ideogram_B108f_Sow             :
      constant Unicode_Char := 16#1008A#;
   Linear_B_Ideogram_B108m_Boar            :
      constant Unicode_Char := 16#1008B#;
   Linear_B_Ideogram_B109f_Cow             :
      constant Unicode_Char := 16#1008C#;
   Linear_B_Ideogram_B109m_Bull            :
      constant Unicode_Char := 16#1008D#;
   Linear_B_Ideogram_B120_Wheat            :
      constant Unicode_Char := 16#1008E#;
   Linear_B_Ideogram_B121_Barley           :
      constant Unicode_Char := 16#1008F#;
   Linear_B_Ideogram_B122_Olive            :
      constant Unicode_Char := 16#10090#;
   Linear_B_Ideogram_B123_Spice            :
      constant Unicode_Char := 16#10091#;
   Linear_B_Ideogram_B125_Cyperus          :
      constant Unicode_Char := 16#10092#;
   Linear_B_Monogram_B127_Kapo             :
      constant Unicode_Char := 16#10093#;
   Linear_B_Monogram_B128_Kanako           :
      constant Unicode_Char := 16#10094#;
   Linear_B_Ideogram_B130_Oil              :
      constant Unicode_Char := 16#10095#;
   Linear_B_Ideogram_B131_Wine             :
      constant Unicode_Char := 16#10096#;
   Linear_B_Ideogram_B132                  :
      constant Unicode_Char := 16#10097#;
   Linear_B_Monogram_B133_Arepa            :
      constant Unicode_Char := 16#10098#;
   Linear_B_Monogram_B135_Meri             :
      constant Unicode_Char := 16#10099#;
   Linear_B_Ideogram_B140_Bronze           :
      constant Unicode_Char := 16#1009A#;
   Linear_B_Ideogram_B141_Gold             :
      constant Unicode_Char := 16#1009B#;
   Linear_B_Ideogram_B142                  :
      constant Unicode_Char := 16#1009C#;
   Linear_B_Ideogram_B145_Wool             :
      constant Unicode_Char := 16#1009D#;
   Linear_B_Ideogram_B146                  :
      constant Unicode_Char := 16#1009E#;
   Linear_B_Ideogram_B150                  :
      constant Unicode_Char := 16#1009F#;
   Linear_B_Ideogram_B151_Horn             :
      constant Unicode_Char := 16#100A0#;
   Linear_B_Ideogram_B152                  :
      constant Unicode_Char := 16#100A1#;
   Linear_B_Ideogram_B153                  :
      constant Unicode_Char := 16#100A2#;
   Linear_B_Ideogram_B154                  :
      constant Unicode_Char := 16#100A3#;
   Linear_B_Monogram_B156_Turo2            :
      constant Unicode_Char := 16#100A4#;
   Linear_B_Ideogram_B157                  :
      constant Unicode_Char := 16#100A5#;
   Linear_B_Ideogram_B158                  :
      constant Unicode_Char := 16#100A6#;
   Linear_B_Ideogram_B159_Cloth            :
      constant Unicode_Char := 16#100A7#;
   Linear_B_Ideogram_B160                  :
      constant Unicode_Char := 16#100A8#;
   Linear_B_Ideogram_B161                  :
      constant Unicode_Char := 16#100A9#;
   Linear_B_Ideogram_B162_Garment          :
      constant Unicode_Char := 16#100AA#;
   Linear_B_Ideogram_B163_Armour           :
      constant Unicode_Char := 16#100AB#;
   Linear_B_Ideogram_B164                  :
      constant Unicode_Char := 16#100AC#;
   Linear_B_Ideogram_B165                  :
      constant Unicode_Char := 16#100AD#;
   Linear_B_Ideogram_B166                  :
      constant Unicode_Char := 16#100AE#;
   Linear_B_Ideogram_B167                  :
      constant Unicode_Char := 16#100AF#;
   Linear_B_Ideogram_B168                  :
      constant Unicode_Char := 16#100B0#;
   Linear_B_Ideogram_B169                  :
      constant Unicode_Char := 16#100B1#;
   Linear_B_Ideogram_B170                  :
      constant Unicode_Char := 16#100B2#;
   Linear_B_Ideogram_B171                  :
      constant Unicode_Char := 16#100B3#;
   Linear_B_Ideogram_B172                  :
      constant Unicode_Char := 16#100B4#;
   Linear_B_Ideogram_B173_Month            :
      constant Unicode_Char := 16#100B5#;
   Linear_B_Ideogram_B174                  :
      constant Unicode_Char := 16#100B6#;
   Linear_B_Ideogram_B176_Tree             :
      constant Unicode_Char := 16#100B7#;
   Linear_B_Ideogram_B177                  :
      constant Unicode_Char := 16#100B8#;
   Linear_B_Ideogram_B178                  :
      constant Unicode_Char := 16#100B9#;
   Linear_B_Ideogram_B179                  :
      constant Unicode_Char := 16#100BA#;
   Linear_B_Ideogram_B180                  :
      constant Unicode_Char := 16#100BB#;
   Linear_B_Ideogram_B181                  :
      constant Unicode_Char := 16#100BC#;
   Linear_B_Ideogram_B182                  :
      constant Unicode_Char := 16#100BD#;
   Linear_B_Ideogram_B183                  :
      constant Unicode_Char := 16#100BE#;
   Linear_B_Ideogram_B184                  :
      constant Unicode_Char := 16#100BF#;
   Linear_B_Ideogram_B185                  :
      constant Unicode_Char := 16#100C0#;
   Linear_B_Ideogram_B189                  :
      constant Unicode_Char := 16#100C1#;
   Linear_B_Ideogram_B190                  :
      constant Unicode_Char := 16#100C2#;
   Linear_B_Ideogram_B191_Helmet           :
      constant Unicode_Char := 16#100C3#;
   Linear_B_Ideogram_B220_Footstool        :
      constant Unicode_Char := 16#100C4#;
   Linear_B_Ideogram_B225_Bathtub          :
      constant Unicode_Char := 16#100C5#;
   Linear_B_Ideogram_B230_Spear            :
      constant Unicode_Char := 16#100C6#;
   Linear_B_Ideogram_B231_Arrow            :
      constant Unicode_Char := 16#100C7#;
   Linear_B_Ideogram_B232                  :
      constant Unicode_Char := 16#100C8#;
   Linear_B_Ideogram_B233_Sword            :
      constant Unicode_Char := 16#100C9#;
   Linear_B_Ideogram_B234                  :
      constant Unicode_Char := 16#100CA#;
   Linear_B_Ideogram_B236                  :
      constant Unicode_Char := 16#100CB#;
   Linear_B_Ideogram_B240_Wheeled_Chariot  :
      constant Unicode_Char := 16#100CC#;
   Linear_B_Ideogram_B241_Chariot          :
      constant Unicode_Char := 16#100CD#;
   Linear_B_Ideogram_B242_Chariot_Frame    :
      constant Unicode_Char := 16#100CE#;
   Linear_B_Ideogram_B243_Wheel            :
      constant Unicode_Char := 16#100CF#;
   Linear_B_Ideogram_B245                  :
      constant Unicode_Char := 16#100D0#;
   Linear_B_Ideogram_B246                  :
      constant Unicode_Char := 16#100D1#;
   Linear_B_Monogram_B247_Dipte            :
      constant Unicode_Char := 16#100D2#;
   Linear_B_Ideogram_B248                  :
      constant Unicode_Char := 16#100D3#;
   Linear_B_Ideogram_B249                  :
      constant Unicode_Char := 16#100D4#;
   Linear_B_Ideogram_B251                  :
      constant Unicode_Char := 16#100D5#;
   Linear_B_Ideogram_B252                  :
      constant Unicode_Char := 16#100D6#;
   Linear_B_Ideogram_B253                  :
      constant Unicode_Char := 16#100D7#;
   Linear_B_Ideogram_B254_Dart             :
      constant Unicode_Char := 16#100D8#;
   Linear_B_Ideogram_B255                  :
      constant Unicode_Char := 16#100D9#;
   Linear_B_Ideogram_B256                  :
      constant Unicode_Char := 16#100DA#;
   Linear_B_Ideogram_B257                  :
      constant Unicode_Char := 16#100DB#;
   Linear_B_Ideogram_B258                  :
      constant Unicode_Char := 16#100DC#;
   Linear_B_Ideogram_B259                  :
      constant Unicode_Char := 16#100DD#;
   Linear_B_Ideogram_Vessel_B155           :
      constant Unicode_Char := 16#100DE#;
   Linear_B_Ideogram_Vessel_B200           :
      constant Unicode_Char := 16#100DF#;
   Linear_B_Ideogram_Vessel_B201           :
      constant Unicode_Char := 16#100E0#;
   Linear_B_Ideogram_Vessel_B202           :
      constant Unicode_Char := 16#100E1#;
   Linear_B_Ideogram_Vessel_B203           :
      constant Unicode_Char := 16#100E2#;
   Linear_B_Ideogram_Vessel_B204           :
      constant Unicode_Char := 16#100E3#;
   Linear_B_Ideogram_Vessel_B205           :
      constant Unicode_Char := 16#100E4#;
   Linear_B_Ideogram_Vessel_B206           :
      constant Unicode_Char := 16#100E5#;
   Linear_B_Ideogram_Vessel_B207           :
      constant Unicode_Char := 16#100E6#;
   Linear_B_Ideogram_Vessel_B208           :
      constant Unicode_Char := 16#100E7#;
   Linear_B_Ideogram_Vessel_B209           :
      constant Unicode_Char := 16#100E8#;
   Linear_B_Ideogram_Vessel_B210           :
      constant Unicode_Char := 16#100E9#;
   Linear_B_Ideogram_Vessel_B211           :
      constant Unicode_Char := 16#100EA#;
   Linear_B_Ideogram_Vessel_B212           :
      constant Unicode_Char := 16#100EB#;
   Linear_B_Ideogram_Vessel_B213           :
      constant Unicode_Char := 16#100EC#;
   Linear_B_Ideogram_Vessel_B214           :
      constant Unicode_Char := 16#100ED#;
   Linear_B_Ideogram_Vessel_B215           :
      constant Unicode_Char := 16#100EE#;
   Linear_B_Ideogram_Vessel_B216           :
      constant Unicode_Char := 16#100EF#;
   Linear_B_Ideogram_Vessel_B217           :
      constant Unicode_Char := 16#100F0#;
   Linear_B_Ideogram_Vessel_B218           :
      constant Unicode_Char := 16#100F1#;
   Linear_B_Ideogram_Vessel_B219           :
      constant Unicode_Char := 16#100F2#;
   Linear_B_Ideogram_Vessel_B221           :
      constant Unicode_Char := 16#100F3#;
   Linear_B_Ideogram_Vessel_B222           :
      constant Unicode_Char := 16#100F4#;
   Linear_B_Ideogram_Vessel_B226           :
      constant Unicode_Char := 16#100F5#;
   Linear_B_Ideogram_Vessel_B227           :
      constant Unicode_Char := 16#100F6#;
   Linear_B_Ideogram_Vessel_B228           :
      constant Unicode_Char := 16#100F7#;
   Linear_B_Ideogram_Vessel_B229           :
      constant Unicode_Char := 16#100F8#;
   Linear_B_Ideogram_Vessel_B250           :
      constant Unicode_Char := 16#100F9#;
   Linear_B_Ideogram_Vessel_B305           :
      constant Unicode_Char := 16#100FA#;
end Unicode.Names.Linear_B_Ideograms;
