--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Mende_Kikakui is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Mende_Kikakui_Syllable_M001_Ki          :
      constant Unicode_Char := 16#1E800#;
   Mende_Kikakui_Syllable_M002_Ka          :
      constant Unicode_Char := 16#1E801#;
   Mende_Kikakui_Syllable_M003_Ku          :
      constant Unicode_Char := 16#1E802#;
   Mende_Kikakui_Syllable_M065_Kee         :
      constant Unicode_Char := 16#1E803#;
   Mende_Kikakui_Syllable_M095_Ke          :
      constant Unicode_Char := 16#1E804#;
   Mende_Kikakui_Syllable_M076_Koo         :
      constant Unicode_Char := 16#1E805#;
   Mende_Kikakui_Syllable_M048_Ko          :
      constant Unicode_Char := 16#1E806#;
   Mende_Kikakui_Syllable_M179_Kua         :
      constant Unicode_Char := 16#1E807#;
   Mende_Kikakui_Syllable_M004_Wi          :
      constant Unicode_Char := 16#1E808#;
   Mende_Kikakui_Syllable_M005_Wa          :
      constant Unicode_Char := 16#1E809#;
   Mende_Kikakui_Syllable_M006_Wu          :
      constant Unicode_Char := 16#1E80A#;
   Mende_Kikakui_Syllable_M126_Wee         :
      constant Unicode_Char := 16#1E80B#;
   Mende_Kikakui_Syllable_M118_We          :
      constant Unicode_Char := 16#1E80C#;
   Mende_Kikakui_Syllable_M114_Woo         :
      constant Unicode_Char := 16#1E80D#;
   Mende_Kikakui_Syllable_M045_Wo          :
      constant Unicode_Char := 16#1E80E#;
   Mende_Kikakui_Syllable_M194_Wui         :
      constant Unicode_Char := 16#1E80F#;
   Mende_Kikakui_Syllable_M143_Wei         :
      constant Unicode_Char := 16#1E810#;
   Mende_Kikakui_Syllable_M061_Wvi         :
      constant Unicode_Char := 16#1E811#;
   Mende_Kikakui_Syllable_M049_Wva         :
      constant Unicode_Char := 16#1E812#;
   Mende_Kikakui_Syllable_M139_Wve         :
      constant Unicode_Char := 16#1E813#;
   Mende_Kikakui_Syllable_M007_Min         :
      constant Unicode_Char := 16#1E814#;
   Mende_Kikakui_Syllable_M008_Man         :
      constant Unicode_Char := 16#1E815#;
   Mende_Kikakui_Syllable_M009_Mun         :
      constant Unicode_Char := 16#1E816#;
   Mende_Kikakui_Syllable_M059_Men         :
      constant Unicode_Char := 16#1E817#;
   Mende_Kikakui_Syllable_M094_Mon         :
      constant Unicode_Char := 16#1E818#;
   Mende_Kikakui_Syllable_M154_Muan        :
      constant Unicode_Char := 16#1E819#;
   Mende_Kikakui_Syllable_M189_Muen        :
      constant Unicode_Char := 16#1E81A#;
   Mende_Kikakui_Syllable_M010_Bi          :
      constant Unicode_Char := 16#1E81B#;
   Mende_Kikakui_Syllable_M011_Ba          :
      constant Unicode_Char := 16#1E81C#;
   Mende_Kikakui_Syllable_M012_Bu          :
      constant Unicode_Char := 16#1E81D#;
   Mende_Kikakui_Syllable_M150_Bee         :
      constant Unicode_Char := 16#1E81E#;
   Mende_Kikakui_Syllable_M097_Be          :
      constant Unicode_Char := 16#1E81F#;
   Mende_Kikakui_Syllable_M103_Boo         :
      constant Unicode_Char := 16#1E820#;
   Mende_Kikakui_Syllable_M138_Bo          :
      constant Unicode_Char := 16#1E821#;
   Mende_Kikakui_Syllable_M013_I           :
      constant Unicode_Char := 16#1E822#;
   Mende_Kikakui_Syllable_M014_A           :
      constant Unicode_Char := 16#1E823#;
   Mende_Kikakui_Syllable_M015_U           :
      constant Unicode_Char := 16#1E824#;
   Mende_Kikakui_Syllable_M163_Ee          :
      constant Unicode_Char := 16#1E825#;
   Mende_Kikakui_Syllable_M100_E           :
      constant Unicode_Char := 16#1E826#;
   Mende_Kikakui_Syllable_M165_Oo          :
      constant Unicode_Char := 16#1E827#;
   Mende_Kikakui_Syllable_M147_O           :
      constant Unicode_Char := 16#1E828#;
   Mende_Kikakui_Syllable_M137_Ei          :
      constant Unicode_Char := 16#1E829#;
   Mende_Kikakui_Syllable_M131_In          :
      constant Unicode_Char := 16#1E82A#;
   Mende_Kikakui_Syllable_M135_In          :
      constant Unicode_Char := 16#1E82B#;
   Mende_Kikakui_Syllable_M195_An          :
      constant Unicode_Char := 16#1E82C#;
   Mende_Kikakui_Syllable_M178_En          :
      constant Unicode_Char := 16#1E82D#;
   Mende_Kikakui_Syllable_M019_Si          :
      constant Unicode_Char := 16#1E82E#;
   Mende_Kikakui_Syllable_M020_Sa          :
      constant Unicode_Char := 16#1E82F#;
   Mende_Kikakui_Syllable_M021_Su          :
      constant Unicode_Char := 16#1E830#;
   Mende_Kikakui_Syllable_M162_See         :
      constant Unicode_Char := 16#1E831#;
   Mende_Kikakui_Syllable_M116_Se          :
      constant Unicode_Char := 16#1E832#;
   Mende_Kikakui_Syllable_M136_Soo         :
      constant Unicode_Char := 16#1E833#;
   Mende_Kikakui_Syllable_M079_So          :
      constant Unicode_Char := 16#1E834#;
   Mende_Kikakui_Syllable_M196_Sia         :
      constant Unicode_Char := 16#1E835#;
   Mende_Kikakui_Syllable_M025_Li          :
      constant Unicode_Char := 16#1E836#;
   Mende_Kikakui_Syllable_M026_La          :
      constant Unicode_Char := 16#1E837#;
   Mende_Kikakui_Syllable_M027_Lu          :
      constant Unicode_Char := 16#1E838#;
   Mende_Kikakui_Syllable_M084_Lee         :
      constant Unicode_Char := 16#1E839#;
   Mende_Kikakui_Syllable_M073_Le          :
      constant Unicode_Char := 16#1E83A#;
   Mende_Kikakui_Syllable_M054_Loo         :
      constant Unicode_Char := 16#1E83B#;
   Mende_Kikakui_Syllable_M153_Lo          :
      constant Unicode_Char := 16#1E83C#;
   Mende_Kikakui_Syllable_M110_Long_Le     :
      constant Unicode_Char := 16#1E83D#;
   Mende_Kikakui_Syllable_M016_Di          :
      constant Unicode_Char := 16#1E83E#;
   Mende_Kikakui_Syllable_M017_Da          :
      constant Unicode_Char := 16#1E83F#;
   Mende_Kikakui_Syllable_M018_Du          :
      constant Unicode_Char := 16#1E840#;
   Mende_Kikakui_Syllable_M089_Dee         :
      constant Unicode_Char := 16#1E841#;
   Mende_Kikakui_Syllable_M180_Doo         :
      constant Unicode_Char := 16#1E842#;
   Mende_Kikakui_Syllable_M181_Do          :
      constant Unicode_Char := 16#1E843#;
   Mende_Kikakui_Syllable_M022_Ti          :
      constant Unicode_Char := 16#1E844#;
   Mende_Kikakui_Syllable_M023_Ta          :
      constant Unicode_Char := 16#1E845#;
   Mende_Kikakui_Syllable_M024_Tu          :
      constant Unicode_Char := 16#1E846#;
   Mende_Kikakui_Syllable_M091_Tee         :
      constant Unicode_Char := 16#1E847#;
   Mende_Kikakui_Syllable_M055_Te          :
      constant Unicode_Char := 16#1E848#;
   Mende_Kikakui_Syllable_M104_Too         :
      constant Unicode_Char := 16#1E849#;
   Mende_Kikakui_Syllable_M069_To          :
      constant Unicode_Char := 16#1E84A#;
   Mende_Kikakui_Syllable_M028_Ji          :
      constant Unicode_Char := 16#1E84B#;
   Mende_Kikakui_Syllable_M029_Ja          :
      constant Unicode_Char := 16#1E84C#;
   Mende_Kikakui_Syllable_M030_Ju          :
      constant Unicode_Char := 16#1E84D#;
   Mende_Kikakui_Syllable_M157_Jee         :
      constant Unicode_Char := 16#1E84E#;
   Mende_Kikakui_Syllable_M113_Je          :
      constant Unicode_Char := 16#1E84F#;
   Mende_Kikakui_Syllable_M160_Joo         :
      constant Unicode_Char := 16#1E850#;
   Mende_Kikakui_Syllable_M063_Jo          :
      constant Unicode_Char := 16#1E851#;
   Mende_Kikakui_Syllable_M175_Long_Jo     :
      constant Unicode_Char := 16#1E852#;
   Mende_Kikakui_Syllable_M031_Yi          :
      constant Unicode_Char := 16#1E853#;
   Mende_Kikakui_Syllable_M032_Ya          :
      constant Unicode_Char := 16#1E854#;
   Mende_Kikakui_Syllable_M033_Yu          :
      constant Unicode_Char := 16#1E855#;
   Mende_Kikakui_Syllable_M109_Yee         :
      constant Unicode_Char := 16#1E856#;
   Mende_Kikakui_Syllable_M080_Ye          :
      constant Unicode_Char := 16#1E857#;
   Mende_Kikakui_Syllable_M141_Yoo         :
      constant Unicode_Char := 16#1E858#;
   Mende_Kikakui_Syllable_M121_Yo          :
      constant Unicode_Char := 16#1E859#;
   Mende_Kikakui_Syllable_M034_Fi          :
      constant Unicode_Char := 16#1E85A#;
   Mende_Kikakui_Syllable_M035_Fa          :
      constant Unicode_Char := 16#1E85B#;
   Mende_Kikakui_Syllable_M036_Fu          :
      constant Unicode_Char := 16#1E85C#;
   Mende_Kikakui_Syllable_M078_Fee         :
      constant Unicode_Char := 16#1E85D#;
   Mende_Kikakui_Syllable_M075_Fe          :
      constant Unicode_Char := 16#1E85E#;
   Mende_Kikakui_Syllable_M133_Foo         :
      constant Unicode_Char := 16#1E85F#;
   Mende_Kikakui_Syllable_M088_Fo          :
      constant Unicode_Char := 16#1E860#;
   Mende_Kikakui_Syllable_M197_Fua         :
      constant Unicode_Char := 16#1E861#;
   Mende_Kikakui_Syllable_M101_Fan         :
      constant Unicode_Char := 16#1E862#;
   Mende_Kikakui_Syllable_M037_Nin         :
      constant Unicode_Char := 16#1E863#;
   Mende_Kikakui_Syllable_M038_Nan         :
      constant Unicode_Char := 16#1E864#;
   Mende_Kikakui_Syllable_M039_Nun         :
      constant Unicode_Char := 16#1E865#;
   Mende_Kikakui_Syllable_M117_Nen         :
      constant Unicode_Char := 16#1E866#;
   Mende_Kikakui_Syllable_M169_Non         :
      constant Unicode_Char := 16#1E867#;
   Mende_Kikakui_Syllable_M176_Hi          :
      constant Unicode_Char := 16#1E868#;
   Mende_Kikakui_Syllable_M041_Ha          :
      constant Unicode_Char := 16#1E869#;
   Mende_Kikakui_Syllable_M186_Hu          :
      constant Unicode_Char := 16#1E86A#;
   Mende_Kikakui_Syllable_M040_Hee         :
      constant Unicode_Char := 16#1E86B#;
   Mende_Kikakui_Syllable_M096_He          :
      constant Unicode_Char := 16#1E86C#;
   Mende_Kikakui_Syllable_M042_Hoo         :
      constant Unicode_Char := 16#1E86D#;
   Mende_Kikakui_Syllable_M140_Ho          :
      constant Unicode_Char := 16#1E86E#;
   Mende_Kikakui_Syllable_M083_Heei        :
      constant Unicode_Char := 16#1E86F#;
   Mende_Kikakui_Syllable_M128_Hoou        :
      constant Unicode_Char := 16#1E870#;
   Mende_Kikakui_Syllable_M053_Hin         :
      constant Unicode_Char := 16#1E871#;
   Mende_Kikakui_Syllable_M130_Han         :
      constant Unicode_Char := 16#1E872#;
   Mende_Kikakui_Syllable_M087_Hun         :
      constant Unicode_Char := 16#1E873#;
   Mende_Kikakui_Syllable_M052_Hen         :
      constant Unicode_Char := 16#1E874#;
   Mende_Kikakui_Syllable_M193_Hon         :
      constant Unicode_Char := 16#1E875#;
   Mende_Kikakui_Syllable_M046_Huan        :
      constant Unicode_Char := 16#1E876#;
   Mende_Kikakui_Syllable_M090_Nggi        :
      constant Unicode_Char := 16#1E877#;
   Mende_Kikakui_Syllable_M043_Ngga        :
      constant Unicode_Char := 16#1E878#;
   Mende_Kikakui_Syllable_M082_Nggu        :
      constant Unicode_Char := 16#1E879#;
   Mende_Kikakui_Syllable_M115_Nggee       :
      constant Unicode_Char := 16#1E87A#;
   Mende_Kikakui_Syllable_M146_Ngge        :
      constant Unicode_Char := 16#1E87B#;
   Mende_Kikakui_Syllable_M156_Nggoo       :
      constant Unicode_Char := 16#1E87C#;
   Mende_Kikakui_Syllable_M120_Nggo        :
      constant Unicode_Char := 16#1E87D#;
   Mende_Kikakui_Syllable_M159_Nggaa       :
      constant Unicode_Char := 16#1E87E#;
   Mende_Kikakui_Syllable_M127_Nggua       :
      constant Unicode_Char := 16#1E87F#;
   Mende_Kikakui_Syllable_M086_Long_Ngge   :
      constant Unicode_Char := 16#1E880#;
   Mende_Kikakui_Syllable_M106_Long_Nggoo  :
      constant Unicode_Char := 16#1E881#;
   Mende_Kikakui_Syllable_M183_Long_Nggo   :
      constant Unicode_Char := 16#1E882#;
   Mende_Kikakui_Syllable_M155_Gi          :
      constant Unicode_Char := 16#1E883#;
   Mende_Kikakui_Syllable_M111_Ga          :
      constant Unicode_Char := 16#1E884#;
   Mende_Kikakui_Syllable_M168_Gu          :
      constant Unicode_Char := 16#1E885#;
   Mende_Kikakui_Syllable_M190_Gee         :
      constant Unicode_Char := 16#1E886#;
   Mende_Kikakui_Syllable_M166_Guei        :
      constant Unicode_Char := 16#1E887#;
   Mende_Kikakui_Syllable_M167_Guan        :
      constant Unicode_Char := 16#1E888#;
   Mende_Kikakui_Syllable_M184_Ngen        :
      constant Unicode_Char := 16#1E889#;
   Mende_Kikakui_Syllable_M057_Ngon        :
      constant Unicode_Char := 16#1E88A#;
   Mende_Kikakui_Syllable_M177_Nguan       :
      constant Unicode_Char := 16#1E88B#;
   Mende_Kikakui_Syllable_M068_Pi          :
      constant Unicode_Char := 16#1E88C#;
   Mende_Kikakui_Syllable_M099_Pa          :
      constant Unicode_Char := 16#1E88D#;
   Mende_Kikakui_Syllable_M050_Pu          :
      constant Unicode_Char := 16#1E88E#;
   Mende_Kikakui_Syllable_M081_Pee         :
      constant Unicode_Char := 16#1E88F#;
   Mende_Kikakui_Syllable_M051_Pe          :
      constant Unicode_Char := 16#1E890#;
   Mende_Kikakui_Syllable_M102_Poo         :
      constant Unicode_Char := 16#1E891#;
   Mende_Kikakui_Syllable_M066_Po          :
      constant Unicode_Char := 16#1E892#;
   Mende_Kikakui_Syllable_M145_Mbi         :
      constant Unicode_Char := 16#1E893#;
   Mende_Kikakui_Syllable_M062_Mba         :
      constant Unicode_Char := 16#1E894#;
   Mende_Kikakui_Syllable_M122_Mbu         :
      constant Unicode_Char := 16#1E895#;
   Mende_Kikakui_Syllable_M047_Mbee        :
      constant Unicode_Char := 16#1E896#;
   Mende_Kikakui_Syllable_M188_Mbee        :
      constant Unicode_Char := 16#1E897#;
   Mende_Kikakui_Syllable_M072_Mbe         :
      constant Unicode_Char := 16#1E898#;
   Mende_Kikakui_Syllable_M172_Mboo        :
      constant Unicode_Char := 16#1E899#;
   Mende_Kikakui_Syllable_M174_Mbo         :
      constant Unicode_Char := 16#1E89A#;
   Mende_Kikakui_Syllable_M187_Mbuu        :
      constant Unicode_Char := 16#1E89B#;
   Mende_Kikakui_Syllable_M161_Long_Mbe    :
      constant Unicode_Char := 16#1E89C#;
   Mende_Kikakui_Syllable_M105_Long_Mboo   :
      constant Unicode_Char := 16#1E89D#;
   Mende_Kikakui_Syllable_M142_Long_Mbo    :
      constant Unicode_Char := 16#1E89E#;
   Mende_Kikakui_Syllable_M132_Kpi         :
      constant Unicode_Char := 16#1E89F#;
   Mende_Kikakui_Syllable_M092_Kpa         :
      constant Unicode_Char := 16#1E8A0#;
   Mende_Kikakui_Syllable_M074_Kpu         :
      constant Unicode_Char := 16#1E8A1#;
   Mende_Kikakui_Syllable_M044_Kpee        :
      constant Unicode_Char := 16#1E8A2#;
   Mende_Kikakui_Syllable_M108_Kpe         :
      constant Unicode_Char := 16#1E8A3#;
   Mende_Kikakui_Syllable_M112_Kpoo        :
      constant Unicode_Char := 16#1E8A4#;
   Mende_Kikakui_Syllable_M158_Kpo         :
      constant Unicode_Char := 16#1E8A5#;
   Mende_Kikakui_Syllable_M124_Gbi         :
      constant Unicode_Char := 16#1E8A6#;
   Mende_Kikakui_Syllable_M056_Gba         :
      constant Unicode_Char := 16#1E8A7#;
   Mende_Kikakui_Syllable_M148_Gbu         :
      constant Unicode_Char := 16#1E8A8#;
   Mende_Kikakui_Syllable_M093_Gbee        :
      constant Unicode_Char := 16#1E8A9#;
   Mende_Kikakui_Syllable_M107_Gbe         :
      constant Unicode_Char := 16#1E8AA#;
   Mende_Kikakui_Syllable_M071_Gboo        :
      constant Unicode_Char := 16#1E8AB#;
   Mende_Kikakui_Syllable_M070_Gbo         :
      constant Unicode_Char := 16#1E8AC#;
   Mende_Kikakui_Syllable_M171_Ra          :
      constant Unicode_Char := 16#1E8AD#;
   Mende_Kikakui_Syllable_M123_Ndi         :
      constant Unicode_Char := 16#1E8AE#;
   Mende_Kikakui_Syllable_M129_Nda         :
      constant Unicode_Char := 16#1E8AF#;
   Mende_Kikakui_Syllable_M125_Ndu         :
      constant Unicode_Char := 16#1E8B0#;
   Mende_Kikakui_Syllable_M191_Ndee        :
      constant Unicode_Char := 16#1E8B1#;
   Mende_Kikakui_Syllable_M119_Nde         :
      constant Unicode_Char := 16#1E8B2#;
   Mende_Kikakui_Syllable_M067_Ndoo        :
      constant Unicode_Char := 16#1E8B3#;
   Mende_Kikakui_Syllable_M064_Ndo         :
      constant Unicode_Char := 16#1E8B4#;
   Mende_Kikakui_Syllable_M152_Nja         :
      constant Unicode_Char := 16#1E8B5#;
   Mende_Kikakui_Syllable_M192_Nju         :
      constant Unicode_Char := 16#1E8B6#;
   Mende_Kikakui_Syllable_M149_Njee        :
      constant Unicode_Char := 16#1E8B7#;
   Mende_Kikakui_Syllable_M134_Njoo        :
      constant Unicode_Char := 16#1E8B8#;
   Mende_Kikakui_Syllable_M182_Vi          :
      constant Unicode_Char := 16#1E8B9#;
   Mende_Kikakui_Syllable_M185_Va          :
      constant Unicode_Char := 16#1E8BA#;
   Mende_Kikakui_Syllable_M151_Vu          :
      constant Unicode_Char := 16#1E8BB#;
   Mende_Kikakui_Syllable_M173_Vee         :
      constant Unicode_Char := 16#1E8BC#;
   Mende_Kikakui_Syllable_M085_Ve          :
      constant Unicode_Char := 16#1E8BD#;
   Mende_Kikakui_Syllable_M144_Voo         :
      constant Unicode_Char := 16#1E8BE#;
   Mende_Kikakui_Syllable_M077_Vo          :
      constant Unicode_Char := 16#1E8BF#;
   Mende_Kikakui_Syllable_M164_Nyin        :
      constant Unicode_Char := 16#1E8C0#;
   Mende_Kikakui_Syllable_M058_Nyan        :
      constant Unicode_Char := 16#1E8C1#;
   Mende_Kikakui_Syllable_M170_Nyun        :
      constant Unicode_Char := 16#1E8C2#;
   Mende_Kikakui_Syllable_M098_Nyen        :
      constant Unicode_Char := 16#1E8C3#;
   Mende_Kikakui_Syllable_M060_Nyon        :
      constant Unicode_Char := 16#1E8C4#;
   Mende_Kikakui_Digit_One                 :
      constant Unicode_Char := 16#1E8C7#;
   Mende_Kikakui_Digit_Two                 :
      constant Unicode_Char := 16#1E8C8#;
   Mende_Kikakui_Digit_Three               :
      constant Unicode_Char := 16#1E8C9#;
   Mende_Kikakui_Digit_Four                :
      constant Unicode_Char := 16#1E8CA#;
   Mende_Kikakui_Digit_Five                :
      constant Unicode_Char := 16#1E8CB#;
   Mende_Kikakui_Digit_Six                 :
      constant Unicode_Char := 16#1E8CC#;
   Mende_Kikakui_Digit_Seven               :
      constant Unicode_Char := 16#1E8CD#;
   Mende_Kikakui_Digit_Eight               :
      constant Unicode_Char := 16#1E8CE#;
   Mende_Kikakui_Digit_Nine                :
      constant Unicode_Char := 16#1E8CF#;
   Mende_Kikakui_Combining_Number_Teens    :
      constant Unicode_Char := 16#1E8D0#;
   Mende_Kikakui_Combining_Number_Tens     :
      constant Unicode_Char := 16#1E8D1#;
   Mende_Kikakui_Combining_Number_Hundreds :
      constant Unicode_Char := 16#1E8D2#;
   Mende_Kikakui_Combining_Number_Thousands :
      constant Unicode_Char := 16#1E8D3#;
   Mende_Kikakui_Combining_Number_Ten_Thousands :
      constant Unicode_Char := 16#1E8D4#;
   Mende_Kikakui_Combining_Number_Hundred_Thousands :
      constant Unicode_Char := 16#1E8D5#;
   Mende_Kikakui_Combining_Number_Millions :
      constant Unicode_Char := 16#1E8D6#;
end Unicode.Names.Mende_Kikakui;
