--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Khudawadi is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Khudawadi_Letter_A                      :
      constant Unicode_Char := 16#112B0#;
   Khudawadi_Letter_Aa                     :
      constant Unicode_Char := 16#112B1#;
   Khudawadi_Letter_I                      :
      constant Unicode_Char := 16#112B2#;
   Khudawadi_Letter_Ii                     :
      constant Unicode_Char := 16#112B3#;
   Khudawadi_Letter_U                      :
      constant Unicode_Char := 16#112B4#;
   Khudawadi_Letter_Uu                     :
      constant Unicode_Char := 16#112B5#;
   Khudawadi_Letter_E                      :
      constant Unicode_Char := 16#112B6#;
   Khudawadi_Letter_Ai                     :
      constant Unicode_Char := 16#112B7#;
   Khudawadi_Letter_O                      :
      constant Unicode_Char := 16#112B8#;
   Khudawadi_Letter_Au                     :
      constant Unicode_Char := 16#112B9#;
   Khudawadi_Letter_Ka                     :
      constant Unicode_Char := 16#112BA#;
   Khudawadi_Letter_Kha                    :
      constant Unicode_Char := 16#112BB#;
   Khudawadi_Letter_Ga                     :
      constant Unicode_Char := 16#112BC#;
   Khudawadi_Letter_Gga                    :
      constant Unicode_Char := 16#112BD#;
   Khudawadi_Letter_Gha                    :
      constant Unicode_Char := 16#112BE#;
   Khudawadi_Letter_Nga                    :
      constant Unicode_Char := 16#112BF#;
   Khudawadi_Letter_Ca                     :
      constant Unicode_Char := 16#112C0#;
   Khudawadi_Letter_Cha                    :
      constant Unicode_Char := 16#112C1#;
   Khudawadi_Letter_Ja                     :
      constant Unicode_Char := 16#112C2#;
   Khudawadi_Letter_Jja                    :
      constant Unicode_Char := 16#112C3#;
   Khudawadi_Letter_Jha                    :
      constant Unicode_Char := 16#112C4#;
   Khudawadi_Letter_Nya                    :
      constant Unicode_Char := 16#112C5#;
   Khudawadi_Letter_Tta                    :
      constant Unicode_Char := 16#112C6#;
   Khudawadi_Letter_Ttha                   :
      constant Unicode_Char := 16#112C7#;
   Khudawadi_Letter_Dda                    :
      constant Unicode_Char := 16#112C8#;
   Khudawadi_Letter_Ddda                   :
      constant Unicode_Char := 16#112C9#;
   Khudawadi_Letter_Rra                    :
      constant Unicode_Char := 16#112CA#;
   Khudawadi_Letter_Ddha                   :
      constant Unicode_Char := 16#112CB#;
   Khudawadi_Letter_Nna                    :
      constant Unicode_Char := 16#112CC#;
   Khudawadi_Letter_Ta                     :
      constant Unicode_Char := 16#112CD#;
   Khudawadi_Letter_Tha                    :
      constant Unicode_Char := 16#112CE#;
   Khudawadi_Letter_Da                     :
      constant Unicode_Char := 16#112CF#;
   Khudawadi_Letter_Dha                    :
      constant Unicode_Char := 16#112D0#;
   Khudawadi_Letter_Na                     :
      constant Unicode_Char := 16#112D1#;
   Khudawadi_Letter_Pa                     :
      constant Unicode_Char := 16#112D2#;
   Khudawadi_Letter_Pha                    :
      constant Unicode_Char := 16#112D3#;
   Khudawadi_Letter_Ba                     :
      constant Unicode_Char := 16#112D4#;
   Khudawadi_Letter_Bba                    :
      constant Unicode_Char := 16#112D5#;
   Khudawadi_Letter_Bha                    :
      constant Unicode_Char := 16#112D6#;
   Khudawadi_Letter_Ma                     :
      constant Unicode_Char := 16#112D7#;
   Khudawadi_Letter_Ya                     :
      constant Unicode_Char := 16#112D8#;
   Khudawadi_Letter_Ra                     :
      constant Unicode_Char := 16#112D9#;
   Khudawadi_Letter_La                     :
      constant Unicode_Char := 16#112DA#;
   Khudawadi_Letter_Va                     :
      constant Unicode_Char := 16#112DB#;
   Khudawadi_Letter_Sha                    :
      constant Unicode_Char := 16#112DC#;
   Khudawadi_Letter_Sa                     :
      constant Unicode_Char := 16#112DD#;
   Khudawadi_Letter_Ha                     :
      constant Unicode_Char := 16#112DE#;
   Khudawadi_Sign_Anusvara                 :
      constant Unicode_Char := 16#112DF#;
   Khudawadi_Vowel_Sign_Aa                 :
      constant Unicode_Char := 16#112E0#;
   Khudawadi_Vowel_Sign_I                  :
      constant Unicode_Char := 16#112E1#;
   Khudawadi_Vowel_Sign_Ii                 :
      constant Unicode_Char := 16#112E2#;
   Khudawadi_Vowel_Sign_U                  :
      constant Unicode_Char := 16#112E3#;
   Khudawadi_Vowel_Sign_Uu                 :
      constant Unicode_Char := 16#112E4#;
   Khudawadi_Vowel_Sign_E                  :
      constant Unicode_Char := 16#112E5#;
   Khudawadi_Vowel_Sign_Ai                 :
      constant Unicode_Char := 16#112E6#;
   Khudawadi_Vowel_Sign_O                  :
      constant Unicode_Char := 16#112E7#;
   Khudawadi_Vowel_Sign_Au                 :
      constant Unicode_Char := 16#112E8#;
   Khudawadi_Sign_Nukta                    :
      constant Unicode_Char := 16#112E9#;
   Khudawadi_Sign_Virama                   :
      constant Unicode_Char := 16#112EA#;
   Khudawadi_Digit_Zero                    :
      constant Unicode_Char := 16#112F0#;
   Khudawadi_Digit_One                     :
      constant Unicode_Char := 16#112F1#;
   Khudawadi_Digit_Two                     :
      constant Unicode_Char := 16#112F2#;
   Khudawadi_Digit_Three                   :
      constant Unicode_Char := 16#112F3#;
   Khudawadi_Digit_Four                    :
      constant Unicode_Char := 16#112F4#;
   Khudawadi_Digit_Five                    :
      constant Unicode_Char := 16#112F5#;
   Khudawadi_Digit_Six                     :
      constant Unicode_Char := 16#112F6#;
   Khudawadi_Digit_Seven                   :
      constant Unicode_Char := 16#112F7#;
   Khudawadi_Digit_Eight                   :
      constant Unicode_Char := 16#112F8#;
   Khudawadi_Digit_Nine                    :
      constant Unicode_Char := 16#112F9#;
end Unicode.Names.Khudawadi;
