--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Old_South_Arabian is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Old_South_Arabian_Letter_He             :
      constant Unicode_Char := 16#10A60#;
   Old_South_Arabian_Letter_Lamedh         :
      constant Unicode_Char := 16#10A61#;
   Old_South_Arabian_Letter_Heth           :
      constant Unicode_Char := 16#10A62#;
   Old_South_Arabian_Letter_Mem            :
      constant Unicode_Char := 16#10A63#;
   Old_South_Arabian_Letter_Qoph           :
      constant Unicode_Char := 16#10A64#;
   Old_South_Arabian_Letter_Waw            :
      constant Unicode_Char := 16#10A65#;
   Old_South_Arabian_Letter_Shin           :
      constant Unicode_Char := 16#10A66#;
   Old_South_Arabian_Letter_Resh           :
      constant Unicode_Char := 16#10A67#;
   Old_South_Arabian_Letter_Beth           :
      constant Unicode_Char := 16#10A68#;
   Old_South_Arabian_Letter_Taw            :
      constant Unicode_Char := 16#10A69#;
   Old_South_Arabian_Letter_Sat            :
      constant Unicode_Char := 16#10A6A#;
   Old_South_Arabian_Letter_Kaph           :
      constant Unicode_Char := 16#10A6B#;
   Old_South_Arabian_Letter_Nun            :
      constant Unicode_Char := 16#10A6C#;
   Old_South_Arabian_Letter_Kheth          :
      constant Unicode_Char := 16#10A6D#;
   Old_South_Arabian_Letter_Sadhe          :
      constant Unicode_Char := 16#10A6E#;
   Old_South_Arabian_Letter_Samekh         :
      constant Unicode_Char := 16#10A6F#;
   Old_South_Arabian_Letter_Fe             :
      constant Unicode_Char := 16#10A70#;
   Old_South_Arabian_Letter_Alef           :
      constant Unicode_Char := 16#10A71#;
   Old_South_Arabian_Letter_Ayn            :
      constant Unicode_Char := 16#10A72#;
   Old_South_Arabian_Letter_Dhadhe         :
      constant Unicode_Char := 16#10A73#;
   Old_South_Arabian_Letter_Gimel          :
      constant Unicode_Char := 16#10A74#;
   Old_South_Arabian_Letter_Daleth         :
      constant Unicode_Char := 16#10A75#;
   Old_South_Arabian_Letter_Ghayn          :
      constant Unicode_Char := 16#10A76#;
   Old_South_Arabian_Letter_Teth           :
      constant Unicode_Char := 16#10A77#;
   Old_South_Arabian_Letter_Zayn           :
      constant Unicode_Char := 16#10A78#;
   Old_South_Arabian_Letter_Dhaleth        :
      constant Unicode_Char := 16#10A79#;
   Old_South_Arabian_Letter_Yodh           :
      constant Unicode_Char := 16#10A7A#;
   Old_South_Arabian_Letter_Thaw           :
      constant Unicode_Char := 16#10A7B#;
   Old_South_Arabian_Letter_Theth          :
      constant Unicode_Char := 16#10A7C#;
   Old_South_Arabian_Number_One            :
      constant Unicode_Char := 16#10A7D#;
   Old_South_Arabian_Number_Fifty          :
      constant Unicode_Char := 16#10A7E#;
   Old_South_Arabian_Numeric_Indicator     :
      constant Unicode_Char := 16#10A7F#;
end Unicode.Names.Old_South_Arabian;
