--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Balinese is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Balinese_Sign_Ulu_Ricem                 : constant Unicode_Char := 16#1B00#;
   Balinese_Sign_Ulu_Candra                : constant Unicode_Char := 16#1B01#;
   Balinese_Sign_Cecek                     : constant Unicode_Char := 16#1B02#;
   Balinese_Sign_Surang                    : constant Unicode_Char := 16#1B03#;
   Balinese_Sign_Bisah                     : constant Unicode_Char := 16#1B04#;
   Balinese_Letter_Akara                   : constant Unicode_Char := 16#1B05#;
   Balinese_Letter_Akara_Tedung            : constant Unicode_Char := 16#1B06#;
   Balinese_Letter_Ikara                   : constant Unicode_Char := 16#1B07#;
   Balinese_Letter_Ikara_Tedung            : constant Unicode_Char := 16#1B08#;
   Balinese_Letter_Ukara                   : constant Unicode_Char := 16#1B09#;
   Balinese_Letter_Ukara_Tedung            : constant Unicode_Char := 16#1B0A#;
   Balinese_Letter_Ra_Repa                 : constant Unicode_Char := 16#1B0B#;
   Balinese_Letter_Ra_Repa_Tedung          : constant Unicode_Char := 16#1B0C#;
   Balinese_Letter_La_Lenga                : constant Unicode_Char := 16#1B0D#;
   Balinese_Letter_La_Lenga_Tedung         : constant Unicode_Char := 16#1B0E#;
   Balinese_Letter_Ekara                   : constant Unicode_Char := 16#1B0F#;
   Balinese_Letter_Aikara                  : constant Unicode_Char := 16#1B10#;
   Balinese_Letter_Okara                   : constant Unicode_Char := 16#1B11#;
   Balinese_Letter_Okara_Tedung            : constant Unicode_Char := 16#1B12#;
   Balinese_Letter_Ka                      : constant Unicode_Char := 16#1B13#;
   Balinese_Letter_Ka_Mahaprana            : constant Unicode_Char := 16#1B14#;
   Balinese_Letter_Ga                      : constant Unicode_Char := 16#1B15#;
   Balinese_Letter_Ga_Gora                 : constant Unicode_Char := 16#1B16#;
   Balinese_Letter_Nga                     : constant Unicode_Char := 16#1B17#;
   Balinese_Letter_Ca                      : constant Unicode_Char := 16#1B18#;
   Balinese_Letter_Ca_Laca                 : constant Unicode_Char := 16#1B19#;
   Balinese_Letter_Ja                      : constant Unicode_Char := 16#1B1A#;
   Balinese_Letter_Ja_Jera                 : constant Unicode_Char := 16#1B1B#;
   Balinese_Letter_Nya                     : constant Unicode_Char := 16#1B1C#;
   Balinese_Letter_Ta_Latik                : constant Unicode_Char := 16#1B1D#;
   Balinese_Letter_Ta_Murda_Mahaprana      : constant Unicode_Char := 16#1B1E#;
   Balinese_Letter_Da_Murda_Alpaprana      : constant Unicode_Char := 16#1B1F#;
   Balinese_Letter_Da_Murda_Mahaprana      : constant Unicode_Char := 16#1B20#;
   Balinese_Letter_Na_Rambat               : constant Unicode_Char := 16#1B21#;
   Balinese_Letter_Ta                      : constant Unicode_Char := 16#1B22#;
   Balinese_Letter_Ta_Tawa                 : constant Unicode_Char := 16#1B23#;
   Balinese_Letter_Da                      : constant Unicode_Char := 16#1B24#;
   Balinese_Letter_Da_Madu                 : constant Unicode_Char := 16#1B25#;
   Balinese_Letter_Na                      : constant Unicode_Char := 16#1B26#;
   Balinese_Letter_Pa                      : constant Unicode_Char := 16#1B27#;
   Balinese_Letter_Pa_Kapal                : constant Unicode_Char := 16#1B28#;
   Balinese_Letter_Ba                      : constant Unicode_Char := 16#1B29#;
   Balinese_Letter_Ba_Kembang              : constant Unicode_Char := 16#1B2A#;
   Balinese_Letter_Ma                      : constant Unicode_Char := 16#1B2B#;
   Balinese_Letter_Ya                      : constant Unicode_Char := 16#1B2C#;
   Balinese_Letter_Ra                      : constant Unicode_Char := 16#1B2D#;
   Balinese_Letter_La                      : constant Unicode_Char := 16#1B2E#;
   Balinese_Letter_Wa                      : constant Unicode_Char := 16#1B2F#;
   Balinese_Letter_Sa_Saga                 : constant Unicode_Char := 16#1B30#;
   Balinese_Letter_Sa_Sapa                 : constant Unicode_Char := 16#1B31#;
   Balinese_Letter_Sa                      : constant Unicode_Char := 16#1B32#;
   Balinese_Letter_Ha                      : constant Unicode_Char := 16#1B33#;
   Balinese_Sign_Rerekan                   : constant Unicode_Char := 16#1B34#;
   Balinese_Vowel_Sign_Tedung              : constant Unicode_Char := 16#1B35#;
   Balinese_Vowel_Sign_Ulu                 : constant Unicode_Char := 16#1B36#;
   Balinese_Vowel_Sign_Ulu_Sari            : constant Unicode_Char := 16#1B37#;
   Balinese_Vowel_Sign_Suku                : constant Unicode_Char := 16#1B38#;
   Balinese_Vowel_Sign_Suku_Ilut           : constant Unicode_Char := 16#1B39#;
   Balinese_Vowel_Sign_Ra_Repa             : constant Unicode_Char := 16#1B3A#;
   Balinese_Vowel_Sign_Ra_Repa_Tedung      : constant Unicode_Char := 16#1B3B#;
   Balinese_Vowel_Sign_La_Lenga            : constant Unicode_Char := 16#1B3C#;
   Balinese_Vowel_Sign_La_Lenga_Tedung     : constant Unicode_Char := 16#1B3D#;
   Balinese_Vowel_Sign_Taling              : constant Unicode_Char := 16#1B3E#;
   Balinese_Vowel_Sign_Taling_Repa         : constant Unicode_Char := 16#1B3F#;
   Balinese_Vowel_Sign_Taling_Tedung       : constant Unicode_Char := 16#1B40#;
   Balinese_Vowel_Sign_Taling_Repa_Tedung  : constant Unicode_Char := 16#1B41#;
   Balinese_Vowel_Sign_Pepet               : constant Unicode_Char := 16#1B42#;
   Balinese_Vowel_Sign_Pepet_Tedung        : constant Unicode_Char := 16#1B43#;
   Balinese_Adeg_Adeg                      : constant Unicode_Char := 16#1B44#;
   Balinese_Letter_Kaf_Sasak               : constant Unicode_Char := 16#1B45#;
   Balinese_Letter_Khot_Sasak              : constant Unicode_Char := 16#1B46#;
   Balinese_Letter_Tzir_Sasak              : constant Unicode_Char := 16#1B47#;
   Balinese_Letter_Ef_Sasak                : constant Unicode_Char := 16#1B48#;
   Balinese_Letter_Ve_Sasak                : constant Unicode_Char := 16#1B49#;
   Balinese_Letter_Zal_Sasak               : constant Unicode_Char := 16#1B4A#;
   Balinese_Letter_Asyura_Sasak            : constant Unicode_Char := 16#1B4B#;
   Balinese_Digit_Zero                     : constant Unicode_Char := 16#1B50#;
   Balinese_Digit_One                      : constant Unicode_Char := 16#1B51#;
   Balinese_Digit_Two                      : constant Unicode_Char := 16#1B52#;
   Balinese_Digit_Three                    : constant Unicode_Char := 16#1B53#;
   Balinese_Digit_Four                     : constant Unicode_Char := 16#1B54#;
   Balinese_Digit_Five                     : constant Unicode_Char := 16#1B55#;
   Balinese_Digit_Six                      : constant Unicode_Char := 16#1B56#;
   Balinese_Digit_Seven                    : constant Unicode_Char := 16#1B57#;
   Balinese_Digit_Eight                    : constant Unicode_Char := 16#1B58#;
   Balinese_Digit_Nine                     : constant Unicode_Char := 16#1B59#;
   Balinese_Panti                          : constant Unicode_Char := 16#1B5A#;
   Balinese_Pamada                         : constant Unicode_Char := 16#1B5B#;
   Balinese_Windu                          : constant Unicode_Char := 16#1B5C#;
   Balinese_Carik_Pamungkah                : constant Unicode_Char := 16#1B5D#;
   Balinese_Carik_Siki                     : constant Unicode_Char := 16#1B5E#;
   Balinese_Carik_Pareren                  : constant Unicode_Char := 16#1B5F#;
   Balinese_Pameneng                       : constant Unicode_Char := 16#1B60#;
   Balinese_Musical_Symbol_Dong            : constant Unicode_Char := 16#1B61#;
   Balinese_Musical_Symbol_Deng            : constant Unicode_Char := 16#1B62#;
   Balinese_Musical_Symbol_Dung            : constant Unicode_Char := 16#1B63#;
   Balinese_Musical_Symbol_Dang            : constant Unicode_Char := 16#1B64#;
   Balinese_Musical_Symbol_Dang_Surang     : constant Unicode_Char := 16#1B65#;
   Balinese_Musical_Symbol_Ding            : constant Unicode_Char := 16#1B66#;
   Balinese_Musical_Symbol_Daeng           : constant Unicode_Char := 16#1B67#;
   Balinese_Musical_Symbol_Deung           : constant Unicode_Char := 16#1B68#;
   Balinese_Musical_Symbol_Daing           : constant Unicode_Char := 16#1B69#;
   Balinese_Musical_Symbol_Dang_Gede       : constant Unicode_Char := 16#1B6A#;
   Balinese_Musical_Symbol_Combining_Tegeh : constant Unicode_Char := 16#1B6B#;
   Balinese_Musical_Symbol_Combining_Endep : constant Unicode_Char := 16#1B6C#;
   Balinese_Musical_Symbol_Combining_Kempul :
      constant Unicode_Char := 16#1B6D#;
   Balinese_Musical_Symbol_Combining_Kempli :
      constant Unicode_Char := 16#1B6E#;
   Balinese_Musical_Symbol_Combining_Jegogan :
      constant Unicode_Char := 16#1B6F#;
   Balinese_Musical_Symbol_Combining_Kempul_With_Jegogan :
      constant Unicode_Char := 16#1B70#;
   Balinese_Musical_Symbol_Combining_Kempli_With_Jegogan :
      constant Unicode_Char := 16#1B71#;
   Balinese_Musical_Symbol_Combining_Bende : constant Unicode_Char := 16#1B72#;
   Balinese_Musical_Symbol_Combining_Gong  : constant Unicode_Char := 16#1B73#;
   Balinese_Musical_Symbol_Right_Hand_Open_Dug :
      constant Unicode_Char := 16#1B74#;
   Balinese_Musical_Symbol_Right_Hand_Open_Dag :
      constant Unicode_Char := 16#1B75#;
   Balinese_Musical_Symbol_Right_Hand_Closed_Tuk :
      constant Unicode_Char := 16#1B76#;
   Balinese_Musical_Symbol_Right_Hand_Closed_Tak :
      constant Unicode_Char := 16#1B77#;
   Balinese_Musical_Symbol_Left_Hand_Open_Pang :
      constant Unicode_Char := 16#1B78#;
   Balinese_Musical_Symbol_Left_Hand_Open_Pung :
      constant Unicode_Char := 16#1B79#;
   Balinese_Musical_Symbol_Left_Hand_Closed_Plak :
      constant Unicode_Char := 16#1B7A#;
   Balinese_Musical_Symbol_Left_Hand_Closed_Pluk :
      constant Unicode_Char := 16#1B7B#;
   Balinese_Musical_Symbol_Left_Hand_Open_Ping :
      constant Unicode_Char := 16#1B7C#;
end Unicode.Names.Balinese;
