--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Katakana is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Katakana_Hiragana_Double_Hyphen         : constant Unicode_Char := 16#30A0#;
   Katakana_Letter_Small_A                 : constant Unicode_Char := 16#30A1#;
   Katakana_Letter_A                       : constant Unicode_Char := 16#30A2#;
   Katakana_Letter_Small_I                 : constant Unicode_Char := 16#30A3#;
   Katakana_Letter_I                       : constant Unicode_Char := 16#30A4#;
   Katakana_Letter_Small_U                 : constant Unicode_Char := 16#30A5#;
   Katakana_Letter_U                       : constant Unicode_Char := 16#30A6#;
   Katakana_Letter_Small_E                 : constant Unicode_Char := 16#30A7#;
   Katakana_Letter_E                       : constant Unicode_Char := 16#30A8#;
   Katakana_Letter_Small_O                 : constant Unicode_Char := 16#30A9#;
   Katakana_Letter_O                       : constant Unicode_Char := 16#30AA#;
   Katakana_Letter_Ka                      : constant Unicode_Char := 16#30AB#;
   Katakana_Letter_Ga                      : constant Unicode_Char := 16#30AC#;
   Katakana_Letter_Ki                      : constant Unicode_Char := 16#30AD#;
   Katakana_Letter_Gi                      : constant Unicode_Char := 16#30AE#;
   Katakana_Letter_Ku                      : constant Unicode_Char := 16#30AF#;
   Katakana_Letter_Gu                      : constant Unicode_Char := 16#30B0#;
   Katakana_Letter_Ke                      : constant Unicode_Char := 16#30B1#;
   Katakana_Letter_Ge                      : constant Unicode_Char := 16#30B2#;
   Katakana_Letter_Ko                      : constant Unicode_Char := 16#30B3#;
   Katakana_Letter_Go                      : constant Unicode_Char := 16#30B4#;
   Katakana_Letter_Sa                      : constant Unicode_Char := 16#30B5#;
   Katakana_Letter_Za                      : constant Unicode_Char := 16#30B6#;
   Katakana_Letter_Si                      : constant Unicode_Char := 16#30B7#;
   Katakana_Letter_Zi                      : constant Unicode_Char := 16#30B8#;
   Katakana_Letter_Su                      : constant Unicode_Char := 16#30B9#;
   Katakana_Letter_Zu                      : constant Unicode_Char := 16#30BA#;
   Katakana_Letter_Se                      : constant Unicode_Char := 16#30BB#;
   Katakana_Letter_Ze                      : constant Unicode_Char := 16#30BC#;
   Katakana_Letter_So                      : constant Unicode_Char := 16#30BD#;
   Katakana_Letter_Zo                      : constant Unicode_Char := 16#30BE#;
   Katakana_Letter_Ta                      : constant Unicode_Char := 16#30BF#;
   Katakana_Letter_Da                      : constant Unicode_Char := 16#30C0#;
   Katakana_Letter_Ti                      : constant Unicode_Char := 16#30C1#;
   Katakana_Letter_Di                      : constant Unicode_Char := 16#30C2#;
   Katakana_Letter_Small_Tu                : constant Unicode_Char := 16#30C3#;
   Katakana_Letter_Tu                      : constant Unicode_Char := 16#30C4#;
   Katakana_Letter_Du                      : constant Unicode_Char := 16#30C5#;
   Katakana_Letter_Te                      : constant Unicode_Char := 16#30C6#;
   Katakana_Letter_De                      : constant Unicode_Char := 16#30C7#;
   Katakana_Letter_To                      : constant Unicode_Char := 16#30C8#;
   Katakana_Letter_Do                      : constant Unicode_Char := 16#30C9#;
   Katakana_Letter_Na                      : constant Unicode_Char := 16#30CA#;
   Katakana_Letter_Ni                      : constant Unicode_Char := 16#30CB#;
   Katakana_Letter_Nu                      : constant Unicode_Char := 16#30CC#;
   Katakana_Letter_Ne                      : constant Unicode_Char := 16#30CD#;
   Katakana_Letter_No                      : constant Unicode_Char := 16#30CE#;
   Katakana_Letter_Ha                      : constant Unicode_Char := 16#30CF#;
   Katakana_Letter_Ba                      : constant Unicode_Char := 16#30D0#;
   Katakana_Letter_Pa                      : constant Unicode_Char := 16#30D1#;
   Katakana_Letter_Hi                      : constant Unicode_Char := 16#30D2#;
   Katakana_Letter_Bi                      : constant Unicode_Char := 16#30D3#;
   Katakana_Letter_Pi                      : constant Unicode_Char := 16#30D4#;
   Katakana_Letter_Hu                      : constant Unicode_Char := 16#30D5#;
   Katakana_Letter_Bu                      : constant Unicode_Char := 16#30D6#;
   Katakana_Letter_Pu                      : constant Unicode_Char := 16#30D7#;
   Katakana_Letter_He                      : constant Unicode_Char := 16#30D8#;
   Katakana_Letter_Be                      : constant Unicode_Char := 16#30D9#;
   Katakana_Letter_Pe                      : constant Unicode_Char := 16#30DA#;
   Katakana_Letter_Ho                      : constant Unicode_Char := 16#30DB#;
   Katakana_Letter_Bo                      : constant Unicode_Char := 16#30DC#;
   Katakana_Letter_Po                      : constant Unicode_Char := 16#30DD#;
   Katakana_Letter_Ma                      : constant Unicode_Char := 16#30DE#;
   Katakana_Letter_Mi                      : constant Unicode_Char := 16#30DF#;
   Katakana_Letter_Mu                      : constant Unicode_Char := 16#30E0#;
   Katakana_Letter_Me                      : constant Unicode_Char := 16#30E1#;
   Katakana_Letter_Mo                      : constant Unicode_Char := 16#30E2#;
   Katakana_Letter_Small_Ya                : constant Unicode_Char := 16#30E3#;
   Katakana_Letter_Ya                      : constant Unicode_Char := 16#30E4#;
   Katakana_Letter_Small_Yu                : constant Unicode_Char := 16#30E5#;
   Katakana_Letter_Yu                      : constant Unicode_Char := 16#30E6#;
   Katakana_Letter_Small_Yo                : constant Unicode_Char := 16#30E7#;
   Katakana_Letter_Yo                      : constant Unicode_Char := 16#30E8#;
   Katakana_Letter_Ra                      : constant Unicode_Char := 16#30E9#;
   Katakana_Letter_Ri                      : constant Unicode_Char := 16#30EA#;
   Katakana_Letter_Ru                      : constant Unicode_Char := 16#30EB#;
   Katakana_Letter_Re                      : constant Unicode_Char := 16#30EC#;
   Katakana_Letter_Ro                      : constant Unicode_Char := 16#30ED#;
   Katakana_Letter_Small_Wa                : constant Unicode_Char := 16#30EE#;
   Katakana_Letter_Wa                      : constant Unicode_Char := 16#30EF#;
   Katakana_Letter_Wi                      : constant Unicode_Char := 16#30F0#;
   Katakana_Letter_We                      : constant Unicode_Char := 16#30F1#;
   Katakana_Letter_Wo                      : constant Unicode_Char := 16#30F2#;
   Katakana_Letter_N                       : constant Unicode_Char := 16#30F3#;
   Katakana_Letter_Vu                      : constant Unicode_Char := 16#30F4#;
   Katakana_Letter_Small_Ka                : constant Unicode_Char := 16#30F5#;
   Katakana_Letter_Small_Ke                : constant Unicode_Char := 16#30F6#;
   Katakana_Letter_Va                      : constant Unicode_Char := 16#30F7#;
   Katakana_Letter_Vi                      : constant Unicode_Char := 16#30F8#;
   Katakana_Letter_Ve                      : constant Unicode_Char := 16#30F9#;
   Katakana_Letter_Vo                      : constant Unicode_Char := 16#30FA#;
   Katakana_Middle_Dot                     : constant Unicode_Char := 16#30FB#;
   Katakana_Hiragana_Prolonged_Sound_Mark  : constant Unicode_Char := 16#30FC#;
   Katakana_Iteration_Mark                 : constant Unicode_Char := 16#30FD#;
   Katakana_Voiced_Iteration_Mark          : constant Unicode_Char := 16#30FE#;
   Katakana_Digraph_Koto                   : constant Unicode_Char := 16#30FF#;
end Unicode.Names.Katakana;
