--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Enclosed_Alphanum_Sup is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Digit_Zero_Full_Stop                    :
      constant Unicode_Char := 16#1F100#;
   Digit_Zero_Comma                        :
      constant Unicode_Char := 16#1F101#;
   Digit_One_Comma                         :
      constant Unicode_Char := 16#1F102#;
   Digit_Two_Comma                         :
      constant Unicode_Char := 16#1F103#;
   Digit_Three_Comma                       :
      constant Unicode_Char := 16#1F104#;
   Digit_Four_Comma                        :
      constant Unicode_Char := 16#1F105#;
   Digit_Five_Comma                        :
      constant Unicode_Char := 16#1F106#;
   Digit_Six_Comma                         :
      constant Unicode_Char := 16#1F107#;
   Digit_Seven_Comma                       :
      constant Unicode_Char := 16#1F108#;
   Digit_Eight_Comma                       :
      constant Unicode_Char := 16#1F109#;
   Digit_Nine_Comma                        :
      constant Unicode_Char := 16#1F10A#;
   Dingbat_Circled_Sans_Serif_Digit_Zero   :
      constant Unicode_Char := 16#1F10B#;
   Dingbat_Negative_Circled_Sans_Serif_Digit_Zero :
      constant Unicode_Char := 16#1F10C#;
   Parenthesized_Latin_Capital_Letter_A    :
      constant Unicode_Char := 16#1F110#;
   Parenthesized_Latin_Capital_Letter_B    :
      constant Unicode_Char := 16#1F111#;
   Parenthesized_Latin_Capital_Letter_C    :
      constant Unicode_Char := 16#1F112#;
   Parenthesized_Latin_Capital_Letter_D    :
      constant Unicode_Char := 16#1F113#;
   Parenthesized_Latin_Capital_Letter_E    :
      constant Unicode_Char := 16#1F114#;
   Parenthesized_Latin_Capital_Letter_F    :
      constant Unicode_Char := 16#1F115#;
   Parenthesized_Latin_Capital_Letter_G    :
      constant Unicode_Char := 16#1F116#;
   Parenthesized_Latin_Capital_Letter_H    :
      constant Unicode_Char := 16#1F117#;
   Parenthesized_Latin_Capital_Letter_I    :
      constant Unicode_Char := 16#1F118#;
   Parenthesized_Latin_Capital_Letter_J    :
      constant Unicode_Char := 16#1F119#;
   Parenthesized_Latin_Capital_Letter_K    :
      constant Unicode_Char := 16#1F11A#;
   Parenthesized_Latin_Capital_Letter_L    :
      constant Unicode_Char := 16#1F11B#;
   Parenthesized_Latin_Capital_Letter_M    :
      constant Unicode_Char := 16#1F11C#;
   Parenthesized_Latin_Capital_Letter_N    :
      constant Unicode_Char := 16#1F11D#;
   Parenthesized_Latin_Capital_Letter_O    :
      constant Unicode_Char := 16#1F11E#;
   Parenthesized_Latin_Capital_Letter_P    :
      constant Unicode_Char := 16#1F11F#;
   Parenthesized_Latin_Capital_Letter_Q    :
      constant Unicode_Char := 16#1F120#;
   Parenthesized_Latin_Capital_Letter_R    :
      constant Unicode_Char := 16#1F121#;
   Parenthesized_Latin_Capital_Letter_S    :
      constant Unicode_Char := 16#1F122#;
   Parenthesized_Latin_Capital_Letter_T    :
      constant Unicode_Char := 16#1F123#;
   Parenthesized_Latin_Capital_Letter_U    :
      constant Unicode_Char := 16#1F124#;
   Parenthesized_Latin_Capital_Letter_V    :
      constant Unicode_Char := 16#1F125#;
   Parenthesized_Latin_Capital_Letter_W    :
      constant Unicode_Char := 16#1F126#;
   Parenthesized_Latin_Capital_Letter_X    :
      constant Unicode_Char := 16#1F127#;
   Parenthesized_Latin_Capital_Letter_Y    :
      constant Unicode_Char := 16#1F128#;
   Parenthesized_Latin_Capital_Letter_Z    :
      constant Unicode_Char := 16#1F129#;
   Tortoise_Shell_Bracketed_Latin_Capital_Letter_S :
      constant Unicode_Char := 16#1F12A#;
   Circled_Italic_Latin_Capital_Letter_C   :
      constant Unicode_Char := 16#1F12B#;
   Circled_Italic_Latin_Capital_Letter_R   :
      constant Unicode_Char := 16#1F12C#;
   Circled_Cd                              :
      constant Unicode_Char := 16#1F12D#;
   Circled_Wz                              :
      constant Unicode_Char := 16#1F12E#;
   Squared_Latin_Capital_Letter_A          :
      constant Unicode_Char := 16#1F130#;
   Squared_Latin_Capital_Letter_B          :
      constant Unicode_Char := 16#1F131#;
   Squared_Latin_Capital_Letter_C          :
      constant Unicode_Char := 16#1F132#;
   Squared_Latin_Capital_Letter_D          :
      constant Unicode_Char := 16#1F133#;
   Squared_Latin_Capital_Letter_E          :
      constant Unicode_Char := 16#1F134#;
   Squared_Latin_Capital_Letter_F          :
      constant Unicode_Char := 16#1F135#;
   Squared_Latin_Capital_Letter_G          :
      constant Unicode_Char := 16#1F136#;
   Squared_Latin_Capital_Letter_H          :
      constant Unicode_Char := 16#1F137#;
   Squared_Latin_Capital_Letter_I          :
      constant Unicode_Char := 16#1F138#;
   Squared_Latin_Capital_Letter_J          :
      constant Unicode_Char := 16#1F139#;
   Squared_Latin_Capital_Letter_K          :
      constant Unicode_Char := 16#1F13A#;
   Squared_Latin_Capital_Letter_L          :
      constant Unicode_Char := 16#1F13B#;
   Squared_Latin_Capital_Letter_M          :
      constant Unicode_Char := 16#1F13C#;
   Squared_Latin_Capital_Letter_N          :
      constant Unicode_Char := 16#1F13D#;
   Squared_Latin_Capital_Letter_O          :
      constant Unicode_Char := 16#1F13E#;
   Squared_Latin_Capital_Letter_P          :
      constant Unicode_Char := 16#1F13F#;
   Squared_Latin_Capital_Letter_Q          :
      constant Unicode_Char := 16#1F140#;
   Squared_Latin_Capital_Letter_R          :
      constant Unicode_Char := 16#1F141#;
   Squared_Latin_Capital_Letter_S          :
      constant Unicode_Char := 16#1F142#;
   Squared_Latin_Capital_Letter_T          :
      constant Unicode_Char := 16#1F143#;
   Squared_Latin_Capital_Letter_U          :
      constant Unicode_Char := 16#1F144#;
   Squared_Latin_Capital_Letter_V          :
      constant Unicode_Char := 16#1F145#;
   Squared_Latin_Capital_Letter_W          :
      constant Unicode_Char := 16#1F146#;
   Squared_Latin_Capital_Letter_X          :
      constant Unicode_Char := 16#1F147#;
   Squared_Latin_Capital_Letter_Y          :
      constant Unicode_Char := 16#1F148#;
   Squared_Latin_Capital_Letter_Z          :
      constant Unicode_Char := 16#1F149#;
   Squared_Hv                              :
      constant Unicode_Char := 16#1F14A#;
   Squared_Mv                              :
      constant Unicode_Char := 16#1F14B#;
   Squared_Sd                              :
      constant Unicode_Char := 16#1F14C#;
   Squared_Ss                              :
      constant Unicode_Char := 16#1F14D#;
   Squared_Ppv                             :
      constant Unicode_Char := 16#1F14E#;
   Squared_Wc                              :
      constant Unicode_Char := 16#1F14F#;
   Negative_Circled_Latin_Capital_Letter_A :
      constant Unicode_Char := 16#1F150#;
   Negative_Circled_Latin_Capital_Letter_B :
      constant Unicode_Char := 16#1F151#;
   Negative_Circled_Latin_Capital_Letter_C :
      constant Unicode_Char := 16#1F152#;
   Negative_Circled_Latin_Capital_Letter_D :
      constant Unicode_Char := 16#1F153#;
   Negative_Circled_Latin_Capital_Letter_E :
      constant Unicode_Char := 16#1F154#;
   Negative_Circled_Latin_Capital_Letter_F :
      constant Unicode_Char := 16#1F155#;
   Negative_Circled_Latin_Capital_Letter_G :
      constant Unicode_Char := 16#1F156#;
   Negative_Circled_Latin_Capital_Letter_H :
      constant Unicode_Char := 16#1F157#;
   Negative_Circled_Latin_Capital_Letter_I :
      constant Unicode_Char := 16#1F158#;
   Negative_Circled_Latin_Capital_Letter_J :
      constant Unicode_Char := 16#1F159#;
   Negative_Circled_Latin_Capital_Letter_K :
      constant Unicode_Char := 16#1F15A#;
   Negative_Circled_Latin_Capital_Letter_L :
      constant Unicode_Char := 16#1F15B#;
   Negative_Circled_Latin_Capital_Letter_M :
      constant Unicode_Char := 16#1F15C#;
   Negative_Circled_Latin_Capital_Letter_N :
      constant Unicode_Char := 16#1F15D#;
   Negative_Circled_Latin_Capital_Letter_O :
      constant Unicode_Char := 16#1F15E#;
   Negative_Circled_Latin_Capital_Letter_P :
      constant Unicode_Char := 16#1F15F#;
   Negative_Circled_Latin_Capital_Letter_Q :
      constant Unicode_Char := 16#1F160#;
   Negative_Circled_Latin_Capital_Letter_R :
      constant Unicode_Char := 16#1F161#;
   Negative_Circled_Latin_Capital_Letter_S :
      constant Unicode_Char := 16#1F162#;
   Negative_Circled_Latin_Capital_Letter_T :
      constant Unicode_Char := 16#1F163#;
   Negative_Circled_Latin_Capital_Letter_U :
      constant Unicode_Char := 16#1F164#;
   Negative_Circled_Latin_Capital_Letter_V :
      constant Unicode_Char := 16#1F165#;
   Negative_Circled_Latin_Capital_Letter_W :
      constant Unicode_Char := 16#1F166#;
   Negative_Circled_Latin_Capital_Letter_X :
      constant Unicode_Char := 16#1F167#;
   Negative_Circled_Latin_Capital_Letter_Y :
      constant Unicode_Char := 16#1F168#;
   Negative_Circled_Latin_Capital_Letter_Z :
      constant Unicode_Char := 16#1F169#;
   Raised_Mc_Sign                          :
      constant Unicode_Char := 16#1F16A#;
   Raised_Md_Sign                          :
      constant Unicode_Char := 16#1F16B#;
   Negative_Squared_Latin_Capital_Letter_A :
      constant Unicode_Char := 16#1F170#;
   Negative_Squared_Latin_Capital_Letter_B :
      constant Unicode_Char := 16#1F171#;
   Negative_Squared_Latin_Capital_Letter_C :
      constant Unicode_Char := 16#1F172#;
   Negative_Squared_Latin_Capital_Letter_D :
      constant Unicode_Char := 16#1F173#;
   Negative_Squared_Latin_Capital_Letter_E :
      constant Unicode_Char := 16#1F174#;
   Negative_Squared_Latin_Capital_Letter_F :
      constant Unicode_Char := 16#1F175#;
   Negative_Squared_Latin_Capital_Letter_G :
      constant Unicode_Char := 16#1F176#;
   Negative_Squared_Latin_Capital_Letter_H :
      constant Unicode_Char := 16#1F177#;
   Negative_Squared_Latin_Capital_Letter_I :
      constant Unicode_Char := 16#1F178#;
   Negative_Squared_Latin_Capital_Letter_J :
      constant Unicode_Char := 16#1F179#;
   Negative_Squared_Latin_Capital_Letter_K :
      constant Unicode_Char := 16#1F17A#;
   Negative_Squared_Latin_Capital_Letter_L :
      constant Unicode_Char := 16#1F17B#;
   Negative_Squared_Latin_Capital_Letter_M :
      constant Unicode_Char := 16#1F17C#;
   Negative_Squared_Latin_Capital_Letter_N :
      constant Unicode_Char := 16#1F17D#;
   Negative_Squared_Latin_Capital_Letter_O :
      constant Unicode_Char := 16#1F17E#;
   Negative_Squared_Latin_Capital_Letter_P :
      constant Unicode_Char := 16#1F17F#;
   Negative_Squared_Latin_Capital_Letter_Q :
      constant Unicode_Char := 16#1F180#;
   Negative_Squared_Latin_Capital_Letter_R :
      constant Unicode_Char := 16#1F181#;
   Negative_Squared_Latin_Capital_Letter_S :
      constant Unicode_Char := 16#1F182#;
   Negative_Squared_Latin_Capital_Letter_T :
      constant Unicode_Char := 16#1F183#;
   Negative_Squared_Latin_Capital_Letter_U :
      constant Unicode_Char := 16#1F184#;
   Negative_Squared_Latin_Capital_Letter_V :
      constant Unicode_Char := 16#1F185#;
   Negative_Squared_Latin_Capital_Letter_W :
      constant Unicode_Char := 16#1F186#;
   Negative_Squared_Latin_Capital_Letter_X :
      constant Unicode_Char := 16#1F187#;
   Negative_Squared_Latin_Capital_Letter_Y :
      constant Unicode_Char := 16#1F188#;
   Negative_Squared_Latin_Capital_Letter_Z :
      constant Unicode_Char := 16#1F189#;
   Crossed_Negative_Squared_Latin_Capital_Letter_P :
      constant Unicode_Char := 16#1F18A#;
   Negative_Squared_Ic                     :
      constant Unicode_Char := 16#1F18B#;
   Negative_Squared_Pa                     :
      constant Unicode_Char := 16#1F18C#;
   Negative_Squared_Sa                     :
      constant Unicode_Char := 16#1F18D#;
   Negative_Squared_Ab                     :
      constant Unicode_Char := 16#1F18E#;
   Negative_Squared_Wc                     :
      constant Unicode_Char := 16#1F18F#;
   Square_Dj                               :
      constant Unicode_Char := 16#1F190#;
   Squared_Cl                              :
      constant Unicode_Char := 16#1F191#;
   Squared_Cool                            :
      constant Unicode_Char := 16#1F192#;
   Squared_Free                            :
      constant Unicode_Char := 16#1F193#;
   Squared_Id                              :
      constant Unicode_Char := 16#1F194#;
   Squared_New                             :
      constant Unicode_Char := 16#1F195#;
   Squared_Ng                              :
      constant Unicode_Char := 16#1F196#;
   Squared_Ok                              :
      constant Unicode_Char := 16#1F197#;
   Squared_Sos                             :
      constant Unicode_Char := 16#1F198#;
   Squared_Up_With_Exclamation_Mark        :
      constant Unicode_Char := 16#1F199#;
   Squared_Vs                              :
      constant Unicode_Char := 16#1F19A#;
   Regional_Indicator_Symbol_Letter_A      :
      constant Unicode_Char := 16#1F1E6#;
   Regional_Indicator_Symbol_Letter_B      :
      constant Unicode_Char := 16#1F1E7#;
   Regional_Indicator_Symbol_Letter_C      :
      constant Unicode_Char := 16#1F1E8#;
   Regional_Indicator_Symbol_Letter_D      :
      constant Unicode_Char := 16#1F1E9#;
   Regional_Indicator_Symbol_Letter_E      :
      constant Unicode_Char := 16#1F1EA#;
   Regional_Indicator_Symbol_Letter_F      :
      constant Unicode_Char := 16#1F1EB#;
   Regional_Indicator_Symbol_Letter_G      :
      constant Unicode_Char := 16#1F1EC#;
   Regional_Indicator_Symbol_Letter_H      :
      constant Unicode_Char := 16#1F1ED#;
   Regional_Indicator_Symbol_Letter_I      :
      constant Unicode_Char := 16#1F1EE#;
   Regional_Indicator_Symbol_Letter_J      :
      constant Unicode_Char := 16#1F1EF#;
   Regional_Indicator_Symbol_Letter_K      :
      constant Unicode_Char := 16#1F1F0#;
   Regional_Indicator_Symbol_Letter_L      :
      constant Unicode_Char := 16#1F1F1#;
   Regional_Indicator_Symbol_Letter_M      :
      constant Unicode_Char := 16#1F1F2#;
   Regional_Indicator_Symbol_Letter_N      :
      constant Unicode_Char := 16#1F1F3#;
   Regional_Indicator_Symbol_Letter_O      :
      constant Unicode_Char := 16#1F1F4#;
   Regional_Indicator_Symbol_Letter_P      :
      constant Unicode_Char := 16#1F1F5#;
   Regional_Indicator_Symbol_Letter_Q      :
      constant Unicode_Char := 16#1F1F6#;
   Regional_Indicator_Symbol_Letter_R      :
      constant Unicode_Char := 16#1F1F7#;
   Regional_Indicator_Symbol_Letter_S      :
      constant Unicode_Char := 16#1F1F8#;
   Regional_Indicator_Symbol_Letter_T      :
      constant Unicode_Char := 16#1F1F9#;
   Regional_Indicator_Symbol_Letter_U      :
      constant Unicode_Char := 16#1F1FA#;
   Regional_Indicator_Symbol_Letter_V      :
      constant Unicode_Char := 16#1F1FB#;
   Regional_Indicator_Symbol_Letter_W      :
      constant Unicode_Char := 16#1F1FC#;
   Regional_Indicator_Symbol_Letter_X      :
      constant Unicode_Char := 16#1F1FD#;
   Regional_Indicator_Symbol_Letter_Y      :
      constant Unicode_Char := 16#1F1FE#;
   Regional_Indicator_Symbol_Letter_Z      :
      constant Unicode_Char := 16#1F1FF#;
end Unicode.Names.Enclosed_Alphanum_Sup;
