--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Gujarati is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Gujarati_Sign_Candrabindu               : constant Unicode_Char := 16#0A81#;
   Gujarati_Sign_Anusvara                  : constant Unicode_Char := 16#0A82#;
   Gujarati_Sign_Visarga                   : constant Unicode_Char := 16#0A83#;
   Gujarati_Letter_A                       : constant Unicode_Char := 16#0A85#;
   Gujarati_Letter_Aa                      : constant Unicode_Char := 16#0A86#;
   Gujarati_Letter_I                       : constant Unicode_Char := 16#0A87#;
   Gujarati_Letter_Ii                      : constant Unicode_Char := 16#0A88#;
   Gujarati_Letter_U                       : constant Unicode_Char := 16#0A89#;
   Gujarati_Letter_Uu                      : constant Unicode_Char := 16#0A8A#;
   Gujarati_Letter_Vocalic_R               : constant Unicode_Char := 16#0A8B#;
   Gujarati_Letter_Vocalic_L               : constant Unicode_Char := 16#0A8C#;
   Gujarati_Vowel_Candra_E                 : constant Unicode_Char := 16#0A8D#;
   Gujarati_Letter_E                       : constant Unicode_Char := 16#0A8F#;
   Gujarati_Letter_Ai                      : constant Unicode_Char := 16#0A90#;
   Gujarati_Vowel_Candra_O                 : constant Unicode_Char := 16#0A91#;
   Gujarati_Letter_O                       : constant Unicode_Char := 16#0A93#;
   Gujarati_Letter_Au                      : constant Unicode_Char := 16#0A94#;
   Gujarati_Letter_Ka                      : constant Unicode_Char := 16#0A95#;
   Gujarati_Letter_Kha                     : constant Unicode_Char := 16#0A96#;
   Gujarati_Letter_Ga                      : constant Unicode_Char := 16#0A97#;
   Gujarati_Letter_Gha                     : constant Unicode_Char := 16#0A98#;
   Gujarati_Letter_Nga                     : constant Unicode_Char := 16#0A99#;
   Gujarati_Letter_Ca                      : constant Unicode_Char := 16#0A9A#;
   Gujarati_Letter_Cha                     : constant Unicode_Char := 16#0A9B#;
   Gujarati_Letter_Ja                      : constant Unicode_Char := 16#0A9C#;
   Gujarati_Letter_Jha                     : constant Unicode_Char := 16#0A9D#;
   Gujarati_Letter_Nya                     : constant Unicode_Char := 16#0A9E#;
   Gujarati_Letter_Tta                     : constant Unicode_Char := 16#0A9F#;
   Gujarati_Letter_Ttha                    : constant Unicode_Char := 16#0AA0#;
   Gujarati_Letter_Dda                     : constant Unicode_Char := 16#0AA1#;
   Gujarati_Letter_Ddha                    : constant Unicode_Char := 16#0AA2#;
   Gujarati_Letter_Nna                     : constant Unicode_Char := 16#0AA3#;
   Gujarati_Letter_Ta                      : constant Unicode_Char := 16#0AA4#;
   Gujarati_Letter_Tha                     : constant Unicode_Char := 16#0AA5#;
   Gujarati_Letter_Da                      : constant Unicode_Char := 16#0AA6#;
   Gujarati_Letter_Dha                     : constant Unicode_Char := 16#0AA7#;
   Gujarati_Letter_Na                      : constant Unicode_Char := 16#0AA8#;
   Gujarati_Letter_Pa                      : constant Unicode_Char := 16#0AAA#;
   Gujarati_Letter_Pha                     : constant Unicode_Char := 16#0AAB#;
   Gujarati_Letter_Ba                      : constant Unicode_Char := 16#0AAC#;
   Gujarati_Letter_Bha                     : constant Unicode_Char := 16#0AAD#;
   Gujarati_Letter_Ma                      : constant Unicode_Char := 16#0AAE#;
   Gujarati_Letter_Ya                      : constant Unicode_Char := 16#0AAF#;
   Gujarati_Letter_Ra                      : constant Unicode_Char := 16#0AB0#;
   Gujarati_Letter_La                      : constant Unicode_Char := 16#0AB2#;
   Gujarati_Letter_Lla                     : constant Unicode_Char := 16#0AB3#;
   Gujarati_Letter_Va                      : constant Unicode_Char := 16#0AB5#;
   Gujarati_Letter_Sha                     : constant Unicode_Char := 16#0AB6#;
   Gujarati_Letter_Ssa                     : constant Unicode_Char := 16#0AB7#;
   Gujarati_Letter_Sa                      : constant Unicode_Char := 16#0AB8#;
   Gujarati_Letter_Ha                      : constant Unicode_Char := 16#0AB9#;
   Gujarati_Sign_Nukta                     : constant Unicode_Char := 16#0ABC#;
   Gujarati_Sign_Avagraha                  : constant Unicode_Char := 16#0ABD#;
   Gujarati_Vowel_Sign_Aa                  : constant Unicode_Char := 16#0ABE#;
   Gujarati_Vowel_Sign_I                   : constant Unicode_Char := 16#0ABF#;
   Gujarati_Vowel_Sign_Ii                  : constant Unicode_Char := 16#0AC0#;
   Gujarati_Vowel_Sign_U                   : constant Unicode_Char := 16#0AC1#;
   Gujarati_Vowel_Sign_Uu                  : constant Unicode_Char := 16#0AC2#;
   Gujarati_Vowel_Sign_Vocalic_R           : constant Unicode_Char := 16#0AC3#;
   Gujarati_Vowel_Sign_Vocalic_Rr          : constant Unicode_Char := 16#0AC4#;
   Gujarati_Vowel_Sign_Candra_E            : constant Unicode_Char := 16#0AC5#;
   Gujarati_Vowel_Sign_E                   : constant Unicode_Char := 16#0AC7#;
   Gujarati_Vowel_Sign_Ai                  : constant Unicode_Char := 16#0AC8#;
   Gujarati_Vowel_Sign_Candra_O            : constant Unicode_Char := 16#0AC9#;
   Gujarati_Vowel_Sign_O                   : constant Unicode_Char := 16#0ACB#;
   Gujarati_Vowel_Sign_Au                  : constant Unicode_Char := 16#0ACC#;
   Gujarati_Sign_Virama                    : constant Unicode_Char := 16#0ACD#;
   Gujarati_Om                             : constant Unicode_Char := 16#0AD0#;
   Gujarati_Letter_Vocalic_Rr              : constant Unicode_Char := 16#0AE0#;
   Gujarati_Letter_Vocalic_Ll              : constant Unicode_Char := 16#0AE1#;
   Gujarati_Vowel_Sign_Vocalic_L           : constant Unicode_Char := 16#0AE2#;
   Gujarati_Vowel_Sign_Vocalic_Ll          : constant Unicode_Char := 16#0AE3#;
   Gujarati_Digit_Zero                     : constant Unicode_Char := 16#0AE6#;
   Gujarati_Digit_One                      : constant Unicode_Char := 16#0AE7#;
   Gujarati_Digit_Two                      : constant Unicode_Char := 16#0AE8#;
   Gujarati_Digit_Three                    : constant Unicode_Char := 16#0AE9#;
   Gujarati_Digit_Four                     : constant Unicode_Char := 16#0AEA#;
   Gujarati_Digit_Five                     : constant Unicode_Char := 16#0AEB#;
   Gujarati_Digit_Six                      : constant Unicode_Char := 16#0AEC#;
   Gujarati_Digit_Seven                    : constant Unicode_Char := 16#0AED#;
   Gujarati_Digit_Eight                    : constant Unicode_Char := 16#0AEE#;
   Gujarati_Digit_Nine                     : constant Unicode_Char := 16#0AEF#;
   Gujarati_Abbreviation_Sign              : constant Unicode_Char := 16#0AF0#;
   Gujarati_Rupee_Sign                     : constant Unicode_Char := 16#0AF1#;
   Gujarati_Letter_Zha                     : constant Unicode_Char := 16#0AF9#;
end Unicode.Names.Gujarati;
