--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Rumi_Numeral_Symbols is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Rumi_Digit_One                          :
      constant Unicode_Char := 16#10E60#;
   Rumi_Digit_Two                          :
      constant Unicode_Char := 16#10E61#;
   Rumi_Digit_Three                        :
      constant Unicode_Char := 16#10E62#;
   Rumi_Digit_Four                         :
      constant Unicode_Char := 16#10E63#;
   Rumi_Digit_Five                         :
      constant Unicode_Char := 16#10E64#;
   Rumi_Digit_Six                          :
      constant Unicode_Char := 16#10E65#;
   Rumi_Digit_Seven                        :
      constant Unicode_Char := 16#10E66#;
   Rumi_Digit_Eight                        :
      constant Unicode_Char := 16#10E67#;
   Rumi_Digit_Nine                         :
      constant Unicode_Char := 16#10E68#;
   Rumi_Number_Ten                         :
      constant Unicode_Char := 16#10E69#;
   Rumi_Number_Twenty                      :
      constant Unicode_Char := 16#10E6A#;
   Rumi_Number_Thirty                      :
      constant Unicode_Char := 16#10E6B#;
   Rumi_Number_Forty                       :
      constant Unicode_Char := 16#10E6C#;
   Rumi_Number_Fifty                       :
      constant Unicode_Char := 16#10E6D#;
   Rumi_Number_Sixty                       :
      constant Unicode_Char := 16#10E6E#;
   Rumi_Number_Seventy                     :
      constant Unicode_Char := 16#10E6F#;
   Rumi_Number_Eighty                      :
      constant Unicode_Char := 16#10E70#;
   Rumi_Number_Ninety                      :
      constant Unicode_Char := 16#10E71#;
   Rumi_Number_One_Hundred                 :
      constant Unicode_Char := 16#10E72#;
   Rumi_Number_Two_Hundred                 :
      constant Unicode_Char := 16#10E73#;
   Rumi_Number_Three_Hundred               :
      constant Unicode_Char := 16#10E74#;
   Rumi_Number_Four_Hundred                :
      constant Unicode_Char := 16#10E75#;
   Rumi_Number_Five_Hundred                :
      constant Unicode_Char := 16#10E76#;
   Rumi_Number_Six_Hundred                 :
      constant Unicode_Char := 16#10E77#;
   Rumi_Number_Seven_Hundred               :
      constant Unicode_Char := 16#10E78#;
   Rumi_Number_Eight_Hundred               :
      constant Unicode_Char := 16#10E79#;
   Rumi_Number_Nine_Hundred                :
      constant Unicode_Char := 16#10E7A#;
   Rumi_Fraction_One_Half                  :
      constant Unicode_Char := 16#10E7B#;
   Rumi_Fraction_One_Quarter               :
      constant Unicode_Char := 16#10E7C#;
   Rumi_Fraction_One_Third                 :
      constant Unicode_Char := 16#10E7D#;
   Rumi_Fraction_Two_Thirds                :
      constant Unicode_Char := 16#10E7E#;
end Unicode.Names.Rumi_Numeral_Symbols;
