--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Kannada is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Kannada_Sign_Candrabindu                : constant Unicode_Char := 16#0C81#;
   Kannada_Sign_Anusvara                   : constant Unicode_Char := 16#0C82#;
   Kannada_Sign_Visarga                    : constant Unicode_Char := 16#0C83#;
   Kannada_Letter_A                        : constant Unicode_Char := 16#0C85#;
   Kannada_Letter_Aa                       : constant Unicode_Char := 16#0C86#;
   Kannada_Letter_I                        : constant Unicode_Char := 16#0C87#;
   Kannada_Letter_Ii                       : constant Unicode_Char := 16#0C88#;
   Kannada_Letter_U                        : constant Unicode_Char := 16#0C89#;
   Kannada_Letter_Uu                       : constant Unicode_Char := 16#0C8A#;
   Kannada_Letter_Vocalic_R                : constant Unicode_Char := 16#0C8B#;
   Kannada_Letter_Vocalic_L                : constant Unicode_Char := 16#0C8C#;
   Kannada_Letter_E                        : constant Unicode_Char := 16#0C8E#;
   Kannada_Letter_Ee                       : constant Unicode_Char := 16#0C8F#;
   Kannada_Letter_Ai                       : constant Unicode_Char := 16#0C90#;
   Kannada_Letter_O                        : constant Unicode_Char := 16#0C92#;
   Kannada_Letter_Oo                       : constant Unicode_Char := 16#0C93#;
   Kannada_Letter_Au                       : constant Unicode_Char := 16#0C94#;
   Kannada_Letter_Ka                       : constant Unicode_Char := 16#0C95#;
   Kannada_Letter_Kha                      : constant Unicode_Char := 16#0C96#;
   Kannada_Letter_Ga                       : constant Unicode_Char := 16#0C97#;
   Kannada_Letter_Gha                      : constant Unicode_Char := 16#0C98#;
   Kannada_Letter_Nga                      : constant Unicode_Char := 16#0C99#;
   Kannada_Letter_Ca                       : constant Unicode_Char := 16#0C9A#;
   Kannada_Letter_Cha                      : constant Unicode_Char := 16#0C9B#;
   Kannada_Letter_Ja                       : constant Unicode_Char := 16#0C9C#;
   Kannada_Letter_Jha                      : constant Unicode_Char := 16#0C9D#;
   Kannada_Letter_Nya                      : constant Unicode_Char := 16#0C9E#;
   Kannada_Letter_Tta                      : constant Unicode_Char := 16#0C9F#;
   Kannada_Letter_Ttha                     : constant Unicode_Char := 16#0CA0#;
   Kannada_Letter_Dda                      : constant Unicode_Char := 16#0CA1#;
   Kannada_Letter_Ddha                     : constant Unicode_Char := 16#0CA2#;
   Kannada_Letter_Nna                      : constant Unicode_Char := 16#0CA3#;
   Kannada_Letter_Ta                       : constant Unicode_Char := 16#0CA4#;
   Kannada_Letter_Tha                      : constant Unicode_Char := 16#0CA5#;
   Kannada_Letter_Da                       : constant Unicode_Char := 16#0CA6#;
   Kannada_Letter_Dha                      : constant Unicode_Char := 16#0CA7#;
   Kannada_Letter_Na                       : constant Unicode_Char := 16#0CA8#;
   Kannada_Letter_Pa                       : constant Unicode_Char := 16#0CAA#;
   Kannada_Letter_Pha                      : constant Unicode_Char := 16#0CAB#;
   Kannada_Letter_Ba                       : constant Unicode_Char := 16#0CAC#;
   Kannada_Letter_Bha                      : constant Unicode_Char := 16#0CAD#;
   Kannada_Letter_Ma                       : constant Unicode_Char := 16#0CAE#;
   Kannada_Letter_Ya                       : constant Unicode_Char := 16#0CAF#;
   Kannada_Letter_Ra                       : constant Unicode_Char := 16#0CB0#;
   Kannada_Letter_Rra                      : constant Unicode_Char := 16#0CB1#;
   Kannada_Letter_La                       : constant Unicode_Char := 16#0CB2#;
   Kannada_Letter_Lla                      : constant Unicode_Char := 16#0CB3#;
   Kannada_Letter_Va                       : constant Unicode_Char := 16#0CB5#;
   Kannada_Letter_Sha                      : constant Unicode_Char := 16#0CB6#;
   Kannada_Letter_Ssa                      : constant Unicode_Char := 16#0CB7#;
   Kannada_Letter_Sa                       : constant Unicode_Char := 16#0CB8#;
   Kannada_Letter_Ha                       : constant Unicode_Char := 16#0CB9#;
   Kannada_Sign_Nukta                      : constant Unicode_Char := 16#0CBC#;
   Kannada_Sign_Avagraha                   : constant Unicode_Char := 16#0CBD#;
   Kannada_Vowel_Sign_Aa                   : constant Unicode_Char := 16#0CBE#;
   Kannada_Vowel_Sign_I                    : constant Unicode_Char := 16#0CBF#;
   Kannada_Vowel_Sign_Ii                   : constant Unicode_Char := 16#0CC0#;
   Kannada_Vowel_Sign_U                    : constant Unicode_Char := 16#0CC1#;
   Kannada_Vowel_Sign_Uu                   : constant Unicode_Char := 16#0CC2#;
   Kannada_Vowel_Sign_Vocalic_R            : constant Unicode_Char := 16#0CC3#;
   Kannada_Vowel_Sign_Vocalic_Rr           : constant Unicode_Char := 16#0CC4#;
   Kannada_Vowel_Sign_E                    : constant Unicode_Char := 16#0CC6#;
   Kannada_Vowel_Sign_Ee                   : constant Unicode_Char := 16#0CC7#;
   Kannada_Vowel_Sign_Ai                   : constant Unicode_Char := 16#0CC8#;
   Kannada_Vowel_Sign_O                    : constant Unicode_Char := 16#0CCA#;
   Kannada_Vowel_Sign_Oo                   : constant Unicode_Char := 16#0CCB#;
   Kannada_Vowel_Sign_Au                   : constant Unicode_Char := 16#0CCC#;
   Kannada_Sign_Virama                     : constant Unicode_Char := 16#0CCD#;
   Kannada_Length_Mark                     : constant Unicode_Char := 16#0CD5#;
   Kannada_Ai_Length_Mark                  : constant Unicode_Char := 16#0CD6#;
   Kannada_Letter_Fa                       : constant Unicode_Char := 16#0CDE#;
   Kannada_Letter_Llla                     :
      Unicode_Char renames Kannada_Letter_Fa;
   Kannada_Letter_Vocalic_Rr               : constant Unicode_Char := 16#0CE0#;
   Kannada_Letter_Vocalic_Ll               : constant Unicode_Char := 16#0CE1#;
   Kannada_Vowel_Sign_Vocalic_L            : constant Unicode_Char := 16#0CE2#;
   Kannada_Vowel_Sign_Vocalic_Ll           : constant Unicode_Char := 16#0CE3#;
   Kannada_Digit_Zero                      : constant Unicode_Char := 16#0CE6#;
   Kannada_Digit_One                       : constant Unicode_Char := 16#0CE7#;
   Kannada_Digit_Two                       : constant Unicode_Char := 16#0CE8#;
   Kannada_Digit_Three                     : constant Unicode_Char := 16#0CE9#;
   Kannada_Digit_Four                      : constant Unicode_Char := 16#0CEA#;
   Kannada_Digit_Five                      : constant Unicode_Char := 16#0CEB#;
   Kannada_Digit_Six                       : constant Unicode_Char := 16#0CEC#;
   Kannada_Digit_Seven                     : constant Unicode_Char := 16#0CED#;
   Kannada_Digit_Eight                     : constant Unicode_Char := 16#0CEE#;
   Kannada_Digit_Nine                      : constant Unicode_Char := 16#0CEF#;
   Kannada_Sign_Jihvamuliya                : constant Unicode_Char := 16#0CF1#;
   Kannada_Sign_Upadhmaniya                : constant Unicode_Char := 16#0CF2#;
end Unicode.Names.Kannada;
