--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Arabic is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Arabic_Number_Sign                      : constant Unicode_Char := 16#0600#;
   Arabic_Sign_Sanah                       : constant Unicode_Char := 16#0601#;
   Arabic_Footnote_Marker                  : constant Unicode_Char := 16#0602#;
   Arabic_Sign_Safha                       : constant Unicode_Char := 16#0603#;
   Arabic_Sign_Samvat                      : constant Unicode_Char := 16#0604#;
   Arabic_Number_Mark_Above                : constant Unicode_Char := 16#0605#;
   Arabic_Indic_Cube_Root                  : constant Unicode_Char := 16#0606#;
   Arabic_Indic_Fourth_Root                : constant Unicode_Char := 16#0607#;
   Arabic_Ray                              : constant Unicode_Char := 16#0608#;
   Arabic_Indic_Per_Mille_Sign             : constant Unicode_Char := 16#0609#;
   Arabic_Indic_Per_Ten_Thousand_Sign      : constant Unicode_Char := 16#060A#;
   Afghani_Sign                            : constant Unicode_Char := 16#060B#;
   Arabic_Comma                            : constant Unicode_Char := 16#060C#;
   Arabic_Date_Separator                   : constant Unicode_Char := 16#060D#;
   Arabic_Poetic_Verse_Sign                : constant Unicode_Char := 16#060E#;
   Arabic_Sign_Misra                       : constant Unicode_Char := 16#060F#;
   Arabic_Sign_Sallallahou_Alayhe_Wassallam :
      constant Unicode_Char := 16#0610#;
   Arabic_Sign_Alayhe_Assallam             : constant Unicode_Char := 16#0611#;
   Arabic_Sign_Rahmatullah_Alayhe          : constant Unicode_Char := 16#0612#;
   Arabic_Sign_Radi_Allahou_Anhu           : constant Unicode_Char := 16#0613#;
   Arabic_Sign_Takhallus                   : constant Unicode_Char := 16#0614#;
   Arabic_Small_High_Tah                   : constant Unicode_Char := 16#0615#;
   Arabic_Small_High_Ligature_Alef_With_Lam_With_Yeh :
      constant Unicode_Char := 16#0616#;
   Arabic_Small_High_Zain                  : constant Unicode_Char := 16#0617#;
   Arabic_Small_Fatha                      : constant Unicode_Char := 16#0618#;
   Arabic_Small_Damma                      : constant Unicode_Char := 16#0619#;
   Arabic_Small_Kasra                      : constant Unicode_Char := 16#061A#;
   Arabic_Semicolon                        : constant Unicode_Char := 16#061B#;
   Arabic_Letter_Mark                      : constant Unicode_Char := 16#061C#;
   Alm                                     :
      Unicode_Char renames Arabic_Letter_Mark;
   Arabic_Triple_Dot_Punctuation_Mark      : constant Unicode_Char := 16#061E#;
   Arabic_Question_Mark                    : constant Unicode_Char := 16#061F#;
   Arabic_Letter_Kashmiri_Yeh              : constant Unicode_Char := 16#0620#;
   Arabic_Letter_Hamza                     : constant Unicode_Char := 16#0621#;
   Arabic_Letter_Alef_With_Madda_Above     : constant Unicode_Char := 16#0622#;
   Arabic_Letter_Alef_With_Hamza_Above     : constant Unicode_Char := 16#0623#;
   Arabic_Letter_Waw_With_Hamza_Above      : constant Unicode_Char := 16#0624#;
   Arabic_Letter_Alef_With_Hamza_Below     : constant Unicode_Char := 16#0625#;
   Arabic_Letter_Yeh_With_Hamza_Above      : constant Unicode_Char := 16#0626#;
   Arabic_Letter_Alef                      : constant Unicode_Char := 16#0627#;
   Arabic_Letter_Beh                       : constant Unicode_Char := 16#0628#;
   Arabic_Letter_Teh_Marbuta               : constant Unicode_Char := 16#0629#;
   Arabic_Letter_Teh                       : constant Unicode_Char := 16#062A#;
   Arabic_Letter_Theh                      : constant Unicode_Char := 16#062B#;
   Arabic_Letter_Jeem                      : constant Unicode_Char := 16#062C#;
   Arabic_Letter_Hah                       : constant Unicode_Char := 16#062D#;
   Arabic_Letter_Khah                      : constant Unicode_Char := 16#062E#;
   Arabic_Letter_Dal                       : constant Unicode_Char := 16#062F#;
   Arabic_Letter_Thal                      : constant Unicode_Char := 16#0630#;
   Arabic_Letter_Reh                       : constant Unicode_Char := 16#0631#;
   Arabic_Letter_Zain                      : constant Unicode_Char := 16#0632#;
   Arabic_Letter_Seen                      : constant Unicode_Char := 16#0633#;
   Arabic_Letter_Sheen                     : constant Unicode_Char := 16#0634#;
   Arabic_Letter_Sad                       : constant Unicode_Char := 16#0635#;
   Arabic_Letter_Dad                       : constant Unicode_Char := 16#0636#;
   Arabic_Letter_Tah                       : constant Unicode_Char := 16#0637#;
   Arabic_Letter_Zah                       : constant Unicode_Char := 16#0638#;
   Arabic_Letter_Ain                       : constant Unicode_Char := 16#0639#;
   Arabic_Letter_Ghain                     : constant Unicode_Char := 16#063A#;
   Arabic_Letter_Keheh_With_Two_Dots_Above : constant Unicode_Char := 16#063B#;
   Arabic_Letter_Keheh_With_Three_Dots_Below :
      constant Unicode_Char := 16#063C#;
   Arabic_Letter_Farsi_Yeh_With_Inverted_V : constant Unicode_Char := 16#063D#;
   Arabic_Letter_Farsi_Yeh_With_Two_Dots_Above :
      constant Unicode_Char := 16#063E#;
   Arabic_Letter_Farsi_Yeh_With_Three_Dots_Above :
      constant Unicode_Char := 16#063F#;
   Arabic_Tatweel                          : constant Unicode_Char := 16#0640#;
   Arabic_Letter_Feh                       : constant Unicode_Char := 16#0641#;
   Arabic_Letter_Qaf                       : constant Unicode_Char := 16#0642#;
   Arabic_Letter_Kaf                       : constant Unicode_Char := 16#0643#;
   Arabic_Letter_Lam                       : constant Unicode_Char := 16#0644#;
   Arabic_Letter_Meem                      : constant Unicode_Char := 16#0645#;
   Arabic_Letter_Noon                      : constant Unicode_Char := 16#0646#;
   Arabic_Letter_Heh                       : constant Unicode_Char := 16#0647#;
   Arabic_Letter_Waw                       : constant Unicode_Char := 16#0648#;
   Arabic_Letter_Alef_Maksura              : constant Unicode_Char := 16#0649#;
   Arabic_Letter_Yeh                       : constant Unicode_Char := 16#064A#;
   Arabic_Fathatan                         : constant Unicode_Char := 16#064B#;
   Arabic_Dammatan                         : constant Unicode_Char := 16#064C#;
   Arabic_Kasratan                         : constant Unicode_Char := 16#064D#;
   Arabic_Fatha                            : constant Unicode_Char := 16#064E#;
   Arabic_Damma                            : constant Unicode_Char := 16#064F#;
   Arabic_Kasra                            : constant Unicode_Char := 16#0650#;
   Arabic_Shadda                           : constant Unicode_Char := 16#0651#;
   Arabic_Sukun                            : constant Unicode_Char := 16#0652#;
   Arabic_Maddah_Above                     : constant Unicode_Char := 16#0653#;
   Arabic_Hamza_Above                      : constant Unicode_Char := 16#0654#;
   Arabic_Hamza_Below                      : constant Unicode_Char := 16#0655#;
   Arabic_Subscript_Alef                   : constant Unicode_Char := 16#0656#;
   Arabic_Inverted_Damma                   : constant Unicode_Char := 16#0657#;
   Arabic_Mark_Noon_Ghunna                 : constant Unicode_Char := 16#0658#;
   Arabic_Zwarakay                         : constant Unicode_Char := 16#0659#;
   Arabic_Vowel_Sign_Small_V_Above         : constant Unicode_Char := 16#065A#;
   Arabic_Vowel_Sign_Inverted_Small_V_Above :
      constant Unicode_Char := 16#065B#;
   Arabic_Vowel_Sign_Dot_Below             : constant Unicode_Char := 16#065C#;
   Arabic_Reversed_Damma                   : constant Unicode_Char := 16#065D#;
   Arabic_Fatha_With_Two_Dots              : constant Unicode_Char := 16#065E#;
   Arabic_Wavy_Hamza_Below                 : constant Unicode_Char := 16#065F#;
   Arabic_Indic_Digit_Zero                 : constant Unicode_Char := 16#0660#;
   Arabic_Indic_Digit_One                  : constant Unicode_Char := 16#0661#;
   Arabic_Indic_Digit_Two                  : constant Unicode_Char := 16#0662#;
   Arabic_Indic_Digit_Three                : constant Unicode_Char := 16#0663#;
   Arabic_Indic_Digit_Four                 : constant Unicode_Char := 16#0664#;
   Arabic_Indic_Digit_Five                 : constant Unicode_Char := 16#0665#;
   Arabic_Indic_Digit_Six                  : constant Unicode_Char := 16#0666#;
   Arabic_Indic_Digit_Seven                : constant Unicode_Char := 16#0667#;
   Arabic_Indic_Digit_Eight                : constant Unicode_Char := 16#0668#;
   Arabic_Indic_Digit_Nine                 : constant Unicode_Char := 16#0669#;
   Arabic_Percent_Sign                     : constant Unicode_Char := 16#066A#;
   Arabic_Decimal_Separator                : constant Unicode_Char := 16#066B#;
   Arabic_Thousands_Separator              : constant Unicode_Char := 16#066C#;
   Arabic_Five_Pointed_Star                : constant Unicode_Char := 16#066D#;
   Arabic_Letter_Dotless_Beh               : constant Unicode_Char := 16#066E#;
   Arabic_Letter_Dotless_Qaf               : constant Unicode_Char := 16#066F#;
   Arabic_Letter_Superscript_Alef          : constant Unicode_Char := 16#0670#;
   Arabic_Letter_Alef_Wasla                : constant Unicode_Char := 16#0671#;
   Arabic_Letter_Alef_With_Wavy_Hamza_Above :
      constant Unicode_Char := 16#0672#;
   Arabic_Letter_Alef_With_Wavy_Hamza_Below :
      constant Unicode_Char := 16#0673#;
   Arabic_Letter_High_Hamza                : constant Unicode_Char := 16#0674#;
   Arabic_Letter_High_Hamza_Alef           : constant Unicode_Char := 16#0675#;
   Arabic_Letter_High_Hamza_Waw            : constant Unicode_Char := 16#0676#;
   Arabic_Letter_U_With_Hamza_Above        : constant Unicode_Char := 16#0677#;
   Arabic_Letter_High_Hamza_Yeh            : constant Unicode_Char := 16#0678#;
   Arabic_Letter_Tteh                      : constant Unicode_Char := 16#0679#;
   Arabic_Letter_Tteheh                    : constant Unicode_Char := 16#067A#;
   Arabic_Letter_Beeh                      : constant Unicode_Char := 16#067B#;
   Arabic_Letter_Teh_With_Ring             : constant Unicode_Char := 16#067C#;
   Arabic_Letter_Teh_With_Three_Dots_Above_Downwards :
      constant Unicode_Char := 16#067D#;
   Arabic_Letter_Peh                       : constant Unicode_Char := 16#067E#;
   Arabic_Letter_Teheh                     : constant Unicode_Char := 16#067F#;
   Arabic_Letter_Beheh                     : constant Unicode_Char := 16#0680#;
   Arabic_Letter_Hah_With_Hamza_Above      : constant Unicode_Char := 16#0681#;
   Arabic_Letter_Hah_With_Two_Dots_Vertical_Above :
      constant Unicode_Char := 16#0682#;
   Arabic_Letter_Nyeh                      : constant Unicode_Char := 16#0683#;
   Arabic_Letter_Dyeh                      : constant Unicode_Char := 16#0684#;
   Arabic_Letter_Hah_With_Three_Dots_Above : constant Unicode_Char := 16#0685#;
   Arabic_Letter_Tcheh                     : constant Unicode_Char := 16#0686#;
   Arabic_Letter_Tcheheh                   : constant Unicode_Char := 16#0687#;
   Arabic_Letter_Ddal                      : constant Unicode_Char := 16#0688#;
   Arabic_Letter_Dal_With_Ring             : constant Unicode_Char := 16#0689#;
   Arabic_Letter_Dal_With_Dot_Below        : constant Unicode_Char := 16#068A#;
   Arabic_Letter_Dal_With_Dot_Below_And_Small_Tah :
      constant Unicode_Char := 16#068B#;
   Arabic_Letter_Dahal                     : constant Unicode_Char := 16#068C#;
   Arabic_Letter_Ddahal                    : constant Unicode_Char := 16#068D#;
   Arabic_Letter_Dul                       : constant Unicode_Char := 16#068E#;
   Arabic_Letter_Dal_With_Three_Dots_Above_Downwards :
      constant Unicode_Char := 16#068F#;
   Arabic_Letter_Dal_With_Four_Dots_Above  : constant Unicode_Char := 16#0690#;
   Arabic_Letter_Rreh                      : constant Unicode_Char := 16#0691#;
   Arabic_Letter_Reh_With_Small_V          : constant Unicode_Char := 16#0692#;
   Arabic_Letter_Reh_With_Ring             : constant Unicode_Char := 16#0693#;
   Arabic_Letter_Reh_With_Dot_Below        : constant Unicode_Char := 16#0694#;
   Arabic_Letter_Reh_With_Small_V_Below    : constant Unicode_Char := 16#0695#;
   Arabic_Letter_Reh_With_Dot_Below_And_Dot_Above :
      constant Unicode_Char := 16#0696#;
   Arabic_Letter_Reh_With_Two_Dots_Above   : constant Unicode_Char := 16#0697#;
   Arabic_Letter_Jeh                       : constant Unicode_Char := 16#0698#;
   Arabic_Letter_Reh_With_Four_Dots_Above  : constant Unicode_Char := 16#0699#;
   Arabic_Letter_Seen_With_Dot_Below_And_Dot_Above :
      constant Unicode_Char := 16#069A#;
   Arabic_Letter_Seen_With_Three_Dots_Below :
      constant Unicode_Char := 16#069B#;
   Arabic_Letter_Seen_With_Three_Dots_Below_And_Three_Dots_Above :
      constant Unicode_Char := 16#069C#;
   Arabic_Letter_Sad_With_Two_Dots_Below   : constant Unicode_Char := 16#069D#;
   Arabic_Letter_Sad_With_Three_Dots_Above : constant Unicode_Char := 16#069E#;
   Arabic_Letter_Tah_With_Three_Dots_Above : constant Unicode_Char := 16#069F#;
   Arabic_Letter_Ain_With_Three_Dots_Above : constant Unicode_Char := 16#06A0#;
   Arabic_Letter_Dotless_Feh               : constant Unicode_Char := 16#06A1#;
   Arabic_Letter_Feh_With_Dot_Moved_Below  : constant Unicode_Char := 16#06A2#;
   Arabic_Letter_Feh_With_Dot_Below        : constant Unicode_Char := 16#06A3#;
   Arabic_Letter_Veh                       : constant Unicode_Char := 16#06A4#;
   Arabic_Letter_Feh_With_Three_Dots_Below : constant Unicode_Char := 16#06A5#;
   Arabic_Letter_Peheh                     : constant Unicode_Char := 16#06A6#;
   Arabic_Letter_Qaf_With_Dot_Above        : constant Unicode_Char := 16#06A7#;
   Arabic_Letter_Qaf_With_Three_Dots_Above : constant Unicode_Char := 16#06A8#;
   Arabic_Letter_Keheh                     : constant Unicode_Char := 16#06A9#;
   Arabic_Letter_Swash_Kaf                 : constant Unicode_Char := 16#06AA#;
   Arabic_Letter_Kaf_With_Ring             : constant Unicode_Char := 16#06AB#;
   Arabic_Letter_Kaf_With_Dot_Above        : constant Unicode_Char := 16#06AC#;
   Arabic_Letter_Ng                        : constant Unicode_Char := 16#06AD#;
   Arabic_Letter_Kaf_With_Three_Dots_Below : constant Unicode_Char := 16#06AE#;
   Arabic_Letter_Gaf                       : constant Unicode_Char := 16#06AF#;
   Arabic_Letter_Gaf_With_Ring             : constant Unicode_Char := 16#06B0#;
   Arabic_Letter_Ngoeh                     : constant Unicode_Char := 16#06B1#;
   Arabic_Letter_Gaf_With_Two_Dots_Below   : constant Unicode_Char := 16#06B2#;
   Arabic_Letter_Gueh                      : constant Unicode_Char := 16#06B3#;
   Arabic_Letter_Gaf_With_Three_Dots_Above : constant Unicode_Char := 16#06B4#;
   Arabic_Letter_Lam_With_Small_V          : constant Unicode_Char := 16#06B5#;
   Arabic_Letter_Lam_With_Dot_Above        : constant Unicode_Char := 16#06B6#;
   Arabic_Letter_Lam_With_Three_Dots_Above : constant Unicode_Char := 16#06B7#;
   Arabic_Letter_Lam_With_Three_Dots_Below : constant Unicode_Char := 16#06B8#;
   Arabic_Letter_Noon_With_Dot_Below       : constant Unicode_Char := 16#06B9#;
   Arabic_Letter_Noon_Ghunna               : constant Unicode_Char := 16#06BA#;
   Arabic_Letter_Rnoon                     : constant Unicode_Char := 16#06BB#;
   Arabic_Letter_Noon_With_Ring            : constant Unicode_Char := 16#06BC#;
   Arabic_Letter_Noon_With_Three_Dots_Above :
      constant Unicode_Char := 16#06BD#;
   Arabic_Letter_Heh_Doachashmee           : constant Unicode_Char := 16#06BE#;
   Arabic_Letter_Tcheh_With_Dot_Above      : constant Unicode_Char := 16#06BF#;
   Arabic_Letter_Heh_With_Yeh_Above        : constant Unicode_Char := 16#06C0#;
   Arabic_Letter_Heh_Goal                  : constant Unicode_Char := 16#06C1#;
   Arabic_Letter_Heh_Goal_With_Hamza_Above : constant Unicode_Char := 16#06C2#;
   Arabic_Letter_Teh_Marbuta_Goal          : constant Unicode_Char := 16#06C3#;
   Arabic_Letter_Waw_With_Ring             : constant Unicode_Char := 16#06C4#;
   Arabic_Letter_Kirghiz_Oe                : constant Unicode_Char := 16#06C5#;
   Arabic_Letter_Oe                        : constant Unicode_Char := 16#06C6#;
   Arabic_Letter_U                         : constant Unicode_Char := 16#06C7#;
   Arabic_Letter_Yu                        : constant Unicode_Char := 16#06C8#;
   Arabic_Letter_Kirghiz_Yu                : constant Unicode_Char := 16#06C9#;
   Arabic_Letter_Waw_With_Two_Dots_Above   : constant Unicode_Char := 16#06CA#;
   Arabic_Letter_Ve                        : constant Unicode_Char := 16#06CB#;
   Arabic_Letter_Farsi_Yeh                 : constant Unicode_Char := 16#06CC#;
   Arabic_Letter_Yeh_With_Tail             : constant Unicode_Char := 16#06CD#;
   Arabic_Letter_Yeh_With_Small_V          : constant Unicode_Char := 16#06CE#;
   Arabic_Letter_Waw_With_Dot_Above        : constant Unicode_Char := 16#06CF#;
   Arabic_Letter_E                         : constant Unicode_Char := 16#06D0#;
   Arabic_Letter_Yeh_With_Three_Dots_Below : constant Unicode_Char := 16#06D1#;
   Arabic_Letter_Yeh_Barree                : constant Unicode_Char := 16#06D2#;
   Arabic_Letter_Yeh_Barree_With_Hamza_Above :
      constant Unicode_Char := 16#06D3#;
   Arabic_Full_Stop                        : constant Unicode_Char := 16#06D4#;
   Arabic_Letter_Ae                        : constant Unicode_Char := 16#06D5#;
   Arabic_Small_High_Ligature_Sad_With_Lam_With_Alef_Maksura :
      constant Unicode_Char := 16#06D6#;
   Arabic_Small_High_Ligature_Qaf_With_Lam_With_Alef_Maksura :
      constant Unicode_Char := 16#06D7#;
   Arabic_Small_High_Meem_Initial_Form     : constant Unicode_Char := 16#06D8#;
   Arabic_Small_High_Lam_Alef              : constant Unicode_Char := 16#06D9#;
   Arabic_Small_High_Jeem                  : constant Unicode_Char := 16#06DA#;
   Arabic_Small_High_Three_Dots            : constant Unicode_Char := 16#06DB#;
   Arabic_Small_High_Seen                  : constant Unicode_Char := 16#06DC#;
   Arabic_End_Of_Ayah                      : constant Unicode_Char := 16#06DD#;
   Arabic_Start_Of_Rub_El_Hizb             : constant Unicode_Char := 16#06DE#;
   Arabic_Small_High_Rounded_Zero          : constant Unicode_Char := 16#06DF#;
   Arabic_Small_High_Upright_Rectangular_Zero :
      constant Unicode_Char := 16#06E0#;
   Arabic_Small_High_Dotless_Head_Of_Khah  : constant Unicode_Char := 16#06E1#;
   Arabic_Small_High_Meem_Isolated_Form    : constant Unicode_Char := 16#06E2#;
   Arabic_Small_Low_Seen                   : constant Unicode_Char := 16#06E3#;
   Arabic_Small_High_Madda                 : constant Unicode_Char := 16#06E4#;
   Arabic_Small_Waw                        : constant Unicode_Char := 16#06E5#;
   Arabic_Small_Yeh                        : constant Unicode_Char := 16#06E6#;
   Arabic_Small_High_Yeh                   : constant Unicode_Char := 16#06E7#;
   Arabic_Small_High_Noon                  : constant Unicode_Char := 16#06E8#;
   Arabic_Place_Of_Sajdah                  : constant Unicode_Char := 16#06E9#;
   Arabic_Empty_Centre_Low_Stop            : constant Unicode_Char := 16#06EA#;
   Arabic_Empty_Centre_High_Stop           : constant Unicode_Char := 16#06EB#;
   Arabic_Rounded_High_Stop_With_Filled_Centre :
      constant Unicode_Char := 16#06EC#;
   Arabic_Small_Low_Meem                   : constant Unicode_Char := 16#06ED#;
   Arabic_Letter_Dal_With_Inverted_V       : constant Unicode_Char := 16#06EE#;
   Arabic_Letter_Reh_With_Inverted_V       : constant Unicode_Char := 16#06EF#;
   Extended_Arabic_Indic_Digit_Zero        : constant Unicode_Char := 16#06F0#;
   Extended_Arabic_Indic_Digit_One         : constant Unicode_Char := 16#06F1#;
   Extended_Arabic_Indic_Digit_Two         : constant Unicode_Char := 16#06F2#;
   Extended_Arabic_Indic_Digit_Three       : constant Unicode_Char := 16#06F3#;
   Extended_Arabic_Indic_Digit_Four        : constant Unicode_Char := 16#06F4#;
   Extended_Arabic_Indic_Digit_Five        : constant Unicode_Char := 16#06F5#;
   Extended_Arabic_Indic_Digit_Six         : constant Unicode_Char := 16#06F6#;
   Extended_Arabic_Indic_Digit_Seven       : constant Unicode_Char := 16#06F7#;
   Extended_Arabic_Indic_Digit_Eight       : constant Unicode_Char := 16#06F8#;
   Extended_Arabic_Indic_Digit_Nine        : constant Unicode_Char := 16#06F9#;
   Arabic_Letter_Sheen_With_Dot_Below      : constant Unicode_Char := 16#06FA#;
   Arabic_Letter_Dad_With_Dot_Below        : constant Unicode_Char := 16#06FB#;
   Arabic_Letter_Ghain_With_Dot_Below      : constant Unicode_Char := 16#06FC#;
   Arabic_Sign_Sindhi_Ampersand            : constant Unicode_Char := 16#06FD#;
   Arabic_Sign_Sindhi_Postposition_Men     : constant Unicode_Char := 16#06FE#;
   Arabic_Letter_Heh_With_Inverted_V       : constant Unicode_Char := 16#06FF#;
end Unicode.Names.Arabic;
