--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Byzantine_Musical_Symbols is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Byzantine_Musical_Symbol_Psili          :
      constant Unicode_Char := 16#1D000#;
   Byzantine_Musical_Symbol_Daseia         :
      constant Unicode_Char := 16#1D001#;
   Byzantine_Musical_Symbol_Perispomeni    :
      constant Unicode_Char := 16#1D002#;
   Byzantine_Musical_Symbol_Oxeia_Ekfonitikon :
      constant Unicode_Char := 16#1D003#;
   Byzantine_Musical_Symbol_Oxeia_Dipli    :
      constant Unicode_Char := 16#1D004#;
   Byzantine_Musical_Symbol_Vareia_Ekfonitikon :
      constant Unicode_Char := 16#1D005#;
   Byzantine_Musical_Symbol_Vareia_Dipli   :
      constant Unicode_Char := 16#1D006#;
   Byzantine_Musical_Symbol_Kathisti       :
      constant Unicode_Char := 16#1D007#;
   Byzantine_Musical_Symbol_Syrmatiki      :
      constant Unicode_Char := 16#1D008#;
   Byzantine_Musical_Symbol_Paraklitiki    :
      constant Unicode_Char := 16#1D009#;
   Byzantine_Musical_Symbol_Ypokrisis      :
      constant Unicode_Char := 16#1D00A#;
   Byzantine_Musical_Symbol_Ypokrisis_Dipli :
      constant Unicode_Char := 16#1D00B#;
   Byzantine_Musical_Symbol_Kremasti       :
      constant Unicode_Char := 16#1D00C#;
   Byzantine_Musical_Symbol_Apeso_Ekfonitikon :
      constant Unicode_Char := 16#1D00D#;
   Byzantine_Musical_Symbol_Exo_Ekfonitikon :
      constant Unicode_Char := 16#1D00E#;
   Byzantine_Musical_Symbol_Teleia         :
      constant Unicode_Char := 16#1D00F#;
   Byzantine_Musical_Symbol_Kentimata      :
      constant Unicode_Char := 16#1D010#;
   Byzantine_Musical_Symbol_Apostrofos     :
      constant Unicode_Char := 16#1D011#;
   Byzantine_Musical_Symbol_Apostrofos_Dipli :
      constant Unicode_Char := 16#1D012#;
   Byzantine_Musical_Symbol_Synevma        :
      constant Unicode_Char := 16#1D013#;
   Byzantine_Musical_Symbol_Thita          :
      constant Unicode_Char := 16#1D014#;
   Byzantine_Musical_Symbol_Oligon_Archaion :
      constant Unicode_Char := 16#1D015#;
   Byzantine_Musical_Symbol_Gorgon_Archaion :
      constant Unicode_Char := 16#1D016#;
   Byzantine_Musical_Symbol_Psilon         :
      constant Unicode_Char := 16#1D017#;
   Byzantine_Musical_Symbol_Chamilon       :
      constant Unicode_Char := 16#1D018#;
   Byzantine_Musical_Symbol_Vathy          :
      constant Unicode_Char := 16#1D019#;
   Byzantine_Musical_Symbol_Ison_Archaion  :
      constant Unicode_Char := 16#1D01A#;
   Byzantine_Musical_Symbol_Kentima_Archaion :
      constant Unicode_Char := 16#1D01B#;
   Byzantine_Musical_Symbol_Kentimata_Archaion :
      constant Unicode_Char := 16#1D01C#;
   Byzantine_Musical_Symbol_Saximata       :
      constant Unicode_Char := 16#1D01D#;
   Byzantine_Musical_Symbol_Parichon       :
      constant Unicode_Char := 16#1D01E#;
   Byzantine_Musical_Symbol_Stavros_Apodexia :
      constant Unicode_Char := 16#1D01F#;
   Byzantine_Musical_Symbol_Oxeiai_Archaion :
      constant Unicode_Char := 16#1D020#;
   Byzantine_Musical_Symbol_Vareiai_Archaion :
      constant Unicode_Char := 16#1D021#;
   Byzantine_Musical_Symbol_Apoderma_Archaion :
      constant Unicode_Char := 16#1D022#;
   Byzantine_Musical_Symbol_Apothema       :
      constant Unicode_Char := 16#1D023#;
   Byzantine_Musical_Symbol_Klasma         :
      constant Unicode_Char := 16#1D024#;
   Byzantine_Musical_Symbol_Revma          :
      constant Unicode_Char := 16#1D025#;
   Byzantine_Musical_Symbol_Piasma_Archaion :
      constant Unicode_Char := 16#1D026#;
   Byzantine_Musical_Symbol_Tinagma        :
      constant Unicode_Char := 16#1D027#;
   Byzantine_Musical_Symbol_Anatrichisma   :
      constant Unicode_Char := 16#1D028#;
   Byzantine_Musical_Symbol_Seisma         :
      constant Unicode_Char := 16#1D029#;
   Byzantine_Musical_Symbol_Synagma_Archaion :
      constant Unicode_Char := 16#1D02A#;
   Byzantine_Musical_Symbol_Synagma_Meta_Stavrou :
      constant Unicode_Char := 16#1D02B#;
   Byzantine_Musical_Symbol_Oyranisma_Archaion :
      constant Unicode_Char := 16#1D02C#;
   Byzantine_Musical_Symbol_Thema          :
      constant Unicode_Char := 16#1D02D#;
   Byzantine_Musical_Symbol_Lemoi          :
      constant Unicode_Char := 16#1D02E#;
   Byzantine_Musical_Symbol_Dyo            :
      constant Unicode_Char := 16#1D02F#;
   Byzantine_Musical_Symbol_Tria           :
      constant Unicode_Char := 16#1D030#;
   Byzantine_Musical_Symbol_Tessera        :
      constant Unicode_Char := 16#1D031#;
   Byzantine_Musical_Symbol_Kratimata      :
      constant Unicode_Char := 16#1D032#;
   Byzantine_Musical_Symbol_Apeso_Exo_Neo  :
      constant Unicode_Char := 16#1D033#;
   Byzantine_Musical_Symbol_Fthora_Archaion :
      constant Unicode_Char := 16#1D034#;
   Byzantine_Musical_Symbol_Imifthora      :
      constant Unicode_Char := 16#1D035#;
   Byzantine_Musical_Symbol_Tromikon_Archaion :
      constant Unicode_Char := 16#1D036#;
   Byzantine_Musical_Symbol_Katava_Tromikon :
      constant Unicode_Char := 16#1D037#;
   Byzantine_Musical_Symbol_Pelaston       :
      constant Unicode_Char := 16#1D038#;
   Byzantine_Musical_Symbol_Psifiston      :
      constant Unicode_Char := 16#1D039#;
   Byzantine_Musical_Symbol_Kontevma       :
      constant Unicode_Char := 16#1D03A#;
   Byzantine_Musical_Symbol_Chorevma_Archaion :
      constant Unicode_Char := 16#1D03B#;
   Byzantine_Musical_Symbol_Rapisma        :
      constant Unicode_Char := 16#1D03C#;
   Byzantine_Musical_Symbol_Parakalesma_Archaion :
      constant Unicode_Char := 16#1D03D#;
   Byzantine_Musical_Symbol_Paraklitiki_Archaion :
      constant Unicode_Char := 16#1D03E#;
   Byzantine_Musical_Symbol_Ichadin        :
      constant Unicode_Char := 16#1D03F#;
   Byzantine_Musical_Symbol_Nana           :
      constant Unicode_Char := 16#1D040#;
   Byzantine_Musical_Symbol_Petasma        :
      constant Unicode_Char := 16#1D041#;
   Byzantine_Musical_Symbol_Kontevma_Allo  :
      constant Unicode_Char := 16#1D042#;
   Byzantine_Musical_Symbol_Tromikon_Allo  :
      constant Unicode_Char := 16#1D043#;
   Byzantine_Musical_Symbol_Straggismata   :
      constant Unicode_Char := 16#1D044#;
   Byzantine_Musical_Symbol_Gronthismata   :
      constant Unicode_Char := 16#1D045#;
   Byzantine_Musical_Symbol_Ison_Neo       :
      constant Unicode_Char := 16#1D046#;
   Byzantine_Musical_Symbol_Oligon_Neo     :
      constant Unicode_Char := 16#1D047#;
   Byzantine_Musical_Symbol_Oxeia_Neo      :
      constant Unicode_Char := 16#1D048#;
   Byzantine_Musical_Symbol_Petasti        :
      constant Unicode_Char := 16#1D049#;
   Byzantine_Musical_Symbol_Koufisma       :
      constant Unicode_Char := 16#1D04A#;
   Byzantine_Musical_Symbol_Petastokoufisma :
      constant Unicode_Char := 16#1D04B#;
   Byzantine_Musical_Symbol_Kratimokoufisma :
      constant Unicode_Char := 16#1D04C#;
   Byzantine_Musical_Symbol_Pelaston_Neo   :
      constant Unicode_Char := 16#1D04D#;
   Byzantine_Musical_Symbol_Kentimata_Neo_Ano :
      constant Unicode_Char := 16#1D04E#;
   Byzantine_Musical_Symbol_Kentima_Neo_Ano :
      constant Unicode_Char := 16#1D04F#;
   Byzantine_Musical_Symbol_Ypsili         :
      constant Unicode_Char := 16#1D050#;
   Byzantine_Musical_Symbol_Apostrofos_Neo :
      constant Unicode_Char := 16#1D051#;
   Byzantine_Musical_Symbol_Apostrofoi_Syndesmos_Neo :
      constant Unicode_Char := 16#1D052#;
   Byzantine_Musical_Symbol_Yporroi        :
      constant Unicode_Char := 16#1D053#;
   Byzantine_Musical_Symbol_Kratimoyporroon :
      constant Unicode_Char := 16#1D054#;
   Byzantine_Musical_Symbol_Elafron        :
      constant Unicode_Char := 16#1D055#;
   Byzantine_Musical_Symbol_Chamili        :
      constant Unicode_Char := 16#1D056#;
   Byzantine_Musical_Symbol_Mikron_Ison    :
      constant Unicode_Char := 16#1D057#;
   Byzantine_Musical_Symbol_Vareia_Neo     :
      constant Unicode_Char := 16#1D058#;
   Byzantine_Musical_Symbol_Piasma_Neo     :
      constant Unicode_Char := 16#1D059#;
   Byzantine_Musical_Symbol_Psifiston_Neo  :
      constant Unicode_Char := 16#1D05A#;
   Byzantine_Musical_Symbol_Omalon         :
      constant Unicode_Char := 16#1D05B#;
   Byzantine_Musical_Symbol_Antikenoma     :
      constant Unicode_Char := 16#1D05C#;
   Byzantine_Musical_Symbol_Lygisma        :
      constant Unicode_Char := 16#1D05D#;
   Byzantine_Musical_Symbol_Paraklitiki_Neo :
      constant Unicode_Char := 16#1D05E#;
   Byzantine_Musical_Symbol_Parakalesma_Neo :
      constant Unicode_Char := 16#1D05F#;
   Byzantine_Musical_Symbol_Eteron_Parakalesma :
      constant Unicode_Char := 16#1D060#;
   Byzantine_Musical_Symbol_Kylisma        :
      constant Unicode_Char := 16#1D061#;
   Byzantine_Musical_Symbol_Antikenokylisma :
      constant Unicode_Char := 16#1D062#;
   Byzantine_Musical_Symbol_Tromikon_Neo   :
      constant Unicode_Char := 16#1D063#;
   Byzantine_Musical_Symbol_Ekstrepton     :
      constant Unicode_Char := 16#1D064#;
   Byzantine_Musical_Symbol_Synagma_Neo    :
      constant Unicode_Char := 16#1D065#;
   Byzantine_Musical_Symbol_Syrma          :
      constant Unicode_Char := 16#1D066#;
   Byzantine_Musical_Symbol_Chorevma_Neo   :
      constant Unicode_Char := 16#1D067#;
   Byzantine_Musical_Symbol_Epegerma       :
      constant Unicode_Char := 16#1D068#;
   Byzantine_Musical_Symbol_Seisma_Neo     :
      constant Unicode_Char := 16#1D069#;
   Byzantine_Musical_Symbol_Xiron_Klasma   :
      constant Unicode_Char := 16#1D06A#;
   Byzantine_Musical_Symbol_Tromikopsifiston :
      constant Unicode_Char := 16#1D06B#;
   Byzantine_Musical_Symbol_Psifistolygisma :
      constant Unicode_Char := 16#1D06C#;
   Byzantine_Musical_Symbol_Tromikolygisma :
      constant Unicode_Char := 16#1D06D#;
   Byzantine_Musical_Symbol_Tromikoparakalesma :
      constant Unicode_Char := 16#1D06E#;
   Byzantine_Musical_Symbol_Psifistoparakalesma :
      constant Unicode_Char := 16#1D06F#;
   Byzantine_Musical_Symbol_Tromikosynagma :
      constant Unicode_Char := 16#1D070#;
   Byzantine_Musical_Symbol_Psifistosynagma :
      constant Unicode_Char := 16#1D071#;
   Byzantine_Musical_Symbol_Gorgosyntheton :
      constant Unicode_Char := 16#1D072#;
   Byzantine_Musical_Symbol_Argosyntheton  :
      constant Unicode_Char := 16#1D073#;
   Byzantine_Musical_Symbol_Eteron_Argosyntheton :
      constant Unicode_Char := 16#1D074#;
   Byzantine_Musical_Symbol_Oyranisma_Neo  :
      constant Unicode_Char := 16#1D075#;
   Byzantine_Musical_Symbol_Thematismos_Eso :
      constant Unicode_Char := 16#1D076#;
   Byzantine_Musical_Symbol_Thematismos_Exo :
      constant Unicode_Char := 16#1D077#;
   Byzantine_Musical_Symbol_Thema_Aploun   :
      constant Unicode_Char := 16#1D078#;
   Byzantine_Musical_Symbol_Thes_Kai_Apothes :
      constant Unicode_Char := 16#1D079#;
   Byzantine_Musical_Symbol_Katavasma      :
      constant Unicode_Char := 16#1D07A#;
   Byzantine_Musical_Symbol_Endofonon      :
      constant Unicode_Char := 16#1D07B#;
   Byzantine_Musical_Symbol_Yfen_Kato      :
      constant Unicode_Char := 16#1D07C#;
   Byzantine_Musical_Symbol_Yfen_Ano       :
      constant Unicode_Char := 16#1D07D#;
   Byzantine_Musical_Symbol_Stavros        :
      constant Unicode_Char := 16#1D07E#;
   Byzantine_Musical_Symbol_Klasma_Ano     :
      constant Unicode_Char := 16#1D07F#;
   Byzantine_Musical_Symbol_Dipli_Archaion :
      constant Unicode_Char := 16#1D080#;
   Byzantine_Musical_Symbol_Kratima_Archaion :
      constant Unicode_Char := 16#1D081#;
   Byzantine_Musical_Symbol_Kratima_Allo   :
      constant Unicode_Char := 16#1D082#;
   Byzantine_Musical_Symbol_Kratima_Neo    :
      constant Unicode_Char := 16#1D083#;
   Byzantine_Musical_Symbol_Apoderma_Neo   :
      constant Unicode_Char := 16#1D084#;
   Byzantine_Musical_Symbol_Apli           :
      constant Unicode_Char := 16#1D085#;
   Byzantine_Musical_Symbol_Dipli          :
      constant Unicode_Char := 16#1D086#;
   Byzantine_Musical_Symbol_Tripli         :
      constant Unicode_Char := 16#1D087#;
   Byzantine_Musical_Symbol_Tetrapli       :
      constant Unicode_Char := 16#1D088#;
   Byzantine_Musical_Symbol_Koronis        :
      constant Unicode_Char := 16#1D089#;
   Byzantine_Musical_Symbol_Leimma_Enos_Chronou :
      constant Unicode_Char := 16#1D08A#;
   Byzantine_Musical_Symbol_Leimma_Dyo_Chronon :
      constant Unicode_Char := 16#1D08B#;
   Byzantine_Musical_Symbol_Leimma_Trion_Chronon :
      constant Unicode_Char := 16#1D08C#;
   Byzantine_Musical_Symbol_Leimma_Tessaron_Chronon :
      constant Unicode_Char := 16#1D08D#;
   Byzantine_Musical_Symbol_Leimma_Imiseos_Chronou :
      constant Unicode_Char := 16#1D08E#;
   Byzantine_Musical_Symbol_Gorgon_Neo_Ano :
      constant Unicode_Char := 16#1D08F#;
   Byzantine_Musical_Symbol_Gorgon_Parestigmenon_Aristera :
      constant Unicode_Char := 16#1D090#;
   Byzantine_Musical_Symbol_Gorgon_Parestigmenon_Dexia :
      constant Unicode_Char := 16#1D091#;
   Byzantine_Musical_Symbol_Digorgon       :
      constant Unicode_Char := 16#1D092#;
   Byzantine_Musical_Symbol_Digorgon_Parestigmenon_Aristera_Kato :
      constant Unicode_Char := 16#1D093#;
   Byzantine_Musical_Symbol_Digorgon_Parestigmenon_Aristera_Ano :
      constant Unicode_Char := 16#1D094#;
   Byzantine_Musical_Symbol_Digorgon_Parestigmenon_Dexia :
      constant Unicode_Char := 16#1D095#;
   Byzantine_Musical_Symbol_Trigorgon      :
      constant Unicode_Char := 16#1D096#;
   Byzantine_Musical_Symbol_Argon          :
      constant Unicode_Char := 16#1D097#;
   Byzantine_Musical_Symbol_Imidiargon     :
      constant Unicode_Char := 16#1D098#;
   Byzantine_Musical_Symbol_Diargon        :
      constant Unicode_Char := 16#1D099#;
   Byzantine_Musical_Symbol_Agogi_Poli_Argi :
      constant Unicode_Char := 16#1D09A#;
   Byzantine_Musical_Symbol_Agogi_Argoteri :
      constant Unicode_Char := 16#1D09B#;
   Byzantine_Musical_Symbol_Agogi_Argi     :
      constant Unicode_Char := 16#1D09C#;
   Byzantine_Musical_Symbol_Agogi_Metria   :
      constant Unicode_Char := 16#1D09D#;
   Byzantine_Musical_Symbol_Agogi_Mesi     :
      constant Unicode_Char := 16#1D09E#;
   Byzantine_Musical_Symbol_Agogi_Gorgi    :
      constant Unicode_Char := 16#1D09F#;
   Byzantine_Musical_Symbol_Agogi_Gorgoteri :
      constant Unicode_Char := 16#1D0A0#;
   Byzantine_Musical_Symbol_Agogi_Poli_Gorgi :
      constant Unicode_Char := 16#1D0A1#;
   Byzantine_Musical_Symbol_Martyria_Protos_Ichos :
      constant Unicode_Char := 16#1D0A2#;
   Byzantine_Musical_Symbol_Martyria_Alli_Protos_Ichos :
      constant Unicode_Char := 16#1D0A3#;
   Byzantine_Musical_Symbol_Martyria_Deyteros_Ichos :
      constant Unicode_Char := 16#1D0A4#;
   Byzantine_Musical_Symbol_Martyria_Alli_Deyteros_Ichos :
      constant Unicode_Char := 16#1D0A5#;
   Byzantine_Musical_Symbol_Martyria_Tritos_Ichos :
      constant Unicode_Char := 16#1D0A6#;
   Byzantine_Musical_Symbol_Martyria_Trifonias :
      constant Unicode_Char := 16#1D0A7#;
   Byzantine_Musical_Symbol_Martyria_Tetartos_Ichos :
      constant Unicode_Char := 16#1D0A8#;
   Byzantine_Musical_Symbol_Martyria_Tetartos_Legetos_Ichos :
      constant Unicode_Char := 16#1D0A9#;
   Byzantine_Musical_Symbol_Martyria_Legetos_Ichos :
      constant Unicode_Char := 16#1D0AA#;
   Byzantine_Musical_Symbol_Martyria_Plagios_Ichos :
      constant Unicode_Char := 16#1D0AB#;
   Byzantine_Musical_Symbol_Isakia_Telous_Ichimatos :
      constant Unicode_Char := 16#1D0AC#;
   Byzantine_Musical_Symbol_Apostrofoi_Telous_Ichimatos :
      constant Unicode_Char := 16#1D0AD#;
   Byzantine_Musical_Symbol_Fanerosis_Tetrafonias :
      constant Unicode_Char := 16#1D0AE#;
   Byzantine_Musical_Symbol_Fanerosis_Monofonias :
      constant Unicode_Char := 16#1D0AF#;
   Byzantine_Musical_Symbol_Fanerosis_Difonias :
      constant Unicode_Char := 16#1D0B0#;
   Byzantine_Musical_Symbol_Martyria_Varys_Ichos :
      constant Unicode_Char := 16#1D0B1#;
   Byzantine_Musical_Symbol_Martyria_Protovarys_Ichos :
      constant Unicode_Char := 16#1D0B2#;
   Byzantine_Musical_Symbol_Martyria_Plagios_Tetartos_Ichos :
      constant Unicode_Char := 16#1D0B3#;
   Byzantine_Musical_Symbol_Gorthmikon_N_Aploun :
      constant Unicode_Char := 16#1D0B4#;
   Byzantine_Musical_Symbol_Gorthmikon_N_Diploun :
      constant Unicode_Char := 16#1D0B5#;
   Byzantine_Musical_Symbol_Enarxis_Kai_Fthora_Vou :
      constant Unicode_Char := 16#1D0B6#;
   Byzantine_Musical_Symbol_Imifonon       :
      constant Unicode_Char := 16#1D0B7#;
   Byzantine_Musical_Symbol_Imifthoron     :
      constant Unicode_Char := 16#1D0B8#;
   Byzantine_Musical_Symbol_Fthora_Archaion_Deyterou_Ichou :
      constant Unicode_Char := 16#1D0B9#;
   Byzantine_Musical_Symbol_Fthora_Diatoniki_Pa :
      constant Unicode_Char := 16#1D0BA#;
   Byzantine_Musical_Symbol_Fthora_Diatoniki_Nana :
      constant Unicode_Char := 16#1D0BB#;
   Byzantine_Musical_Symbol_Fthora_Naos_Ichos :
      constant Unicode_Char := 16#1D0BC#;
   Byzantine_Musical_Symbol_Fthora_Diatoniki_Di :
      constant Unicode_Char := 16#1D0BD#;
   Byzantine_Musical_Symbol_Fthora_Skliron_Diatonon_Di :
      constant Unicode_Char := 16#1D0BE#;
   Byzantine_Musical_Symbol_Fthora_Diatoniki_Ke :
      constant Unicode_Char := 16#1D0BF#;
   Byzantine_Musical_Symbol_Fthora_Diatoniki_Zo :
      constant Unicode_Char := 16#1D0C0#;
   Byzantine_Musical_Symbol_Fthora_Diatoniki_Ni_Kato :
      constant Unicode_Char := 16#1D0C1#;
   Byzantine_Musical_Symbol_Fthora_Diatoniki_Ni_Ano :
      constant Unicode_Char := 16#1D0C2#;
   Byzantine_Musical_Symbol_Fthora_Malakon_Chroma_Difonias :
      constant Unicode_Char := 16#1D0C3#;
   Byzantine_Musical_Symbol_Fthora_Malakon_Chroma_Monofonias :
      constant Unicode_Char := 16#1D0C4#;
   Byzantine_Musical_Symbol_Fhtora_Skliron_Chroma_Vasis :
      constant Unicode_Char := 16#1D0C5#;
   Byzantine_Musical_Symbol_Fthora_Skliron_Chroma_Vasis :
      Unicode_Char renames Byzantine_Musical_Symbol_Fhtora_Skliron_Chroma_Vasis;
   Byzantine_Musical_Symbol_Fthora_Skliron_Chroma_Synafi :
      constant Unicode_Char := 16#1D0C6#;
   Byzantine_Musical_Symbol_Fthora_Nenano  :
      constant Unicode_Char := 16#1D0C7#;
   Byzantine_Musical_Symbol_Chroa_Zygos    :
      constant Unicode_Char := 16#1D0C8#;
   Byzantine_Musical_Symbol_Chroa_Kliton   :
      constant Unicode_Char := 16#1D0C9#;
   Byzantine_Musical_Symbol_Chroa_Spathi   :
      constant Unicode_Char := 16#1D0CA#;
   Byzantine_Musical_Symbol_Fthora_I_Yfesis_Tetartimorion :
      constant Unicode_Char := 16#1D0CB#;
   Byzantine_Musical_Symbol_Fthora_Enarmonios_Antifonia :
      constant Unicode_Char := 16#1D0CC#;
   Byzantine_Musical_Symbol_Yfesis_Tritimorion :
      constant Unicode_Char := 16#1D0CD#;
   Byzantine_Musical_Symbol_Diesis_Tritimorion :
      constant Unicode_Char := 16#1D0CE#;
   Byzantine_Musical_Symbol_Diesis_Tetartimorion :
      constant Unicode_Char := 16#1D0CF#;
   Byzantine_Musical_Symbol_Diesis_Apli_Dyo_Dodekata :
      constant Unicode_Char := 16#1D0D0#;
   Byzantine_Musical_Symbol_Diesis_Monogrammos_Tessera_Dodekata :
      constant Unicode_Char := 16#1D0D1#;
   Byzantine_Musical_Symbol_Diesis_Digrammos_Ex_Dodekata :
      constant Unicode_Char := 16#1D0D2#;
   Byzantine_Musical_Symbol_Diesis_Trigrammos_Okto_Dodekata :
      constant Unicode_Char := 16#1D0D3#;
   Byzantine_Musical_Symbol_Yfesis_Apli_Dyo_Dodekata :
      constant Unicode_Char := 16#1D0D4#;
   Byzantine_Musical_Symbol_Yfesis_Monogrammos_Tessera_Dodekata :
      constant Unicode_Char := 16#1D0D5#;
   Byzantine_Musical_Symbol_Yfesis_Digrammos_Ex_Dodekata :
      constant Unicode_Char := 16#1D0D6#;
   Byzantine_Musical_Symbol_Yfesis_Trigrammos_Okto_Dodekata :
      constant Unicode_Char := 16#1D0D7#;
   Byzantine_Musical_Symbol_Geniki_Diesis  :
      constant Unicode_Char := 16#1D0D8#;
   Byzantine_Musical_Symbol_Geniki_Yfesis  :
      constant Unicode_Char := 16#1D0D9#;
   Byzantine_Musical_Symbol_Diastoli_Apli_Mikri :
      constant Unicode_Char := 16#1D0DA#;
   Byzantine_Musical_Symbol_Diastoli_Apli_Megali :
      constant Unicode_Char := 16#1D0DB#;
   Byzantine_Musical_Symbol_Diastoli_Dipli :
      constant Unicode_Char := 16#1D0DC#;
   Byzantine_Musical_Symbol_Diastoli_Theseos :
      constant Unicode_Char := 16#1D0DD#;
   Byzantine_Musical_Symbol_Simansis_Theseos :
      constant Unicode_Char := 16#1D0DE#;
   Byzantine_Musical_Symbol_Simansis_Theseos_Disimou :
      constant Unicode_Char := 16#1D0DF#;
   Byzantine_Musical_Symbol_Simansis_Theseos_Trisimou :
      constant Unicode_Char := 16#1D0E0#;
   Byzantine_Musical_Symbol_Simansis_Theseos_Tetrasimou :
      constant Unicode_Char := 16#1D0E1#;
   Byzantine_Musical_Symbol_Simansis_Arseos :
      constant Unicode_Char := 16#1D0E2#;
   Byzantine_Musical_Symbol_Simansis_Arseos_Disimou :
      constant Unicode_Char := 16#1D0E3#;
   Byzantine_Musical_Symbol_Simansis_Arseos_Trisimou :
      constant Unicode_Char := 16#1D0E4#;
   Byzantine_Musical_Symbol_Simansis_Arseos_Tetrasimou :
      constant Unicode_Char := 16#1D0E5#;
   Byzantine_Musical_Symbol_Digramma_Gg    :
      constant Unicode_Char := 16#1D0E6#;
   Byzantine_Musical_Symbol_Diftoggos_Ou   :
      constant Unicode_Char := 16#1D0E7#;
   Byzantine_Musical_Symbol_Stigma         :
      constant Unicode_Char := 16#1D0E8#;
   Byzantine_Musical_Symbol_Arktiko_Pa     :
      constant Unicode_Char := 16#1D0E9#;
   Byzantine_Musical_Symbol_Arktiko_Vou    :
      constant Unicode_Char := 16#1D0EA#;
   Byzantine_Musical_Symbol_Arktiko_Ga     :
      constant Unicode_Char := 16#1D0EB#;
   Byzantine_Musical_Symbol_Arktiko_Di     :
      constant Unicode_Char := 16#1D0EC#;
   Byzantine_Musical_Symbol_Arktiko_Ke     :
      constant Unicode_Char := 16#1D0ED#;
   Byzantine_Musical_Symbol_Arktiko_Zo     :
      constant Unicode_Char := 16#1D0EE#;
   Byzantine_Musical_Symbol_Arktiko_Ni     :
      constant Unicode_Char := 16#1D0EF#;
   Byzantine_Musical_Symbol_Kentimata_Neo_Meso :
      constant Unicode_Char := 16#1D0F0#;
   Byzantine_Musical_Symbol_Kentima_Neo_Meso :
      constant Unicode_Char := 16#1D0F1#;
   Byzantine_Musical_Symbol_Kentimata_Neo_Kato :
      constant Unicode_Char := 16#1D0F2#;
   Byzantine_Musical_Symbol_Kentima_Neo_Kato :
      constant Unicode_Char := 16#1D0F3#;
   Byzantine_Musical_Symbol_Klasma_Kato    :
      constant Unicode_Char := 16#1D0F4#;
   Byzantine_Musical_Symbol_Gorgon_Neo_Kato :
      constant Unicode_Char := 16#1D0F5#;
end Unicode.Names.Byzantine_Musical_Symbols;
