--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Super_And_Sub_Scripts is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Superscript_Zero                        : constant Unicode_Char := 16#2070#;
   Superscript_Latin_Small_Letter_I        : constant Unicode_Char := 16#2071#;
   Superscript_Four                        : constant Unicode_Char := 16#2074#;
   Superscript_Five                        : constant Unicode_Char := 16#2075#;
   Superscript_Six                         : constant Unicode_Char := 16#2076#;
   Superscript_Seven                       : constant Unicode_Char := 16#2077#;
   Superscript_Eight                       : constant Unicode_Char := 16#2078#;
   Superscript_Nine                        : constant Unicode_Char := 16#2079#;
   Superscript_Plus_Sign                   : constant Unicode_Char := 16#207A#;
   Superscript_Minus                       : constant Unicode_Char := 16#207B#;
   Superscript_Equals_Sign                 : constant Unicode_Char := 16#207C#;
   Superscript_Left_Parenthesis            : constant Unicode_Char := 16#207D#;
   Superscript_Right_Parenthesis           : constant Unicode_Char := 16#207E#;
   Superscript_Latin_Small_Letter_N        : constant Unicode_Char := 16#207F#;
   Subscript_Zero                          : constant Unicode_Char := 16#2080#;
   Subscript_One                           : constant Unicode_Char := 16#2081#;
   Subscript_Two                           : constant Unicode_Char := 16#2082#;
   Subscript_Three                         : constant Unicode_Char := 16#2083#;
   Subscript_Four                          : constant Unicode_Char := 16#2084#;
   Subscript_Five                          : constant Unicode_Char := 16#2085#;
   Subscript_Six                           : constant Unicode_Char := 16#2086#;
   Subscript_Seven                         : constant Unicode_Char := 16#2087#;
   Subscript_Eight                         : constant Unicode_Char := 16#2088#;
   Subscript_Nine                          : constant Unicode_Char := 16#2089#;
   Subscript_Plus_Sign                     : constant Unicode_Char := 16#208A#;
   Subscript_Minus                         : constant Unicode_Char := 16#208B#;
   Subscript_Equals_Sign                   : constant Unicode_Char := 16#208C#;
   Subscript_Left_Parenthesis              : constant Unicode_Char := 16#208D#;
   Subscript_Right_Parenthesis             : constant Unicode_Char := 16#208E#;
   Latin_Subscript_Small_Letter_A          : constant Unicode_Char := 16#2090#;
   Latin_Subscript_Small_Letter_E          : constant Unicode_Char := 16#2091#;
   Latin_Subscript_Small_Letter_O          : constant Unicode_Char := 16#2092#;
   Latin_Subscript_Small_Letter_X          : constant Unicode_Char := 16#2093#;
   Latin_Subscript_Small_Letter_Schwa      : constant Unicode_Char := 16#2094#;
   Latin_Subscript_Small_Letter_H          : constant Unicode_Char := 16#2095#;
   Latin_Subscript_Small_Letter_K          : constant Unicode_Char := 16#2096#;
   Latin_Subscript_Small_Letter_L          : constant Unicode_Char := 16#2097#;
   Latin_Subscript_Small_Letter_M          : constant Unicode_Char := 16#2098#;
   Latin_Subscript_Small_Letter_N          : constant Unicode_Char := 16#2099#;
   Latin_Subscript_Small_Letter_P          : constant Unicode_Char := 16#209A#;
   Latin_Subscript_Small_Letter_S          : constant Unicode_Char := 16#209B#;
   Latin_Subscript_Small_Letter_T          : constant Unicode_Char := 16#209C#;
end Unicode.Names.Super_And_Sub_Scripts;
