--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Arabic_Extended_A is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Arabic_Letter_Beh_With_Small_V_Below    : constant Unicode_Char := 16#08A0#;
   Arabic_Letter_Beh_With_Hamza_Above      : constant Unicode_Char := 16#08A1#;
   Arabic_Letter_Jeem_With_Two_Dots_Above  : constant Unicode_Char := 16#08A2#;
   Arabic_Letter_Tah_With_Two_Dots_Above   : constant Unicode_Char := 16#08A3#;
   Arabic_Letter_Feh_With_Dot_Below_And_Three_Dots_Above :
      constant Unicode_Char := 16#08A4#;
   Arabic_Letter_Qaf_With_Dot_Below        : constant Unicode_Char := 16#08A5#;
   Arabic_Letter_Lam_With_Double_Bar       : constant Unicode_Char := 16#08A6#;
   Arabic_Letter_Meem_With_Three_Dots_Above :
      constant Unicode_Char := 16#08A7#;
   Arabic_Letter_Yeh_With_Two_Dots_Below_And_Hamza_Above :
      constant Unicode_Char := 16#08A8#;
   Arabic_Letter_Yeh_With_Two_Dots_Below_And_Dot_Above :
      constant Unicode_Char := 16#08A9#;
   Arabic_Letter_Reh_With_Loop             : constant Unicode_Char := 16#08AA#;
   Arabic_Letter_Waw_With_Dot_Within       : constant Unicode_Char := 16#08AB#;
   Arabic_Letter_Rohingya_Yeh              : constant Unicode_Char := 16#08AC#;
   Arabic_Letter_Low_Alef                  : constant Unicode_Char := 16#08AD#;
   Arabic_Letter_Dal_With_Three_Dots_Below : constant Unicode_Char := 16#08AE#;
   Arabic_Letter_Sad_With_Three_Dots_Below : constant Unicode_Char := 16#08AF#;
   Arabic_Letter_Gaf_With_Inverted_Stroke  : constant Unicode_Char := 16#08B0#;
   Arabic_Letter_Straight_Waw              : constant Unicode_Char := 16#08B1#;
   Arabic_Letter_Zain_With_Inverted_V_Above :
      constant Unicode_Char := 16#08B2#;
   Arabic_Letter_Ain_With_Three_Dots_Below : constant Unicode_Char := 16#08B3#;
   Arabic_Letter_Kaf_With_Dot_Below        : constant Unicode_Char := 16#08B4#;
   Arabic_Turned_Damma_Below               : constant Unicode_Char := 16#08E3#;
   Arabic_Curly_Fatha                      : constant Unicode_Char := 16#08E4#;
   Arabic_Curly_Damma                      : constant Unicode_Char := 16#08E5#;
   Arabic_Curly_Kasra                      : constant Unicode_Char := 16#08E6#;
   Arabic_Curly_Fathatan                   : constant Unicode_Char := 16#08E7#;
   Arabic_Curly_Dammatan                   : constant Unicode_Char := 16#08E8#;
   Arabic_Curly_Kasratan                   : constant Unicode_Char := 16#08E9#;
   Arabic_Tone_One_Dot_Above               : constant Unicode_Char := 16#08EA#;
   Arabic_Tone_Two_Dots_Above              : constant Unicode_Char := 16#08EB#;
   Arabic_Tone_Loop_Above                  : constant Unicode_Char := 16#08EC#;
   Arabic_Tone_One_Dot_Below               : constant Unicode_Char := 16#08ED#;
   Arabic_Tone_Two_Dots_Below              : constant Unicode_Char := 16#08EE#;
   Arabic_Tone_Loop_Below                  : constant Unicode_Char := 16#08EF#;
   Arabic_Open_Fathatan                    : constant Unicode_Char := 16#08F0#;
   Arabic_Open_Dammatan                    : constant Unicode_Char := 16#08F1#;
   Arabic_Open_Kasratan                    : constant Unicode_Char := 16#08F2#;
   Arabic_Small_High_Waw                   : constant Unicode_Char := 16#08F3#;
   Arabic_Fatha_With_Ring                  : constant Unicode_Char := 16#08F4#;
   Arabic_Fatha_With_Dot_Above             : constant Unicode_Char := 16#08F5#;
   Arabic_Kasra_With_Dot_Below             : constant Unicode_Char := 16#08F6#;
   Arabic_Left_Arrowhead_Above             : constant Unicode_Char := 16#08F7#;
   Arabic_Right_Arrowhead_Above            : constant Unicode_Char := 16#08F8#;
   Arabic_Left_Arrowhead_Below             : constant Unicode_Char := 16#08F9#;
   Arabic_Right_Arrowhead_Below            : constant Unicode_Char := 16#08FA#;
   Arabic_Double_Right_Arrowhead_Above     : constant Unicode_Char := 16#08FB#;
   Arabic_Double_Right_Arrowhead_Above_With_Dot :
      constant Unicode_Char := 16#08FC#;
   Arabic_Right_Arrowhead_Above_With_Dot   : constant Unicode_Char := 16#08FD#;
   Arabic_Damma_With_Dot                   : constant Unicode_Char := 16#08FE#;
   Arabic_Mark_Sideways_Noon_Ghunna        : constant Unicode_Char := 16#08FF#;
end Unicode.Names.Arabic_Extended_A;
