--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Linear_B_Syllabary is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Linear_B_Syllable_B008_A                :
      constant Unicode_Char := 16#10000#;
   Linear_B_Syllable_B038_E                :
      constant Unicode_Char := 16#10001#;
   Linear_B_Syllable_B028_I                :
      constant Unicode_Char := 16#10002#;
   Linear_B_Syllable_B061_O                :
      constant Unicode_Char := 16#10003#;
   Linear_B_Syllable_B010_U                :
      constant Unicode_Char := 16#10004#;
   Linear_B_Syllable_B001_Da               :
      constant Unicode_Char := 16#10005#;
   Linear_B_Syllable_B045_De               :
      constant Unicode_Char := 16#10006#;
   Linear_B_Syllable_B007_Di               :
      constant Unicode_Char := 16#10007#;
   Linear_B_Syllable_B014_Do               :
      constant Unicode_Char := 16#10008#;
   Linear_B_Syllable_B051_Du               :
      constant Unicode_Char := 16#10009#;
   Linear_B_Syllable_B057_Ja               :
      constant Unicode_Char := 16#1000A#;
   Linear_B_Syllable_B046_Je               :
      constant Unicode_Char := 16#1000B#;
   Linear_B_Syllable_B036_Jo               :
      constant Unicode_Char := 16#1000D#;
   Linear_B_Syllable_B065_Ju               :
      constant Unicode_Char := 16#1000E#;
   Linear_B_Syllable_B077_Ka               :
      constant Unicode_Char := 16#1000F#;
   Linear_B_Syllable_B044_Ke               :
      constant Unicode_Char := 16#10010#;
   Linear_B_Syllable_B067_Ki               :
      constant Unicode_Char := 16#10011#;
   Linear_B_Syllable_B070_Ko               :
      constant Unicode_Char := 16#10012#;
   Linear_B_Syllable_B081_Ku               :
      constant Unicode_Char := 16#10013#;
   Linear_B_Syllable_B080_Ma               :
      constant Unicode_Char := 16#10014#;
   Linear_B_Syllable_B013_Me               :
      constant Unicode_Char := 16#10015#;
   Linear_B_Syllable_B073_Mi               :
      constant Unicode_Char := 16#10016#;
   Linear_B_Syllable_B015_Mo               :
      constant Unicode_Char := 16#10017#;
   Linear_B_Syllable_B023_Mu               :
      constant Unicode_Char := 16#10018#;
   Linear_B_Syllable_B006_Na               :
      constant Unicode_Char := 16#10019#;
   Linear_B_Syllable_B024_Ne               :
      constant Unicode_Char := 16#1001A#;
   Linear_B_Syllable_B030_Ni               :
      constant Unicode_Char := 16#1001B#;
   Linear_B_Syllable_B052_No               :
      constant Unicode_Char := 16#1001C#;
   Linear_B_Syllable_B055_Nu               :
      constant Unicode_Char := 16#1001D#;
   Linear_B_Syllable_B003_Pa               :
      constant Unicode_Char := 16#1001E#;
   Linear_B_Syllable_B072_Pe               :
      constant Unicode_Char := 16#1001F#;
   Linear_B_Syllable_B039_Pi               :
      constant Unicode_Char := 16#10020#;
   Linear_B_Syllable_B011_Po               :
      constant Unicode_Char := 16#10021#;
   Linear_B_Syllable_B050_Pu               :
      constant Unicode_Char := 16#10022#;
   Linear_B_Syllable_B016_Qa               :
      constant Unicode_Char := 16#10023#;
   Linear_B_Syllable_B078_Qe               :
      constant Unicode_Char := 16#10024#;
   Linear_B_Syllable_B021_Qi               :
      constant Unicode_Char := 16#10025#;
   Linear_B_Syllable_B032_Qo               :
      constant Unicode_Char := 16#10026#;
   Linear_B_Syllable_B060_Ra               :
      constant Unicode_Char := 16#10028#;
   Linear_B_Syllable_B027_Re               :
      constant Unicode_Char := 16#10029#;
   Linear_B_Syllable_B053_Ri               :
      constant Unicode_Char := 16#1002A#;
   Linear_B_Syllable_B002_Ro               :
      constant Unicode_Char := 16#1002B#;
   Linear_B_Syllable_B026_Ru               :
      constant Unicode_Char := 16#1002C#;
   Linear_B_Syllable_B031_Sa               :
      constant Unicode_Char := 16#1002D#;
   Linear_B_Syllable_B009_Se               :
      constant Unicode_Char := 16#1002E#;
   Linear_B_Syllable_B041_Si               :
      constant Unicode_Char := 16#1002F#;
   Linear_B_Syllable_B012_So               :
      constant Unicode_Char := 16#10030#;
   Linear_B_Syllable_B058_Su               :
      constant Unicode_Char := 16#10031#;
   Linear_B_Syllable_B059_Ta               :
      constant Unicode_Char := 16#10032#;
   Linear_B_Syllable_B004_Te               :
      constant Unicode_Char := 16#10033#;
   Linear_B_Syllable_B037_Ti               :
      constant Unicode_Char := 16#10034#;
   Linear_B_Syllable_B005_To               :
      constant Unicode_Char := 16#10035#;
   Linear_B_Syllable_B069_Tu               :
      constant Unicode_Char := 16#10036#;
   Linear_B_Syllable_B054_Wa               :
      constant Unicode_Char := 16#10037#;
   Linear_B_Syllable_B075_We               :
      constant Unicode_Char := 16#10038#;
   Linear_B_Syllable_B040_Wi               :
      constant Unicode_Char := 16#10039#;
   Linear_B_Syllable_B042_Wo               :
      constant Unicode_Char := 16#1003A#;
   Linear_B_Syllable_B017_Za               :
      constant Unicode_Char := 16#1003C#;
   Linear_B_Syllable_B074_Ze               :
      constant Unicode_Char := 16#1003D#;
   Linear_B_Syllable_B020_Zo               :
      constant Unicode_Char := 16#1003F#;
   Linear_B_Syllable_B025_A2               :
      constant Unicode_Char := 16#10040#;
   Linear_B_Syllable_B043_A3               :
      constant Unicode_Char := 16#10041#;
   Linear_B_Syllable_B085_Au               :
      constant Unicode_Char := 16#10042#;
   Linear_B_Syllable_B071_Dwe              :
      constant Unicode_Char := 16#10043#;
   Linear_B_Syllable_B090_Dwo              :
      constant Unicode_Char := 16#10044#;
   Linear_B_Syllable_B048_Nwa              :
      constant Unicode_Char := 16#10045#;
   Linear_B_Syllable_B029_Pu2              :
      constant Unicode_Char := 16#10046#;
   Linear_B_Syllable_B062_Pte              :
      constant Unicode_Char := 16#10047#;
   Linear_B_Syllable_B076_Ra2              :
      constant Unicode_Char := 16#10048#;
   Linear_B_Syllable_B033_Ra3              :
      constant Unicode_Char := 16#10049#;
   Linear_B_Syllable_B068_Ro2              :
      constant Unicode_Char := 16#1004A#;
   Linear_B_Syllable_B066_Ta2              :
      constant Unicode_Char := 16#1004B#;
   Linear_B_Syllable_B087_Twe              :
      constant Unicode_Char := 16#1004C#;
   Linear_B_Syllable_B091_Two              :
      constant Unicode_Char := 16#1004D#;
   Linear_B_Symbol_B018                    :
      constant Unicode_Char := 16#10050#;
   Linear_B_Symbol_B019                    :
      constant Unicode_Char := 16#10051#;
   Linear_B_Symbol_B022                    :
      constant Unicode_Char := 16#10052#;
   Linear_B_Symbol_B034                    :
      constant Unicode_Char := 16#10053#;
   Linear_B_Symbol_B047                    :
      constant Unicode_Char := 16#10054#;
   Linear_B_Symbol_B049                    :
      constant Unicode_Char := 16#10055#;
   Linear_B_Symbol_B056                    :
      constant Unicode_Char := 16#10056#;
   Linear_B_Symbol_B063                    :
      constant Unicode_Char := 16#10057#;
   Linear_B_Symbol_B064                    :
      constant Unicode_Char := 16#10058#;
   Linear_B_Symbol_B079                    :
      constant Unicode_Char := 16#10059#;
   Linear_B_Symbol_B082                    :
      constant Unicode_Char := 16#1005A#;
   Linear_B_Symbol_B083                    :
      constant Unicode_Char := 16#1005B#;
   Linear_B_Symbol_B086                    :
      constant Unicode_Char := 16#1005C#;
   Linear_B_Symbol_B089                    :
      constant Unicode_Char := 16#1005D#;
end Unicode.Names.Linear_B_Syllabary;
