--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Mahjong_Tiles is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Mahjong_Tile_East_Wind                  :
      constant Unicode_Char := 16#1F000#;
   Mahjong_Tile_South_Wind                 :
      constant Unicode_Char := 16#1F001#;
   Mahjong_Tile_West_Wind                  :
      constant Unicode_Char := 16#1F002#;
   Mahjong_Tile_North_Wind                 :
      constant Unicode_Char := 16#1F003#;
   Mahjong_Tile_Red_Dragon                 :
      constant Unicode_Char := 16#1F004#;
   Mahjong_Tile_Green_Dragon               :
      constant Unicode_Char := 16#1F005#;
   Mahjong_Tile_White_Dragon               :
      constant Unicode_Char := 16#1F006#;
   Mahjong_Tile_One_Of_Characters          :
      constant Unicode_Char := 16#1F007#;
   Mahjong_Tile_Two_Of_Characters          :
      constant Unicode_Char := 16#1F008#;
   Mahjong_Tile_Three_Of_Characters        :
      constant Unicode_Char := 16#1F009#;
   Mahjong_Tile_Four_Of_Characters         :
      constant Unicode_Char := 16#1F00A#;
   Mahjong_Tile_Five_Of_Characters         :
      constant Unicode_Char := 16#1F00B#;
   Mahjong_Tile_Six_Of_Characters          :
      constant Unicode_Char := 16#1F00C#;
   Mahjong_Tile_Seven_Of_Characters        :
      constant Unicode_Char := 16#1F00D#;
   Mahjong_Tile_Eight_Of_Characters        :
      constant Unicode_Char := 16#1F00E#;
   Mahjong_Tile_Nine_Of_Characters         :
      constant Unicode_Char := 16#1F00F#;
   Mahjong_Tile_One_Of_Bamboos             :
      constant Unicode_Char := 16#1F010#;
   Mahjong_Tile_Two_Of_Bamboos             :
      constant Unicode_Char := 16#1F011#;
   Mahjong_Tile_Three_Of_Bamboos           :
      constant Unicode_Char := 16#1F012#;
   Mahjong_Tile_Four_Of_Bamboos            :
      constant Unicode_Char := 16#1F013#;
   Mahjong_Tile_Five_Of_Bamboos            :
      constant Unicode_Char := 16#1F014#;
   Mahjong_Tile_Six_Of_Bamboos             :
      constant Unicode_Char := 16#1F015#;
   Mahjong_Tile_Seven_Of_Bamboos           :
      constant Unicode_Char := 16#1F016#;
   Mahjong_Tile_Eight_Of_Bamboos           :
      constant Unicode_Char := 16#1F017#;
   Mahjong_Tile_Nine_Of_Bamboos            :
      constant Unicode_Char := 16#1F018#;
   Mahjong_Tile_One_Of_Circles             :
      constant Unicode_Char := 16#1F019#;
   Mahjong_Tile_Two_Of_Circles             :
      constant Unicode_Char := 16#1F01A#;
   Mahjong_Tile_Three_Of_Circles           :
      constant Unicode_Char := 16#1F01B#;
   Mahjong_Tile_Four_Of_Circles            :
      constant Unicode_Char := 16#1F01C#;
   Mahjong_Tile_Five_Of_Circles            :
      constant Unicode_Char := 16#1F01D#;
   Mahjong_Tile_Six_Of_Circles             :
      constant Unicode_Char := 16#1F01E#;
   Mahjong_Tile_Seven_Of_Circles           :
      constant Unicode_Char := 16#1F01F#;
   Mahjong_Tile_Eight_Of_Circles           :
      constant Unicode_Char := 16#1F020#;
   Mahjong_Tile_Nine_Of_Circles            :
      constant Unicode_Char := 16#1F021#;
   Mahjong_Tile_Plum                       :
      constant Unicode_Char := 16#1F022#;
   Mahjong_Tile_Orchid                     :
      constant Unicode_Char := 16#1F023#;
   Mahjong_Tile_Bamboo                     :
      constant Unicode_Char := 16#1F024#;
   Mahjong_Tile_Chrysanthemum              :
      constant Unicode_Char := 16#1F025#;
   Mahjong_Tile_Spring                     :
      constant Unicode_Char := 16#1F026#;
   Mahjong_Tile_Summer                     :
      constant Unicode_Char := 16#1F027#;
   Mahjong_Tile_Autumn                     :
      constant Unicode_Char := 16#1F028#;
   Mahjong_Tile_Winter                     :
      constant Unicode_Char := 16#1F029#;
   Mahjong_Tile_Joker                      :
      constant Unicode_Char := 16#1F02A#;
   Mahjong_Tile_Back                       :
      constant Unicode_Char := 16#1F02B#;
end Unicode.Names.Mahjong_Tiles;
