--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Math_Alphanumeric_Symb is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Mathematical_Bold_Capital_A             :
      constant Unicode_Char := 16#1D400#;
   Mathematical_Bold_Capital_B             :
      constant Unicode_Char := 16#1D401#;
   Mathematical_Bold_Capital_C             :
      constant Unicode_Char := 16#1D402#;
   Mathematical_Bold_Capital_D             :
      constant Unicode_Char := 16#1D403#;
   Mathematical_Bold_Capital_E             :
      constant Unicode_Char := 16#1D404#;
   Mathematical_Bold_Capital_F             :
      constant Unicode_Char := 16#1D405#;
   Mathematical_Bold_Capital_G             :
      constant Unicode_Char := 16#1D406#;
   Mathematical_Bold_Capital_H             :
      constant Unicode_Char := 16#1D407#;
   Mathematical_Bold_Capital_I             :
      constant Unicode_Char := 16#1D408#;
   Mathematical_Bold_Capital_J             :
      constant Unicode_Char := 16#1D409#;
   Mathematical_Bold_Capital_K             :
      constant Unicode_Char := 16#1D40A#;
   Mathematical_Bold_Capital_L             :
      constant Unicode_Char := 16#1D40B#;
   Mathematical_Bold_Capital_M             :
      constant Unicode_Char := 16#1D40C#;
   Mathematical_Bold_Capital_N             :
      constant Unicode_Char := 16#1D40D#;
   Mathematical_Bold_Capital_O             :
      constant Unicode_Char := 16#1D40E#;
   Mathematical_Bold_Capital_P             :
      constant Unicode_Char := 16#1D40F#;
   Mathematical_Bold_Capital_Q             :
      constant Unicode_Char := 16#1D410#;
   Mathematical_Bold_Capital_R             :
      constant Unicode_Char := 16#1D411#;
   Mathematical_Bold_Capital_S             :
      constant Unicode_Char := 16#1D412#;
   Mathematical_Bold_Capital_T             :
      constant Unicode_Char := 16#1D413#;
   Mathematical_Bold_Capital_U             :
      constant Unicode_Char := 16#1D414#;
   Mathematical_Bold_Capital_V             :
      constant Unicode_Char := 16#1D415#;
   Mathematical_Bold_Capital_W             :
      constant Unicode_Char := 16#1D416#;
   Mathematical_Bold_Capital_X             :
      constant Unicode_Char := 16#1D417#;
   Mathematical_Bold_Capital_Y             :
      constant Unicode_Char := 16#1D418#;
   Mathematical_Bold_Capital_Z             :
      constant Unicode_Char := 16#1D419#;
   Mathematical_Bold_Small_A               :
      constant Unicode_Char := 16#1D41A#;
   Mathematical_Bold_Small_B               :
      constant Unicode_Char := 16#1D41B#;
   Mathematical_Bold_Small_C               :
      constant Unicode_Char := 16#1D41C#;
   Mathematical_Bold_Small_D               :
      constant Unicode_Char := 16#1D41D#;
   Mathematical_Bold_Small_E               :
      constant Unicode_Char := 16#1D41E#;
   Mathematical_Bold_Small_F               :
      constant Unicode_Char := 16#1D41F#;
   Mathematical_Bold_Small_G               :
      constant Unicode_Char := 16#1D420#;
   Mathematical_Bold_Small_H               :
      constant Unicode_Char := 16#1D421#;
   Mathematical_Bold_Small_I               :
      constant Unicode_Char := 16#1D422#;
   Mathematical_Bold_Small_J               :
      constant Unicode_Char := 16#1D423#;
   Mathematical_Bold_Small_K               :
      constant Unicode_Char := 16#1D424#;
   Mathematical_Bold_Small_L               :
      constant Unicode_Char := 16#1D425#;
   Mathematical_Bold_Small_M               :
      constant Unicode_Char := 16#1D426#;
   Mathematical_Bold_Small_N               :
      constant Unicode_Char := 16#1D427#;
   Mathematical_Bold_Small_O               :
      constant Unicode_Char := 16#1D428#;
   Mathematical_Bold_Small_P               :
      constant Unicode_Char := 16#1D429#;
   Mathematical_Bold_Small_Q               :
      constant Unicode_Char := 16#1D42A#;
   Mathematical_Bold_Small_R               :
      constant Unicode_Char := 16#1D42B#;
   Mathematical_Bold_Small_S               :
      constant Unicode_Char := 16#1D42C#;
   Mathematical_Bold_Small_T               :
      constant Unicode_Char := 16#1D42D#;
   Mathematical_Bold_Small_U               :
      constant Unicode_Char := 16#1D42E#;
   Mathematical_Bold_Small_V               :
      constant Unicode_Char := 16#1D42F#;
   Mathematical_Bold_Small_W               :
      constant Unicode_Char := 16#1D430#;
   Mathematical_Bold_Small_X               :
      constant Unicode_Char := 16#1D431#;
   Mathematical_Bold_Small_Y               :
      constant Unicode_Char := 16#1D432#;
   Mathematical_Bold_Small_Z               :
      constant Unicode_Char := 16#1D433#;
   Mathematical_Italic_Capital_A           :
      constant Unicode_Char := 16#1D434#;
   Mathematical_Italic_Capital_B           :
      constant Unicode_Char := 16#1D435#;
   Mathematical_Italic_Capital_C           :
      constant Unicode_Char := 16#1D436#;
   Mathematical_Italic_Capital_D           :
      constant Unicode_Char := 16#1D437#;
   Mathematical_Italic_Capital_E           :
      constant Unicode_Char := 16#1D438#;
   Mathematical_Italic_Capital_F           :
      constant Unicode_Char := 16#1D439#;
   Mathematical_Italic_Capital_G           :
      constant Unicode_Char := 16#1D43A#;
   Mathematical_Italic_Capital_H           :
      constant Unicode_Char := 16#1D43B#;
   Mathematical_Italic_Capital_I           :
      constant Unicode_Char := 16#1D43C#;
   Mathematical_Italic_Capital_J           :
      constant Unicode_Char := 16#1D43D#;
   Mathematical_Italic_Capital_K           :
      constant Unicode_Char := 16#1D43E#;
   Mathematical_Italic_Capital_L           :
      constant Unicode_Char := 16#1D43F#;
   Mathematical_Italic_Capital_M           :
      constant Unicode_Char := 16#1D440#;
   Mathematical_Italic_Capital_N           :
      constant Unicode_Char := 16#1D441#;
   Mathematical_Italic_Capital_O           :
      constant Unicode_Char := 16#1D442#;
   Mathematical_Italic_Capital_P           :
      constant Unicode_Char := 16#1D443#;
   Mathematical_Italic_Capital_Q           :
      constant Unicode_Char := 16#1D444#;
   Mathematical_Italic_Capital_R           :
      constant Unicode_Char := 16#1D445#;
   Mathematical_Italic_Capital_S           :
      constant Unicode_Char := 16#1D446#;
   Mathematical_Italic_Capital_T           :
      constant Unicode_Char := 16#1D447#;
   Mathematical_Italic_Capital_U           :
      constant Unicode_Char := 16#1D448#;
   Mathematical_Italic_Capital_V           :
      constant Unicode_Char := 16#1D449#;
   Mathematical_Italic_Capital_W           :
      constant Unicode_Char := 16#1D44A#;
   Mathematical_Italic_Capital_X           :
      constant Unicode_Char := 16#1D44B#;
   Mathematical_Italic_Capital_Y           :
      constant Unicode_Char := 16#1D44C#;
   Mathematical_Italic_Capital_Z           :
      constant Unicode_Char := 16#1D44D#;
   Mathematical_Italic_Small_A             :
      constant Unicode_Char := 16#1D44E#;
   Mathematical_Italic_Small_B             :
      constant Unicode_Char := 16#1D44F#;
   Mathematical_Italic_Small_C             :
      constant Unicode_Char := 16#1D450#;
   Mathematical_Italic_Small_D             :
      constant Unicode_Char := 16#1D451#;
   Mathematical_Italic_Small_E             :
      constant Unicode_Char := 16#1D452#;
   Mathematical_Italic_Small_F             :
      constant Unicode_Char := 16#1D453#;
   Mathematical_Italic_Small_G             :
      constant Unicode_Char := 16#1D454#;
   Mathematical_Italic_Small_I             :
      constant Unicode_Char := 16#1D456#;
   Mathematical_Italic_Small_J             :
      constant Unicode_Char := 16#1D457#;
   Mathematical_Italic_Small_K             :
      constant Unicode_Char := 16#1D458#;
   Mathematical_Italic_Small_L             :
      constant Unicode_Char := 16#1D459#;
   Mathematical_Italic_Small_M             :
      constant Unicode_Char := 16#1D45A#;
   Mathematical_Italic_Small_N             :
      constant Unicode_Char := 16#1D45B#;
   Mathematical_Italic_Small_O             :
      constant Unicode_Char := 16#1D45C#;
   Mathematical_Italic_Small_P             :
      constant Unicode_Char := 16#1D45D#;
   Mathematical_Italic_Small_Q             :
      constant Unicode_Char := 16#1D45E#;
   Mathematical_Italic_Small_R             :
      constant Unicode_Char := 16#1D45F#;
   Mathematical_Italic_Small_S             :
      constant Unicode_Char := 16#1D460#;
   Mathematical_Italic_Small_T             :
      constant Unicode_Char := 16#1D461#;
   Mathematical_Italic_Small_U             :
      constant Unicode_Char := 16#1D462#;
   Mathematical_Italic_Small_V             :
      constant Unicode_Char := 16#1D463#;
   Mathematical_Italic_Small_W             :
      constant Unicode_Char := 16#1D464#;
   Mathematical_Italic_Small_X             :
      constant Unicode_Char := 16#1D465#;
   Mathematical_Italic_Small_Y             :
      constant Unicode_Char := 16#1D466#;
   Mathematical_Italic_Small_Z             :
      constant Unicode_Char := 16#1D467#;
   Mathematical_Bold_Italic_Capital_A      :
      constant Unicode_Char := 16#1D468#;
   Mathematical_Bold_Italic_Capital_B      :
      constant Unicode_Char := 16#1D469#;
   Mathematical_Bold_Italic_Capital_C      :
      constant Unicode_Char := 16#1D46A#;
   Mathematical_Bold_Italic_Capital_D      :
      constant Unicode_Char := 16#1D46B#;
   Mathematical_Bold_Italic_Capital_E      :
      constant Unicode_Char := 16#1D46C#;
   Mathematical_Bold_Italic_Capital_F      :
      constant Unicode_Char := 16#1D46D#;
   Mathematical_Bold_Italic_Capital_G      :
      constant Unicode_Char := 16#1D46E#;
   Mathematical_Bold_Italic_Capital_H      :
      constant Unicode_Char := 16#1D46F#;
   Mathematical_Bold_Italic_Capital_I      :
      constant Unicode_Char := 16#1D470#;
   Mathematical_Bold_Italic_Capital_J      :
      constant Unicode_Char := 16#1D471#;
   Mathematical_Bold_Italic_Capital_K      :
      constant Unicode_Char := 16#1D472#;
   Mathematical_Bold_Italic_Capital_L      :
      constant Unicode_Char := 16#1D473#;
   Mathematical_Bold_Italic_Capital_M      :
      constant Unicode_Char := 16#1D474#;
   Mathematical_Bold_Italic_Capital_N      :
      constant Unicode_Char := 16#1D475#;
   Mathematical_Bold_Italic_Capital_O      :
      constant Unicode_Char := 16#1D476#;
   Mathematical_Bold_Italic_Capital_P      :
      constant Unicode_Char := 16#1D477#;
   Mathematical_Bold_Italic_Capital_Q      :
      constant Unicode_Char := 16#1D478#;
   Mathematical_Bold_Italic_Capital_R      :
      constant Unicode_Char := 16#1D479#;
   Mathematical_Bold_Italic_Capital_S      :
      constant Unicode_Char := 16#1D47A#;
   Mathematical_Bold_Italic_Capital_T      :
      constant Unicode_Char := 16#1D47B#;
   Mathematical_Bold_Italic_Capital_U      :
      constant Unicode_Char := 16#1D47C#;
   Mathematical_Bold_Italic_Capital_V      :
      constant Unicode_Char := 16#1D47D#;
   Mathematical_Bold_Italic_Capital_W      :
      constant Unicode_Char := 16#1D47E#;
   Mathematical_Bold_Italic_Capital_X      :
      constant Unicode_Char := 16#1D47F#;
   Mathematical_Bold_Italic_Capital_Y      :
      constant Unicode_Char := 16#1D480#;
   Mathematical_Bold_Italic_Capital_Z      :
      constant Unicode_Char := 16#1D481#;
   Mathematical_Bold_Italic_Small_A        :
      constant Unicode_Char := 16#1D482#;
   Mathematical_Bold_Italic_Small_B        :
      constant Unicode_Char := 16#1D483#;
   Mathematical_Bold_Italic_Small_C        :
      constant Unicode_Char := 16#1D484#;
   Mathematical_Bold_Italic_Small_D        :
      constant Unicode_Char := 16#1D485#;
   Mathematical_Bold_Italic_Small_E        :
      constant Unicode_Char := 16#1D486#;
   Mathematical_Bold_Italic_Small_F        :
      constant Unicode_Char := 16#1D487#;
   Mathematical_Bold_Italic_Small_G        :
      constant Unicode_Char := 16#1D488#;
   Mathematical_Bold_Italic_Small_H        :
      constant Unicode_Char := 16#1D489#;
   Mathematical_Bold_Italic_Small_I        :
      constant Unicode_Char := 16#1D48A#;
   Mathematical_Bold_Italic_Small_J        :
      constant Unicode_Char := 16#1D48B#;
   Mathematical_Bold_Italic_Small_K        :
      constant Unicode_Char := 16#1D48C#;
   Mathematical_Bold_Italic_Small_L        :
      constant Unicode_Char := 16#1D48D#;
   Mathematical_Bold_Italic_Small_M        :
      constant Unicode_Char := 16#1D48E#;
   Mathematical_Bold_Italic_Small_N        :
      constant Unicode_Char := 16#1D48F#;
   Mathematical_Bold_Italic_Small_O        :
      constant Unicode_Char := 16#1D490#;
   Mathematical_Bold_Italic_Small_P        :
      constant Unicode_Char := 16#1D491#;
   Mathematical_Bold_Italic_Small_Q        :
      constant Unicode_Char := 16#1D492#;
   Mathematical_Bold_Italic_Small_R        :
      constant Unicode_Char := 16#1D493#;
   Mathematical_Bold_Italic_Small_S        :
      constant Unicode_Char := 16#1D494#;
   Mathematical_Bold_Italic_Small_T        :
      constant Unicode_Char := 16#1D495#;
   Mathematical_Bold_Italic_Small_U        :
      constant Unicode_Char := 16#1D496#;
   Mathematical_Bold_Italic_Small_V        :
      constant Unicode_Char := 16#1D497#;
   Mathematical_Bold_Italic_Small_W        :
      constant Unicode_Char := 16#1D498#;
   Mathematical_Bold_Italic_Small_X        :
      constant Unicode_Char := 16#1D499#;
   Mathematical_Bold_Italic_Small_Y        :
      constant Unicode_Char := 16#1D49A#;
   Mathematical_Bold_Italic_Small_Z        :
      constant Unicode_Char := 16#1D49B#;
   Mathematical_Script_Capital_A           :
      constant Unicode_Char := 16#1D49C#;
   Mathematical_Script_Capital_C           :
      constant Unicode_Char := 16#1D49E#;
   Mathematical_Script_Capital_D           :
      constant Unicode_Char := 16#1D49F#;
   Mathematical_Script_Capital_G           :
      constant Unicode_Char := 16#1D4A2#;
   Mathematical_Script_Capital_J           :
      constant Unicode_Char := 16#1D4A5#;
   Mathematical_Script_Capital_K           :
      constant Unicode_Char := 16#1D4A6#;
   Mathematical_Script_Capital_N           :
      constant Unicode_Char := 16#1D4A9#;
   Mathematical_Script_Capital_O           :
      constant Unicode_Char := 16#1D4AA#;
   Mathematical_Script_Capital_P           :
      constant Unicode_Char := 16#1D4AB#;
   Mathematical_Script_Capital_Q           :
      constant Unicode_Char := 16#1D4AC#;
   Mathematical_Script_Capital_S           :
      constant Unicode_Char := 16#1D4AE#;
   Mathematical_Script_Capital_T           :
      constant Unicode_Char := 16#1D4AF#;
   Mathematical_Script_Capital_U           :
      constant Unicode_Char := 16#1D4B0#;
   Mathematical_Script_Capital_V           :
      constant Unicode_Char := 16#1D4B1#;
   Mathematical_Script_Capital_W           :
      constant Unicode_Char := 16#1D4B2#;
   Mathematical_Script_Capital_X           :
      constant Unicode_Char := 16#1D4B3#;
   Mathematical_Script_Capital_Y           :
      constant Unicode_Char := 16#1D4B4#;
   Mathematical_Script_Capital_Z           :
      constant Unicode_Char := 16#1D4B5#;
   Mathematical_Script_Small_A             :
      constant Unicode_Char := 16#1D4B6#;
   Mathematical_Script_Small_B             :
      constant Unicode_Char := 16#1D4B7#;
   Mathematical_Script_Small_C             :
      constant Unicode_Char := 16#1D4B8#;
   Mathematical_Script_Small_D             :
      constant Unicode_Char := 16#1D4B9#;
   Mathematical_Script_Small_F             :
      constant Unicode_Char := 16#1D4BB#;
   Mathematical_Script_Small_H             :
      constant Unicode_Char := 16#1D4BD#;
   Mathematical_Script_Small_I             :
      constant Unicode_Char := 16#1D4BE#;
   Mathematical_Script_Small_J             :
      constant Unicode_Char := 16#1D4BF#;
   Mathematical_Script_Small_K             :
      constant Unicode_Char := 16#1D4C0#;
   Mathematical_Script_Small_L             :
      constant Unicode_Char := 16#1D4C1#;
   Mathematical_Script_Small_M             :
      constant Unicode_Char := 16#1D4C2#;
   Mathematical_Script_Small_N             :
      constant Unicode_Char := 16#1D4C3#;
   Mathematical_Script_Small_P             :
      constant Unicode_Char := 16#1D4C5#;
   Mathematical_Script_Small_Q             :
      constant Unicode_Char := 16#1D4C6#;
   Mathematical_Script_Small_R             :
      constant Unicode_Char := 16#1D4C7#;
   Mathematical_Script_Small_S             :
      constant Unicode_Char := 16#1D4C8#;
   Mathematical_Script_Small_T             :
      constant Unicode_Char := 16#1D4C9#;
   Mathematical_Script_Small_U             :
      constant Unicode_Char := 16#1D4CA#;
   Mathematical_Script_Small_V             :
      constant Unicode_Char := 16#1D4CB#;
   Mathematical_Script_Small_W             :
      constant Unicode_Char := 16#1D4CC#;
   Mathematical_Script_Small_X             :
      constant Unicode_Char := 16#1D4CD#;
   Mathematical_Script_Small_Y             :
      constant Unicode_Char := 16#1D4CE#;
   Mathematical_Script_Small_Z             :
      constant Unicode_Char := 16#1D4CF#;
   Mathematical_Bold_Script_Capital_A      :
      constant Unicode_Char := 16#1D4D0#;
   Mathematical_Bold_Script_Capital_B      :
      constant Unicode_Char := 16#1D4D1#;
   Mathematical_Bold_Script_Capital_C      :
      constant Unicode_Char := 16#1D4D2#;
   Mathematical_Bold_Script_Capital_D      :
      constant Unicode_Char := 16#1D4D3#;
   Mathematical_Bold_Script_Capital_E      :
      constant Unicode_Char := 16#1D4D4#;
   Mathematical_Bold_Script_Capital_F      :
      constant Unicode_Char := 16#1D4D5#;
   Mathematical_Bold_Script_Capital_G      :
      constant Unicode_Char := 16#1D4D6#;
   Mathematical_Bold_Script_Capital_H      :
      constant Unicode_Char := 16#1D4D7#;
   Mathematical_Bold_Script_Capital_I      :
      constant Unicode_Char := 16#1D4D8#;
   Mathematical_Bold_Script_Capital_J      :
      constant Unicode_Char := 16#1D4D9#;
   Mathematical_Bold_Script_Capital_K      :
      constant Unicode_Char := 16#1D4DA#;
   Mathematical_Bold_Script_Capital_L      :
      constant Unicode_Char := 16#1D4DB#;
   Mathematical_Bold_Script_Capital_M      :
      constant Unicode_Char := 16#1D4DC#;
   Mathematical_Bold_Script_Capital_N      :
      constant Unicode_Char := 16#1D4DD#;
   Mathematical_Bold_Script_Capital_O      :
      constant Unicode_Char := 16#1D4DE#;
   Mathematical_Bold_Script_Capital_P      :
      constant Unicode_Char := 16#1D4DF#;
   Mathematical_Bold_Script_Capital_Q      :
      constant Unicode_Char := 16#1D4E0#;
   Mathematical_Bold_Script_Capital_R      :
      constant Unicode_Char := 16#1D4E1#;
   Mathematical_Bold_Script_Capital_S      :
      constant Unicode_Char := 16#1D4E2#;
   Mathematical_Bold_Script_Capital_T      :
      constant Unicode_Char := 16#1D4E3#;
   Mathematical_Bold_Script_Capital_U      :
      constant Unicode_Char := 16#1D4E4#;
   Mathematical_Bold_Script_Capital_V      :
      constant Unicode_Char := 16#1D4E5#;
   Mathematical_Bold_Script_Capital_W      :
      constant Unicode_Char := 16#1D4E6#;
   Mathematical_Bold_Script_Capital_X      :
      constant Unicode_Char := 16#1D4E7#;
   Mathematical_Bold_Script_Capital_Y      :
      constant Unicode_Char := 16#1D4E8#;
   Mathematical_Bold_Script_Capital_Z      :
      constant Unicode_Char := 16#1D4E9#;
   Mathematical_Bold_Script_Small_A        :
      constant Unicode_Char := 16#1D4EA#;
   Mathematical_Bold_Script_Small_B        :
      constant Unicode_Char := 16#1D4EB#;
   Mathematical_Bold_Script_Small_C        :
      constant Unicode_Char := 16#1D4EC#;
   Mathematical_Bold_Script_Small_D        :
      constant Unicode_Char := 16#1D4ED#;
   Mathematical_Bold_Script_Small_E        :
      constant Unicode_Char := 16#1D4EE#;
   Mathematical_Bold_Script_Small_F        :
      constant Unicode_Char := 16#1D4EF#;
   Mathematical_Bold_Script_Small_G        :
      constant Unicode_Char := 16#1D4F0#;
   Mathematical_Bold_Script_Small_H        :
      constant Unicode_Char := 16#1D4F1#;
   Mathematical_Bold_Script_Small_I        :
      constant Unicode_Char := 16#1D4F2#;
   Mathematical_Bold_Script_Small_J        :
      constant Unicode_Char := 16#1D4F3#;
   Mathematical_Bold_Script_Small_K        :
      constant Unicode_Char := 16#1D4F4#;
   Mathematical_Bold_Script_Small_L        :
      constant Unicode_Char := 16#1D4F5#;
   Mathematical_Bold_Script_Small_M        :
      constant Unicode_Char := 16#1D4F6#;
   Mathematical_Bold_Script_Small_N        :
      constant Unicode_Char := 16#1D4F7#;
   Mathematical_Bold_Script_Small_O        :
      constant Unicode_Char := 16#1D4F8#;
   Mathematical_Bold_Script_Small_P        :
      constant Unicode_Char := 16#1D4F9#;
   Mathematical_Bold_Script_Small_Q        :
      constant Unicode_Char := 16#1D4FA#;
   Mathematical_Bold_Script_Small_R        :
      constant Unicode_Char := 16#1D4FB#;
   Mathematical_Bold_Script_Small_S        :
      constant Unicode_Char := 16#1D4FC#;
   Mathematical_Bold_Script_Small_T        :
      constant Unicode_Char := 16#1D4FD#;
   Mathematical_Bold_Script_Small_U        :
      constant Unicode_Char := 16#1D4FE#;
   Mathematical_Bold_Script_Small_V        :
      constant Unicode_Char := 16#1D4FF#;
   Mathematical_Bold_Script_Small_W        :
      constant Unicode_Char := 16#1D500#;
   Mathematical_Bold_Script_Small_X        :
      constant Unicode_Char := 16#1D501#;
   Mathematical_Bold_Script_Small_Y        :
      constant Unicode_Char := 16#1D502#;
   Mathematical_Bold_Script_Small_Z        :
      constant Unicode_Char := 16#1D503#;
   Mathematical_Fraktur_Capital_A          :
      constant Unicode_Char := 16#1D504#;
   Mathematical_Fraktur_Capital_B          :
      constant Unicode_Char := 16#1D505#;
   Mathematical_Fraktur_Capital_D          :
      constant Unicode_Char := 16#1D507#;
   Mathematical_Fraktur_Capital_E          :
      constant Unicode_Char := 16#1D508#;
   Mathematical_Fraktur_Capital_F          :
      constant Unicode_Char := 16#1D509#;
   Mathematical_Fraktur_Capital_G          :
      constant Unicode_Char := 16#1D50A#;
   Mathematical_Fraktur_Capital_J          :
      constant Unicode_Char := 16#1D50D#;
   Mathematical_Fraktur_Capital_K          :
      constant Unicode_Char := 16#1D50E#;
   Mathematical_Fraktur_Capital_L          :
      constant Unicode_Char := 16#1D50F#;
   Mathematical_Fraktur_Capital_M          :
      constant Unicode_Char := 16#1D510#;
   Mathematical_Fraktur_Capital_N          :
      constant Unicode_Char := 16#1D511#;
   Mathematical_Fraktur_Capital_O          :
      constant Unicode_Char := 16#1D512#;
   Mathematical_Fraktur_Capital_P          :
      constant Unicode_Char := 16#1D513#;
   Mathematical_Fraktur_Capital_Q          :
      constant Unicode_Char := 16#1D514#;
   Mathematical_Fraktur_Capital_S          :
      constant Unicode_Char := 16#1D516#;
   Mathematical_Fraktur_Capital_T          :
      constant Unicode_Char := 16#1D517#;
   Mathematical_Fraktur_Capital_U          :
      constant Unicode_Char := 16#1D518#;
   Mathematical_Fraktur_Capital_V          :
      constant Unicode_Char := 16#1D519#;
   Mathematical_Fraktur_Capital_W          :
      constant Unicode_Char := 16#1D51A#;
   Mathematical_Fraktur_Capital_X          :
      constant Unicode_Char := 16#1D51B#;
   Mathematical_Fraktur_Capital_Y          :
      constant Unicode_Char := 16#1D51C#;
   Mathematical_Fraktur_Small_A            :
      constant Unicode_Char := 16#1D51E#;
   Mathematical_Fraktur_Small_B            :
      constant Unicode_Char := 16#1D51F#;
   Mathematical_Fraktur_Small_C            :
      constant Unicode_Char := 16#1D520#;
   Mathematical_Fraktur_Small_D            :
      constant Unicode_Char := 16#1D521#;
   Mathematical_Fraktur_Small_E            :
      constant Unicode_Char := 16#1D522#;
   Mathematical_Fraktur_Small_F            :
      constant Unicode_Char := 16#1D523#;
   Mathematical_Fraktur_Small_G            :
      constant Unicode_Char := 16#1D524#;
   Mathematical_Fraktur_Small_H            :
      constant Unicode_Char := 16#1D525#;
   Mathematical_Fraktur_Small_I            :
      constant Unicode_Char := 16#1D526#;
   Mathematical_Fraktur_Small_J            :
      constant Unicode_Char := 16#1D527#;
   Mathematical_Fraktur_Small_K            :
      constant Unicode_Char := 16#1D528#;
   Mathematical_Fraktur_Small_L            :
      constant Unicode_Char := 16#1D529#;
   Mathematical_Fraktur_Small_M            :
      constant Unicode_Char := 16#1D52A#;
   Mathematical_Fraktur_Small_N            :
      constant Unicode_Char := 16#1D52B#;
   Mathematical_Fraktur_Small_O            :
      constant Unicode_Char := 16#1D52C#;
   Mathematical_Fraktur_Small_P            :
      constant Unicode_Char := 16#1D52D#;
   Mathematical_Fraktur_Small_Q            :
      constant Unicode_Char := 16#1D52E#;
   Mathematical_Fraktur_Small_R            :
      constant Unicode_Char := 16#1D52F#;
   Mathematical_Fraktur_Small_S            :
      constant Unicode_Char := 16#1D530#;
   Mathematical_Fraktur_Small_T            :
      constant Unicode_Char := 16#1D531#;
   Mathematical_Fraktur_Small_U            :
      constant Unicode_Char := 16#1D532#;
   Mathematical_Fraktur_Small_V            :
      constant Unicode_Char := 16#1D533#;
   Mathematical_Fraktur_Small_W            :
      constant Unicode_Char := 16#1D534#;
   Mathematical_Fraktur_Small_X            :
      constant Unicode_Char := 16#1D535#;
   Mathematical_Fraktur_Small_Y            :
      constant Unicode_Char := 16#1D536#;
   Mathematical_Fraktur_Small_Z            :
      constant Unicode_Char := 16#1D537#;
   Mathematical_Double_Struck_Capital_A    :
      constant Unicode_Char := 16#1D538#;
   Mathematical_Double_Struck_Capital_B    :
      constant Unicode_Char := 16#1D539#;
   Mathematical_Double_Struck_Capital_D    :
      constant Unicode_Char := 16#1D53B#;
   Mathematical_Double_Struck_Capital_E    :
      constant Unicode_Char := 16#1D53C#;
   Mathematical_Double_Struck_Capital_F    :
      constant Unicode_Char := 16#1D53D#;
   Mathematical_Double_Struck_Capital_G    :
      constant Unicode_Char := 16#1D53E#;
   Mathematical_Double_Struck_Capital_I    :
      constant Unicode_Char := 16#1D540#;
   Mathematical_Double_Struck_Capital_J    :
      constant Unicode_Char := 16#1D541#;
   Mathematical_Double_Struck_Capital_K    :
      constant Unicode_Char := 16#1D542#;
   Mathematical_Double_Struck_Capital_L    :
      constant Unicode_Char := 16#1D543#;
   Mathematical_Double_Struck_Capital_M    :
      constant Unicode_Char := 16#1D544#;
   Mathematical_Double_Struck_Capital_O    :
      constant Unicode_Char := 16#1D546#;
   Mathematical_Double_Struck_Capital_S    :
      constant Unicode_Char := 16#1D54A#;
   Mathematical_Double_Struck_Capital_T    :
      constant Unicode_Char := 16#1D54B#;
   Mathematical_Double_Struck_Capital_U    :
      constant Unicode_Char := 16#1D54C#;
   Mathematical_Double_Struck_Capital_V    :
      constant Unicode_Char := 16#1D54D#;
   Mathematical_Double_Struck_Capital_W    :
      constant Unicode_Char := 16#1D54E#;
   Mathematical_Double_Struck_Capital_X    :
      constant Unicode_Char := 16#1D54F#;
   Mathematical_Double_Struck_Capital_Y    :
      constant Unicode_Char := 16#1D550#;
   Mathematical_Double_Struck_Small_A      :
      constant Unicode_Char := 16#1D552#;
   Mathematical_Double_Struck_Small_B      :
      constant Unicode_Char := 16#1D553#;
   Mathematical_Double_Struck_Small_C      :
      constant Unicode_Char := 16#1D554#;
   Mathematical_Double_Struck_Small_D      :
      constant Unicode_Char := 16#1D555#;
   Mathematical_Double_Struck_Small_E      :
      constant Unicode_Char := 16#1D556#;
   Mathematical_Double_Struck_Small_F      :
      constant Unicode_Char := 16#1D557#;
   Mathematical_Double_Struck_Small_G      :
      constant Unicode_Char := 16#1D558#;
   Mathematical_Double_Struck_Small_H      :
      constant Unicode_Char := 16#1D559#;
   Mathematical_Double_Struck_Small_I      :
      constant Unicode_Char := 16#1D55A#;
   Mathematical_Double_Struck_Small_J      :
      constant Unicode_Char := 16#1D55B#;
   Mathematical_Double_Struck_Small_K      :
      constant Unicode_Char := 16#1D55C#;
   Mathematical_Double_Struck_Small_L      :
      constant Unicode_Char := 16#1D55D#;
   Mathematical_Double_Struck_Small_M      :
      constant Unicode_Char := 16#1D55E#;
   Mathematical_Double_Struck_Small_N      :
      constant Unicode_Char := 16#1D55F#;
   Mathematical_Double_Struck_Small_O      :
      constant Unicode_Char := 16#1D560#;
   Mathematical_Double_Struck_Small_P      :
      constant Unicode_Char := 16#1D561#;
   Mathematical_Double_Struck_Small_Q      :
      constant Unicode_Char := 16#1D562#;
   Mathematical_Double_Struck_Small_R      :
      constant Unicode_Char := 16#1D563#;
   Mathematical_Double_Struck_Small_S      :
      constant Unicode_Char := 16#1D564#;
   Mathematical_Double_Struck_Small_T      :
      constant Unicode_Char := 16#1D565#;
   Mathematical_Double_Struck_Small_U      :
      constant Unicode_Char := 16#1D566#;
   Mathematical_Double_Struck_Small_V      :
      constant Unicode_Char := 16#1D567#;
   Mathematical_Double_Struck_Small_W      :
      constant Unicode_Char := 16#1D568#;
   Mathematical_Double_Struck_Small_X      :
      constant Unicode_Char := 16#1D569#;
   Mathematical_Double_Struck_Small_Y      :
      constant Unicode_Char := 16#1D56A#;
   Mathematical_Double_Struck_Small_Z      :
      constant Unicode_Char := 16#1D56B#;
   Mathematical_Bold_Fraktur_Capital_A     :
      constant Unicode_Char := 16#1D56C#;
   Mathematical_Bold_Fraktur_Capital_B     :
      constant Unicode_Char := 16#1D56D#;
   Mathematical_Bold_Fraktur_Capital_C     :
      constant Unicode_Char := 16#1D56E#;
   Mathematical_Bold_Fraktur_Capital_D     :
      constant Unicode_Char := 16#1D56F#;
   Mathematical_Bold_Fraktur_Capital_E     :
      constant Unicode_Char := 16#1D570#;
   Mathematical_Bold_Fraktur_Capital_F     :
      constant Unicode_Char := 16#1D571#;
   Mathematical_Bold_Fraktur_Capital_G     :
      constant Unicode_Char := 16#1D572#;
   Mathematical_Bold_Fraktur_Capital_H     :
      constant Unicode_Char := 16#1D573#;
   Mathematical_Bold_Fraktur_Capital_I     :
      constant Unicode_Char := 16#1D574#;
   Mathematical_Bold_Fraktur_Capital_J     :
      constant Unicode_Char := 16#1D575#;
   Mathematical_Bold_Fraktur_Capital_K     :
      constant Unicode_Char := 16#1D576#;
   Mathematical_Bold_Fraktur_Capital_L     :
      constant Unicode_Char := 16#1D577#;
   Mathematical_Bold_Fraktur_Capital_M     :
      constant Unicode_Char := 16#1D578#;
   Mathematical_Bold_Fraktur_Capital_N     :
      constant Unicode_Char := 16#1D579#;
   Mathematical_Bold_Fraktur_Capital_O     :
      constant Unicode_Char := 16#1D57A#;
   Mathematical_Bold_Fraktur_Capital_P     :
      constant Unicode_Char := 16#1D57B#;
   Mathematical_Bold_Fraktur_Capital_Q     :
      constant Unicode_Char := 16#1D57C#;
   Mathematical_Bold_Fraktur_Capital_R     :
      constant Unicode_Char := 16#1D57D#;
   Mathematical_Bold_Fraktur_Capital_S     :
      constant Unicode_Char := 16#1D57E#;
   Mathematical_Bold_Fraktur_Capital_T     :
      constant Unicode_Char := 16#1D57F#;
   Mathematical_Bold_Fraktur_Capital_U     :
      constant Unicode_Char := 16#1D580#;
   Mathematical_Bold_Fraktur_Capital_V     :
      constant Unicode_Char := 16#1D581#;
   Mathematical_Bold_Fraktur_Capital_W     :
      constant Unicode_Char := 16#1D582#;
   Mathematical_Bold_Fraktur_Capital_X     :
      constant Unicode_Char := 16#1D583#;
   Mathematical_Bold_Fraktur_Capital_Y     :
      constant Unicode_Char := 16#1D584#;
   Mathematical_Bold_Fraktur_Capital_Z     :
      constant Unicode_Char := 16#1D585#;
   Mathematical_Bold_Fraktur_Small_A       :
      constant Unicode_Char := 16#1D586#;
   Mathematical_Bold_Fraktur_Small_B       :
      constant Unicode_Char := 16#1D587#;
   Mathematical_Bold_Fraktur_Small_C       :
      constant Unicode_Char := 16#1D588#;
   Mathematical_Bold_Fraktur_Small_D       :
      constant Unicode_Char := 16#1D589#;
   Mathematical_Bold_Fraktur_Small_E       :
      constant Unicode_Char := 16#1D58A#;
   Mathematical_Bold_Fraktur_Small_F       :
      constant Unicode_Char := 16#1D58B#;
   Mathematical_Bold_Fraktur_Small_G       :
      constant Unicode_Char := 16#1D58C#;
   Mathematical_Bold_Fraktur_Small_H       :
      constant Unicode_Char := 16#1D58D#;
   Mathematical_Bold_Fraktur_Small_I       :
      constant Unicode_Char := 16#1D58E#;
   Mathematical_Bold_Fraktur_Small_J       :
      constant Unicode_Char := 16#1D58F#;
   Mathematical_Bold_Fraktur_Small_K       :
      constant Unicode_Char := 16#1D590#;
   Mathematical_Bold_Fraktur_Small_L       :
      constant Unicode_Char := 16#1D591#;
   Mathematical_Bold_Fraktur_Small_M       :
      constant Unicode_Char := 16#1D592#;
   Mathematical_Bold_Fraktur_Small_N       :
      constant Unicode_Char := 16#1D593#;
   Mathematical_Bold_Fraktur_Small_O       :
      constant Unicode_Char := 16#1D594#;
   Mathematical_Bold_Fraktur_Small_P       :
      constant Unicode_Char := 16#1D595#;
   Mathematical_Bold_Fraktur_Small_Q       :
      constant Unicode_Char := 16#1D596#;
   Mathematical_Bold_Fraktur_Small_R       :
      constant Unicode_Char := 16#1D597#;
   Mathematical_Bold_Fraktur_Small_S       :
      constant Unicode_Char := 16#1D598#;
   Mathematical_Bold_Fraktur_Small_T       :
      constant Unicode_Char := 16#1D599#;
   Mathematical_Bold_Fraktur_Small_U       :
      constant Unicode_Char := 16#1D59A#;
   Mathematical_Bold_Fraktur_Small_V       :
      constant Unicode_Char := 16#1D59B#;
   Mathematical_Bold_Fraktur_Small_W       :
      constant Unicode_Char := 16#1D59C#;
   Mathematical_Bold_Fraktur_Small_X       :
      constant Unicode_Char := 16#1D59D#;
   Mathematical_Bold_Fraktur_Small_Y       :
      constant Unicode_Char := 16#1D59E#;
   Mathematical_Bold_Fraktur_Small_Z       :
      constant Unicode_Char := 16#1D59F#;
   Mathematical_Sans_Serif_Capital_A       :
      constant Unicode_Char := 16#1D5A0#;
   Mathematical_Sans_Serif_Capital_B       :
      constant Unicode_Char := 16#1D5A1#;
   Mathematical_Sans_Serif_Capital_C       :
      constant Unicode_Char := 16#1D5A2#;
   Mathematical_Sans_Serif_Capital_D       :
      constant Unicode_Char := 16#1D5A3#;
   Mathematical_Sans_Serif_Capital_E       :
      constant Unicode_Char := 16#1D5A4#;
   Mathematical_Sans_Serif_Capital_F       :
      constant Unicode_Char := 16#1D5A5#;
   Mathematical_Sans_Serif_Capital_G       :
      constant Unicode_Char := 16#1D5A6#;
   Mathematical_Sans_Serif_Capital_H       :
      constant Unicode_Char := 16#1D5A7#;
   Mathematical_Sans_Serif_Capital_I       :
      constant Unicode_Char := 16#1D5A8#;
   Mathematical_Sans_Serif_Capital_J       :
      constant Unicode_Char := 16#1D5A9#;
   Mathematical_Sans_Serif_Capital_K       :
      constant Unicode_Char := 16#1D5AA#;
   Mathematical_Sans_Serif_Capital_L       :
      constant Unicode_Char := 16#1D5AB#;
   Mathematical_Sans_Serif_Capital_M       :
      constant Unicode_Char := 16#1D5AC#;
   Mathematical_Sans_Serif_Capital_N       :
      constant Unicode_Char := 16#1D5AD#;
   Mathematical_Sans_Serif_Capital_O       :
      constant Unicode_Char := 16#1D5AE#;
   Mathematical_Sans_Serif_Capital_P       :
      constant Unicode_Char := 16#1D5AF#;
   Mathematical_Sans_Serif_Capital_Q       :
      constant Unicode_Char := 16#1D5B0#;
   Mathematical_Sans_Serif_Capital_R       :
      constant Unicode_Char := 16#1D5B1#;
   Mathematical_Sans_Serif_Capital_S       :
      constant Unicode_Char := 16#1D5B2#;
   Mathematical_Sans_Serif_Capital_T       :
      constant Unicode_Char := 16#1D5B3#;
   Mathematical_Sans_Serif_Capital_U       :
      constant Unicode_Char := 16#1D5B4#;
   Mathematical_Sans_Serif_Capital_V       :
      constant Unicode_Char := 16#1D5B5#;
   Mathematical_Sans_Serif_Capital_W       :
      constant Unicode_Char := 16#1D5B6#;
   Mathematical_Sans_Serif_Capital_X       :
      constant Unicode_Char := 16#1D5B7#;
   Mathematical_Sans_Serif_Capital_Y       :
      constant Unicode_Char := 16#1D5B8#;
   Mathematical_Sans_Serif_Capital_Z       :
      constant Unicode_Char := 16#1D5B9#;
   Mathematical_Sans_Serif_Small_A         :
      constant Unicode_Char := 16#1D5BA#;
   Mathematical_Sans_Serif_Small_B         :
      constant Unicode_Char := 16#1D5BB#;
   Mathematical_Sans_Serif_Small_C         :
      constant Unicode_Char := 16#1D5BC#;
   Mathematical_Sans_Serif_Small_D         :
      constant Unicode_Char := 16#1D5BD#;
   Mathematical_Sans_Serif_Small_E         :
      constant Unicode_Char := 16#1D5BE#;
   Mathematical_Sans_Serif_Small_F         :
      constant Unicode_Char := 16#1D5BF#;
   Mathematical_Sans_Serif_Small_G         :
      constant Unicode_Char := 16#1D5C0#;
   Mathematical_Sans_Serif_Small_H         :
      constant Unicode_Char := 16#1D5C1#;
   Mathematical_Sans_Serif_Small_I         :
      constant Unicode_Char := 16#1D5C2#;
   Mathematical_Sans_Serif_Small_J         :
      constant Unicode_Char := 16#1D5C3#;
   Mathematical_Sans_Serif_Small_K         :
      constant Unicode_Char := 16#1D5C4#;
   Mathematical_Sans_Serif_Small_L         :
      constant Unicode_Char := 16#1D5C5#;
   Mathematical_Sans_Serif_Small_M         :
      constant Unicode_Char := 16#1D5C6#;
   Mathematical_Sans_Serif_Small_N         :
      constant Unicode_Char := 16#1D5C7#;
   Mathematical_Sans_Serif_Small_O         :
      constant Unicode_Char := 16#1D5C8#;
   Mathematical_Sans_Serif_Small_P         :
      constant Unicode_Char := 16#1D5C9#;
   Mathematical_Sans_Serif_Small_Q         :
      constant Unicode_Char := 16#1D5CA#;
   Mathematical_Sans_Serif_Small_R         :
      constant Unicode_Char := 16#1D5CB#;
   Mathematical_Sans_Serif_Small_S         :
      constant Unicode_Char := 16#1D5CC#;
   Mathematical_Sans_Serif_Small_T         :
      constant Unicode_Char := 16#1D5CD#;
   Mathematical_Sans_Serif_Small_U         :
      constant Unicode_Char := 16#1D5CE#;
   Mathematical_Sans_Serif_Small_V         :
      constant Unicode_Char := 16#1D5CF#;
   Mathematical_Sans_Serif_Small_W         :
      constant Unicode_Char := 16#1D5D0#;
   Mathematical_Sans_Serif_Small_X         :
      constant Unicode_Char := 16#1D5D1#;
   Mathematical_Sans_Serif_Small_Y         :
      constant Unicode_Char := 16#1D5D2#;
   Mathematical_Sans_Serif_Small_Z         :
      constant Unicode_Char := 16#1D5D3#;
   Mathematical_Sans_Serif_Bold_Capital_A  :
      constant Unicode_Char := 16#1D5D4#;
   Mathematical_Sans_Serif_Bold_Capital_B  :
      constant Unicode_Char := 16#1D5D5#;
   Mathematical_Sans_Serif_Bold_Capital_C  :
      constant Unicode_Char := 16#1D5D6#;
   Mathematical_Sans_Serif_Bold_Capital_D  :
      constant Unicode_Char := 16#1D5D7#;
   Mathematical_Sans_Serif_Bold_Capital_E  :
      constant Unicode_Char := 16#1D5D8#;
   Mathematical_Sans_Serif_Bold_Capital_F  :
      constant Unicode_Char := 16#1D5D9#;
   Mathematical_Sans_Serif_Bold_Capital_G  :
      constant Unicode_Char := 16#1D5DA#;
   Mathematical_Sans_Serif_Bold_Capital_H  :
      constant Unicode_Char := 16#1D5DB#;
   Mathematical_Sans_Serif_Bold_Capital_I  :
      constant Unicode_Char := 16#1D5DC#;
   Mathematical_Sans_Serif_Bold_Capital_J  :
      constant Unicode_Char := 16#1D5DD#;
   Mathematical_Sans_Serif_Bold_Capital_K  :
      constant Unicode_Char := 16#1D5DE#;
   Mathematical_Sans_Serif_Bold_Capital_L  :
      constant Unicode_Char := 16#1D5DF#;
   Mathematical_Sans_Serif_Bold_Capital_M  :
      constant Unicode_Char := 16#1D5E0#;
   Mathematical_Sans_Serif_Bold_Capital_N  :
      constant Unicode_Char := 16#1D5E1#;
   Mathematical_Sans_Serif_Bold_Capital_O  :
      constant Unicode_Char := 16#1D5E2#;
   Mathematical_Sans_Serif_Bold_Capital_P  :
      constant Unicode_Char := 16#1D5E3#;
   Mathematical_Sans_Serif_Bold_Capital_Q  :
      constant Unicode_Char := 16#1D5E4#;
   Mathematical_Sans_Serif_Bold_Capital_R  :
      constant Unicode_Char := 16#1D5E5#;
   Mathematical_Sans_Serif_Bold_Capital_S  :
      constant Unicode_Char := 16#1D5E6#;
   Mathematical_Sans_Serif_Bold_Capital_T  :
      constant Unicode_Char := 16#1D5E7#;
   Mathematical_Sans_Serif_Bold_Capital_U  :
      constant Unicode_Char := 16#1D5E8#;
   Mathematical_Sans_Serif_Bold_Capital_V  :
      constant Unicode_Char := 16#1D5E9#;
   Mathematical_Sans_Serif_Bold_Capital_W  :
      constant Unicode_Char := 16#1D5EA#;
   Mathematical_Sans_Serif_Bold_Capital_X  :
      constant Unicode_Char := 16#1D5EB#;
   Mathematical_Sans_Serif_Bold_Capital_Y  :
      constant Unicode_Char := 16#1D5EC#;
   Mathematical_Sans_Serif_Bold_Capital_Z  :
      constant Unicode_Char := 16#1D5ED#;
   Mathematical_Sans_Serif_Bold_Small_A    :
      constant Unicode_Char := 16#1D5EE#;
   Mathematical_Sans_Serif_Bold_Small_B    :
      constant Unicode_Char := 16#1D5EF#;
   Mathematical_Sans_Serif_Bold_Small_C    :
      constant Unicode_Char := 16#1D5F0#;
   Mathematical_Sans_Serif_Bold_Small_D    :
      constant Unicode_Char := 16#1D5F1#;
   Mathematical_Sans_Serif_Bold_Small_E    :
      constant Unicode_Char := 16#1D5F2#;
   Mathematical_Sans_Serif_Bold_Small_F    :
      constant Unicode_Char := 16#1D5F3#;
   Mathematical_Sans_Serif_Bold_Small_G    :
      constant Unicode_Char := 16#1D5F4#;
   Mathematical_Sans_Serif_Bold_Small_H    :
      constant Unicode_Char := 16#1D5F5#;
   Mathematical_Sans_Serif_Bold_Small_I    :
      constant Unicode_Char := 16#1D5F6#;
   Mathematical_Sans_Serif_Bold_Small_J    :
      constant Unicode_Char := 16#1D5F7#;
   Mathematical_Sans_Serif_Bold_Small_K    :
      constant Unicode_Char := 16#1D5F8#;
   Mathematical_Sans_Serif_Bold_Small_L    :
      constant Unicode_Char := 16#1D5F9#;
   Mathematical_Sans_Serif_Bold_Small_M    :
      constant Unicode_Char := 16#1D5FA#;
   Mathematical_Sans_Serif_Bold_Small_N    :
      constant Unicode_Char := 16#1D5FB#;
   Mathematical_Sans_Serif_Bold_Small_O    :
      constant Unicode_Char := 16#1D5FC#;
   Mathematical_Sans_Serif_Bold_Small_P    :
      constant Unicode_Char := 16#1D5FD#;
   Mathematical_Sans_Serif_Bold_Small_Q    :
      constant Unicode_Char := 16#1D5FE#;
   Mathematical_Sans_Serif_Bold_Small_R    :
      constant Unicode_Char := 16#1D5FF#;
   Mathematical_Sans_Serif_Bold_Small_S    :
      constant Unicode_Char := 16#1D600#;
   Mathematical_Sans_Serif_Bold_Small_T    :
      constant Unicode_Char := 16#1D601#;
   Mathematical_Sans_Serif_Bold_Small_U    :
      constant Unicode_Char := 16#1D602#;
   Mathematical_Sans_Serif_Bold_Small_V    :
      constant Unicode_Char := 16#1D603#;
   Mathematical_Sans_Serif_Bold_Small_W    :
      constant Unicode_Char := 16#1D604#;
   Mathematical_Sans_Serif_Bold_Small_X    :
      constant Unicode_Char := 16#1D605#;
   Mathematical_Sans_Serif_Bold_Small_Y    :
      constant Unicode_Char := 16#1D606#;
   Mathematical_Sans_Serif_Bold_Small_Z    :
      constant Unicode_Char := 16#1D607#;
   Mathematical_Sans_Serif_Italic_Capital_A :
      constant Unicode_Char := 16#1D608#;
   Mathematical_Sans_Serif_Italic_Capital_B :
      constant Unicode_Char := 16#1D609#;
   Mathematical_Sans_Serif_Italic_Capital_C :
      constant Unicode_Char := 16#1D60A#;
   Mathematical_Sans_Serif_Italic_Capital_D :
      constant Unicode_Char := 16#1D60B#;
   Mathematical_Sans_Serif_Italic_Capital_E :
      constant Unicode_Char := 16#1D60C#;
   Mathematical_Sans_Serif_Italic_Capital_F :
      constant Unicode_Char := 16#1D60D#;
   Mathematical_Sans_Serif_Italic_Capital_G :
      constant Unicode_Char := 16#1D60E#;
   Mathematical_Sans_Serif_Italic_Capital_H :
      constant Unicode_Char := 16#1D60F#;
   Mathematical_Sans_Serif_Italic_Capital_I :
      constant Unicode_Char := 16#1D610#;
   Mathematical_Sans_Serif_Italic_Capital_J :
      constant Unicode_Char := 16#1D611#;
   Mathematical_Sans_Serif_Italic_Capital_K :
      constant Unicode_Char := 16#1D612#;
   Mathematical_Sans_Serif_Italic_Capital_L :
      constant Unicode_Char := 16#1D613#;
   Mathematical_Sans_Serif_Italic_Capital_M :
      constant Unicode_Char := 16#1D614#;
   Mathematical_Sans_Serif_Italic_Capital_N :
      constant Unicode_Char := 16#1D615#;
   Mathematical_Sans_Serif_Italic_Capital_O :
      constant Unicode_Char := 16#1D616#;
   Mathematical_Sans_Serif_Italic_Capital_P :
      constant Unicode_Char := 16#1D617#;
   Mathematical_Sans_Serif_Italic_Capital_Q :
      constant Unicode_Char := 16#1D618#;
   Mathematical_Sans_Serif_Italic_Capital_R :
      constant Unicode_Char := 16#1D619#;
   Mathematical_Sans_Serif_Italic_Capital_S :
      constant Unicode_Char := 16#1D61A#;
   Mathematical_Sans_Serif_Italic_Capital_T :
      constant Unicode_Char := 16#1D61B#;
   Mathematical_Sans_Serif_Italic_Capital_U :
      constant Unicode_Char := 16#1D61C#;
   Mathematical_Sans_Serif_Italic_Capital_V :
      constant Unicode_Char := 16#1D61D#;
   Mathematical_Sans_Serif_Italic_Capital_W :
      constant Unicode_Char := 16#1D61E#;
   Mathematical_Sans_Serif_Italic_Capital_X :
      constant Unicode_Char := 16#1D61F#;
   Mathematical_Sans_Serif_Italic_Capital_Y :
      constant Unicode_Char := 16#1D620#;
   Mathematical_Sans_Serif_Italic_Capital_Z :
      constant Unicode_Char := 16#1D621#;
   Mathematical_Sans_Serif_Italic_Small_A  :
      constant Unicode_Char := 16#1D622#;
   Mathematical_Sans_Serif_Italic_Small_B  :
      constant Unicode_Char := 16#1D623#;
   Mathematical_Sans_Serif_Italic_Small_C  :
      constant Unicode_Char := 16#1D624#;
   Mathematical_Sans_Serif_Italic_Small_D  :
      constant Unicode_Char := 16#1D625#;
   Mathematical_Sans_Serif_Italic_Small_E  :
      constant Unicode_Char := 16#1D626#;
   Mathematical_Sans_Serif_Italic_Small_F  :
      constant Unicode_Char := 16#1D627#;
   Mathematical_Sans_Serif_Italic_Small_G  :
      constant Unicode_Char := 16#1D628#;
   Mathematical_Sans_Serif_Italic_Small_H  :
      constant Unicode_Char := 16#1D629#;
   Mathematical_Sans_Serif_Italic_Small_I  :
      constant Unicode_Char := 16#1D62A#;
   Mathematical_Sans_Serif_Italic_Small_J  :
      constant Unicode_Char := 16#1D62B#;
   Mathematical_Sans_Serif_Italic_Small_K  :
      constant Unicode_Char := 16#1D62C#;
   Mathematical_Sans_Serif_Italic_Small_L  :
      constant Unicode_Char := 16#1D62D#;
   Mathematical_Sans_Serif_Italic_Small_M  :
      constant Unicode_Char := 16#1D62E#;
   Mathematical_Sans_Serif_Italic_Small_N  :
      constant Unicode_Char := 16#1D62F#;
   Mathematical_Sans_Serif_Italic_Small_O  :
      constant Unicode_Char := 16#1D630#;
   Mathematical_Sans_Serif_Italic_Small_P  :
      constant Unicode_Char := 16#1D631#;
   Mathematical_Sans_Serif_Italic_Small_Q  :
      constant Unicode_Char := 16#1D632#;
   Mathematical_Sans_Serif_Italic_Small_R  :
      constant Unicode_Char := 16#1D633#;
   Mathematical_Sans_Serif_Italic_Small_S  :
      constant Unicode_Char := 16#1D634#;
   Mathematical_Sans_Serif_Italic_Small_T  :
      constant Unicode_Char := 16#1D635#;
   Mathematical_Sans_Serif_Italic_Small_U  :
      constant Unicode_Char := 16#1D636#;
   Mathematical_Sans_Serif_Italic_Small_V  :
      constant Unicode_Char := 16#1D637#;
   Mathematical_Sans_Serif_Italic_Small_W  :
      constant Unicode_Char := 16#1D638#;
   Mathematical_Sans_Serif_Italic_Small_X  :
      constant Unicode_Char := 16#1D639#;
   Mathematical_Sans_Serif_Italic_Small_Y  :
      constant Unicode_Char := 16#1D63A#;
   Mathematical_Sans_Serif_Italic_Small_Z  :
      constant Unicode_Char := 16#1D63B#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_A :
      constant Unicode_Char := 16#1D63C#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_B :
      constant Unicode_Char := 16#1D63D#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_C :
      constant Unicode_Char := 16#1D63E#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_D :
      constant Unicode_Char := 16#1D63F#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_E :
      constant Unicode_Char := 16#1D640#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_F :
      constant Unicode_Char := 16#1D641#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_G :
      constant Unicode_Char := 16#1D642#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_H :
      constant Unicode_Char := 16#1D643#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_I :
      constant Unicode_Char := 16#1D644#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_J :
      constant Unicode_Char := 16#1D645#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_K :
      constant Unicode_Char := 16#1D646#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_L :
      constant Unicode_Char := 16#1D647#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_M :
      constant Unicode_Char := 16#1D648#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_N :
      constant Unicode_Char := 16#1D649#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_O :
      constant Unicode_Char := 16#1D64A#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_P :
      constant Unicode_Char := 16#1D64B#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Q :
      constant Unicode_Char := 16#1D64C#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_R :
      constant Unicode_Char := 16#1D64D#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_S :
      constant Unicode_Char := 16#1D64E#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_T :
      constant Unicode_Char := 16#1D64F#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_U :
      constant Unicode_Char := 16#1D650#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_V :
      constant Unicode_Char := 16#1D651#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_W :
      constant Unicode_Char := 16#1D652#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_X :
      constant Unicode_Char := 16#1D653#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Y :
      constant Unicode_Char := 16#1D654#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Z :
      constant Unicode_Char := 16#1D655#;
   Mathematical_Sans_Serif_Bold_Italic_Small_A :
      constant Unicode_Char := 16#1D656#;
   Mathematical_Sans_Serif_Bold_Italic_Small_B :
      constant Unicode_Char := 16#1D657#;
   Mathematical_Sans_Serif_Bold_Italic_Small_C :
      constant Unicode_Char := 16#1D658#;
   Mathematical_Sans_Serif_Bold_Italic_Small_D :
      constant Unicode_Char := 16#1D659#;
   Mathematical_Sans_Serif_Bold_Italic_Small_E :
      constant Unicode_Char := 16#1D65A#;
   Mathematical_Sans_Serif_Bold_Italic_Small_F :
      constant Unicode_Char := 16#1D65B#;
   Mathematical_Sans_Serif_Bold_Italic_Small_G :
      constant Unicode_Char := 16#1D65C#;
   Mathematical_Sans_Serif_Bold_Italic_Small_H :
      constant Unicode_Char := 16#1D65D#;
   Mathematical_Sans_Serif_Bold_Italic_Small_I :
      constant Unicode_Char := 16#1D65E#;
   Mathematical_Sans_Serif_Bold_Italic_Small_J :
      constant Unicode_Char := 16#1D65F#;
   Mathematical_Sans_Serif_Bold_Italic_Small_K :
      constant Unicode_Char := 16#1D660#;
   Mathematical_Sans_Serif_Bold_Italic_Small_L :
      constant Unicode_Char := 16#1D661#;
   Mathematical_Sans_Serif_Bold_Italic_Small_M :
      constant Unicode_Char := 16#1D662#;
   Mathematical_Sans_Serif_Bold_Italic_Small_N :
      constant Unicode_Char := 16#1D663#;
   Mathematical_Sans_Serif_Bold_Italic_Small_O :
      constant Unicode_Char := 16#1D664#;
   Mathematical_Sans_Serif_Bold_Italic_Small_P :
      constant Unicode_Char := 16#1D665#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Q :
      constant Unicode_Char := 16#1D666#;
   Mathematical_Sans_Serif_Bold_Italic_Small_R :
      constant Unicode_Char := 16#1D667#;
   Mathematical_Sans_Serif_Bold_Italic_Small_S :
      constant Unicode_Char := 16#1D668#;
   Mathematical_Sans_Serif_Bold_Italic_Small_T :
      constant Unicode_Char := 16#1D669#;
   Mathematical_Sans_Serif_Bold_Italic_Small_U :
      constant Unicode_Char := 16#1D66A#;
   Mathematical_Sans_Serif_Bold_Italic_Small_V :
      constant Unicode_Char := 16#1D66B#;
   Mathematical_Sans_Serif_Bold_Italic_Small_W :
      constant Unicode_Char := 16#1D66C#;
   Mathematical_Sans_Serif_Bold_Italic_Small_X :
      constant Unicode_Char := 16#1D66D#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Y :
      constant Unicode_Char := 16#1D66E#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Z :
      constant Unicode_Char := 16#1D66F#;
   Mathematical_Monospace_Capital_A        :
      constant Unicode_Char := 16#1D670#;
   Mathematical_Monospace_Capital_B        :
      constant Unicode_Char := 16#1D671#;
   Mathematical_Monospace_Capital_C        :
      constant Unicode_Char := 16#1D672#;
   Mathematical_Monospace_Capital_D        :
      constant Unicode_Char := 16#1D673#;
   Mathematical_Monospace_Capital_E        :
      constant Unicode_Char := 16#1D674#;
   Mathematical_Monospace_Capital_F        :
      constant Unicode_Char := 16#1D675#;
   Mathematical_Monospace_Capital_G        :
      constant Unicode_Char := 16#1D676#;
   Mathematical_Monospace_Capital_H        :
      constant Unicode_Char := 16#1D677#;
   Mathematical_Monospace_Capital_I        :
      constant Unicode_Char := 16#1D678#;
   Mathematical_Monospace_Capital_J        :
      constant Unicode_Char := 16#1D679#;
   Mathematical_Monospace_Capital_K        :
      constant Unicode_Char := 16#1D67A#;
   Mathematical_Monospace_Capital_L        :
      constant Unicode_Char := 16#1D67B#;
   Mathematical_Monospace_Capital_M        :
      constant Unicode_Char := 16#1D67C#;
   Mathematical_Monospace_Capital_N        :
      constant Unicode_Char := 16#1D67D#;
   Mathematical_Monospace_Capital_O        :
      constant Unicode_Char := 16#1D67E#;
   Mathematical_Monospace_Capital_P        :
      constant Unicode_Char := 16#1D67F#;
   Mathematical_Monospace_Capital_Q        :
      constant Unicode_Char := 16#1D680#;
   Mathematical_Monospace_Capital_R        :
      constant Unicode_Char := 16#1D681#;
   Mathematical_Monospace_Capital_S        :
      constant Unicode_Char := 16#1D682#;
   Mathematical_Monospace_Capital_T        :
      constant Unicode_Char := 16#1D683#;
   Mathematical_Monospace_Capital_U        :
      constant Unicode_Char := 16#1D684#;
   Mathematical_Monospace_Capital_V        :
      constant Unicode_Char := 16#1D685#;
   Mathematical_Monospace_Capital_W        :
      constant Unicode_Char := 16#1D686#;
   Mathematical_Monospace_Capital_X        :
      constant Unicode_Char := 16#1D687#;
   Mathematical_Monospace_Capital_Y        :
      constant Unicode_Char := 16#1D688#;
   Mathematical_Monospace_Capital_Z        :
      constant Unicode_Char := 16#1D689#;
   Mathematical_Monospace_Small_A          :
      constant Unicode_Char := 16#1D68A#;
   Mathematical_Monospace_Small_B          :
      constant Unicode_Char := 16#1D68B#;
   Mathematical_Monospace_Small_C          :
      constant Unicode_Char := 16#1D68C#;
   Mathematical_Monospace_Small_D          :
      constant Unicode_Char := 16#1D68D#;
   Mathematical_Monospace_Small_E          :
      constant Unicode_Char := 16#1D68E#;
   Mathematical_Monospace_Small_F          :
      constant Unicode_Char := 16#1D68F#;
   Mathematical_Monospace_Small_G          :
      constant Unicode_Char := 16#1D690#;
   Mathematical_Monospace_Small_H          :
      constant Unicode_Char := 16#1D691#;
   Mathematical_Monospace_Small_I          :
      constant Unicode_Char := 16#1D692#;
   Mathematical_Monospace_Small_J          :
      constant Unicode_Char := 16#1D693#;
   Mathematical_Monospace_Small_K          :
      constant Unicode_Char := 16#1D694#;
   Mathematical_Monospace_Small_L          :
      constant Unicode_Char := 16#1D695#;
   Mathematical_Monospace_Small_M          :
      constant Unicode_Char := 16#1D696#;
   Mathematical_Monospace_Small_N          :
      constant Unicode_Char := 16#1D697#;
   Mathematical_Monospace_Small_O          :
      constant Unicode_Char := 16#1D698#;
   Mathematical_Monospace_Small_P          :
      constant Unicode_Char := 16#1D699#;
   Mathematical_Monospace_Small_Q          :
      constant Unicode_Char := 16#1D69A#;
   Mathematical_Monospace_Small_R          :
      constant Unicode_Char := 16#1D69B#;
   Mathematical_Monospace_Small_S          :
      constant Unicode_Char := 16#1D69C#;
   Mathematical_Monospace_Small_T          :
      constant Unicode_Char := 16#1D69D#;
   Mathematical_Monospace_Small_U          :
      constant Unicode_Char := 16#1D69E#;
   Mathematical_Monospace_Small_V          :
      constant Unicode_Char := 16#1D69F#;
   Mathematical_Monospace_Small_W          :
      constant Unicode_Char := 16#1D6A0#;
   Mathematical_Monospace_Small_X          :
      constant Unicode_Char := 16#1D6A1#;
   Mathematical_Monospace_Small_Y          :
      constant Unicode_Char := 16#1D6A2#;
   Mathematical_Monospace_Small_Z          :
      constant Unicode_Char := 16#1D6A3#;
   Mathematical_Italic_Small_Dotless_I     :
      constant Unicode_Char := 16#1D6A4#;
   Mathematical_Italic_Small_Dotless_J     :
      constant Unicode_Char := 16#1D6A5#;
   Mathematical_Bold_Capital_Alpha         :
      constant Unicode_Char := 16#1D6A8#;
   Mathematical_Bold_Capital_Beta          :
      constant Unicode_Char := 16#1D6A9#;
   Mathematical_Bold_Capital_Gamma         :
      constant Unicode_Char := 16#1D6AA#;
   Mathematical_Bold_Capital_Delta         :
      constant Unicode_Char := 16#1D6AB#;
   Mathematical_Bold_Capital_Epsilon       :
      constant Unicode_Char := 16#1D6AC#;
   Mathematical_Bold_Capital_Zeta          :
      constant Unicode_Char := 16#1D6AD#;
   Mathematical_Bold_Capital_Eta           :
      constant Unicode_Char := 16#1D6AE#;
   Mathematical_Bold_Capital_Theta         :
      constant Unicode_Char := 16#1D6AF#;
   Mathematical_Bold_Capital_Iota          :
      constant Unicode_Char := 16#1D6B0#;
   Mathematical_Bold_Capital_Kappa         :
      constant Unicode_Char := 16#1D6B1#;
   Mathematical_Bold_Capital_Lamda         :
      constant Unicode_Char := 16#1D6B2#;
   Mathematical_Bold_Capital_Mu            :
      constant Unicode_Char := 16#1D6B3#;
   Mathematical_Bold_Capital_Nu            :
      constant Unicode_Char := 16#1D6B4#;
   Mathematical_Bold_Capital_Xi            :
      constant Unicode_Char := 16#1D6B5#;
   Mathematical_Bold_Capital_Omicron       :
      constant Unicode_Char := 16#1D6B6#;
   Mathematical_Bold_Capital_Pi            :
      constant Unicode_Char := 16#1D6B7#;
   Mathematical_Bold_Capital_Rho           :
      constant Unicode_Char := 16#1D6B8#;
   Mathematical_Bold_Capital_Theta_Symbol  :
      constant Unicode_Char := 16#1D6B9#;
   Mathematical_Bold_Capital_Sigma         :
      constant Unicode_Char := 16#1D6BA#;
   Mathematical_Bold_Capital_Tau           :
      constant Unicode_Char := 16#1D6BB#;
   Mathematical_Bold_Capital_Upsilon       :
      constant Unicode_Char := 16#1D6BC#;
   Mathematical_Bold_Capital_Phi           :
      constant Unicode_Char := 16#1D6BD#;
   Mathematical_Bold_Capital_Chi           :
      constant Unicode_Char := 16#1D6BE#;
   Mathematical_Bold_Capital_Psi           :
      constant Unicode_Char := 16#1D6BF#;
   Mathematical_Bold_Capital_Omega         :
      constant Unicode_Char := 16#1D6C0#;
   Mathematical_Bold_Nabla                 :
      constant Unicode_Char := 16#1D6C1#;
   Mathematical_Bold_Small_Alpha           :
      constant Unicode_Char := 16#1D6C2#;
   Mathematical_Bold_Small_Beta            :
      constant Unicode_Char := 16#1D6C3#;
   Mathematical_Bold_Small_Gamma           :
      constant Unicode_Char := 16#1D6C4#;
   Mathematical_Bold_Small_Delta           :
      constant Unicode_Char := 16#1D6C5#;
   Mathematical_Bold_Small_Epsilon         :
      constant Unicode_Char := 16#1D6C6#;
   Mathematical_Bold_Small_Zeta            :
      constant Unicode_Char := 16#1D6C7#;
   Mathematical_Bold_Small_Eta             :
      constant Unicode_Char := 16#1D6C8#;
   Mathematical_Bold_Small_Theta           :
      constant Unicode_Char := 16#1D6C9#;
   Mathematical_Bold_Small_Iota            :
      constant Unicode_Char := 16#1D6CA#;
   Mathematical_Bold_Small_Kappa           :
      constant Unicode_Char := 16#1D6CB#;
   Mathematical_Bold_Small_Lamda           :
      constant Unicode_Char := 16#1D6CC#;
   Mathematical_Bold_Small_Mu              :
      constant Unicode_Char := 16#1D6CD#;
   Mathematical_Bold_Small_Nu              :
      constant Unicode_Char := 16#1D6CE#;
   Mathematical_Bold_Small_Xi              :
      constant Unicode_Char := 16#1D6CF#;
   Mathematical_Bold_Small_Omicron         :
      constant Unicode_Char := 16#1D6D0#;
   Mathematical_Bold_Small_Pi              :
      constant Unicode_Char := 16#1D6D1#;
   Mathematical_Bold_Small_Rho             :
      constant Unicode_Char := 16#1D6D2#;
   Mathematical_Bold_Small_Final_Sigma     :
      constant Unicode_Char := 16#1D6D3#;
   Mathematical_Bold_Small_Sigma           :
      constant Unicode_Char := 16#1D6D4#;
   Mathematical_Bold_Small_Tau             :
      constant Unicode_Char := 16#1D6D5#;
   Mathematical_Bold_Small_Upsilon         :
      constant Unicode_Char := 16#1D6D6#;
   Mathematical_Bold_Small_Phi             :
      constant Unicode_Char := 16#1D6D7#;
   Mathematical_Bold_Small_Chi             :
      constant Unicode_Char := 16#1D6D8#;
   Mathematical_Bold_Small_Psi             :
      constant Unicode_Char := 16#1D6D9#;
   Mathematical_Bold_Small_Omega           :
      constant Unicode_Char := 16#1D6DA#;
   Mathematical_Bold_Partial_Differential  :
      constant Unicode_Char := 16#1D6DB#;
   Mathematical_Bold_Epsilon_Symbol        :
      constant Unicode_Char := 16#1D6DC#;
   Mathematical_Bold_Theta_Symbol          :
      constant Unicode_Char := 16#1D6DD#;
   Mathematical_Bold_Kappa_Symbol          :
      constant Unicode_Char := 16#1D6DE#;
   Mathematical_Bold_Phi_Symbol            :
      constant Unicode_Char := 16#1D6DF#;
   Mathematical_Bold_Rho_Symbol            :
      constant Unicode_Char := 16#1D6E0#;
   Mathematical_Bold_Pi_Symbol             :
      constant Unicode_Char := 16#1D6E1#;
   Mathematical_Italic_Capital_Alpha       :
      constant Unicode_Char := 16#1D6E2#;
   Mathematical_Italic_Capital_Beta        :
      constant Unicode_Char := 16#1D6E3#;
   Mathematical_Italic_Capital_Gamma       :
      constant Unicode_Char := 16#1D6E4#;
   Mathematical_Italic_Capital_Delta       :
      constant Unicode_Char := 16#1D6E5#;
   Mathematical_Italic_Capital_Epsilon     :
      constant Unicode_Char := 16#1D6E6#;
   Mathematical_Italic_Capital_Zeta        :
      constant Unicode_Char := 16#1D6E7#;
   Mathematical_Italic_Capital_Eta         :
      constant Unicode_Char := 16#1D6E8#;
   Mathematical_Italic_Capital_Theta       :
      constant Unicode_Char := 16#1D6E9#;
   Mathematical_Italic_Capital_Iota        :
      constant Unicode_Char := 16#1D6EA#;
   Mathematical_Italic_Capital_Kappa       :
      constant Unicode_Char := 16#1D6EB#;
   Mathematical_Italic_Capital_Lamda       :
      constant Unicode_Char := 16#1D6EC#;
   Mathematical_Italic_Capital_Mu          :
      constant Unicode_Char := 16#1D6ED#;
   Mathematical_Italic_Capital_Nu          :
      constant Unicode_Char := 16#1D6EE#;
   Mathematical_Italic_Capital_Xi          :
      constant Unicode_Char := 16#1D6EF#;
   Mathematical_Italic_Capital_Omicron     :
      constant Unicode_Char := 16#1D6F0#;
   Mathematical_Italic_Capital_Pi          :
      constant Unicode_Char := 16#1D6F1#;
   Mathematical_Italic_Capital_Rho         :
      constant Unicode_Char := 16#1D6F2#;
   Mathematical_Italic_Capital_Theta_Symbol :
      constant Unicode_Char := 16#1D6F3#;
   Mathematical_Italic_Capital_Sigma       :
      constant Unicode_Char := 16#1D6F4#;
   Mathematical_Italic_Capital_Tau         :
      constant Unicode_Char := 16#1D6F5#;
   Mathematical_Italic_Capital_Upsilon     :
      constant Unicode_Char := 16#1D6F6#;
   Mathematical_Italic_Capital_Phi         :
      constant Unicode_Char := 16#1D6F7#;
   Mathematical_Italic_Capital_Chi         :
      constant Unicode_Char := 16#1D6F8#;
   Mathematical_Italic_Capital_Psi         :
      constant Unicode_Char := 16#1D6F9#;
   Mathematical_Italic_Capital_Omega       :
      constant Unicode_Char := 16#1D6FA#;
   Mathematical_Italic_Nabla               :
      constant Unicode_Char := 16#1D6FB#;
   Mathematical_Italic_Small_Alpha         :
      constant Unicode_Char := 16#1D6FC#;
   Mathematical_Italic_Small_Beta          :
      constant Unicode_Char := 16#1D6FD#;
   Mathematical_Italic_Small_Gamma         :
      constant Unicode_Char := 16#1D6FE#;
   Mathematical_Italic_Small_Delta         :
      constant Unicode_Char := 16#1D6FF#;
   Mathematical_Italic_Small_Epsilon       :
      constant Unicode_Char := 16#1D700#;
   Mathematical_Italic_Small_Zeta          :
      constant Unicode_Char := 16#1D701#;
   Mathematical_Italic_Small_Eta           :
      constant Unicode_Char := 16#1D702#;
   Mathematical_Italic_Small_Theta         :
      constant Unicode_Char := 16#1D703#;
   Mathematical_Italic_Small_Iota          :
      constant Unicode_Char := 16#1D704#;
   Mathematical_Italic_Small_Kappa         :
      constant Unicode_Char := 16#1D705#;
   Mathematical_Italic_Small_Lamda         :
      constant Unicode_Char := 16#1D706#;
   Mathematical_Italic_Small_Mu            :
      constant Unicode_Char := 16#1D707#;
   Mathematical_Italic_Small_Nu            :
      constant Unicode_Char := 16#1D708#;
   Mathematical_Italic_Small_Xi            :
      constant Unicode_Char := 16#1D709#;
   Mathematical_Italic_Small_Omicron       :
      constant Unicode_Char := 16#1D70A#;
   Mathematical_Italic_Small_Pi            :
      constant Unicode_Char := 16#1D70B#;
   Mathematical_Italic_Small_Rho           :
      constant Unicode_Char := 16#1D70C#;
   Mathematical_Italic_Small_Final_Sigma   :
      constant Unicode_Char := 16#1D70D#;
   Mathematical_Italic_Small_Sigma         :
      constant Unicode_Char := 16#1D70E#;
   Mathematical_Italic_Small_Tau           :
      constant Unicode_Char := 16#1D70F#;
   Mathematical_Italic_Small_Upsilon       :
      constant Unicode_Char := 16#1D710#;
   Mathematical_Italic_Small_Phi           :
      constant Unicode_Char := 16#1D711#;
   Mathematical_Italic_Small_Chi           :
      constant Unicode_Char := 16#1D712#;
   Mathematical_Italic_Small_Psi           :
      constant Unicode_Char := 16#1D713#;
   Mathematical_Italic_Small_Omega         :
      constant Unicode_Char := 16#1D714#;
   Mathematical_Italic_Partial_Differential :
      constant Unicode_Char := 16#1D715#;
   Mathematical_Italic_Epsilon_Symbol      :
      constant Unicode_Char := 16#1D716#;
   Mathematical_Italic_Theta_Symbol        :
      constant Unicode_Char := 16#1D717#;
   Mathematical_Italic_Kappa_Symbol        :
      constant Unicode_Char := 16#1D718#;
   Mathematical_Italic_Phi_Symbol          :
      constant Unicode_Char := 16#1D719#;
   Mathematical_Italic_Rho_Symbol          :
      constant Unicode_Char := 16#1D71A#;
   Mathematical_Italic_Pi_Symbol           :
      constant Unicode_Char := 16#1D71B#;
   Mathematical_Bold_Italic_Capital_Alpha  :
      constant Unicode_Char := 16#1D71C#;
   Mathematical_Bold_Italic_Capital_Beta   :
      constant Unicode_Char := 16#1D71D#;
   Mathematical_Bold_Italic_Capital_Gamma  :
      constant Unicode_Char := 16#1D71E#;
   Mathematical_Bold_Italic_Capital_Delta  :
      constant Unicode_Char := 16#1D71F#;
   Mathematical_Bold_Italic_Capital_Epsilon :
      constant Unicode_Char := 16#1D720#;
   Mathematical_Bold_Italic_Capital_Zeta   :
      constant Unicode_Char := 16#1D721#;
   Mathematical_Bold_Italic_Capital_Eta    :
      constant Unicode_Char := 16#1D722#;
   Mathematical_Bold_Italic_Capital_Theta  :
      constant Unicode_Char := 16#1D723#;
   Mathematical_Bold_Italic_Capital_Iota   :
      constant Unicode_Char := 16#1D724#;
   Mathematical_Bold_Italic_Capital_Kappa  :
      constant Unicode_Char := 16#1D725#;
   Mathematical_Bold_Italic_Capital_Lamda  :
      constant Unicode_Char := 16#1D726#;
   Mathematical_Bold_Italic_Capital_Mu     :
      constant Unicode_Char := 16#1D727#;
   Mathematical_Bold_Italic_Capital_Nu     :
      constant Unicode_Char := 16#1D728#;
   Mathematical_Bold_Italic_Capital_Xi     :
      constant Unicode_Char := 16#1D729#;
   Mathematical_Bold_Italic_Capital_Omicron :
      constant Unicode_Char := 16#1D72A#;
   Mathematical_Bold_Italic_Capital_Pi     :
      constant Unicode_Char := 16#1D72B#;
   Mathematical_Bold_Italic_Capital_Rho    :
      constant Unicode_Char := 16#1D72C#;
   Mathematical_Bold_Italic_Capital_Theta_Symbol :
      constant Unicode_Char := 16#1D72D#;
   Mathematical_Bold_Italic_Capital_Sigma  :
      constant Unicode_Char := 16#1D72E#;
   Mathematical_Bold_Italic_Capital_Tau    :
      constant Unicode_Char := 16#1D72F#;
   Mathematical_Bold_Italic_Capital_Upsilon :
      constant Unicode_Char := 16#1D730#;
   Mathematical_Bold_Italic_Capital_Phi    :
      constant Unicode_Char := 16#1D731#;
   Mathematical_Bold_Italic_Capital_Chi    :
      constant Unicode_Char := 16#1D732#;
   Mathematical_Bold_Italic_Capital_Psi    :
      constant Unicode_Char := 16#1D733#;
   Mathematical_Bold_Italic_Capital_Omega  :
      constant Unicode_Char := 16#1D734#;
   Mathematical_Bold_Italic_Nabla          :
      constant Unicode_Char := 16#1D735#;
   Mathematical_Bold_Italic_Small_Alpha    :
      constant Unicode_Char := 16#1D736#;
   Mathematical_Bold_Italic_Small_Beta     :
      constant Unicode_Char := 16#1D737#;
   Mathematical_Bold_Italic_Small_Gamma    :
      constant Unicode_Char := 16#1D738#;
   Mathematical_Bold_Italic_Small_Delta    :
      constant Unicode_Char := 16#1D739#;
   Mathematical_Bold_Italic_Small_Epsilon  :
      constant Unicode_Char := 16#1D73A#;
   Mathematical_Bold_Italic_Small_Zeta     :
      constant Unicode_Char := 16#1D73B#;
   Mathematical_Bold_Italic_Small_Eta      :
      constant Unicode_Char := 16#1D73C#;
   Mathematical_Bold_Italic_Small_Theta    :
      constant Unicode_Char := 16#1D73D#;
   Mathematical_Bold_Italic_Small_Iota     :
      constant Unicode_Char := 16#1D73E#;
   Mathematical_Bold_Italic_Small_Kappa    :
      constant Unicode_Char := 16#1D73F#;
   Mathematical_Bold_Italic_Small_Lamda    :
      constant Unicode_Char := 16#1D740#;
   Mathematical_Bold_Italic_Small_Mu       :
      constant Unicode_Char := 16#1D741#;
   Mathematical_Bold_Italic_Small_Nu       :
      constant Unicode_Char := 16#1D742#;
   Mathematical_Bold_Italic_Small_Xi       :
      constant Unicode_Char := 16#1D743#;
   Mathematical_Bold_Italic_Small_Omicron  :
      constant Unicode_Char := 16#1D744#;
   Mathematical_Bold_Italic_Small_Pi       :
      constant Unicode_Char := 16#1D745#;
   Mathematical_Bold_Italic_Small_Rho      :
      constant Unicode_Char := 16#1D746#;
   Mathematical_Bold_Italic_Small_Final_Sigma :
      constant Unicode_Char := 16#1D747#;
   Mathematical_Bold_Italic_Small_Sigma    :
      constant Unicode_Char := 16#1D748#;
   Mathematical_Bold_Italic_Small_Tau      :
      constant Unicode_Char := 16#1D749#;
   Mathematical_Bold_Italic_Small_Upsilon  :
      constant Unicode_Char := 16#1D74A#;
   Mathematical_Bold_Italic_Small_Phi      :
      constant Unicode_Char := 16#1D74B#;
   Mathematical_Bold_Italic_Small_Chi      :
      constant Unicode_Char := 16#1D74C#;
   Mathematical_Bold_Italic_Small_Psi      :
      constant Unicode_Char := 16#1D74D#;
   Mathematical_Bold_Italic_Small_Omega    :
      constant Unicode_Char := 16#1D74E#;
   Mathematical_Bold_Italic_Partial_Differential :
      constant Unicode_Char := 16#1D74F#;
   Mathematical_Bold_Italic_Epsilon_Symbol :
      constant Unicode_Char := 16#1D750#;
   Mathematical_Bold_Italic_Theta_Symbol   :
      constant Unicode_Char := 16#1D751#;
   Mathematical_Bold_Italic_Kappa_Symbol   :
      constant Unicode_Char := 16#1D752#;
   Mathematical_Bold_Italic_Phi_Symbol     :
      constant Unicode_Char := 16#1D753#;
   Mathematical_Bold_Italic_Rho_Symbol     :
      constant Unicode_Char := 16#1D754#;
   Mathematical_Bold_Italic_Pi_Symbol      :
      constant Unicode_Char := 16#1D755#;
   Mathematical_Sans_Serif_Bold_Capital_Alpha :
      constant Unicode_Char := 16#1D756#;
   Mathematical_Sans_Serif_Bold_Capital_Beta :
      constant Unicode_Char := 16#1D757#;
   Mathematical_Sans_Serif_Bold_Capital_Gamma :
      constant Unicode_Char := 16#1D758#;
   Mathematical_Sans_Serif_Bold_Capital_Delta :
      constant Unicode_Char := 16#1D759#;
   Mathematical_Sans_Serif_Bold_Capital_Epsilon :
      constant Unicode_Char := 16#1D75A#;
   Mathematical_Sans_Serif_Bold_Capital_Zeta :
      constant Unicode_Char := 16#1D75B#;
   Mathematical_Sans_Serif_Bold_Capital_Eta :
      constant Unicode_Char := 16#1D75C#;
   Mathematical_Sans_Serif_Bold_Capital_Theta :
      constant Unicode_Char := 16#1D75D#;
   Mathematical_Sans_Serif_Bold_Capital_Iota :
      constant Unicode_Char := 16#1D75E#;
   Mathematical_Sans_Serif_Bold_Capital_Kappa :
      constant Unicode_Char := 16#1D75F#;
   Mathematical_Sans_Serif_Bold_Capital_Lamda :
      constant Unicode_Char := 16#1D760#;
   Mathematical_Sans_Serif_Bold_Capital_Mu :
      constant Unicode_Char := 16#1D761#;
   Mathematical_Sans_Serif_Bold_Capital_Nu :
      constant Unicode_Char := 16#1D762#;
   Mathematical_Sans_Serif_Bold_Capital_Xi :
      constant Unicode_Char := 16#1D763#;
   Mathematical_Sans_Serif_Bold_Capital_Omicron :
      constant Unicode_Char := 16#1D764#;
   Mathematical_Sans_Serif_Bold_Capital_Pi :
      constant Unicode_Char := 16#1D765#;
   Mathematical_Sans_Serif_Bold_Capital_Rho :
      constant Unicode_Char := 16#1D766#;
   Mathematical_Sans_Serif_Bold_Capital_Theta_Symbol :
      constant Unicode_Char := 16#1D767#;
   Mathematical_Sans_Serif_Bold_Capital_Sigma :
      constant Unicode_Char := 16#1D768#;
   Mathematical_Sans_Serif_Bold_Capital_Tau :
      constant Unicode_Char := 16#1D769#;
   Mathematical_Sans_Serif_Bold_Capital_Upsilon :
      constant Unicode_Char := 16#1D76A#;
   Mathematical_Sans_Serif_Bold_Capital_Phi :
      constant Unicode_Char := 16#1D76B#;
   Mathematical_Sans_Serif_Bold_Capital_Chi :
      constant Unicode_Char := 16#1D76C#;
   Mathematical_Sans_Serif_Bold_Capital_Psi :
      constant Unicode_Char := 16#1D76D#;
   Mathematical_Sans_Serif_Bold_Capital_Omega :
      constant Unicode_Char := 16#1D76E#;
   Mathematical_Sans_Serif_Bold_Nabla      :
      constant Unicode_Char := 16#1D76F#;
   Mathematical_Sans_Serif_Bold_Small_Alpha :
      constant Unicode_Char := 16#1D770#;
   Mathematical_Sans_Serif_Bold_Small_Beta :
      constant Unicode_Char := 16#1D771#;
   Mathematical_Sans_Serif_Bold_Small_Gamma :
      constant Unicode_Char := 16#1D772#;
   Mathematical_Sans_Serif_Bold_Small_Delta :
      constant Unicode_Char := 16#1D773#;
   Mathematical_Sans_Serif_Bold_Small_Epsilon :
      constant Unicode_Char := 16#1D774#;
   Mathematical_Sans_Serif_Bold_Small_Zeta :
      constant Unicode_Char := 16#1D775#;
   Mathematical_Sans_Serif_Bold_Small_Eta  :
      constant Unicode_Char := 16#1D776#;
   Mathematical_Sans_Serif_Bold_Small_Theta :
      constant Unicode_Char := 16#1D777#;
   Mathematical_Sans_Serif_Bold_Small_Iota :
      constant Unicode_Char := 16#1D778#;
   Mathematical_Sans_Serif_Bold_Small_Kappa :
      constant Unicode_Char := 16#1D779#;
   Mathematical_Sans_Serif_Bold_Small_Lamda :
      constant Unicode_Char := 16#1D77A#;
   Mathematical_Sans_Serif_Bold_Small_Mu   :
      constant Unicode_Char := 16#1D77B#;
   Mathematical_Sans_Serif_Bold_Small_Nu   :
      constant Unicode_Char := 16#1D77C#;
   Mathematical_Sans_Serif_Bold_Small_Xi   :
      constant Unicode_Char := 16#1D77D#;
   Mathematical_Sans_Serif_Bold_Small_Omicron :
      constant Unicode_Char := 16#1D77E#;
   Mathematical_Sans_Serif_Bold_Small_Pi   :
      constant Unicode_Char := 16#1D77F#;
   Mathematical_Sans_Serif_Bold_Small_Rho  :
      constant Unicode_Char := 16#1D780#;
   Mathematical_Sans_Serif_Bold_Small_Final_Sigma :
      constant Unicode_Char := 16#1D781#;
   Mathematical_Sans_Serif_Bold_Small_Sigma :
      constant Unicode_Char := 16#1D782#;
   Mathematical_Sans_Serif_Bold_Small_Tau  :
      constant Unicode_Char := 16#1D783#;
   Mathematical_Sans_Serif_Bold_Small_Upsilon :
      constant Unicode_Char := 16#1D784#;
   Mathematical_Sans_Serif_Bold_Small_Phi  :
      constant Unicode_Char := 16#1D785#;
   Mathematical_Sans_Serif_Bold_Small_Chi  :
      constant Unicode_Char := 16#1D786#;
   Mathematical_Sans_Serif_Bold_Small_Psi  :
      constant Unicode_Char := 16#1D787#;
   Mathematical_Sans_Serif_Bold_Small_Omega :
      constant Unicode_Char := 16#1D788#;
   Mathematical_Sans_Serif_Bold_Partial_Differential :
      constant Unicode_Char := 16#1D789#;
   Mathematical_Sans_Serif_Bold_Epsilon_Symbol :
      constant Unicode_Char := 16#1D78A#;
   Mathematical_Sans_Serif_Bold_Theta_Symbol :
      constant Unicode_Char := 16#1D78B#;
   Mathematical_Sans_Serif_Bold_Kappa_Symbol :
      constant Unicode_Char := 16#1D78C#;
   Mathematical_Sans_Serif_Bold_Phi_Symbol :
      constant Unicode_Char := 16#1D78D#;
   Mathematical_Sans_Serif_Bold_Rho_Symbol :
      constant Unicode_Char := 16#1D78E#;
   Mathematical_Sans_Serif_Bold_Pi_Symbol  :
      constant Unicode_Char := 16#1D78F#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Alpha :
      constant Unicode_Char := 16#1D790#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Beta :
      constant Unicode_Char := 16#1D791#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Gamma :
      constant Unicode_Char := 16#1D792#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Delta :
      constant Unicode_Char := 16#1D793#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Epsilon :
      constant Unicode_Char := 16#1D794#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Zeta :
      constant Unicode_Char := 16#1D795#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Eta :
      constant Unicode_Char := 16#1D796#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Theta :
      constant Unicode_Char := 16#1D797#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Iota :
      constant Unicode_Char := 16#1D798#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Kappa :
      constant Unicode_Char := 16#1D799#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Lamda :
      constant Unicode_Char := 16#1D79A#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Mu :
      constant Unicode_Char := 16#1D79B#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Nu :
      constant Unicode_Char := 16#1D79C#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Xi :
      constant Unicode_Char := 16#1D79D#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Omicron :
      constant Unicode_Char := 16#1D79E#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Pi :
      constant Unicode_Char := 16#1D79F#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Rho :
      constant Unicode_Char := 16#1D7A0#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Theta_Symbol :
      constant Unicode_Char := 16#1D7A1#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Sigma :
      constant Unicode_Char := 16#1D7A2#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Tau :
      constant Unicode_Char := 16#1D7A3#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Upsilon :
      constant Unicode_Char := 16#1D7A4#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Phi :
      constant Unicode_Char := 16#1D7A5#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Chi :
      constant Unicode_Char := 16#1D7A6#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Psi :
      constant Unicode_Char := 16#1D7A7#;
   Mathematical_Sans_Serif_Bold_Italic_Capital_Omega :
      constant Unicode_Char := 16#1D7A8#;
   Mathematical_Sans_Serif_Bold_Italic_Nabla :
      constant Unicode_Char := 16#1D7A9#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Alpha :
      constant Unicode_Char := 16#1D7AA#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Beta :
      constant Unicode_Char := 16#1D7AB#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Gamma :
      constant Unicode_Char := 16#1D7AC#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Delta :
      constant Unicode_Char := 16#1D7AD#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Epsilon :
      constant Unicode_Char := 16#1D7AE#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Zeta :
      constant Unicode_Char := 16#1D7AF#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Eta :
      constant Unicode_Char := 16#1D7B0#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Theta :
      constant Unicode_Char := 16#1D7B1#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Iota :
      constant Unicode_Char := 16#1D7B2#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Kappa :
      constant Unicode_Char := 16#1D7B3#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Lamda :
      constant Unicode_Char := 16#1D7B4#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Mu :
      constant Unicode_Char := 16#1D7B5#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Nu :
      constant Unicode_Char := 16#1D7B6#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Xi :
      constant Unicode_Char := 16#1D7B7#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Omicron :
      constant Unicode_Char := 16#1D7B8#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Pi :
      constant Unicode_Char := 16#1D7B9#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Rho :
      constant Unicode_Char := 16#1D7BA#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Final_Sigma :
      constant Unicode_Char := 16#1D7BB#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Sigma :
      constant Unicode_Char := 16#1D7BC#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Tau :
      constant Unicode_Char := 16#1D7BD#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Upsilon :
      constant Unicode_Char := 16#1D7BE#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Phi :
      constant Unicode_Char := 16#1D7BF#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Chi :
      constant Unicode_Char := 16#1D7C0#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Psi :
      constant Unicode_Char := 16#1D7C1#;
   Mathematical_Sans_Serif_Bold_Italic_Small_Omega :
      constant Unicode_Char := 16#1D7C2#;
   Mathematical_Sans_Serif_Bold_Italic_Partial_Differential :
      constant Unicode_Char := 16#1D7C3#;
   Mathematical_Sans_Serif_Bold_Italic_Epsilon_Symbol :
      constant Unicode_Char := 16#1D7C4#;
   Mathematical_Sans_Serif_Bold_Italic_Theta_Symbol :
      constant Unicode_Char := 16#1D7C5#;
   Mathematical_Sans_Serif_Bold_Italic_Kappa_Symbol :
      constant Unicode_Char := 16#1D7C6#;
   Mathematical_Sans_Serif_Bold_Italic_Phi_Symbol :
      constant Unicode_Char := 16#1D7C7#;
   Mathematical_Sans_Serif_Bold_Italic_Rho_Symbol :
      constant Unicode_Char := 16#1D7C8#;
   Mathematical_Sans_Serif_Bold_Italic_Pi_Symbol :
      constant Unicode_Char := 16#1D7C9#;
   Mathematical_Bold_Capital_Digamma       :
      constant Unicode_Char := 16#1D7CA#;
   Mathematical_Bold_Small_Digamma         :
      constant Unicode_Char := 16#1D7CB#;
   Mathematical_Bold_Digit_Zero            :
      constant Unicode_Char := 16#1D7CE#;
   Mathematical_Bold_Digit_One             :
      constant Unicode_Char := 16#1D7CF#;
   Mathematical_Bold_Digit_Two             :
      constant Unicode_Char := 16#1D7D0#;
   Mathematical_Bold_Digit_Three           :
      constant Unicode_Char := 16#1D7D1#;
   Mathematical_Bold_Digit_Four            :
      constant Unicode_Char := 16#1D7D2#;
   Mathematical_Bold_Digit_Five            :
      constant Unicode_Char := 16#1D7D3#;
   Mathematical_Bold_Digit_Six             :
      constant Unicode_Char := 16#1D7D4#;
   Mathematical_Bold_Digit_Seven           :
      constant Unicode_Char := 16#1D7D5#;
   Mathematical_Bold_Digit_Eight           :
      constant Unicode_Char := 16#1D7D6#;
   Mathematical_Bold_Digit_Nine            :
      constant Unicode_Char := 16#1D7D7#;
   Mathematical_Double_Struck_Digit_Zero   :
      constant Unicode_Char := 16#1D7D8#;
   Mathematical_Double_Struck_Digit_One    :
      constant Unicode_Char := 16#1D7D9#;
   Mathematical_Double_Struck_Digit_Two    :
      constant Unicode_Char := 16#1D7DA#;
   Mathematical_Double_Struck_Digit_Three  :
      constant Unicode_Char := 16#1D7DB#;
   Mathematical_Double_Struck_Digit_Four   :
      constant Unicode_Char := 16#1D7DC#;
   Mathematical_Double_Struck_Digit_Five   :
      constant Unicode_Char := 16#1D7DD#;
   Mathematical_Double_Struck_Digit_Six    :
      constant Unicode_Char := 16#1D7DE#;
   Mathematical_Double_Struck_Digit_Seven  :
      constant Unicode_Char := 16#1D7DF#;
   Mathematical_Double_Struck_Digit_Eight  :
      constant Unicode_Char := 16#1D7E0#;
   Mathematical_Double_Struck_Digit_Nine   :
      constant Unicode_Char := 16#1D7E1#;
   Mathematical_Sans_Serif_Digit_Zero      :
      constant Unicode_Char := 16#1D7E2#;
   Mathematical_Sans_Serif_Digit_One       :
      constant Unicode_Char := 16#1D7E3#;
   Mathematical_Sans_Serif_Digit_Two       :
      constant Unicode_Char := 16#1D7E4#;
   Mathematical_Sans_Serif_Digit_Three     :
      constant Unicode_Char := 16#1D7E5#;
   Mathematical_Sans_Serif_Digit_Four      :
      constant Unicode_Char := 16#1D7E6#;
   Mathematical_Sans_Serif_Digit_Five      :
      constant Unicode_Char := 16#1D7E7#;
   Mathematical_Sans_Serif_Digit_Six       :
      constant Unicode_Char := 16#1D7E8#;
   Mathematical_Sans_Serif_Digit_Seven     :
      constant Unicode_Char := 16#1D7E9#;
   Mathematical_Sans_Serif_Digit_Eight     :
      constant Unicode_Char := 16#1D7EA#;
   Mathematical_Sans_Serif_Digit_Nine      :
      constant Unicode_Char := 16#1D7EB#;
   Mathematical_Sans_Serif_Bold_Digit_Zero :
      constant Unicode_Char := 16#1D7EC#;
   Mathematical_Sans_Serif_Bold_Digit_One  :
      constant Unicode_Char := 16#1D7ED#;
   Mathematical_Sans_Serif_Bold_Digit_Two  :
      constant Unicode_Char := 16#1D7EE#;
   Mathematical_Sans_Serif_Bold_Digit_Three :
      constant Unicode_Char := 16#1D7EF#;
   Mathematical_Sans_Serif_Bold_Digit_Four :
      constant Unicode_Char := 16#1D7F0#;
   Mathematical_Sans_Serif_Bold_Digit_Five :
      constant Unicode_Char := 16#1D7F1#;
   Mathematical_Sans_Serif_Bold_Digit_Six  :
      constant Unicode_Char := 16#1D7F2#;
   Mathematical_Sans_Serif_Bold_Digit_Seven :
      constant Unicode_Char := 16#1D7F3#;
   Mathematical_Sans_Serif_Bold_Digit_Eight :
      constant Unicode_Char := 16#1D7F4#;
   Mathematical_Sans_Serif_Bold_Digit_Nine :
      constant Unicode_Char := 16#1D7F5#;
   Mathematical_Monospace_Digit_Zero       :
      constant Unicode_Char := 16#1D7F6#;
   Mathematical_Monospace_Digit_One        :
      constant Unicode_Char := 16#1D7F7#;
   Mathematical_Monospace_Digit_Two        :
      constant Unicode_Char := 16#1D7F8#;
   Mathematical_Monospace_Digit_Three      :
      constant Unicode_Char := 16#1D7F9#;
   Mathematical_Monospace_Digit_Four       :
      constant Unicode_Char := 16#1D7FA#;
   Mathematical_Monospace_Digit_Five       :
      constant Unicode_Char := 16#1D7FB#;
   Mathematical_Monospace_Digit_Six        :
      constant Unicode_Char := 16#1D7FC#;
   Mathematical_Monospace_Digit_Seven      :
      constant Unicode_Char := 16#1D7FD#;
   Mathematical_Monospace_Digit_Eight      :
      constant Unicode_Char := 16#1D7FE#;
   Mathematical_Monospace_Digit_Nine       :
      constant Unicode_Char := 16#1D7FF#;
end Unicode.Names.Math_Alphanumeric_Symb;
