--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cjk_Compatibility is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Square_Apaato                           : constant Unicode_Char := 16#3300#;
   Square_Aruhua                           : constant Unicode_Char := 16#3301#;
   Square_Anpea                            : constant Unicode_Char := 16#3302#;
   Square_Aaru                             : constant Unicode_Char := 16#3303#;
   Square_Iningu                           : constant Unicode_Char := 16#3304#;
   Square_Inti                             : constant Unicode_Char := 16#3305#;
   Square_Uon                              : constant Unicode_Char := 16#3306#;
   Square_Esukuudo                         : constant Unicode_Char := 16#3307#;
   Square_Eekaa                            : constant Unicode_Char := 16#3308#;
   Square_Onsu                             : constant Unicode_Char := 16#3309#;
   Square_Oomu                             : constant Unicode_Char := 16#330A#;
   Square_Kairi                            : constant Unicode_Char := 16#330B#;
   Square_Karatto                          : constant Unicode_Char := 16#330C#;
   Square_Karorii                          : constant Unicode_Char := 16#330D#;
   Square_Garon                            : constant Unicode_Char := 16#330E#;
   Square_Ganma                            : constant Unicode_Char := 16#330F#;
   Square_Giga                             : constant Unicode_Char := 16#3310#;
   Square_Ginii                            : constant Unicode_Char := 16#3311#;
   Square_Kyurii                           : constant Unicode_Char := 16#3312#;
   Square_Girudaa                          : constant Unicode_Char := 16#3313#;
   Square_Kiro                             : constant Unicode_Char := 16#3314#;
   Square_Kiroguramu                       : constant Unicode_Char := 16#3315#;
   Square_Kiromeetoru                      : constant Unicode_Char := 16#3316#;
   Square_Kirowatto                        : constant Unicode_Char := 16#3317#;
   Square_Guramu                           : constant Unicode_Char := 16#3318#;
   Square_Guramuton                        : constant Unicode_Char := 16#3319#;
   Square_Kuruzeiro                        : constant Unicode_Char := 16#331A#;
   Square_Kuroone                          : constant Unicode_Char := 16#331B#;
   Square_Keesu                            : constant Unicode_Char := 16#331C#;
   Square_Koruna                           : constant Unicode_Char := 16#331D#;
   Square_Koopo                            : constant Unicode_Char := 16#331E#;
   Square_Saikuru                          : constant Unicode_Char := 16#331F#;
   Square_Santiimu                         : constant Unicode_Char := 16#3320#;
   Square_Siringu                          : constant Unicode_Char := 16#3321#;
   Square_Senti                            : constant Unicode_Char := 16#3322#;
   Square_Sento                            : constant Unicode_Char := 16#3323#;
   Square_Daasu                            : constant Unicode_Char := 16#3324#;
   Square_Desi                             : constant Unicode_Char := 16#3325#;
   Square_Doru                             : constant Unicode_Char := 16#3326#;
   Square_Ton                              : constant Unicode_Char := 16#3327#;
   Square_Nano                             : constant Unicode_Char := 16#3328#;
   Square_Notto                            : constant Unicode_Char := 16#3329#;
   Square_Haitu                            : constant Unicode_Char := 16#332A#;
   Square_Paasento                         : constant Unicode_Char := 16#332B#;
   Square_Paatu                            : constant Unicode_Char := 16#332C#;
   Square_Baareru                          : constant Unicode_Char := 16#332D#;
   Square_Piasutoru                        : constant Unicode_Char := 16#332E#;
   Square_Pikuru                           : constant Unicode_Char := 16#332F#;
   Square_Piko                             : constant Unicode_Char := 16#3330#;
   Square_Biru                             : constant Unicode_Char := 16#3331#;
   Square_Huaraddo                         : constant Unicode_Char := 16#3332#;
   Square_Huiito                           : constant Unicode_Char := 16#3333#;
   Square_Bussyeru                         : constant Unicode_Char := 16#3334#;
   Square_Huran                            : constant Unicode_Char := 16#3335#;
   Square_Hekutaaru                        : constant Unicode_Char := 16#3336#;
   Square_Peso                             : constant Unicode_Char := 16#3337#;
   Square_Penihi                           : constant Unicode_Char := 16#3338#;
   Square_Herutu                           : constant Unicode_Char := 16#3339#;
   Square_Pensu                            : constant Unicode_Char := 16#333A#;
   Square_Peezi                            : constant Unicode_Char := 16#333B#;
   Square_Beeta                            : constant Unicode_Char := 16#333C#;
   Square_Pointo                           : constant Unicode_Char := 16#333D#;
   Square_Boruto                           : constant Unicode_Char := 16#333E#;
   Square_Hon                              : constant Unicode_Char := 16#333F#;
   Square_Pondo                            : constant Unicode_Char := 16#3340#;
   Square_Hooru                            : constant Unicode_Char := 16#3341#;
   Square_Hoon                             : constant Unicode_Char := 16#3342#;
   Square_Maikuro                          : constant Unicode_Char := 16#3343#;
   Square_Mairu                            : constant Unicode_Char := 16#3344#;
   Square_Mahha                            : constant Unicode_Char := 16#3345#;
   Square_Maruku                           : constant Unicode_Char := 16#3346#;
   Square_Mansyon                          : constant Unicode_Char := 16#3347#;
   Square_Mikuron                          : constant Unicode_Char := 16#3348#;
   Square_Miri                             : constant Unicode_Char := 16#3349#;
   Square_Miribaaru                        : constant Unicode_Char := 16#334A#;
   Square_Mega                             : constant Unicode_Char := 16#334B#;
   Square_Megaton                          : constant Unicode_Char := 16#334C#;
   Square_Meetoru                          : constant Unicode_Char := 16#334D#;
   Square_Yaado                            : constant Unicode_Char := 16#334E#;
   Square_Yaaru                            : constant Unicode_Char := 16#334F#;
   Square_Yuan                             : constant Unicode_Char := 16#3350#;
   Square_Rittoru                          : constant Unicode_Char := 16#3351#;
   Square_Rira                             : constant Unicode_Char := 16#3352#;
   Square_Rupii                            : constant Unicode_Char := 16#3353#;
   Square_Ruuburu                          : constant Unicode_Char := 16#3354#;
   Square_Remu                             : constant Unicode_Char := 16#3355#;
   Square_Rentogen                         : constant Unicode_Char := 16#3356#;
   Square_Watto                            : constant Unicode_Char := 16#3357#;
   Ideographic_Telegraph_Symbol_For_Hour_Zero :
      constant Unicode_Char := 16#3358#;
   Ideographic_Telegraph_Symbol_For_Hour_One :
      constant Unicode_Char := 16#3359#;
   Ideographic_Telegraph_Symbol_For_Hour_Two :
      constant Unicode_Char := 16#335A#;
   Ideographic_Telegraph_Symbol_For_Hour_Three :
      constant Unicode_Char := 16#335B#;
   Ideographic_Telegraph_Symbol_For_Hour_Four :
      constant Unicode_Char := 16#335C#;
   Ideographic_Telegraph_Symbol_For_Hour_Five :
      constant Unicode_Char := 16#335D#;
   Ideographic_Telegraph_Symbol_For_Hour_Six :
      constant Unicode_Char := 16#335E#;
   Ideographic_Telegraph_Symbol_For_Hour_Seven :
      constant Unicode_Char := 16#335F#;
   Ideographic_Telegraph_Symbol_For_Hour_Eight :
      constant Unicode_Char := 16#3360#;
   Ideographic_Telegraph_Symbol_For_Hour_Nine :
      constant Unicode_Char := 16#3361#;
   Ideographic_Telegraph_Symbol_For_Hour_Ten :
      constant Unicode_Char := 16#3362#;
   Ideographic_Telegraph_Symbol_For_Hour_Eleven :
      constant Unicode_Char := 16#3363#;
   Ideographic_Telegraph_Symbol_For_Hour_Twelve :
      constant Unicode_Char := 16#3364#;
   Ideographic_Telegraph_Symbol_For_Hour_Thirteen :
      constant Unicode_Char := 16#3365#;
   Ideographic_Telegraph_Symbol_For_Hour_Fourteen :
      constant Unicode_Char := 16#3366#;
   Ideographic_Telegraph_Symbol_For_Hour_Fifteen :
      constant Unicode_Char := 16#3367#;
   Ideographic_Telegraph_Symbol_For_Hour_Sixteen :
      constant Unicode_Char := 16#3368#;
   Ideographic_Telegraph_Symbol_For_Hour_Seventeen :
      constant Unicode_Char := 16#3369#;
   Ideographic_Telegraph_Symbol_For_Hour_Eighteen :
      constant Unicode_Char := 16#336A#;
   Ideographic_Telegraph_Symbol_For_Hour_Nineteen :
      constant Unicode_Char := 16#336B#;
   Ideographic_Telegraph_Symbol_For_Hour_Twenty :
      constant Unicode_Char := 16#336C#;
   Ideographic_Telegraph_Symbol_For_Hour_Twenty_One :
      constant Unicode_Char := 16#336D#;
   Ideographic_Telegraph_Symbol_For_Hour_Twenty_Two :
      constant Unicode_Char := 16#336E#;
   Ideographic_Telegraph_Symbol_For_Hour_Twenty_Three :
      constant Unicode_Char := 16#336F#;
   Ideographic_Telegraph_Symbol_For_Hour_Twenty_Four :
      constant Unicode_Char := 16#3370#;
   Square_Hpa                              : constant Unicode_Char := 16#3371#;
   Square_Da                               : constant Unicode_Char := 16#3372#;
   Square_Au                               : constant Unicode_Char := 16#3373#;
   Square_Bar                              : constant Unicode_Char := 16#3374#;
   Square_Ov                               : constant Unicode_Char := 16#3375#;
   Square_Pc                               : constant Unicode_Char := 16#3376#;
   Square_Dm                               : constant Unicode_Char := 16#3377#;
   Square_Dm_Squared                       : constant Unicode_Char := 16#3378#;
   Square_Dm_Cubed                         : constant Unicode_Char := 16#3379#;
   Square_Iu                               : constant Unicode_Char := 16#337A#;
   Square_Era_Name_Heisei                  : constant Unicode_Char := 16#337B#;
   Square_Era_Name_Syouwa                  : constant Unicode_Char := 16#337C#;
   Square_Era_Name_Taisyou                 : constant Unicode_Char := 16#337D#;
   Square_Era_Name_Meizi                   : constant Unicode_Char := 16#337E#;
   Square_Corporation                      : constant Unicode_Char := 16#337F#;
   Square_Pa_Amps                          : constant Unicode_Char := 16#3380#;
   Square_Na                               : constant Unicode_Char := 16#3381#;
   Square_Mu_A                             : constant Unicode_Char := 16#3382#;
   Square_Ma                               : constant Unicode_Char := 16#3383#;
   Square_Ka                               : constant Unicode_Char := 16#3384#;
   Square_Kb                               : constant Unicode_Char := 16#3385#;
   Square_Mb                               : constant Unicode_Char := 16#3386#;
   Square_Gb                               : constant Unicode_Char := 16#3387#;
   Square_Cal                              : constant Unicode_Char := 16#3388#;
   Square_Kcal                             : constant Unicode_Char := 16#3389#;
   Square_Pf                               : constant Unicode_Char := 16#338A#;
   Square_Nf                               : constant Unicode_Char := 16#338B#;
   Square_Mu_F                             : constant Unicode_Char := 16#338C#;
   Square_Mu_G                             : constant Unicode_Char := 16#338D#;
   Square_Mg                               : constant Unicode_Char := 16#338E#;
   Square_Kg                               : constant Unicode_Char := 16#338F#;
   Square_Hz                               : constant Unicode_Char := 16#3390#;
   Square_Khz                              : constant Unicode_Char := 16#3391#;
   Square_Mhz                              : constant Unicode_Char := 16#3392#;
   Square_Ghz                              : constant Unicode_Char := 16#3393#;
   Square_Thz                              : constant Unicode_Char := 16#3394#;
   Square_Mu_L                             : constant Unicode_Char := 16#3395#;
   Square_Ml                               : constant Unicode_Char := 16#3396#;
   Square_Dl                               : constant Unicode_Char := 16#3397#;
   Square_Kl                               : constant Unicode_Char := 16#3398#;
   Square_Fm                               : constant Unicode_Char := 16#3399#;
   Square_Nm                               : constant Unicode_Char := 16#339A#;
   Square_Mu_M                             : constant Unicode_Char := 16#339B#;
   Square_Mm                               : constant Unicode_Char := 16#339C#;
   Square_Cm                               : constant Unicode_Char := 16#339D#;
   Square_Km                               : constant Unicode_Char := 16#339E#;
   Square_Mm_Squared                       : constant Unicode_Char := 16#339F#;
   Square_Cm_Squared                       : constant Unicode_Char := 16#33A0#;
   Square_M_Squared                        : constant Unicode_Char := 16#33A1#;
   Square_Km_Squared                       : constant Unicode_Char := 16#33A2#;
   Square_Mm_Cubed                         : constant Unicode_Char := 16#33A3#;
   Square_Cm_Cubed                         : constant Unicode_Char := 16#33A4#;
   Square_M_Cubed                          : constant Unicode_Char := 16#33A5#;
   Square_Km_Cubed                         : constant Unicode_Char := 16#33A6#;
   Square_M_Over_S                         : constant Unicode_Char := 16#33A7#;
   Square_M_Over_S_Squared                 : constant Unicode_Char := 16#33A8#;
   Square_Pa                               : constant Unicode_Char := 16#33A9#;
   Square_Kpa                              : constant Unicode_Char := 16#33AA#;
   Square_Mpa                              : constant Unicode_Char := 16#33AB#;
   Square_Gpa                              : constant Unicode_Char := 16#33AC#;
   Square_Rad                              : constant Unicode_Char := 16#33AD#;
   Square_Rad_Over_S                       : constant Unicode_Char := 16#33AE#;
   Square_Rad_Over_S_Squared               : constant Unicode_Char := 16#33AF#;
   Square_Ps                               : constant Unicode_Char := 16#33B0#;
   Square_Ns                               : constant Unicode_Char := 16#33B1#;
   Square_Mu_S                             : constant Unicode_Char := 16#33B2#;
   Square_Ms                               : constant Unicode_Char := 16#33B3#;
   Square_Pv                               : constant Unicode_Char := 16#33B4#;
   Square_Nv                               : constant Unicode_Char := 16#33B5#;
   Square_Mu_V                             : constant Unicode_Char := 16#33B6#;
   Square_Mv                               : constant Unicode_Char := 16#33B7#;
   Square_Kv                               : constant Unicode_Char := 16#33B8#;
   Square_Mv_Mega                          : constant Unicode_Char := 16#33B9#;
   Square_Pw                               : constant Unicode_Char := 16#33BA#;
   Square_Nw                               : constant Unicode_Char := 16#33BB#;
   Square_Mu_W                             : constant Unicode_Char := 16#33BC#;
   Square_Mw                               : constant Unicode_Char := 16#33BD#;
   Square_Kw                               : constant Unicode_Char := 16#33BE#;
   Square_Mw_Mega                          : constant Unicode_Char := 16#33BF#;
   Square_K_Ohm                            : constant Unicode_Char := 16#33C0#;
   Square_M_Ohm                            : constant Unicode_Char := 16#33C1#;
   Square_Am                               : constant Unicode_Char := 16#33C2#;
   Square_Bq                               : constant Unicode_Char := 16#33C3#;
   Square_Cc                               : constant Unicode_Char := 16#33C4#;
   Square_Cd                               : constant Unicode_Char := 16#33C5#;
   Square_C_Over_Kg                        : constant Unicode_Char := 16#33C6#;
   Square_Co                               : constant Unicode_Char := 16#33C7#;
   Square_Db                               : constant Unicode_Char := 16#33C8#;
   Square_Gy                               : constant Unicode_Char := 16#33C9#;
   Square_Ha                               : constant Unicode_Char := 16#33CA#;
   Square_Hp                               : constant Unicode_Char := 16#33CB#;
   Square_In                               : constant Unicode_Char := 16#33CC#;
   Square_Kk                               : constant Unicode_Char := 16#33CD#;
   Square_Km_Capital                       : constant Unicode_Char := 16#33CE#;
   Square_Kt                               : constant Unicode_Char := 16#33CF#;
   Square_Lm                               : constant Unicode_Char := 16#33D0#;
   Square_Ln                               : constant Unicode_Char := 16#33D1#;
   Square_Log                              : constant Unicode_Char := 16#33D2#;
   Square_Lx                               : constant Unicode_Char := 16#33D3#;
   Square_Mb_Small                         : constant Unicode_Char := 16#33D4#;
   Square_Mil                              : constant Unicode_Char := 16#33D5#;
   Square_Mol                              : constant Unicode_Char := 16#33D6#;
   Square_Ph                               : constant Unicode_Char := 16#33D7#;
   Square_Pm                               : constant Unicode_Char := 16#33D8#;
   Square_Ppm                              : constant Unicode_Char := 16#33D9#;
   Square_Pr                               : constant Unicode_Char := 16#33DA#;
   Square_Sr                               : constant Unicode_Char := 16#33DB#;
   Square_Sv                               : constant Unicode_Char := 16#33DC#;
   Square_Wb                               : constant Unicode_Char := 16#33DD#;
   Square_V_Over_M                         : constant Unicode_Char := 16#33DE#;
   Square_A_Over_M                         : constant Unicode_Char := 16#33DF#;
   Ideographic_Telegraph_Symbol_For_Day_One :
      constant Unicode_Char := 16#33E0#;
   Ideographic_Telegraph_Symbol_For_Day_Two :
      constant Unicode_Char := 16#33E1#;
   Ideographic_Telegraph_Symbol_For_Day_Three :
      constant Unicode_Char := 16#33E2#;
   Ideographic_Telegraph_Symbol_For_Day_Four :
      constant Unicode_Char := 16#33E3#;
   Ideographic_Telegraph_Symbol_For_Day_Five :
      constant Unicode_Char := 16#33E4#;
   Ideographic_Telegraph_Symbol_For_Day_Six :
      constant Unicode_Char := 16#33E5#;
   Ideographic_Telegraph_Symbol_For_Day_Seven :
      constant Unicode_Char := 16#33E6#;
   Ideographic_Telegraph_Symbol_For_Day_Eight :
      constant Unicode_Char := 16#33E7#;
   Ideographic_Telegraph_Symbol_For_Day_Nine :
      constant Unicode_Char := 16#33E8#;
   Ideographic_Telegraph_Symbol_For_Day_Ten :
      constant Unicode_Char := 16#33E9#;
   Ideographic_Telegraph_Symbol_For_Day_Eleven :
      constant Unicode_Char := 16#33EA#;
   Ideographic_Telegraph_Symbol_For_Day_Twelve :
      constant Unicode_Char := 16#33EB#;
   Ideographic_Telegraph_Symbol_For_Day_Thirteen :
      constant Unicode_Char := 16#33EC#;
   Ideographic_Telegraph_Symbol_For_Day_Fourteen :
      constant Unicode_Char := 16#33ED#;
   Ideographic_Telegraph_Symbol_For_Day_Fifteen :
      constant Unicode_Char := 16#33EE#;
   Ideographic_Telegraph_Symbol_For_Day_Sixteen :
      constant Unicode_Char := 16#33EF#;
   Ideographic_Telegraph_Symbol_For_Day_Seventeen :
      constant Unicode_Char := 16#33F0#;
   Ideographic_Telegraph_Symbol_For_Day_Eighteen :
      constant Unicode_Char := 16#33F1#;
   Ideographic_Telegraph_Symbol_For_Day_Nineteen :
      constant Unicode_Char := 16#33F2#;
   Ideographic_Telegraph_Symbol_For_Day_Twenty :
      constant Unicode_Char := 16#33F3#;
   Ideographic_Telegraph_Symbol_For_Day_Twenty_One :
      constant Unicode_Char := 16#33F4#;
   Ideographic_Telegraph_Symbol_For_Day_Twenty_Two :
      constant Unicode_Char := 16#33F5#;
   Ideographic_Telegraph_Symbol_For_Day_Twenty_Three :
      constant Unicode_Char := 16#33F6#;
   Ideographic_Telegraph_Symbol_For_Day_Twenty_Four :
      constant Unicode_Char := 16#33F7#;
   Ideographic_Telegraph_Symbol_For_Day_Twenty_Five :
      constant Unicode_Char := 16#33F8#;
   Ideographic_Telegraph_Symbol_For_Day_Twenty_Six :
      constant Unicode_Char := 16#33F9#;
   Ideographic_Telegraph_Symbol_For_Day_Twenty_Seven :
      constant Unicode_Char := 16#33FA#;
   Ideographic_Telegraph_Symbol_For_Day_Twenty_Eight :
      constant Unicode_Char := 16#33FB#;
   Ideographic_Telegraph_Symbol_For_Day_Twenty_Nine :
      constant Unicode_Char := 16#33FC#;
   Ideographic_Telegraph_Symbol_For_Day_Thirty :
      constant Unicode_Char := 16#33FD#;
   Ideographic_Telegraph_Symbol_For_Day_Thirty_One :
      constant Unicode_Char := 16#33FE#;
   Square_Gal                              : constant Unicode_Char := 16#33FF#;
end Unicode.Names.Cjk_Compatibility;
