--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Phags_Pa is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Phags_Pa_Letter_Ka                      : constant Unicode_Char := 16#A840#;
   Phags_Pa_Letter_Kha                     : constant Unicode_Char := 16#A841#;
   Phags_Pa_Letter_Ga                      : constant Unicode_Char := 16#A842#;
   Phags_Pa_Letter_Nga                     : constant Unicode_Char := 16#A843#;
   Phags_Pa_Letter_Ca                      : constant Unicode_Char := 16#A844#;
   Phags_Pa_Letter_Cha                     : constant Unicode_Char := 16#A845#;
   Phags_Pa_Letter_Ja                      : constant Unicode_Char := 16#A846#;
   Phags_Pa_Letter_Nya                     : constant Unicode_Char := 16#A847#;
   Phags_Pa_Letter_Ta                      : constant Unicode_Char := 16#A848#;
   Phags_Pa_Letter_Tha                     : constant Unicode_Char := 16#A849#;
   Phags_Pa_Letter_Da                      : constant Unicode_Char := 16#A84A#;
   Phags_Pa_Letter_Na                      : constant Unicode_Char := 16#A84B#;
   Phags_Pa_Letter_Pa                      : constant Unicode_Char := 16#A84C#;
   Phags_Pa_Letter_Pha                     : constant Unicode_Char := 16#A84D#;
   Phags_Pa_Letter_Ba                      : constant Unicode_Char := 16#A84E#;
   Phags_Pa_Letter_Ma                      : constant Unicode_Char := 16#A84F#;
   Phags_Pa_Letter_Tsa                     : constant Unicode_Char := 16#A850#;
   Phags_Pa_Letter_Tsha                    : constant Unicode_Char := 16#A851#;
   Phags_Pa_Letter_Dza                     : constant Unicode_Char := 16#A852#;
   Phags_Pa_Letter_Wa                      : constant Unicode_Char := 16#A853#;
   Phags_Pa_Letter_Zha                     : constant Unicode_Char := 16#A854#;
   Phags_Pa_Letter_Za                      : constant Unicode_Char := 16#A855#;
   Phags_Pa_Letter_Small_A                 : constant Unicode_Char := 16#A856#;
   Phags_Pa_Letter_Ya                      : constant Unicode_Char := 16#A857#;
   Phags_Pa_Letter_Ra                      : constant Unicode_Char := 16#A858#;
   Phags_Pa_Letter_La                      : constant Unicode_Char := 16#A859#;
   Phags_Pa_Letter_Sha                     : constant Unicode_Char := 16#A85A#;
   Phags_Pa_Letter_Sa                      : constant Unicode_Char := 16#A85B#;
   Phags_Pa_Letter_Ha                      : constant Unicode_Char := 16#A85C#;
   Phags_Pa_Letter_A                       : constant Unicode_Char := 16#A85D#;
   Phags_Pa_Letter_I                       : constant Unicode_Char := 16#A85E#;
   Phags_Pa_Letter_U                       : constant Unicode_Char := 16#A85F#;
   Phags_Pa_Letter_E                       : constant Unicode_Char := 16#A860#;
   Phags_Pa_Letter_O                       : constant Unicode_Char := 16#A861#;
   Phags_Pa_Letter_Qa                      : constant Unicode_Char := 16#A862#;
   Phags_Pa_Letter_Xa                      : constant Unicode_Char := 16#A863#;
   Phags_Pa_Letter_Fa                      : constant Unicode_Char := 16#A864#;
   Phags_Pa_Letter_Gga                     : constant Unicode_Char := 16#A865#;
   Phags_Pa_Letter_Ee                      : constant Unicode_Char := 16#A866#;
   Phags_Pa_Subjoined_Letter_Wa            : constant Unicode_Char := 16#A867#;
   Phags_Pa_Subjoined_Letter_Ya            : constant Unicode_Char := 16#A868#;
   Phags_Pa_Letter_Tta                     : constant Unicode_Char := 16#A869#;
   Phags_Pa_Letter_Ttha                    : constant Unicode_Char := 16#A86A#;
   Phags_Pa_Letter_Dda                     : constant Unicode_Char := 16#A86B#;
   Phags_Pa_Letter_Nna                     : constant Unicode_Char := 16#A86C#;
   Phags_Pa_Letter_Alternate_Ya            : constant Unicode_Char := 16#A86D#;
   Phags_Pa_Letter_Voiceless_Sha           : constant Unicode_Char := 16#A86E#;
   Phags_Pa_Letter_Voiced_Ha               : constant Unicode_Char := 16#A86F#;
   Phags_Pa_Letter_Aspirated_Fa            : constant Unicode_Char := 16#A870#;
   Phags_Pa_Subjoined_Letter_Ra            : constant Unicode_Char := 16#A871#;
   Phags_Pa_Superfixed_Letter_Ra           : constant Unicode_Char := 16#A872#;
   Phags_Pa_Letter_Candrabindu             : constant Unicode_Char := 16#A873#;
   Phags_Pa_Single_Head_Mark               : constant Unicode_Char := 16#A874#;
   Phags_Pa_Double_Head_Mark               : constant Unicode_Char := 16#A875#;
   Phags_Pa_Mark_Shad                      : constant Unicode_Char := 16#A876#;
   Phags_Pa_Mark_Double_Shad               : constant Unicode_Char := 16#A877#;
end Unicode.Names.Phags_Pa;
