--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Phaistos_Disc is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Phaistos_Disc_Sign_Pedestrian           :
      constant Unicode_Char := 16#101D0#;
   Phaistos_Disc_Sign_Plumed_Head          :
      constant Unicode_Char := 16#101D1#;
   Phaistos_Disc_Sign_Tattooed_Head        :
      constant Unicode_Char := 16#101D2#;
   Phaistos_Disc_Sign_Captive              :
      constant Unicode_Char := 16#101D3#;
   Phaistos_Disc_Sign_Child                :
      constant Unicode_Char := 16#101D4#;
   Phaistos_Disc_Sign_Woman                :
      constant Unicode_Char := 16#101D5#;
   Phaistos_Disc_Sign_Helmet               :
      constant Unicode_Char := 16#101D6#;
   Phaistos_Disc_Sign_Gauntlet             :
      constant Unicode_Char := 16#101D7#;
   Phaistos_Disc_Sign_Tiara                :
      constant Unicode_Char := 16#101D8#;
   Phaistos_Disc_Sign_Arrow                :
      constant Unicode_Char := 16#101D9#;
   Phaistos_Disc_Sign_Bow                  :
      constant Unicode_Char := 16#101DA#;
   Phaistos_Disc_Sign_Shield               :
      constant Unicode_Char := 16#101DB#;
   Phaistos_Disc_Sign_Club                 :
      constant Unicode_Char := 16#101DC#;
   Phaistos_Disc_Sign_Manacles             :
      constant Unicode_Char := 16#101DD#;
   Phaistos_Disc_Sign_Mattock              :
      constant Unicode_Char := 16#101DE#;
   Phaistos_Disc_Sign_Saw                  :
      constant Unicode_Char := 16#101DF#;
   Phaistos_Disc_Sign_Lid                  :
      constant Unicode_Char := 16#101E0#;
   Phaistos_Disc_Sign_Boomerang            :
      constant Unicode_Char := 16#101E1#;
   Phaistos_Disc_Sign_Carpentry_Plane      :
      constant Unicode_Char := 16#101E2#;
   Phaistos_Disc_Sign_Dolium               :
      constant Unicode_Char := 16#101E3#;
   Phaistos_Disc_Sign_Comb                 :
      constant Unicode_Char := 16#101E4#;
   Phaistos_Disc_Sign_Sling                :
      constant Unicode_Char := 16#101E5#;
   Phaistos_Disc_Sign_Column               :
      constant Unicode_Char := 16#101E6#;
   Phaistos_Disc_Sign_Beehive              :
      constant Unicode_Char := 16#101E7#;
   Phaistos_Disc_Sign_Ship                 :
      constant Unicode_Char := 16#101E8#;
   Phaistos_Disc_Sign_Horn                 :
      constant Unicode_Char := 16#101E9#;
   Phaistos_Disc_Sign_Hide                 :
      constant Unicode_Char := 16#101EA#;
   Phaistos_Disc_Sign_Bulls_Leg            :
      constant Unicode_Char := 16#101EB#;
   Phaistos_Disc_Sign_Cat                  :
      constant Unicode_Char := 16#101EC#;
   Phaistos_Disc_Sign_Ram                  :
      constant Unicode_Char := 16#101ED#;
   Phaistos_Disc_Sign_Eagle                :
      constant Unicode_Char := 16#101EE#;
   Phaistos_Disc_Sign_Dove                 :
      constant Unicode_Char := 16#101EF#;
   Phaistos_Disc_Sign_Tunny                :
      constant Unicode_Char := 16#101F0#;
   Phaistos_Disc_Sign_Bee                  :
      constant Unicode_Char := 16#101F1#;
   Phaistos_Disc_Sign_Plane_Tree           :
      constant Unicode_Char := 16#101F2#;
   Phaistos_Disc_Sign_Vine                 :
      constant Unicode_Char := 16#101F3#;
   Phaistos_Disc_Sign_Papyrus              :
      constant Unicode_Char := 16#101F4#;
   Phaistos_Disc_Sign_Rosette              :
      constant Unicode_Char := 16#101F5#;
   Phaistos_Disc_Sign_Lily                 :
      constant Unicode_Char := 16#101F6#;
   Phaistos_Disc_Sign_Ox_Back              :
      constant Unicode_Char := 16#101F7#;
   Phaistos_Disc_Sign_Flute                :
      constant Unicode_Char := 16#101F8#;
   Phaistos_Disc_Sign_Grater               :
      constant Unicode_Char := 16#101F9#;
   Phaistos_Disc_Sign_Strainer             :
      constant Unicode_Char := 16#101FA#;
   Phaistos_Disc_Sign_Small_Axe            :
      constant Unicode_Char := 16#101FB#;
   Phaistos_Disc_Sign_Wavy_Band            :
      constant Unicode_Char := 16#101FC#;
   Phaistos_Disc_Sign_Combining_Oblique_Stroke :
      constant Unicode_Char := 16#101FD#;
end Unicode.Names.Phaistos_Disc;
