--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Miscellaneous_Symbols is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Black_Sun_With_Rays                     : constant Unicode_Char := 16#2600#;
   Cloud                                   : constant Unicode_Char := 16#2601#;
   Umbrella                                : constant Unicode_Char := 16#2602#;
   Snowman                                 : constant Unicode_Char := 16#2603#;
   Comet                                   : constant Unicode_Char := 16#2604#;
   Black_Star                              : constant Unicode_Char := 16#2605#;
   White_Star                              : constant Unicode_Char := 16#2606#;
   Lightning                               : constant Unicode_Char := 16#2607#;
   Thunderstorm                            : constant Unicode_Char := 16#2608#;
   Sun                                     : constant Unicode_Char := 16#2609#;
   Ascending_Node                          : constant Unicode_Char := 16#260A#;
   Descending_Node                         : constant Unicode_Char := 16#260B#;
   Conjunction                             : constant Unicode_Char := 16#260C#;
   Opposition                              : constant Unicode_Char := 16#260D#;
   Black_Telephone                         : constant Unicode_Char := 16#260E#;
   White_Telephone                         : constant Unicode_Char := 16#260F#;
   Ballot_Box                              : constant Unicode_Char := 16#2610#;
   Ballot_Box_With_Check                   : constant Unicode_Char := 16#2611#;
   Ballot_Box_With_X                       : constant Unicode_Char := 16#2612#;
   Saltire                                 : constant Unicode_Char := 16#2613#;
   Umbrella_With_Rain_Drops                : constant Unicode_Char := 16#2614#;
   Hot_Beverage                            : constant Unicode_Char := 16#2615#;
   White_Shogi_Piece                       : constant Unicode_Char := 16#2616#;
   Black_Shogi_Piece                       : constant Unicode_Char := 16#2617#;
   Shamrock                                : constant Unicode_Char := 16#2618#;
   Reversed_Rotated_Floral_Heart_Bullet    : constant Unicode_Char := 16#2619#;
   Black_Left_Pointing_Index               : constant Unicode_Char := 16#261A#;
   Black_Right_Pointing_Index              : constant Unicode_Char := 16#261B#;
   White_Left_Pointing_Index               : constant Unicode_Char := 16#261C#;
   White_Up_Pointing_Index                 : constant Unicode_Char := 16#261D#;
   White_Right_Pointing_Index              : constant Unicode_Char := 16#261E#;
   White_Down_Pointing_Index               : constant Unicode_Char := 16#261F#;
   Skull_And_Crossbones                    : constant Unicode_Char := 16#2620#;
   Caution_Sign                            : constant Unicode_Char := 16#2621#;
   Radioactive_Sign                        : constant Unicode_Char := 16#2622#;
   Biohazard_Sign                          : constant Unicode_Char := 16#2623#;
   Caduceus                                : constant Unicode_Char := 16#2624#;
   Ankh                                    : constant Unicode_Char := 16#2625#;
   Orthodox_Cross                          : constant Unicode_Char := 16#2626#;
   Chi_Rho                                 : constant Unicode_Char := 16#2627#;
   Cross_Of_Lorraine                       : constant Unicode_Char := 16#2628#;
   Cross_Of_Jerusalem                      : constant Unicode_Char := 16#2629#;
   Star_And_Crescent                       : constant Unicode_Char := 16#262A#;
   Farsi_Symbol                            : constant Unicode_Char := 16#262B#;
   Adi_Shakti                              : constant Unicode_Char := 16#262C#;
   Hammer_And_Sickle                       : constant Unicode_Char := 16#262D#;
   Peace_Symbol                            : constant Unicode_Char := 16#262E#;
   Yin_Yang                                : constant Unicode_Char := 16#262F#;
   Trigram_For_Heaven                      : constant Unicode_Char := 16#2630#;
   Trigram_For_Lake                        : constant Unicode_Char := 16#2631#;
   Trigram_For_Fire                        : constant Unicode_Char := 16#2632#;
   Trigram_For_Thunder                     : constant Unicode_Char := 16#2633#;
   Trigram_For_Wind                        : constant Unicode_Char := 16#2634#;
   Trigram_For_Water                       : constant Unicode_Char := 16#2635#;
   Trigram_For_Mountain                    : constant Unicode_Char := 16#2636#;
   Trigram_For_Earth                       : constant Unicode_Char := 16#2637#;
   Wheel_Of_Dharma                         : constant Unicode_Char := 16#2638#;
   White_Frowning_Face                     : constant Unicode_Char := 16#2639#;
   White_Smiling_Face                      : constant Unicode_Char := 16#263A#;
   Black_Smiling_Face                      : constant Unicode_Char := 16#263B#;
   White_Sun_With_Rays                     : constant Unicode_Char := 16#263C#;
   First_Quarter_Moon                      : constant Unicode_Char := 16#263D#;
   Last_Quarter_Moon                       : constant Unicode_Char := 16#263E#;
   Mercury                                 : constant Unicode_Char := 16#263F#;
   Female_Sign                             : constant Unicode_Char := 16#2640#;
   Earth                                   : constant Unicode_Char := 16#2641#;
   Male_Sign                               : constant Unicode_Char := 16#2642#;
   Jupiter                                 : constant Unicode_Char := 16#2643#;
   Saturn                                  : constant Unicode_Char := 16#2644#;
   Uranus                                  : constant Unicode_Char := 16#2645#;
   Neptune                                 : constant Unicode_Char := 16#2646#;
   Pluto                                   : constant Unicode_Char := 16#2647#;
   Aries                                   : constant Unicode_Char := 16#2648#;
   Taurus                                  : constant Unicode_Char := 16#2649#;
   Gemini                                  : constant Unicode_Char := 16#264A#;
   Cancer                                  : constant Unicode_Char := 16#264B#;
   Leo                                     : constant Unicode_Char := 16#264C#;
   Virgo                                   : constant Unicode_Char := 16#264D#;
   Libra                                   : constant Unicode_Char := 16#264E#;
   Scorpius                                : constant Unicode_Char := 16#264F#;
   Sagittarius                             : constant Unicode_Char := 16#2650#;
   Capricorn                               : constant Unicode_Char := 16#2651#;
   Aquarius                                : constant Unicode_Char := 16#2652#;
   Pisces                                  : constant Unicode_Char := 16#2653#;
   White_Chess_King                        : constant Unicode_Char := 16#2654#;
   White_Chess_Queen                       : constant Unicode_Char := 16#2655#;
   White_Chess_Rook                        : constant Unicode_Char := 16#2656#;
   White_Chess_Bishop                      : constant Unicode_Char := 16#2657#;
   White_Chess_Knight                      : constant Unicode_Char := 16#2658#;
   White_Chess_Pawn                        : constant Unicode_Char := 16#2659#;
   Black_Chess_King                        : constant Unicode_Char := 16#265A#;
   Black_Chess_Queen                       : constant Unicode_Char := 16#265B#;
   Black_Chess_Rook                        : constant Unicode_Char := 16#265C#;
   Black_Chess_Bishop                      : constant Unicode_Char := 16#265D#;
   Black_Chess_Knight                      : constant Unicode_Char := 16#265E#;
   Black_Chess_Pawn                        : constant Unicode_Char := 16#265F#;
   Black_Spade_Suit                        : constant Unicode_Char := 16#2660#;
   White_Heart_Suit                        : constant Unicode_Char := 16#2661#;
   White_Diamond_Suit                      : constant Unicode_Char := 16#2662#;
   Black_Club_Suit                         : constant Unicode_Char := 16#2663#;
   White_Spade_Suit                        : constant Unicode_Char := 16#2664#;
   Black_Heart_Suit                        : constant Unicode_Char := 16#2665#;
   Black_Diamond_Suit                      : constant Unicode_Char := 16#2666#;
   White_Club_Suit                         : constant Unicode_Char := 16#2667#;
   Hot_Springs                             : constant Unicode_Char := 16#2668#;
   Quarter_Note                            : constant Unicode_Char := 16#2669#;
   Eighth_Note                             : constant Unicode_Char := 16#266A#;
   Beamed_Eighth_Notes                     : constant Unicode_Char := 16#266B#;
   Beamed_Sixteenth_Notes                  : constant Unicode_Char := 16#266C#;
   Music_Flat_Sign                         : constant Unicode_Char := 16#266D#;
   Music_Natural_Sign                      : constant Unicode_Char := 16#266E#;
   Music_Sharp_Sign                        : constant Unicode_Char := 16#266F#;
   West_Syriac_Cross                       : constant Unicode_Char := 16#2670#;
   East_Syriac_Cross                       : constant Unicode_Char := 16#2671#;
   Universal_Recycling_Symbol              : constant Unicode_Char := 16#2672#;
   Recycling_Symbol_For_Type_1_Plastics    : constant Unicode_Char := 16#2673#;
   Recycling_Symbol_For_Type_2_Plastics    : constant Unicode_Char := 16#2674#;
   Recycling_Symbol_For_Type_3_Plastics    : constant Unicode_Char := 16#2675#;
   Recycling_Symbol_For_Type_4_Plastics    : constant Unicode_Char := 16#2676#;
   Recycling_Symbol_For_Type_5_Plastics    : constant Unicode_Char := 16#2677#;
   Recycling_Symbol_For_Type_6_Plastics    : constant Unicode_Char := 16#2678#;
   Recycling_Symbol_For_Type_7_Plastics    : constant Unicode_Char := 16#2679#;
   Recycling_Symbol_For_Generic_Materials  : constant Unicode_Char := 16#267A#;
   Black_Universal_Recycling_Symbol        : constant Unicode_Char := 16#267B#;
   Recycled_Paper_Symbol                   : constant Unicode_Char := 16#267C#;
   Partially_Recycled_Paper_Symbol         : constant Unicode_Char := 16#267D#;
   Permanent_Paper_Sign                    : constant Unicode_Char := 16#267E#;
   Wheelchair_Symbol                       : constant Unicode_Char := 16#267F#;
   Die_Face_1                              : constant Unicode_Char := 16#2680#;
   Die_Face_2                              : constant Unicode_Char := 16#2681#;
   Die_Face_3                              : constant Unicode_Char := 16#2682#;
   Die_Face_4                              : constant Unicode_Char := 16#2683#;
   Die_Face_5                              : constant Unicode_Char := 16#2684#;
   Die_Face_6                              : constant Unicode_Char := 16#2685#;
   White_Circle_With_Dot_Right             : constant Unicode_Char := 16#2686#;
   White_Circle_With_Two_Dots              : constant Unicode_Char := 16#2687#;
   Black_Circle_With_White_Dot_Right       : constant Unicode_Char := 16#2688#;
   Black_Circle_With_Two_White_Dots        : constant Unicode_Char := 16#2689#;
   Monogram_For_Yang                       : constant Unicode_Char := 16#268A#;
   Monogram_For_Yin                        : constant Unicode_Char := 16#268B#;
   Digram_For_Greater_Yang                 : constant Unicode_Char := 16#268C#;
   Digram_For_Lesser_Yin                   : constant Unicode_Char := 16#268D#;
   Digram_For_Lesser_Yang                  : constant Unicode_Char := 16#268E#;
   Digram_For_Greater_Yin                  : constant Unicode_Char := 16#268F#;
   White_Flag                              : constant Unicode_Char := 16#2690#;
   Black_Flag                              : constant Unicode_Char := 16#2691#;
   Hammer_And_Pick                         : constant Unicode_Char := 16#2692#;
   Anchor                                  : constant Unicode_Char := 16#2693#;
   Crossed_Swords                          : constant Unicode_Char := 16#2694#;
   Staff_Of_Aesculapius                    : constant Unicode_Char := 16#2695#;
   Scales                                  : constant Unicode_Char := 16#2696#;
   Alembic                                 : constant Unicode_Char := 16#2697#;
   Flower                                  : constant Unicode_Char := 16#2698#;
   Gear                                    : constant Unicode_Char := 16#2699#;
   Staff_Of_Hermes                         : constant Unicode_Char := 16#269A#;
   Atom_Symbol                             : constant Unicode_Char := 16#269B#;
   Fleur_De_Lis                            : constant Unicode_Char := 16#269C#;
   Outlined_White_Star                     : constant Unicode_Char := 16#269D#;
   Three_Lines_Converging_Right            : constant Unicode_Char := 16#269E#;
   Three_Lines_Converging_Left             : constant Unicode_Char := 16#269F#;
   Warning_Sign                            : constant Unicode_Char := 16#26A0#;
   High_Voltage_Sign                       : constant Unicode_Char := 16#26A1#;
   Doubled_Female_Sign                     : constant Unicode_Char := 16#26A2#;
   Doubled_Male_Sign                       : constant Unicode_Char := 16#26A3#;
   Interlocked_Female_And_Male_Sign        : constant Unicode_Char := 16#26A4#;
   Male_And_Female_Sign                    : constant Unicode_Char := 16#26A5#;
   Male_With_Stroke_Sign                   : constant Unicode_Char := 16#26A6#;
   Male_With_Stroke_And_Male_And_Female_Sign :
      constant Unicode_Char := 16#26A7#;
   Vertical_Male_With_Stroke_Sign          : constant Unicode_Char := 16#26A8#;
   Horizontal_Male_With_Stroke_Sign        : constant Unicode_Char := 16#26A9#;
   Medium_White_Circle                     : constant Unicode_Char := 16#26AA#;
   Medium_Black_Circle                     : constant Unicode_Char := 16#26AB#;
   Medium_Small_White_Circle               : constant Unicode_Char := 16#26AC#;
   Marriage_Symbol                         : constant Unicode_Char := 16#26AD#;
   Divorce_Symbol                          : constant Unicode_Char := 16#26AE#;
   Unmarried_Partnership_Symbol            : constant Unicode_Char := 16#26AF#;
   Coffin                                  : constant Unicode_Char := 16#26B0#;
   Funeral_Urn                             : constant Unicode_Char := 16#26B1#;
   Neuter                                  : constant Unicode_Char := 16#26B2#;
   Ceres                                   : constant Unicode_Char := 16#26B3#;
   Pallas                                  : constant Unicode_Char := 16#26B4#;
   Juno                                    : constant Unicode_Char := 16#26B5#;
   Vesta                                   : constant Unicode_Char := 16#26B6#;
   Chiron                                  : constant Unicode_Char := 16#26B7#;
   Black_Moon_Lilith                       : constant Unicode_Char := 16#26B8#;
   Sextile                                 : constant Unicode_Char := 16#26B9#;
   Semisextile                             : constant Unicode_Char := 16#26BA#;
   Quincunx                                : constant Unicode_Char := 16#26BB#;
   Sesquiquadrate                          : constant Unicode_Char := 16#26BC#;
   Soccer_Ball                             : constant Unicode_Char := 16#26BD#;
   Baseball                                : constant Unicode_Char := 16#26BE#;
   Squared_Key                             : constant Unicode_Char := 16#26BF#;
   White_Draughts_Man                      : constant Unicode_Char := 16#26C0#;
   White_Draughts_King                     : constant Unicode_Char := 16#26C1#;
   Black_Draughts_Man                      : constant Unicode_Char := 16#26C2#;
   Black_Draughts_King                     : constant Unicode_Char := 16#26C3#;
   Snowman_Without_Snow                    : constant Unicode_Char := 16#26C4#;
   Sun_Behind_Cloud                        : constant Unicode_Char := 16#26C5#;
   Rain                                    : constant Unicode_Char := 16#26C6#;
   Black_Snowman                           : constant Unicode_Char := 16#26C7#;
   Thunder_Cloud_And_Rain                  : constant Unicode_Char := 16#26C8#;
   Turned_White_Shogi_Piece                : constant Unicode_Char := 16#26C9#;
   Turned_Black_Shogi_Piece                : constant Unicode_Char := 16#26CA#;
   White_Diamond_In_Square                 : constant Unicode_Char := 16#26CB#;
   Crossing_Lanes                          : constant Unicode_Char := 16#26CC#;
   Disabled_Car                            : constant Unicode_Char := 16#26CD#;
   Ophiuchus                               : constant Unicode_Char := 16#26CE#;
   Pick                                    : constant Unicode_Char := 16#26CF#;
   Car_Sliding                             : constant Unicode_Char := 16#26D0#;
   Helmet_With_White_Cross                 : constant Unicode_Char := 16#26D1#;
   Circled_Crossing_Lanes                  : constant Unicode_Char := 16#26D2#;
   Chains                                  : constant Unicode_Char := 16#26D3#;
   No_Entry                                : constant Unicode_Char := 16#26D4#;
   Alternate_One_Way_Left_Way_Traffic      : constant Unicode_Char := 16#26D5#;
   Black_Two_Way_Left_Way_Traffic          : constant Unicode_Char := 16#26D6#;
   White_Two_Way_Left_Way_Traffic          : constant Unicode_Char := 16#26D7#;
   Black_Left_Lane_Merge                   : constant Unicode_Char := 16#26D8#;
   White_Left_Lane_Merge                   : constant Unicode_Char := 16#26D9#;
   Drive_Slow_Sign                         : constant Unicode_Char := 16#26DA#;
   Heavy_White_Down_Pointing_Triangle      : constant Unicode_Char := 16#26DB#;
   Left_Closed_Entry                       : constant Unicode_Char := 16#26DC#;
   Squared_Saltire                         : constant Unicode_Char := 16#26DD#;
   Falling_Diagonal_In_White_Circle_In_Black_Square :
      constant Unicode_Char := 16#26DE#;
   Black_Truck                             : constant Unicode_Char := 16#26DF#;
   Restricted_Left_Entry_1                 : constant Unicode_Char := 16#26E0#;
   Restricted_Left_Entry_2                 : constant Unicode_Char := 16#26E1#;
   Astronomical_Symbol_For_Uranus          : constant Unicode_Char := 16#26E2#;
   Heavy_Circle_With_Stroke_And_Two_Dots_Above :
      constant Unicode_Char := 16#26E3#;
   Pentagram                               : constant Unicode_Char := 16#26E4#;
   Right_Handed_Interlaced_Pentagram       : constant Unicode_Char := 16#26E5#;
   Left_Handed_Interlaced_Pentagram        : constant Unicode_Char := 16#26E6#;
   Inverted_Pentagram                      : constant Unicode_Char := 16#26E7#;
   Black_Cross_On_Shield                   : constant Unicode_Char := 16#26E8#;
   Shinto_Shrine                           : constant Unicode_Char := 16#26E9#;
   Church                                  : constant Unicode_Char := 16#26EA#;
   Castle                                  : constant Unicode_Char := 16#26EB#;
   Historic_Site                           : constant Unicode_Char := 16#26EC#;
   Gear_Without_Hub                        : constant Unicode_Char := 16#26ED#;
   Gear_With_Handles                       : constant Unicode_Char := 16#26EE#;
   Map_Symbol_For_Lighthouse               : constant Unicode_Char := 16#26EF#;
   Mountain                                : constant Unicode_Char := 16#26F0#;
   Umbrella_On_Ground                      : constant Unicode_Char := 16#26F1#;
   Fountain                                : constant Unicode_Char := 16#26F2#;
   Flag_In_Hole                            : constant Unicode_Char := 16#26F3#;
   Ferry                                   : constant Unicode_Char := 16#26F4#;
   Sailboat                                : constant Unicode_Char := 16#26F5#;
   Square_Four_Corners                     : constant Unicode_Char := 16#26F6#;
   Skier                                   : constant Unicode_Char := 16#26F7#;
   Ice_Skate                               : constant Unicode_Char := 16#26F8#;
   Person_With_Ball                        : constant Unicode_Char := 16#26F9#;
   Tent                                    : constant Unicode_Char := 16#26FA#;
   Japanese_Bank_Symbol                    : constant Unicode_Char := 16#26FB#;
   Headstone_Graveyard_Symbol              : constant Unicode_Char := 16#26FC#;
   Fuel_Pump                               : constant Unicode_Char := 16#26FD#;
   Cup_On_Black_Square                     : constant Unicode_Char := 16#26FE#;
   White_Flag_With_Horizontal_Middle_Black_Stripe :
      constant Unicode_Char := 16#26FF#;
end Unicode.Names.Miscellaneous_Symbols;
