--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Hangul_Jamo_Extended_B is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Hangul_Jungseong_O_Yeo                  : constant Unicode_Char := 16#D7B0#;
   Hangul_Jungseong_O_O_I                  : constant Unicode_Char := 16#D7B1#;
   Hangul_Jungseong_Yo_A                   : constant Unicode_Char := 16#D7B2#;
   Hangul_Jungseong_Yo_Ae                  : constant Unicode_Char := 16#D7B3#;
   Hangul_Jungseong_Yo_Eo                  : constant Unicode_Char := 16#D7B4#;
   Hangul_Jungseong_U_Yeo                  : constant Unicode_Char := 16#D7B5#;
   Hangul_Jungseong_U_I_I                  : constant Unicode_Char := 16#D7B6#;
   Hangul_Jungseong_Yu_Ae                  : constant Unicode_Char := 16#D7B7#;
   Hangul_Jungseong_Yu_O                   : constant Unicode_Char := 16#D7B8#;
   Hangul_Jungseong_Eu_A                   : constant Unicode_Char := 16#D7B9#;
   Hangul_Jungseong_Eu_Eo                  : constant Unicode_Char := 16#D7BA#;
   Hangul_Jungseong_Eu_E                   : constant Unicode_Char := 16#D7BB#;
   Hangul_Jungseong_Eu_O                   : constant Unicode_Char := 16#D7BC#;
   Hangul_Jungseong_I_Ya_O                 : constant Unicode_Char := 16#D7BD#;
   Hangul_Jungseong_I_Yae                  : constant Unicode_Char := 16#D7BE#;
   Hangul_Jungseong_I_Yeo                  : constant Unicode_Char := 16#D7BF#;
   Hangul_Jungseong_I_Ye                   : constant Unicode_Char := 16#D7C0#;
   Hangul_Jungseong_I_O_I                  : constant Unicode_Char := 16#D7C1#;
   Hangul_Jungseong_I_Yo                   : constant Unicode_Char := 16#D7C2#;
   Hangul_Jungseong_I_Yu                   : constant Unicode_Char := 16#D7C3#;
   Hangul_Jungseong_I_I                    : constant Unicode_Char := 16#D7C4#;
   Hangul_Jungseong_Araea_A                : constant Unicode_Char := 16#D7C5#;
   Hangul_Jungseong_Araea_E                : constant Unicode_Char := 16#D7C6#;
   Hangul_Jongseong_Nieun_Rieul            : constant Unicode_Char := 16#D7CB#;
   Hangul_Jongseong_Nieun_Chieuch          : constant Unicode_Char := 16#D7CC#;
   Hangul_Jongseong_Ssangtikeut            : constant Unicode_Char := 16#D7CD#;
   Hangul_Jongseong_Ssangtikeut_Pieup      : constant Unicode_Char := 16#D7CE#;
   Hangul_Jongseong_Tikeut_Pieup           : constant Unicode_Char := 16#D7CF#;
   Hangul_Jongseong_Tikeut_Sios            : constant Unicode_Char := 16#D7D0#;
   Hangul_Jongseong_Tikeut_Sios_Kiyeok     : constant Unicode_Char := 16#D7D1#;
   Hangul_Jongseong_Tikeut_Cieuc           : constant Unicode_Char := 16#D7D2#;
   Hangul_Jongseong_Tikeut_Chieuch         : constant Unicode_Char := 16#D7D3#;
   Hangul_Jongseong_Tikeut_Thieuth         : constant Unicode_Char := 16#D7D4#;
   Hangul_Jongseong_Rieul_Ssangkiyeok      : constant Unicode_Char := 16#D7D5#;
   Hangul_Jongseong_Rieul_Kiyeok_Hieuh     : constant Unicode_Char := 16#D7D6#;
   Hangul_Jongseong_Ssangrieul_Khieukh     : constant Unicode_Char := 16#D7D7#;
   Hangul_Jongseong_Rieul_Mieum_Hieuh      : constant Unicode_Char := 16#D7D8#;
   Hangul_Jongseong_Rieul_Pieup_Tikeut     : constant Unicode_Char := 16#D7D9#;
   Hangul_Jongseong_Rieul_Pieup_Phieuph    : constant Unicode_Char := 16#D7DA#;
   Hangul_Jongseong_Rieul_Yesieung         : constant Unicode_Char := 16#D7DB#;
   Hangul_Jongseong_Rieul_Yeorinhieuh_Hieuh :
      constant Unicode_Char := 16#D7DC#;
   Hangul_Jongseong_Kapyeounrieul          : constant Unicode_Char := 16#D7DD#;
   Hangul_Jongseong_Mieum_Nieun            : constant Unicode_Char := 16#D7DE#;
   Hangul_Jongseong_Mieum_Ssangnieun       : constant Unicode_Char := 16#D7DF#;
   Hangul_Jongseong_Ssangmieum             : constant Unicode_Char := 16#D7E0#;
   Hangul_Jongseong_Mieum_Pieup_Sios       : constant Unicode_Char := 16#D7E1#;
   Hangul_Jongseong_Mieum_Cieuc            : constant Unicode_Char := 16#D7E2#;
   Hangul_Jongseong_Pieup_Tikeut           : constant Unicode_Char := 16#D7E3#;
   Hangul_Jongseong_Pieup_Rieul_Phieuph    : constant Unicode_Char := 16#D7E4#;
   Hangul_Jongseong_Pieup_Mieum            : constant Unicode_Char := 16#D7E5#;
   Hangul_Jongseong_Ssangpieup             : constant Unicode_Char := 16#D7E6#;
   Hangul_Jongseong_Pieup_Sios_Tikeut      : constant Unicode_Char := 16#D7E7#;
   Hangul_Jongseong_Pieup_Cieuc            : constant Unicode_Char := 16#D7E8#;
   Hangul_Jongseong_Pieup_Chieuch          : constant Unicode_Char := 16#D7E9#;
   Hangul_Jongseong_Sios_Mieum             : constant Unicode_Char := 16#D7EA#;
   Hangul_Jongseong_Sios_Kapyeounpieup     : constant Unicode_Char := 16#D7EB#;
   Hangul_Jongseong_Ssangsios_Kiyeok       : constant Unicode_Char := 16#D7EC#;
   Hangul_Jongseong_Ssangsios_Tikeut       : constant Unicode_Char := 16#D7ED#;
   Hangul_Jongseong_Sios_Pansios           : constant Unicode_Char := 16#D7EE#;
   Hangul_Jongseong_Sios_Cieuc             : constant Unicode_Char := 16#D7EF#;
   Hangul_Jongseong_Sios_Chieuch           : constant Unicode_Char := 16#D7F0#;
   Hangul_Jongseong_Sios_Thieuth           : constant Unicode_Char := 16#D7F1#;
   Hangul_Jongseong_Sios_Hieuh             : constant Unicode_Char := 16#D7F2#;
   Hangul_Jongseong_Pansios_Pieup          : constant Unicode_Char := 16#D7F3#;
   Hangul_Jongseong_Pansios_Kapyeounpieup  : constant Unicode_Char := 16#D7F4#;
   Hangul_Jongseong_Yesieung_Mieum         : constant Unicode_Char := 16#D7F5#;
   Hangul_Jongseong_Yesieung_Hieuh         : constant Unicode_Char := 16#D7F6#;
   Hangul_Jongseong_Cieuc_Pieup            : constant Unicode_Char := 16#D7F7#;
   Hangul_Jongseong_Cieuc_Ssangpieup       : constant Unicode_Char := 16#D7F8#;
   Hangul_Jongseong_Ssangcieuc             : constant Unicode_Char := 16#D7F9#;
   Hangul_Jongseong_Phieuph_Sios           : constant Unicode_Char := 16#D7FA#;
   Hangul_Jongseong_Phieuph_Thieuth        : constant Unicode_Char := 16#D7FB#;
end Unicode.Names.Hangul_Jamo_Extended_B;
