--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Grantha is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Grantha_Sign_Combining_Anusvara_Above   :
      constant Unicode_Char := 16#11300#;
   Grantha_Sign_Candrabindu                :
      constant Unicode_Char := 16#11301#;
   Grantha_Sign_Anusvara                   :
      constant Unicode_Char := 16#11302#;
   Grantha_Sign_Visarga                    :
      constant Unicode_Char := 16#11303#;
   Grantha_Letter_A                        :
      constant Unicode_Char := 16#11305#;
   Grantha_Letter_Aa                       :
      constant Unicode_Char := 16#11306#;
   Grantha_Letter_I                        :
      constant Unicode_Char := 16#11307#;
   Grantha_Letter_Ii                       :
      constant Unicode_Char := 16#11308#;
   Grantha_Letter_U                        :
      constant Unicode_Char := 16#11309#;
   Grantha_Letter_Uu                       :
      constant Unicode_Char := 16#1130A#;
   Grantha_Letter_Vocalic_R                :
      constant Unicode_Char := 16#1130B#;
   Grantha_Letter_Vocalic_L                :
      constant Unicode_Char := 16#1130C#;
   Grantha_Letter_Ee                       :
      constant Unicode_Char := 16#1130F#;
   Grantha_Letter_Ai                       :
      constant Unicode_Char := 16#11310#;
   Grantha_Letter_Oo                       :
      constant Unicode_Char := 16#11313#;
   Grantha_Letter_Au                       :
      constant Unicode_Char := 16#11314#;
   Grantha_Letter_Ka                       :
      constant Unicode_Char := 16#11315#;
   Grantha_Letter_Kha                      :
      constant Unicode_Char := 16#11316#;
   Grantha_Letter_Ga                       :
      constant Unicode_Char := 16#11317#;
   Grantha_Letter_Gha                      :
      constant Unicode_Char := 16#11318#;
   Grantha_Letter_Nga                      :
      constant Unicode_Char := 16#11319#;
   Grantha_Letter_Ca                       :
      constant Unicode_Char := 16#1131A#;
   Grantha_Letter_Cha                      :
      constant Unicode_Char := 16#1131B#;
   Grantha_Letter_Ja                       :
      constant Unicode_Char := 16#1131C#;
   Grantha_Letter_Jha                      :
      constant Unicode_Char := 16#1131D#;
   Grantha_Letter_Nya                      :
      constant Unicode_Char := 16#1131E#;
   Grantha_Letter_Tta                      :
      constant Unicode_Char := 16#1131F#;
   Grantha_Letter_Ttha                     :
      constant Unicode_Char := 16#11320#;
   Grantha_Letter_Dda                      :
      constant Unicode_Char := 16#11321#;
   Grantha_Letter_Ddha                     :
      constant Unicode_Char := 16#11322#;
   Grantha_Letter_Nna                      :
      constant Unicode_Char := 16#11323#;
   Grantha_Letter_Ta                       :
      constant Unicode_Char := 16#11324#;
   Grantha_Letter_Tha                      :
      constant Unicode_Char := 16#11325#;
   Grantha_Letter_Da                       :
      constant Unicode_Char := 16#11326#;
   Grantha_Letter_Dha                      :
      constant Unicode_Char := 16#11327#;
   Grantha_Letter_Na                       :
      constant Unicode_Char := 16#11328#;
   Grantha_Letter_Pa                       :
      constant Unicode_Char := 16#1132A#;
   Grantha_Letter_Pha                      :
      constant Unicode_Char := 16#1132B#;
   Grantha_Letter_Ba                       :
      constant Unicode_Char := 16#1132C#;
   Grantha_Letter_Bha                      :
      constant Unicode_Char := 16#1132D#;
   Grantha_Letter_Ma                       :
      constant Unicode_Char := 16#1132E#;
   Grantha_Letter_Ya                       :
      constant Unicode_Char := 16#1132F#;
   Grantha_Letter_Ra                       :
      constant Unicode_Char := 16#11330#;
   Grantha_Letter_La                       :
      constant Unicode_Char := 16#11332#;
   Grantha_Letter_Lla                      :
      constant Unicode_Char := 16#11333#;
   Grantha_Letter_Va                       :
      constant Unicode_Char := 16#11335#;
   Grantha_Letter_Sha                      :
      constant Unicode_Char := 16#11336#;
   Grantha_Letter_Ssa                      :
      constant Unicode_Char := 16#11337#;
   Grantha_Letter_Sa                       :
      constant Unicode_Char := 16#11338#;
   Grantha_Letter_Ha                       :
      constant Unicode_Char := 16#11339#;
   Grantha_Sign_Nukta                      :
      constant Unicode_Char := 16#1133C#;
   Grantha_Sign_Avagraha                   :
      constant Unicode_Char := 16#1133D#;
   Grantha_Vowel_Sign_Aa                   :
      constant Unicode_Char := 16#1133E#;
   Grantha_Vowel_Sign_I                    :
      constant Unicode_Char := 16#1133F#;
   Grantha_Vowel_Sign_Ii                   :
      constant Unicode_Char := 16#11340#;
   Grantha_Vowel_Sign_U                    :
      constant Unicode_Char := 16#11341#;
   Grantha_Vowel_Sign_Uu                   :
      constant Unicode_Char := 16#11342#;
   Grantha_Vowel_Sign_Vocalic_R            :
      constant Unicode_Char := 16#11343#;
   Grantha_Vowel_Sign_Vocalic_Rr           :
      constant Unicode_Char := 16#11344#;
   Grantha_Vowel_Sign_Ee                   :
      constant Unicode_Char := 16#11347#;
   Grantha_Vowel_Sign_Ai                   :
      constant Unicode_Char := 16#11348#;
   Grantha_Vowel_Sign_Oo                   :
      constant Unicode_Char := 16#1134B#;
   Grantha_Vowel_Sign_Au                   :
      constant Unicode_Char := 16#1134C#;
   Grantha_Sign_Virama                     :
      constant Unicode_Char := 16#1134D#;
   Grantha_Om                              :
      constant Unicode_Char := 16#11350#;
   Grantha_Au_Length_Mark                  :
      constant Unicode_Char := 16#11357#;
   Grantha_Sign_Pluta                      :
      constant Unicode_Char := 16#1135D#;
   Grantha_Letter_Vedic_Anusvara           :
      constant Unicode_Char := 16#1135E#;
   Grantha_Letter_Vedic_Double_Anusvara    :
      constant Unicode_Char := 16#1135F#;
   Grantha_Letter_Vocalic_Rr               :
      constant Unicode_Char := 16#11360#;
   Grantha_Letter_Vocalic_Ll               :
      constant Unicode_Char := 16#11361#;
   Grantha_Vowel_Sign_Vocalic_L            :
      constant Unicode_Char := 16#11362#;
   Grantha_Vowel_Sign_Vocalic_Ll           :
      constant Unicode_Char := 16#11363#;
   Combining_Grantha_Digit_Zero            :
      constant Unicode_Char := 16#11366#;
   Combining_Grantha_Digit_One             :
      constant Unicode_Char := 16#11367#;
   Combining_Grantha_Digit_Two             :
      constant Unicode_Char := 16#11368#;
   Combining_Grantha_Digit_Three           :
      constant Unicode_Char := 16#11369#;
   Combining_Grantha_Digit_Four            :
      constant Unicode_Char := 16#1136A#;
   Combining_Grantha_Digit_Five            :
      constant Unicode_Char := 16#1136B#;
   Combining_Grantha_Digit_Six             :
      constant Unicode_Char := 16#1136C#;
   Combining_Grantha_Letter_A              :
      constant Unicode_Char := 16#11370#;
   Combining_Grantha_Letter_Ka             :
      constant Unicode_Char := 16#11371#;
   Combining_Grantha_Letter_Na             :
      constant Unicode_Char := 16#11372#;
   Combining_Grantha_Letter_Vi             :
      constant Unicode_Char := 16#11373#;
   Combining_Grantha_Letter_Pa             :
      constant Unicode_Char := 16#11374#;
end Unicode.Names.Grantha;
