--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Enclosed_Alphanumerics is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Circled_Digit_One                       : constant Unicode_Char := 16#2460#;
   Circled_Digit_Two                       : constant Unicode_Char := 16#2461#;
   Circled_Digit_Three                     : constant Unicode_Char := 16#2462#;
   Circled_Digit_Four                      : constant Unicode_Char := 16#2463#;
   Circled_Digit_Five                      : constant Unicode_Char := 16#2464#;
   Circled_Digit_Six                       : constant Unicode_Char := 16#2465#;
   Circled_Digit_Seven                     : constant Unicode_Char := 16#2466#;
   Circled_Digit_Eight                     : constant Unicode_Char := 16#2467#;
   Circled_Digit_Nine                      : constant Unicode_Char := 16#2468#;
   Circled_Number_Ten                      : constant Unicode_Char := 16#2469#;
   Circled_Number_Eleven                   : constant Unicode_Char := 16#246A#;
   Circled_Number_Twelve                   : constant Unicode_Char := 16#246B#;
   Circled_Number_Thirteen                 : constant Unicode_Char := 16#246C#;
   Circled_Number_Fourteen                 : constant Unicode_Char := 16#246D#;
   Circled_Number_Fifteen                  : constant Unicode_Char := 16#246E#;
   Circled_Number_Sixteen                  : constant Unicode_Char := 16#246F#;
   Circled_Number_Seventeen                : constant Unicode_Char := 16#2470#;
   Circled_Number_Eighteen                 : constant Unicode_Char := 16#2471#;
   Circled_Number_Nineteen                 : constant Unicode_Char := 16#2472#;
   Circled_Number_Twenty                   : constant Unicode_Char := 16#2473#;
   Parenthesized_Digit_One                 : constant Unicode_Char := 16#2474#;
   Parenthesized_Digit_Two                 : constant Unicode_Char := 16#2475#;
   Parenthesized_Digit_Three               : constant Unicode_Char := 16#2476#;
   Parenthesized_Digit_Four                : constant Unicode_Char := 16#2477#;
   Parenthesized_Digit_Five                : constant Unicode_Char := 16#2478#;
   Parenthesized_Digit_Six                 : constant Unicode_Char := 16#2479#;
   Parenthesized_Digit_Seven               : constant Unicode_Char := 16#247A#;
   Parenthesized_Digit_Eight               : constant Unicode_Char := 16#247B#;
   Parenthesized_Digit_Nine                : constant Unicode_Char := 16#247C#;
   Parenthesized_Number_Ten                : constant Unicode_Char := 16#247D#;
   Parenthesized_Number_Eleven             : constant Unicode_Char := 16#247E#;
   Parenthesized_Number_Twelve             : constant Unicode_Char := 16#247F#;
   Parenthesized_Number_Thirteen           : constant Unicode_Char := 16#2480#;
   Parenthesized_Number_Fourteen           : constant Unicode_Char := 16#2481#;
   Parenthesized_Number_Fifteen            : constant Unicode_Char := 16#2482#;
   Parenthesized_Number_Sixteen            : constant Unicode_Char := 16#2483#;
   Parenthesized_Number_Seventeen          : constant Unicode_Char := 16#2484#;
   Parenthesized_Number_Eighteen           : constant Unicode_Char := 16#2485#;
   Parenthesized_Number_Nineteen           : constant Unicode_Char := 16#2486#;
   Parenthesized_Number_Twenty             : constant Unicode_Char := 16#2487#;
   Digit_One_Full_Stop                     : constant Unicode_Char := 16#2488#;
   Digit_Two_Full_Stop                     : constant Unicode_Char := 16#2489#;
   Digit_Three_Full_Stop                   : constant Unicode_Char := 16#248A#;
   Digit_Four_Full_Stop                    : constant Unicode_Char := 16#248B#;
   Digit_Five_Full_Stop                    : constant Unicode_Char := 16#248C#;
   Digit_Six_Full_Stop                     : constant Unicode_Char := 16#248D#;
   Digit_Seven_Full_Stop                   : constant Unicode_Char := 16#248E#;
   Digit_Eight_Full_Stop                   : constant Unicode_Char := 16#248F#;
   Digit_Nine_Full_Stop                    : constant Unicode_Char := 16#2490#;
   Number_Ten_Full_Stop                    : constant Unicode_Char := 16#2491#;
   Number_Eleven_Full_Stop                 : constant Unicode_Char := 16#2492#;
   Number_Twelve_Full_Stop                 : constant Unicode_Char := 16#2493#;
   Number_Thirteen_Full_Stop               : constant Unicode_Char := 16#2494#;
   Number_Fourteen_Full_Stop               : constant Unicode_Char := 16#2495#;
   Number_Fifteen_Full_Stop                : constant Unicode_Char := 16#2496#;
   Number_Sixteen_Full_Stop                : constant Unicode_Char := 16#2497#;
   Number_Seventeen_Full_Stop              : constant Unicode_Char := 16#2498#;
   Number_Eighteen_Full_Stop               : constant Unicode_Char := 16#2499#;
   Number_Nineteen_Full_Stop               : constant Unicode_Char := 16#249A#;
   Number_Twenty_Full_Stop                 : constant Unicode_Char := 16#249B#;
   Parenthesized_Latin_Small_Letter_A      : constant Unicode_Char := 16#249C#;
   Parenthesized_Latin_Small_Letter_B      : constant Unicode_Char := 16#249D#;
   Parenthesized_Latin_Small_Letter_C      : constant Unicode_Char := 16#249E#;
   Parenthesized_Latin_Small_Letter_D      : constant Unicode_Char := 16#249F#;
   Parenthesized_Latin_Small_Letter_E      : constant Unicode_Char := 16#24A0#;
   Parenthesized_Latin_Small_Letter_F      : constant Unicode_Char := 16#24A1#;
   Parenthesized_Latin_Small_Letter_G      : constant Unicode_Char := 16#24A2#;
   Parenthesized_Latin_Small_Letter_H      : constant Unicode_Char := 16#24A3#;
   Parenthesized_Latin_Small_Letter_I      : constant Unicode_Char := 16#24A4#;
   Parenthesized_Latin_Small_Letter_J      : constant Unicode_Char := 16#24A5#;
   Parenthesized_Latin_Small_Letter_K      : constant Unicode_Char := 16#24A6#;
   Parenthesized_Latin_Small_Letter_L      : constant Unicode_Char := 16#24A7#;
   Parenthesized_Latin_Small_Letter_M      : constant Unicode_Char := 16#24A8#;
   Parenthesized_Latin_Small_Letter_N      : constant Unicode_Char := 16#24A9#;
   Parenthesized_Latin_Small_Letter_O      : constant Unicode_Char := 16#24AA#;
   Parenthesized_Latin_Small_Letter_P      : constant Unicode_Char := 16#24AB#;
   Parenthesized_Latin_Small_Letter_Q      : constant Unicode_Char := 16#24AC#;
   Parenthesized_Latin_Small_Letter_R      : constant Unicode_Char := 16#24AD#;
   Parenthesized_Latin_Small_Letter_S      : constant Unicode_Char := 16#24AE#;
   Parenthesized_Latin_Small_Letter_T      : constant Unicode_Char := 16#24AF#;
   Parenthesized_Latin_Small_Letter_U      : constant Unicode_Char := 16#24B0#;
   Parenthesized_Latin_Small_Letter_V      : constant Unicode_Char := 16#24B1#;
   Parenthesized_Latin_Small_Letter_W      : constant Unicode_Char := 16#24B2#;
   Parenthesized_Latin_Small_Letter_X      : constant Unicode_Char := 16#24B3#;
   Parenthesized_Latin_Small_Letter_Y      : constant Unicode_Char := 16#24B4#;
   Parenthesized_Latin_Small_Letter_Z      : constant Unicode_Char := 16#24B5#;
   Circled_Latin_Capital_Letter_A          : constant Unicode_Char := 16#24B6#;
   Circled_Latin_Capital_Letter_B          : constant Unicode_Char := 16#24B7#;
   Circled_Latin_Capital_Letter_C          : constant Unicode_Char := 16#24B8#;
   Circled_Latin_Capital_Letter_D          : constant Unicode_Char := 16#24B9#;
   Circled_Latin_Capital_Letter_E          : constant Unicode_Char := 16#24BA#;
   Circled_Latin_Capital_Letter_F          : constant Unicode_Char := 16#24BB#;
   Circled_Latin_Capital_Letter_G          : constant Unicode_Char := 16#24BC#;
   Circled_Latin_Capital_Letter_H          : constant Unicode_Char := 16#24BD#;
   Circled_Latin_Capital_Letter_I          : constant Unicode_Char := 16#24BE#;
   Circled_Latin_Capital_Letter_J          : constant Unicode_Char := 16#24BF#;
   Circled_Latin_Capital_Letter_K          : constant Unicode_Char := 16#24C0#;
   Circled_Latin_Capital_Letter_L          : constant Unicode_Char := 16#24C1#;
   Circled_Latin_Capital_Letter_M          : constant Unicode_Char := 16#24C2#;
   Circled_Latin_Capital_Letter_N          : constant Unicode_Char := 16#24C3#;
   Circled_Latin_Capital_Letter_O          : constant Unicode_Char := 16#24C4#;
   Circled_Latin_Capital_Letter_P          : constant Unicode_Char := 16#24C5#;
   Circled_Latin_Capital_Letter_Q          : constant Unicode_Char := 16#24C6#;
   Circled_Latin_Capital_Letter_R          : constant Unicode_Char := 16#24C7#;
   Circled_Latin_Capital_Letter_S          : constant Unicode_Char := 16#24C8#;
   Circled_Latin_Capital_Letter_T          : constant Unicode_Char := 16#24C9#;
   Circled_Latin_Capital_Letter_U          : constant Unicode_Char := 16#24CA#;
   Circled_Latin_Capital_Letter_V          : constant Unicode_Char := 16#24CB#;
   Circled_Latin_Capital_Letter_W          : constant Unicode_Char := 16#24CC#;
   Circled_Latin_Capital_Letter_X          : constant Unicode_Char := 16#24CD#;
   Circled_Latin_Capital_Letter_Y          : constant Unicode_Char := 16#24CE#;
   Circled_Latin_Capital_Letter_Z          : constant Unicode_Char := 16#24CF#;
   Circled_Latin_Small_Letter_A            : constant Unicode_Char := 16#24D0#;
   Circled_Latin_Small_Letter_B            : constant Unicode_Char := 16#24D1#;
   Circled_Latin_Small_Letter_C            : constant Unicode_Char := 16#24D2#;
   Circled_Latin_Small_Letter_D            : constant Unicode_Char := 16#24D3#;
   Circled_Latin_Small_Letter_E            : constant Unicode_Char := 16#24D4#;
   Circled_Latin_Small_Letter_F            : constant Unicode_Char := 16#24D5#;
   Circled_Latin_Small_Letter_G            : constant Unicode_Char := 16#24D6#;
   Circled_Latin_Small_Letter_H            : constant Unicode_Char := 16#24D7#;
   Circled_Latin_Small_Letter_I            : constant Unicode_Char := 16#24D8#;
   Circled_Latin_Small_Letter_J            : constant Unicode_Char := 16#24D9#;
   Circled_Latin_Small_Letter_K            : constant Unicode_Char := 16#24DA#;
   Circled_Latin_Small_Letter_L            : constant Unicode_Char := 16#24DB#;
   Circled_Latin_Small_Letter_M            : constant Unicode_Char := 16#24DC#;
   Circled_Latin_Small_Letter_N            : constant Unicode_Char := 16#24DD#;
   Circled_Latin_Small_Letter_O            : constant Unicode_Char := 16#24DE#;
   Circled_Latin_Small_Letter_P            : constant Unicode_Char := 16#24DF#;
   Circled_Latin_Small_Letter_Q            : constant Unicode_Char := 16#24E0#;
   Circled_Latin_Small_Letter_R            : constant Unicode_Char := 16#24E1#;
   Circled_Latin_Small_Letter_S            : constant Unicode_Char := 16#24E2#;
   Circled_Latin_Small_Letter_T            : constant Unicode_Char := 16#24E3#;
   Circled_Latin_Small_Letter_U            : constant Unicode_Char := 16#24E4#;
   Circled_Latin_Small_Letter_V            : constant Unicode_Char := 16#24E5#;
   Circled_Latin_Small_Letter_W            : constant Unicode_Char := 16#24E6#;
   Circled_Latin_Small_Letter_X            : constant Unicode_Char := 16#24E7#;
   Circled_Latin_Small_Letter_Y            : constant Unicode_Char := 16#24E8#;
   Circled_Latin_Small_Letter_Z            : constant Unicode_Char := 16#24E9#;
   Circled_Digit_Zero                      : constant Unicode_Char := 16#24EA#;
   Negative_Circled_Number_Eleven          : constant Unicode_Char := 16#24EB#;
   Negative_Circled_Number_Twelve          : constant Unicode_Char := 16#24EC#;
   Negative_Circled_Number_Thirteen        : constant Unicode_Char := 16#24ED#;
   Negative_Circled_Number_Fourteen        : constant Unicode_Char := 16#24EE#;
   Negative_Circled_Number_Fifteen         : constant Unicode_Char := 16#24EF#;
   Negative_Circled_Number_Sixteen         : constant Unicode_Char := 16#24F0#;
   Negative_Circled_Number_Seventeen       : constant Unicode_Char := 16#24F1#;
   Negative_Circled_Number_Eighteen        : constant Unicode_Char := 16#24F2#;
   Negative_Circled_Number_Nineteen        : constant Unicode_Char := 16#24F3#;
   Negative_Circled_Number_Twenty          : constant Unicode_Char := 16#24F4#;
   Double_Circled_Digit_One                : constant Unicode_Char := 16#24F5#;
   Double_Circled_Digit_Two                : constant Unicode_Char := 16#24F6#;
   Double_Circled_Digit_Three              : constant Unicode_Char := 16#24F7#;
   Double_Circled_Digit_Four               : constant Unicode_Char := 16#24F8#;
   Double_Circled_Digit_Five               : constant Unicode_Char := 16#24F9#;
   Double_Circled_Digit_Six                : constant Unicode_Char := 16#24FA#;
   Double_Circled_Digit_Seven              : constant Unicode_Char := 16#24FB#;
   Double_Circled_Digit_Eight              : constant Unicode_Char := 16#24FC#;
   Double_Circled_Digit_Nine               : constant Unicode_Char := 16#24FD#;
   Double_Circled_Number_Ten               : constant Unicode_Char := 16#24FE#;
   Negative_Circled_Digit_Zero             : constant Unicode_Char := 16#24FF#;
end Unicode.Names.Enclosed_Alphanumerics;
