--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Oriya is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Oriya_Sign_Candrabindu                  : constant Unicode_Char := 16#0B01#;
   Oriya_Sign_Anusvara                     : constant Unicode_Char := 16#0B02#;
   Oriya_Sign_Visarga                      : constant Unicode_Char := 16#0B03#;
   Oriya_Letter_A                          : constant Unicode_Char := 16#0B05#;
   Oriya_Letter_Aa                         : constant Unicode_Char := 16#0B06#;
   Oriya_Letter_I                          : constant Unicode_Char := 16#0B07#;
   Oriya_Letter_Ii                         : constant Unicode_Char := 16#0B08#;
   Oriya_Letter_U                          : constant Unicode_Char := 16#0B09#;
   Oriya_Letter_Uu                         : constant Unicode_Char := 16#0B0A#;
   Oriya_Letter_Vocalic_R                  : constant Unicode_Char := 16#0B0B#;
   Oriya_Letter_Vocalic_L                  : constant Unicode_Char := 16#0B0C#;
   Oriya_Letter_E                          : constant Unicode_Char := 16#0B0F#;
   Oriya_Letter_Ai                         : constant Unicode_Char := 16#0B10#;
   Oriya_Letter_O                          : constant Unicode_Char := 16#0B13#;
   Oriya_Letter_Au                         : constant Unicode_Char := 16#0B14#;
   Oriya_Letter_Ka                         : constant Unicode_Char := 16#0B15#;
   Oriya_Letter_Kha                        : constant Unicode_Char := 16#0B16#;
   Oriya_Letter_Ga                         : constant Unicode_Char := 16#0B17#;
   Oriya_Letter_Gha                        : constant Unicode_Char := 16#0B18#;
   Oriya_Letter_Nga                        : constant Unicode_Char := 16#0B19#;
   Oriya_Letter_Ca                         : constant Unicode_Char := 16#0B1A#;
   Oriya_Letter_Cha                        : constant Unicode_Char := 16#0B1B#;
   Oriya_Letter_Ja                         : constant Unicode_Char := 16#0B1C#;
   Oriya_Letter_Jha                        : constant Unicode_Char := 16#0B1D#;
   Oriya_Letter_Nya                        : constant Unicode_Char := 16#0B1E#;
   Oriya_Letter_Tta                        : constant Unicode_Char := 16#0B1F#;
   Oriya_Letter_Ttha                       : constant Unicode_Char := 16#0B20#;
   Oriya_Letter_Dda                        : constant Unicode_Char := 16#0B21#;
   Oriya_Letter_Ddha                       : constant Unicode_Char := 16#0B22#;
   Oriya_Letter_Nna                        : constant Unicode_Char := 16#0B23#;
   Oriya_Letter_Ta                         : constant Unicode_Char := 16#0B24#;
   Oriya_Letter_Tha                        : constant Unicode_Char := 16#0B25#;
   Oriya_Letter_Da                         : constant Unicode_Char := 16#0B26#;
   Oriya_Letter_Dha                        : constant Unicode_Char := 16#0B27#;
   Oriya_Letter_Na                         : constant Unicode_Char := 16#0B28#;
   Oriya_Letter_Pa                         : constant Unicode_Char := 16#0B2A#;
   Oriya_Letter_Pha                        : constant Unicode_Char := 16#0B2B#;
   Oriya_Letter_Ba                         : constant Unicode_Char := 16#0B2C#;
   Oriya_Letter_Bha                        : constant Unicode_Char := 16#0B2D#;
   Oriya_Letter_Ma                         : constant Unicode_Char := 16#0B2E#;
   Oriya_Letter_Ya                         : constant Unicode_Char := 16#0B2F#;
   Oriya_Letter_Ra                         : constant Unicode_Char := 16#0B30#;
   Oriya_Letter_La                         : constant Unicode_Char := 16#0B32#;
   Oriya_Letter_Lla                        : constant Unicode_Char := 16#0B33#;
   Oriya_Letter_Va                         : constant Unicode_Char := 16#0B35#;
   Oriya_Letter_Sha                        : constant Unicode_Char := 16#0B36#;
   Oriya_Letter_Ssa                        : constant Unicode_Char := 16#0B37#;
   Oriya_Letter_Sa                         : constant Unicode_Char := 16#0B38#;
   Oriya_Letter_Ha                         : constant Unicode_Char := 16#0B39#;
   Oriya_Sign_Nukta                        : constant Unicode_Char := 16#0B3C#;
   Oriya_Sign_Avagraha                     : constant Unicode_Char := 16#0B3D#;
   Oriya_Vowel_Sign_Aa                     : constant Unicode_Char := 16#0B3E#;
   Oriya_Vowel_Sign_I                      : constant Unicode_Char := 16#0B3F#;
   Oriya_Vowel_Sign_Ii                     : constant Unicode_Char := 16#0B40#;
   Oriya_Vowel_Sign_U                      : constant Unicode_Char := 16#0B41#;
   Oriya_Vowel_Sign_Uu                     : constant Unicode_Char := 16#0B42#;
   Oriya_Vowel_Sign_Vocalic_R              : constant Unicode_Char := 16#0B43#;
   Oriya_Vowel_Sign_Vocalic_Rr             : constant Unicode_Char := 16#0B44#;
   Oriya_Vowel_Sign_E                      : constant Unicode_Char := 16#0B47#;
   Oriya_Vowel_Sign_Ai                     : constant Unicode_Char := 16#0B48#;
   Oriya_Vowel_Sign_O                      : constant Unicode_Char := 16#0B4B#;
   Oriya_Vowel_Sign_Au                     : constant Unicode_Char := 16#0B4C#;
   Oriya_Sign_Virama                       : constant Unicode_Char := 16#0B4D#;
   Oriya_Ai_Length_Mark                    : constant Unicode_Char := 16#0B56#;
   Oriya_Au_Length_Mark                    : constant Unicode_Char := 16#0B57#;
   Oriya_Letter_Rra                        : constant Unicode_Char := 16#0B5C#;
   Oriya_Letter_Rha                        : constant Unicode_Char := 16#0B5D#;
   Oriya_Letter_Yya                        : constant Unicode_Char := 16#0B5F#;
   Oriya_Letter_Vocalic_Rr                 : constant Unicode_Char := 16#0B60#;
   Oriya_Letter_Vocalic_Ll                 : constant Unicode_Char := 16#0B61#;
   Oriya_Vowel_Sign_Vocalic_L              : constant Unicode_Char := 16#0B62#;
   Oriya_Vowel_Sign_Vocalic_Ll             : constant Unicode_Char := 16#0B63#;
   Oriya_Digit_Zero                        : constant Unicode_Char := 16#0B66#;
   Oriya_Digit_One                         : constant Unicode_Char := 16#0B67#;
   Oriya_Digit_Two                         : constant Unicode_Char := 16#0B68#;
   Oriya_Digit_Three                       : constant Unicode_Char := 16#0B69#;
   Oriya_Digit_Four                        : constant Unicode_Char := 16#0B6A#;
   Oriya_Digit_Five                        : constant Unicode_Char := 16#0B6B#;
   Oriya_Digit_Six                         : constant Unicode_Char := 16#0B6C#;
   Oriya_Digit_Seven                       : constant Unicode_Char := 16#0B6D#;
   Oriya_Digit_Eight                       : constant Unicode_Char := 16#0B6E#;
   Oriya_Digit_Nine                        : constant Unicode_Char := 16#0B6F#;
   Oriya_Isshar                            : constant Unicode_Char := 16#0B70#;
   Oriya_Letter_Wa                         : constant Unicode_Char := 16#0B71#;
   Oriya_Fraction_One_Quarter              : constant Unicode_Char := 16#0B72#;
   Oriya_Fraction_One_Half                 : constant Unicode_Char := 16#0B73#;
   Oriya_Fraction_Three_Quarters           : constant Unicode_Char := 16#0B74#;
   Oriya_Fraction_One_Sixteenth            : constant Unicode_Char := 16#0B75#;
   Oriya_Fraction_One_Eighth               : constant Unicode_Char := 16#0B76#;
   Oriya_Fraction_Three_Sixteenths         : constant Unicode_Char := 16#0B77#;
end Unicode.Names.Oriya;
