--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Tifinagh is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Tifinagh_Letter_Ya                      : constant Unicode_Char := 16#2D30#;
   Tifinagh_Letter_Yab                     : constant Unicode_Char := 16#2D31#;
   Tifinagh_Letter_Yabh                    : constant Unicode_Char := 16#2D32#;
   Tifinagh_Letter_Yag                     : constant Unicode_Char := 16#2D33#;
   Tifinagh_Letter_Yaghh                   : constant Unicode_Char := 16#2D34#;
   Tifinagh_Letter_Berber_Academy_Yaj      : constant Unicode_Char := 16#2D35#;
   Tifinagh_Letter_Yaj                     : constant Unicode_Char := 16#2D36#;
   Tifinagh_Letter_Yad                     : constant Unicode_Char := 16#2D37#;
   Tifinagh_Letter_Yadh                    : constant Unicode_Char := 16#2D38#;
   Tifinagh_Letter_Yadd                    : constant Unicode_Char := 16#2D39#;
   Tifinagh_Letter_Yaddh                   : constant Unicode_Char := 16#2D3A#;
   Tifinagh_Letter_Yey                     : constant Unicode_Char := 16#2D3B#;
   Tifinagh_Letter_Yaf                     : constant Unicode_Char := 16#2D3C#;
   Tifinagh_Letter_Yak                     : constant Unicode_Char := 16#2D3D#;
   Tifinagh_Letter_Tuareg_Yak              : constant Unicode_Char := 16#2D3E#;
   Tifinagh_Letter_Yakhh                   : constant Unicode_Char := 16#2D3F#;
   Tifinagh_Letter_Yah                     : constant Unicode_Char := 16#2D40#;
   Tifinagh_Letter_Berber_Academy_Yah      : constant Unicode_Char := 16#2D41#;
   Tifinagh_Letter_Tuareg_Yah              : constant Unicode_Char := 16#2D42#;
   Tifinagh_Letter_Yahh                    : constant Unicode_Char := 16#2D43#;
   Tifinagh_Letter_Yaa                     : constant Unicode_Char := 16#2D44#;
   Tifinagh_Letter_Yakh                    : constant Unicode_Char := 16#2D45#;
   Tifinagh_Letter_Tuareg_Yakh             : constant Unicode_Char := 16#2D46#;
   Tifinagh_Letter_Yaq                     : constant Unicode_Char := 16#2D47#;
   Tifinagh_Letter_Tuareg_Yaq              : constant Unicode_Char := 16#2D48#;
   Tifinagh_Letter_Yi                      : constant Unicode_Char := 16#2D49#;
   Tifinagh_Letter_Yazh                    : constant Unicode_Char := 16#2D4A#;
   Tifinagh_Letter_Ahaggar_Yazh            : constant Unicode_Char := 16#2D4B#;
   Tifinagh_Letter_Tuareg_Yazh             : constant Unicode_Char := 16#2D4C#;
   Tifinagh_Letter_Yal                     : constant Unicode_Char := 16#2D4D#;
   Tifinagh_Letter_Yam                     : constant Unicode_Char := 16#2D4E#;
   Tifinagh_Letter_Yan                     : constant Unicode_Char := 16#2D4F#;
   Tifinagh_Letter_Tuareg_Yagn             : constant Unicode_Char := 16#2D50#;
   Tifinagh_Letter_Tuareg_Yang             : constant Unicode_Char := 16#2D51#;
   Tifinagh_Letter_Yap                     : constant Unicode_Char := 16#2D52#;
   Tifinagh_Letter_Yu                      : constant Unicode_Char := 16#2D53#;
   Tifinagh_Letter_Yar                     : constant Unicode_Char := 16#2D54#;
   Tifinagh_Letter_Yarr                    : constant Unicode_Char := 16#2D55#;
   Tifinagh_Letter_Yagh                    : constant Unicode_Char := 16#2D56#;
   Tifinagh_Letter_Tuareg_Yagh             : constant Unicode_Char := 16#2D57#;
   Tifinagh_Letter_Ayer_Yagh               : constant Unicode_Char := 16#2D58#;
   Tifinagh_Letter_Yas                     : constant Unicode_Char := 16#2D59#;
   Tifinagh_Letter_Yass                    : constant Unicode_Char := 16#2D5A#;
   Tifinagh_Letter_Yash                    : constant Unicode_Char := 16#2D5B#;
   Tifinagh_Letter_Yat                     : constant Unicode_Char := 16#2D5C#;
   Tifinagh_Letter_Yath                    : constant Unicode_Char := 16#2D5D#;
   Tifinagh_Letter_Yach                    : constant Unicode_Char := 16#2D5E#;
   Tifinagh_Letter_Yatt                    : constant Unicode_Char := 16#2D5F#;
   Tifinagh_Letter_Yav                     : constant Unicode_Char := 16#2D60#;
   Tifinagh_Letter_Yaw                     : constant Unicode_Char := 16#2D61#;
   Tifinagh_Letter_Yay                     : constant Unicode_Char := 16#2D62#;
   Tifinagh_Letter_Yaz                     : constant Unicode_Char := 16#2D63#;
   Tifinagh_Letter_Tawellemet_Yaz          : constant Unicode_Char := 16#2D64#;
   Tifinagh_Letter_Yazz                    : constant Unicode_Char := 16#2D65#;
   Tifinagh_Letter_Ye                      : constant Unicode_Char := 16#2D66#;
   Tifinagh_Letter_Yo                      : constant Unicode_Char := 16#2D67#;
   Tifinagh_Modifier_Letter_Labialization_Mark :
      constant Unicode_Char := 16#2D6F#;
   Tifinagh_Separator_Mark                 : constant Unicode_Char := 16#2D70#;
   Tifinagh_Consonant_Joiner               : constant Unicode_Char := 16#2D7F#;
end Unicode.Names.Tifinagh;
