--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Canadian_Aboriginal is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Canadian_Syllabics_Hyphen               : constant Unicode_Char := 16#1400#;
   Canadian_Syllabics_E                    : constant Unicode_Char := 16#1401#;
   Canadian_Syllabics_Aai                  : constant Unicode_Char := 16#1402#;
   Canadian_Syllabics_I                    : constant Unicode_Char := 16#1403#;
   Canadian_Syllabics_Ii                   : constant Unicode_Char := 16#1404#;
   Canadian_Syllabics_O                    : constant Unicode_Char := 16#1405#;
   Canadian_Syllabics_Oo                   : constant Unicode_Char := 16#1406#;
   Canadian_Syllabics_Y_Cree_Oo            : constant Unicode_Char := 16#1407#;
   Canadian_Syllabics_Carrier_Ee           : constant Unicode_Char := 16#1408#;
   Canadian_Syllabics_Carrier_I            : constant Unicode_Char := 16#1409#;
   Canadian_Syllabics_A                    : constant Unicode_Char := 16#140A#;
   Canadian_Syllabics_Aa                   : constant Unicode_Char := 16#140B#;
   Canadian_Syllabics_We                   : constant Unicode_Char := 16#140C#;
   Canadian_Syllabics_West_Cree_We         : constant Unicode_Char := 16#140D#;
   Canadian_Syllabics_Wi                   : constant Unicode_Char := 16#140E#;
   Canadian_Syllabics_West_Cree_Wi         : constant Unicode_Char := 16#140F#;
   Canadian_Syllabics_Wii                  : constant Unicode_Char := 16#1410#;
   Canadian_Syllabics_West_Cree_Wii        : constant Unicode_Char := 16#1411#;
   Canadian_Syllabics_Wo                   : constant Unicode_Char := 16#1412#;
   Canadian_Syllabics_West_Cree_Wo         : constant Unicode_Char := 16#1413#;
   Canadian_Syllabics_Woo                  : constant Unicode_Char := 16#1414#;
   Canadian_Syllabics_West_Cree_Woo        : constant Unicode_Char := 16#1415#;
   Canadian_Syllabics_Naskapi_Woo          : constant Unicode_Char := 16#1416#;
   Canadian_Syllabics_Wa                   : constant Unicode_Char := 16#1417#;
   Canadian_Syllabics_West_Cree_Wa         : constant Unicode_Char := 16#1418#;
   Canadian_Syllabics_Waa                  : constant Unicode_Char := 16#1419#;
   Canadian_Syllabics_West_Cree_Waa        : constant Unicode_Char := 16#141A#;
   Canadian_Syllabics_Naskapi_Waa          : constant Unicode_Char := 16#141B#;
   Canadian_Syllabics_Ai                   : constant Unicode_Char := 16#141C#;
   Canadian_Syllabics_Y_Cree_W             : constant Unicode_Char := 16#141D#;
   Canadian_Syllabics_Glottal_Stop         : constant Unicode_Char := 16#141E#;
   Canadian_Syllabics_Final_Acute          : constant Unicode_Char := 16#141F#;
   Canadian_Syllabics_Final_Grave          : constant Unicode_Char := 16#1420#;
   Canadian_Syllabics_Final_Bottom_Half_Ring :
      constant Unicode_Char := 16#1421#;
   Canadian_Syllabics_Final_Top_Half_Ring  : constant Unicode_Char := 16#1422#;
   Canadian_Syllabics_Final_Right_Half_Ring :
      constant Unicode_Char := 16#1423#;
   Canadian_Syllabics_Final_Ring           : constant Unicode_Char := 16#1424#;
   Canadian_Syllabics_Final_Double_Acute   : constant Unicode_Char := 16#1425#;
   Canadian_Syllabics_Final_Double_Short_Vertical_Strokes :
      constant Unicode_Char := 16#1426#;
   Canadian_Syllabics_Final_Middle_Dot     : constant Unicode_Char := 16#1427#;
   Canadian_Syllabics_Final_Short_Horizontal_Stroke :
      constant Unicode_Char := 16#1428#;
   Canadian_Syllabics_Final_Plus           : constant Unicode_Char := 16#1429#;
   Canadian_Syllabics_Final_Down_Tack      : constant Unicode_Char := 16#142A#;
   Canadian_Syllabics_En                   : constant Unicode_Char := 16#142B#;
   Canadian_Syllabics_In                   : constant Unicode_Char := 16#142C#;
   Canadian_Syllabics_On                   : constant Unicode_Char := 16#142D#;
   Canadian_Syllabics_An                   : constant Unicode_Char := 16#142E#;
   Canadian_Syllabics_Pe                   : constant Unicode_Char := 16#142F#;
   Canadian_Syllabics_Paai                 : constant Unicode_Char := 16#1430#;
   Canadian_Syllabics_Pi                   : constant Unicode_Char := 16#1431#;
   Canadian_Syllabics_Pii                  : constant Unicode_Char := 16#1432#;
   Canadian_Syllabics_Po                   : constant Unicode_Char := 16#1433#;
   Canadian_Syllabics_Poo                  : constant Unicode_Char := 16#1434#;
   Canadian_Syllabics_Y_Cree_Poo           : constant Unicode_Char := 16#1435#;
   Canadian_Syllabics_Carrier_Hee          : constant Unicode_Char := 16#1436#;
   Canadian_Syllabics_Carrier_Hi           : constant Unicode_Char := 16#1437#;
   Canadian_Syllabics_Pa                   : constant Unicode_Char := 16#1438#;
   Canadian_Syllabics_Paa                  : constant Unicode_Char := 16#1439#;
   Canadian_Syllabics_Pwe                  : constant Unicode_Char := 16#143A#;
   Canadian_Syllabics_West_Cree_Pwe        : constant Unicode_Char := 16#143B#;
   Canadian_Syllabics_Pwi                  : constant Unicode_Char := 16#143C#;
   Canadian_Syllabics_West_Cree_Pwi        : constant Unicode_Char := 16#143D#;
   Canadian_Syllabics_Pwii                 : constant Unicode_Char := 16#143E#;
   Canadian_Syllabics_West_Cree_Pwii       : constant Unicode_Char := 16#143F#;
   Canadian_Syllabics_Pwo                  : constant Unicode_Char := 16#1440#;
   Canadian_Syllabics_West_Cree_Pwo        : constant Unicode_Char := 16#1441#;
   Canadian_Syllabics_Pwoo                 : constant Unicode_Char := 16#1442#;
   Canadian_Syllabics_West_Cree_Pwoo       : constant Unicode_Char := 16#1443#;
   Canadian_Syllabics_Pwa                  : constant Unicode_Char := 16#1444#;
   Canadian_Syllabics_West_Cree_Pwa        : constant Unicode_Char := 16#1445#;
   Canadian_Syllabics_Pwaa                 : constant Unicode_Char := 16#1446#;
   Canadian_Syllabics_West_Cree_Pwaa       : constant Unicode_Char := 16#1447#;
   Canadian_Syllabics_Y_Cree_Pwaa          : constant Unicode_Char := 16#1448#;
   Canadian_Syllabics_P                    : constant Unicode_Char := 16#1449#;
   Canadian_Syllabics_West_Cree_P          : constant Unicode_Char := 16#144A#;
   Canadian_Syllabics_Carrier_H            : constant Unicode_Char := 16#144B#;
   Canadian_Syllabics_Te                   : constant Unicode_Char := 16#144C#;
   Canadian_Syllabics_Taai                 : constant Unicode_Char := 16#144D#;
   Canadian_Syllabics_Ti                   : constant Unicode_Char := 16#144E#;
   Canadian_Syllabics_Tii                  : constant Unicode_Char := 16#144F#;
   Canadian_Syllabics_To                   : constant Unicode_Char := 16#1450#;
   Canadian_Syllabics_Too                  : constant Unicode_Char := 16#1451#;
   Canadian_Syllabics_Y_Cree_Too           : constant Unicode_Char := 16#1452#;
   Canadian_Syllabics_Carrier_Dee          : constant Unicode_Char := 16#1453#;
   Canadian_Syllabics_Carrier_Di           : constant Unicode_Char := 16#1454#;
   Canadian_Syllabics_Ta                   : constant Unicode_Char := 16#1455#;
   Canadian_Syllabics_Taa                  : constant Unicode_Char := 16#1456#;
   Canadian_Syllabics_Twe                  : constant Unicode_Char := 16#1457#;
   Canadian_Syllabics_West_Cree_Twe        : constant Unicode_Char := 16#1458#;
   Canadian_Syllabics_Twi                  : constant Unicode_Char := 16#1459#;
   Canadian_Syllabics_West_Cree_Twi        : constant Unicode_Char := 16#145A#;
   Canadian_Syllabics_Twii                 : constant Unicode_Char := 16#145B#;
   Canadian_Syllabics_West_Cree_Twii       : constant Unicode_Char := 16#145C#;
   Canadian_Syllabics_Two                  : constant Unicode_Char := 16#145D#;
   Canadian_Syllabics_West_Cree_Two        : constant Unicode_Char := 16#145E#;
   Canadian_Syllabics_Twoo                 : constant Unicode_Char := 16#145F#;
   Canadian_Syllabics_West_Cree_Twoo       : constant Unicode_Char := 16#1460#;
   Canadian_Syllabics_Twa                  : constant Unicode_Char := 16#1461#;
   Canadian_Syllabics_West_Cree_Twa        : constant Unicode_Char := 16#1462#;
   Canadian_Syllabics_Twaa                 : constant Unicode_Char := 16#1463#;
   Canadian_Syllabics_West_Cree_Twaa       : constant Unicode_Char := 16#1464#;
   Canadian_Syllabics_Naskapi_Twaa         : constant Unicode_Char := 16#1465#;
   Canadian_Syllabics_T                    : constant Unicode_Char := 16#1466#;
   Canadian_Syllabics_Tte                  : constant Unicode_Char := 16#1467#;
   Canadian_Syllabics_Tti                  : constant Unicode_Char := 16#1468#;
   Canadian_Syllabics_Tto                  : constant Unicode_Char := 16#1469#;
   Canadian_Syllabics_Tta                  : constant Unicode_Char := 16#146A#;
   Canadian_Syllabics_Ke                   : constant Unicode_Char := 16#146B#;
   Canadian_Syllabics_Kaai                 : constant Unicode_Char := 16#146C#;
   Canadian_Syllabics_Ki                   : constant Unicode_Char := 16#146D#;
   Canadian_Syllabics_Kii                  : constant Unicode_Char := 16#146E#;
   Canadian_Syllabics_Ko                   : constant Unicode_Char := 16#146F#;
   Canadian_Syllabics_Koo                  : constant Unicode_Char := 16#1470#;
   Canadian_Syllabics_Y_Cree_Koo           : constant Unicode_Char := 16#1471#;
   Canadian_Syllabics_Ka                   : constant Unicode_Char := 16#1472#;
   Canadian_Syllabics_Kaa                  : constant Unicode_Char := 16#1473#;
   Canadian_Syllabics_Kwe                  : constant Unicode_Char := 16#1474#;
   Canadian_Syllabics_West_Cree_Kwe        : constant Unicode_Char := 16#1475#;
   Canadian_Syllabics_Kwi                  : constant Unicode_Char := 16#1476#;
   Canadian_Syllabics_West_Cree_Kwi        : constant Unicode_Char := 16#1477#;
   Canadian_Syllabics_Kwii                 : constant Unicode_Char := 16#1478#;
   Canadian_Syllabics_West_Cree_Kwii       : constant Unicode_Char := 16#1479#;
   Canadian_Syllabics_Kwo                  : constant Unicode_Char := 16#147A#;
   Canadian_Syllabics_West_Cree_Kwo        : constant Unicode_Char := 16#147B#;
   Canadian_Syllabics_Kwoo                 : constant Unicode_Char := 16#147C#;
   Canadian_Syllabics_West_Cree_Kwoo       : constant Unicode_Char := 16#147D#;
   Canadian_Syllabics_Kwa                  : constant Unicode_Char := 16#147E#;
   Canadian_Syllabics_West_Cree_Kwa        : constant Unicode_Char := 16#147F#;
   Canadian_Syllabics_Kwaa                 : constant Unicode_Char := 16#1480#;
   Canadian_Syllabics_West_Cree_Kwaa       : constant Unicode_Char := 16#1481#;
   Canadian_Syllabics_Naskapi_Kwaa         : constant Unicode_Char := 16#1482#;
   Canadian_Syllabics_K                    : constant Unicode_Char := 16#1483#;
   Canadian_Syllabics_Kw                   : constant Unicode_Char := 16#1484#;
   Canadian_Syllabics_South_Slavey_Keh     : constant Unicode_Char := 16#1485#;
   Canadian_Syllabics_South_Slavey_Kih     : constant Unicode_Char := 16#1486#;
   Canadian_Syllabics_South_Slavey_Koh     : constant Unicode_Char := 16#1487#;
   Canadian_Syllabics_South_Slavey_Kah     : constant Unicode_Char := 16#1488#;
   Canadian_Syllabics_Ce                   : constant Unicode_Char := 16#1489#;
   Canadian_Syllabics_Caai                 : constant Unicode_Char := 16#148A#;
   Canadian_Syllabics_Ci                   : constant Unicode_Char := 16#148B#;
   Canadian_Syllabics_Cii                  : constant Unicode_Char := 16#148C#;
   Canadian_Syllabics_Co                   : constant Unicode_Char := 16#148D#;
   Canadian_Syllabics_Coo                  : constant Unicode_Char := 16#148E#;
   Canadian_Syllabics_Y_Cree_Coo           : constant Unicode_Char := 16#148F#;
   Canadian_Syllabics_Ca                   : constant Unicode_Char := 16#1490#;
   Canadian_Syllabics_Caa                  : constant Unicode_Char := 16#1491#;
   Canadian_Syllabics_Cwe                  : constant Unicode_Char := 16#1492#;
   Canadian_Syllabics_West_Cree_Cwe        : constant Unicode_Char := 16#1493#;
   Canadian_Syllabics_Cwi                  : constant Unicode_Char := 16#1494#;
   Canadian_Syllabics_West_Cree_Cwi        : constant Unicode_Char := 16#1495#;
   Canadian_Syllabics_Cwii                 : constant Unicode_Char := 16#1496#;
   Canadian_Syllabics_West_Cree_Cwii       : constant Unicode_Char := 16#1497#;
   Canadian_Syllabics_Cwo                  : constant Unicode_Char := 16#1498#;
   Canadian_Syllabics_West_Cree_Cwo        : constant Unicode_Char := 16#1499#;
   Canadian_Syllabics_Cwoo                 : constant Unicode_Char := 16#149A#;
   Canadian_Syllabics_West_Cree_Cwoo       : constant Unicode_Char := 16#149B#;
   Canadian_Syllabics_Cwa                  : constant Unicode_Char := 16#149C#;
   Canadian_Syllabics_West_Cree_Cwa        : constant Unicode_Char := 16#149D#;
   Canadian_Syllabics_Cwaa                 : constant Unicode_Char := 16#149E#;
   Canadian_Syllabics_West_Cree_Cwaa       : constant Unicode_Char := 16#149F#;
   Canadian_Syllabics_Naskapi_Cwaa         : constant Unicode_Char := 16#14A0#;
   Canadian_Syllabics_C                    : constant Unicode_Char := 16#14A1#;
   Canadian_Syllabics_Sayisi_Th            : constant Unicode_Char := 16#14A2#;
   Canadian_Syllabics_Me                   : constant Unicode_Char := 16#14A3#;
   Canadian_Syllabics_Maai                 : constant Unicode_Char := 16#14A4#;
   Canadian_Syllabics_Mi                   : constant Unicode_Char := 16#14A5#;
   Canadian_Syllabics_Mii                  : constant Unicode_Char := 16#14A6#;
   Canadian_Syllabics_Mo                   : constant Unicode_Char := 16#14A7#;
   Canadian_Syllabics_Moo                  : constant Unicode_Char := 16#14A8#;
   Canadian_Syllabics_Y_Cree_Moo           : constant Unicode_Char := 16#14A9#;
   Canadian_Syllabics_Ma                   : constant Unicode_Char := 16#14AA#;
   Canadian_Syllabics_Maa                  : constant Unicode_Char := 16#14AB#;
   Canadian_Syllabics_Mwe                  : constant Unicode_Char := 16#14AC#;
   Canadian_Syllabics_West_Cree_Mwe        : constant Unicode_Char := 16#14AD#;
   Canadian_Syllabics_Mwi                  : constant Unicode_Char := 16#14AE#;
   Canadian_Syllabics_West_Cree_Mwi        : constant Unicode_Char := 16#14AF#;
   Canadian_Syllabics_Mwii                 : constant Unicode_Char := 16#14B0#;
   Canadian_Syllabics_West_Cree_Mwii       : constant Unicode_Char := 16#14B1#;
   Canadian_Syllabics_Mwo                  : constant Unicode_Char := 16#14B2#;
   Canadian_Syllabics_West_Cree_Mwo        : constant Unicode_Char := 16#14B3#;
   Canadian_Syllabics_Mwoo                 : constant Unicode_Char := 16#14B4#;
   Canadian_Syllabics_West_Cree_Mwoo       : constant Unicode_Char := 16#14B5#;
   Canadian_Syllabics_Mwa                  : constant Unicode_Char := 16#14B6#;
   Canadian_Syllabics_West_Cree_Mwa        : constant Unicode_Char := 16#14B7#;
   Canadian_Syllabics_Mwaa                 : constant Unicode_Char := 16#14B8#;
   Canadian_Syllabics_West_Cree_Mwaa       : constant Unicode_Char := 16#14B9#;
   Canadian_Syllabics_Naskapi_Mwaa         : constant Unicode_Char := 16#14BA#;
   Canadian_Syllabics_M                    : constant Unicode_Char := 16#14BB#;
   Canadian_Syllabics_West_Cree_M          : constant Unicode_Char := 16#14BC#;
   Canadian_Syllabics_Mh                   : constant Unicode_Char := 16#14BD#;
   Canadian_Syllabics_Athapascan_M         : constant Unicode_Char := 16#14BE#;
   Canadian_Syllabics_Sayisi_M             : constant Unicode_Char := 16#14BF#;
   Canadian_Syllabics_Ne                   : constant Unicode_Char := 16#14C0#;
   Canadian_Syllabics_Naai                 : constant Unicode_Char := 16#14C1#;
   Canadian_Syllabics_Ni                   : constant Unicode_Char := 16#14C2#;
   Canadian_Syllabics_Nii                  : constant Unicode_Char := 16#14C3#;
   Canadian_Syllabics_No                   : constant Unicode_Char := 16#14C4#;
   Canadian_Syllabics_Noo                  : constant Unicode_Char := 16#14C5#;
   Canadian_Syllabics_Y_Cree_Noo           : constant Unicode_Char := 16#14C6#;
   Canadian_Syllabics_Na                   : constant Unicode_Char := 16#14C7#;
   Canadian_Syllabics_Naa                  : constant Unicode_Char := 16#14C8#;
   Canadian_Syllabics_Nwe                  : constant Unicode_Char := 16#14C9#;
   Canadian_Syllabics_West_Cree_Nwe        : constant Unicode_Char := 16#14CA#;
   Canadian_Syllabics_Nwa                  : constant Unicode_Char := 16#14CB#;
   Canadian_Syllabics_West_Cree_Nwa        : constant Unicode_Char := 16#14CC#;
   Canadian_Syllabics_Nwaa                 : constant Unicode_Char := 16#14CD#;
   Canadian_Syllabics_West_Cree_Nwaa       : constant Unicode_Char := 16#14CE#;
   Canadian_Syllabics_Naskapi_Nwaa         : constant Unicode_Char := 16#14CF#;
   Canadian_Syllabics_N                    : constant Unicode_Char := 16#14D0#;
   Canadian_Syllabics_Carrier_Ng           : constant Unicode_Char := 16#14D1#;
   Canadian_Syllabics_Nh                   : constant Unicode_Char := 16#14D2#;
   Canadian_Syllabics_Le                   : constant Unicode_Char := 16#14D3#;
   Canadian_Syllabics_Laai                 : constant Unicode_Char := 16#14D4#;
   Canadian_Syllabics_Li                   : constant Unicode_Char := 16#14D5#;
   Canadian_Syllabics_Lii                  : constant Unicode_Char := 16#14D6#;
   Canadian_Syllabics_Lo                   : constant Unicode_Char := 16#14D7#;
   Canadian_Syllabics_Loo                  : constant Unicode_Char := 16#14D8#;
   Canadian_Syllabics_Y_Cree_Loo           : constant Unicode_Char := 16#14D9#;
   Canadian_Syllabics_La                   : constant Unicode_Char := 16#14DA#;
   Canadian_Syllabics_Laa                  : constant Unicode_Char := 16#14DB#;
   Canadian_Syllabics_Lwe                  : constant Unicode_Char := 16#14DC#;
   Canadian_Syllabics_West_Cree_Lwe        : constant Unicode_Char := 16#14DD#;
   Canadian_Syllabics_Lwi                  : constant Unicode_Char := 16#14DE#;
   Canadian_Syllabics_West_Cree_Lwi        : constant Unicode_Char := 16#14DF#;
   Canadian_Syllabics_Lwii                 : constant Unicode_Char := 16#14E0#;
   Canadian_Syllabics_West_Cree_Lwii       : constant Unicode_Char := 16#14E1#;
   Canadian_Syllabics_Lwo                  : constant Unicode_Char := 16#14E2#;
   Canadian_Syllabics_West_Cree_Lwo        : constant Unicode_Char := 16#14E3#;
   Canadian_Syllabics_Lwoo                 : constant Unicode_Char := 16#14E4#;
   Canadian_Syllabics_West_Cree_Lwoo       : constant Unicode_Char := 16#14E5#;
   Canadian_Syllabics_Lwa                  : constant Unicode_Char := 16#14E6#;
   Canadian_Syllabics_West_Cree_Lwa        : constant Unicode_Char := 16#14E7#;
   Canadian_Syllabics_Lwaa                 : constant Unicode_Char := 16#14E8#;
   Canadian_Syllabics_West_Cree_Lwaa       : constant Unicode_Char := 16#14E9#;
   Canadian_Syllabics_L                    : constant Unicode_Char := 16#14EA#;
   Canadian_Syllabics_West_Cree_L          : constant Unicode_Char := 16#14EB#;
   Canadian_Syllabics_Medial_L             : constant Unicode_Char := 16#14EC#;
   Canadian_Syllabics_Se                   : constant Unicode_Char := 16#14ED#;
   Canadian_Syllabics_Saai                 : constant Unicode_Char := 16#14EE#;
   Canadian_Syllabics_Si                   : constant Unicode_Char := 16#14EF#;
   Canadian_Syllabics_Sii                  : constant Unicode_Char := 16#14F0#;
   Canadian_Syllabics_So                   : constant Unicode_Char := 16#14F1#;
   Canadian_Syllabics_Soo                  : constant Unicode_Char := 16#14F2#;
   Canadian_Syllabics_Y_Cree_Soo           : constant Unicode_Char := 16#14F3#;
   Canadian_Syllabics_Sa                   : constant Unicode_Char := 16#14F4#;
   Canadian_Syllabics_Saa                  : constant Unicode_Char := 16#14F5#;
   Canadian_Syllabics_Swe                  : constant Unicode_Char := 16#14F6#;
   Canadian_Syllabics_West_Cree_Swe        : constant Unicode_Char := 16#14F7#;
   Canadian_Syllabics_Swi                  : constant Unicode_Char := 16#14F8#;
   Canadian_Syllabics_West_Cree_Swi        : constant Unicode_Char := 16#14F9#;
   Canadian_Syllabics_Swii                 : constant Unicode_Char := 16#14FA#;
   Canadian_Syllabics_West_Cree_Swii       : constant Unicode_Char := 16#14FB#;
   Canadian_Syllabics_Swo                  : constant Unicode_Char := 16#14FC#;
   Canadian_Syllabics_West_Cree_Swo        : constant Unicode_Char := 16#14FD#;
   Canadian_Syllabics_Swoo                 : constant Unicode_Char := 16#14FE#;
   Canadian_Syllabics_West_Cree_Swoo       : constant Unicode_Char := 16#14FF#;
   Canadian_Syllabics_Swa                  : constant Unicode_Char := 16#1500#;
   Canadian_Syllabics_West_Cree_Swa        : constant Unicode_Char := 16#1501#;
   Canadian_Syllabics_Swaa                 : constant Unicode_Char := 16#1502#;
   Canadian_Syllabics_West_Cree_Swaa       : constant Unicode_Char := 16#1503#;
   Canadian_Syllabics_Naskapi_Swaa         : constant Unicode_Char := 16#1504#;
   Canadian_Syllabics_S                    : constant Unicode_Char := 16#1505#;
   Canadian_Syllabics_Athapascan_S         : constant Unicode_Char := 16#1506#;
   Canadian_Syllabics_Sw                   : constant Unicode_Char := 16#1507#;
   Canadian_Syllabics_Blackfoot_S          : constant Unicode_Char := 16#1508#;
   Canadian_Syllabics_Moose_Cree_Sk        : constant Unicode_Char := 16#1509#;
   Canadian_Syllabics_Naskapi_Skw          : constant Unicode_Char := 16#150A#;
   Canadian_Syllabics_Naskapi_S_W          : constant Unicode_Char := 16#150B#;
   Canadian_Syllabics_Naskapi_Spwa         : constant Unicode_Char := 16#150C#;
   Canadian_Syllabics_Naskapi_Stwa         : constant Unicode_Char := 16#150D#;
   Canadian_Syllabics_Naskapi_Skwa         : constant Unicode_Char := 16#150E#;
   Canadian_Syllabics_Naskapi_Scwa         : constant Unicode_Char := 16#150F#;
   Canadian_Syllabics_She                  : constant Unicode_Char := 16#1510#;
   Canadian_Syllabics_Shi                  : constant Unicode_Char := 16#1511#;
   Canadian_Syllabics_Shii                 : constant Unicode_Char := 16#1512#;
   Canadian_Syllabics_Sho                  : constant Unicode_Char := 16#1513#;
   Canadian_Syllabics_Shoo                 : constant Unicode_Char := 16#1514#;
   Canadian_Syllabics_Sha                  : constant Unicode_Char := 16#1515#;
   Canadian_Syllabics_Shaa                 : constant Unicode_Char := 16#1516#;
   Canadian_Syllabics_Shwe                 : constant Unicode_Char := 16#1517#;
   Canadian_Syllabics_West_Cree_Shwe       : constant Unicode_Char := 16#1518#;
   Canadian_Syllabics_Shwi                 : constant Unicode_Char := 16#1519#;
   Canadian_Syllabics_West_Cree_Shwi       : constant Unicode_Char := 16#151A#;
   Canadian_Syllabics_Shwii                : constant Unicode_Char := 16#151B#;
   Canadian_Syllabics_West_Cree_Shwii      : constant Unicode_Char := 16#151C#;
   Canadian_Syllabics_Shwo                 : constant Unicode_Char := 16#151D#;
   Canadian_Syllabics_West_Cree_Shwo       : constant Unicode_Char := 16#151E#;
   Canadian_Syllabics_Shwoo                : constant Unicode_Char := 16#151F#;
   Canadian_Syllabics_West_Cree_Shwoo      : constant Unicode_Char := 16#1520#;
   Canadian_Syllabics_Shwa                 : constant Unicode_Char := 16#1521#;
   Canadian_Syllabics_West_Cree_Shwa       : constant Unicode_Char := 16#1522#;
   Canadian_Syllabics_Shwaa                : constant Unicode_Char := 16#1523#;
   Canadian_Syllabics_West_Cree_Shwaa      : constant Unicode_Char := 16#1524#;
   Canadian_Syllabics_Sh                   : constant Unicode_Char := 16#1525#;
   Canadian_Syllabics_Ye                   : constant Unicode_Char := 16#1526#;
   Canadian_Syllabics_Yaai                 : constant Unicode_Char := 16#1527#;
   Canadian_Syllabics_Yi                   : constant Unicode_Char := 16#1528#;
   Canadian_Syllabics_Yii                  : constant Unicode_Char := 16#1529#;
   Canadian_Syllabics_Yo                   : constant Unicode_Char := 16#152A#;
   Canadian_Syllabics_Yoo                  : constant Unicode_Char := 16#152B#;
   Canadian_Syllabics_Y_Cree_Yoo           : constant Unicode_Char := 16#152C#;
   Canadian_Syllabics_Ya                   : constant Unicode_Char := 16#152D#;
   Canadian_Syllabics_Yaa                  : constant Unicode_Char := 16#152E#;
   Canadian_Syllabics_Ywe                  : constant Unicode_Char := 16#152F#;
   Canadian_Syllabics_West_Cree_Ywe        : constant Unicode_Char := 16#1530#;
   Canadian_Syllabics_Ywi                  : constant Unicode_Char := 16#1531#;
   Canadian_Syllabics_West_Cree_Ywi        : constant Unicode_Char := 16#1532#;
   Canadian_Syllabics_Ywii                 : constant Unicode_Char := 16#1533#;
   Canadian_Syllabics_West_Cree_Ywii       : constant Unicode_Char := 16#1534#;
   Canadian_Syllabics_Ywo                  : constant Unicode_Char := 16#1535#;
   Canadian_Syllabics_West_Cree_Ywo        : constant Unicode_Char := 16#1536#;
   Canadian_Syllabics_Ywoo                 : constant Unicode_Char := 16#1537#;
   Canadian_Syllabics_West_Cree_Ywoo       : constant Unicode_Char := 16#1538#;
   Canadian_Syllabics_Ywa                  : constant Unicode_Char := 16#1539#;
   Canadian_Syllabics_West_Cree_Ywa        : constant Unicode_Char := 16#153A#;
   Canadian_Syllabics_Ywaa                 : constant Unicode_Char := 16#153B#;
   Canadian_Syllabics_West_Cree_Ywaa       : constant Unicode_Char := 16#153C#;
   Canadian_Syllabics_Naskapi_Ywaa         : constant Unicode_Char := 16#153D#;
   Canadian_Syllabics_Y                    : constant Unicode_Char := 16#153E#;
   Canadian_Syllabics_Bible_Cree_Y         : constant Unicode_Char := 16#153F#;
   Canadian_Syllabics_West_Cree_Y          : constant Unicode_Char := 16#1540#;
   Canadian_Syllabics_Sayisi_Yi            : constant Unicode_Char := 16#1541#;
   Canadian_Syllabics_Re                   : constant Unicode_Char := 16#1542#;
   Canadian_Syllabics_R_Cree_Re            : constant Unicode_Char := 16#1543#;
   Canadian_Syllabics_West_Cree_Le         : constant Unicode_Char := 16#1544#;
   Canadian_Syllabics_Raai                 : constant Unicode_Char := 16#1545#;
   Canadian_Syllabics_Ri                   : constant Unicode_Char := 16#1546#;
   Canadian_Syllabics_Rii                  : constant Unicode_Char := 16#1547#;
   Canadian_Syllabics_Ro                   : constant Unicode_Char := 16#1548#;
   Canadian_Syllabics_Roo                  : constant Unicode_Char := 16#1549#;
   Canadian_Syllabics_West_Cree_Lo         : constant Unicode_Char := 16#154A#;
   Canadian_Syllabics_Ra                   : constant Unicode_Char := 16#154B#;
   Canadian_Syllabics_Raa                  : constant Unicode_Char := 16#154C#;
   Canadian_Syllabics_West_Cree_La         : constant Unicode_Char := 16#154D#;
   Canadian_Syllabics_Rwaa                 : constant Unicode_Char := 16#154E#;
   Canadian_Syllabics_West_Cree_Rwaa       : constant Unicode_Char := 16#154F#;
   Canadian_Syllabics_R                    : constant Unicode_Char := 16#1550#;
   Canadian_Syllabics_West_Cree_R          : constant Unicode_Char := 16#1551#;
   Canadian_Syllabics_Medial_R             : constant Unicode_Char := 16#1552#;
   Canadian_Syllabics_Fe                   : constant Unicode_Char := 16#1553#;
   Canadian_Syllabics_Faai                 : constant Unicode_Char := 16#1554#;
   Canadian_Syllabics_Fi                   : constant Unicode_Char := 16#1555#;
   Canadian_Syllabics_Fii                  : constant Unicode_Char := 16#1556#;
   Canadian_Syllabics_Fo                   : constant Unicode_Char := 16#1557#;
   Canadian_Syllabics_Foo                  : constant Unicode_Char := 16#1558#;
   Canadian_Syllabics_Fa                   : constant Unicode_Char := 16#1559#;
   Canadian_Syllabics_Faa                  : constant Unicode_Char := 16#155A#;
   Canadian_Syllabics_Fwaa                 : constant Unicode_Char := 16#155B#;
   Canadian_Syllabics_West_Cree_Fwaa       : constant Unicode_Char := 16#155C#;
   Canadian_Syllabics_F                    : constant Unicode_Char := 16#155D#;
   Canadian_Syllabics_The                  : constant Unicode_Char := 16#155E#;
   Canadian_Syllabics_N_Cree_The           : constant Unicode_Char := 16#155F#;
   Canadian_Syllabics_Thi                  : constant Unicode_Char := 16#1560#;
   Canadian_Syllabics_N_Cree_Thi           : constant Unicode_Char := 16#1561#;
   Canadian_Syllabics_Thii                 : constant Unicode_Char := 16#1562#;
   Canadian_Syllabics_N_Cree_Thii          : constant Unicode_Char := 16#1563#;
   Canadian_Syllabics_Tho                  : constant Unicode_Char := 16#1564#;
   Canadian_Syllabics_Thoo                 : constant Unicode_Char := 16#1565#;
   Canadian_Syllabics_Tha                  : constant Unicode_Char := 16#1566#;
   Canadian_Syllabics_Thaa                 : constant Unicode_Char := 16#1567#;
   Canadian_Syllabics_Thwaa                : constant Unicode_Char := 16#1568#;
   Canadian_Syllabics_West_Cree_Thwaa      : constant Unicode_Char := 16#1569#;
   Canadian_Syllabics_Th                   : constant Unicode_Char := 16#156A#;
   Canadian_Syllabics_Tthe                 : constant Unicode_Char := 16#156B#;
   Canadian_Syllabics_Tthi                 : constant Unicode_Char := 16#156C#;
   Canadian_Syllabics_Ttho                 : constant Unicode_Char := 16#156D#;
   Canadian_Syllabics_Ttha                 : constant Unicode_Char := 16#156E#;
   Canadian_Syllabics_Tth                  : constant Unicode_Char := 16#156F#;
   Canadian_Syllabics_Tye                  : constant Unicode_Char := 16#1570#;
   Canadian_Syllabics_Tyi                  : constant Unicode_Char := 16#1571#;
   Canadian_Syllabics_Tyo                  : constant Unicode_Char := 16#1572#;
   Canadian_Syllabics_Tya                  : constant Unicode_Char := 16#1573#;
   Canadian_Syllabics_Nunavik_He           : constant Unicode_Char := 16#1574#;
   Canadian_Syllabics_Nunavik_Hi           : constant Unicode_Char := 16#1575#;
   Canadian_Syllabics_Nunavik_Hii          : constant Unicode_Char := 16#1576#;
   Canadian_Syllabics_Nunavik_Ho           : constant Unicode_Char := 16#1577#;
   Canadian_Syllabics_Nunavik_Hoo          : constant Unicode_Char := 16#1578#;
   Canadian_Syllabics_Nunavik_Ha           : constant Unicode_Char := 16#1579#;
   Canadian_Syllabics_Nunavik_Haa          : constant Unicode_Char := 16#157A#;
   Canadian_Syllabics_Nunavik_H            : constant Unicode_Char := 16#157B#;
   Canadian_Syllabics_Nunavut_H            : constant Unicode_Char := 16#157C#;
   Canadian_Syllabics_Hk                   : constant Unicode_Char := 16#157D#;
   Canadian_Syllabics_Qaai                 : constant Unicode_Char := 16#157E#;
   Canadian_Syllabics_Qi                   : constant Unicode_Char := 16#157F#;
   Canadian_Syllabics_Qii                  : constant Unicode_Char := 16#1580#;
   Canadian_Syllabics_Qo                   : constant Unicode_Char := 16#1581#;
   Canadian_Syllabics_Qoo                  : constant Unicode_Char := 16#1582#;
   Canadian_Syllabics_Qa                   : constant Unicode_Char := 16#1583#;
   Canadian_Syllabics_Qaa                  : constant Unicode_Char := 16#1584#;
   Canadian_Syllabics_Q                    : constant Unicode_Char := 16#1585#;
   Canadian_Syllabics_Tlhe                 : constant Unicode_Char := 16#1586#;
   Canadian_Syllabics_Tlhi                 : constant Unicode_Char := 16#1587#;
   Canadian_Syllabics_Tlho                 : constant Unicode_Char := 16#1588#;
   Canadian_Syllabics_Tlha                 : constant Unicode_Char := 16#1589#;
   Canadian_Syllabics_West_Cree_Re         : constant Unicode_Char := 16#158A#;
   Canadian_Syllabics_West_Cree_Ri         : constant Unicode_Char := 16#158B#;
   Canadian_Syllabics_West_Cree_Ro         : constant Unicode_Char := 16#158C#;
   Canadian_Syllabics_West_Cree_Ra         : constant Unicode_Char := 16#158D#;
   Canadian_Syllabics_Ngaai                : constant Unicode_Char := 16#158E#;
   Canadian_Syllabics_Ngi                  : constant Unicode_Char := 16#158F#;
   Canadian_Syllabics_Ngii                 : constant Unicode_Char := 16#1590#;
   Canadian_Syllabics_Ngo                  : constant Unicode_Char := 16#1591#;
   Canadian_Syllabics_Ngoo                 : constant Unicode_Char := 16#1592#;
   Canadian_Syllabics_Nga                  : constant Unicode_Char := 16#1593#;
   Canadian_Syllabics_Ngaa                 : constant Unicode_Char := 16#1594#;
   Canadian_Syllabics_Ng                   : constant Unicode_Char := 16#1595#;
   Canadian_Syllabics_Nng                  : constant Unicode_Char := 16#1596#;
   Canadian_Syllabics_Sayisi_She           : constant Unicode_Char := 16#1597#;
   Canadian_Syllabics_Sayisi_Shi           : constant Unicode_Char := 16#1598#;
   Canadian_Syllabics_Sayisi_Sho           : constant Unicode_Char := 16#1599#;
   Canadian_Syllabics_Sayisi_Sha           : constant Unicode_Char := 16#159A#;
   Canadian_Syllabics_Woods_Cree_The       : constant Unicode_Char := 16#159B#;
   Canadian_Syllabics_Woods_Cree_Thi       : constant Unicode_Char := 16#159C#;
   Canadian_Syllabics_Woods_Cree_Tho       : constant Unicode_Char := 16#159D#;
   Canadian_Syllabics_Woods_Cree_Tha       : constant Unicode_Char := 16#159E#;
   Canadian_Syllabics_Woods_Cree_Th        : constant Unicode_Char := 16#159F#;
   Canadian_Syllabics_Lhi                  : constant Unicode_Char := 16#15A0#;
   Canadian_Syllabics_Lhii                 : constant Unicode_Char := 16#15A1#;
   Canadian_Syllabics_Lho                  : constant Unicode_Char := 16#15A2#;
   Canadian_Syllabics_Lhoo                 : constant Unicode_Char := 16#15A3#;
   Canadian_Syllabics_Lha                  : constant Unicode_Char := 16#15A4#;
   Canadian_Syllabics_Lhaa                 : constant Unicode_Char := 16#15A5#;
   Canadian_Syllabics_Lh                   : constant Unicode_Char := 16#15A6#;
   Canadian_Syllabics_Th_Cree_The          : constant Unicode_Char := 16#15A7#;
   Canadian_Syllabics_Th_Cree_Thi          : constant Unicode_Char := 16#15A8#;
   Canadian_Syllabics_Th_Cree_Thii         : constant Unicode_Char := 16#15A9#;
   Canadian_Syllabics_Th_Cree_Tho          : constant Unicode_Char := 16#15AA#;
   Canadian_Syllabics_Th_Cree_Thoo         : constant Unicode_Char := 16#15AB#;
   Canadian_Syllabics_Th_Cree_Tha          : constant Unicode_Char := 16#15AC#;
   Canadian_Syllabics_Th_Cree_Thaa         : constant Unicode_Char := 16#15AD#;
   Canadian_Syllabics_Th_Cree_Th           : constant Unicode_Char := 16#15AE#;
   Canadian_Syllabics_Aivilik_B            : constant Unicode_Char := 16#15AF#;
   Canadian_Syllabics_Blackfoot_E          : constant Unicode_Char := 16#15B0#;
   Canadian_Syllabics_Blackfoot_I          : constant Unicode_Char := 16#15B1#;
   Canadian_Syllabics_Blackfoot_O          : constant Unicode_Char := 16#15B2#;
   Canadian_Syllabics_Blackfoot_A          : constant Unicode_Char := 16#15B3#;
   Canadian_Syllabics_Blackfoot_We         : constant Unicode_Char := 16#15B4#;
   Canadian_Syllabics_Blackfoot_Wi         : constant Unicode_Char := 16#15B5#;
   Canadian_Syllabics_Blackfoot_Wo         : constant Unicode_Char := 16#15B6#;
   Canadian_Syllabics_Blackfoot_Wa         : constant Unicode_Char := 16#15B7#;
   Canadian_Syllabics_Blackfoot_Ne         : constant Unicode_Char := 16#15B8#;
   Canadian_Syllabics_Blackfoot_Ni         : constant Unicode_Char := 16#15B9#;
   Canadian_Syllabics_Blackfoot_No         : constant Unicode_Char := 16#15BA#;
   Canadian_Syllabics_Blackfoot_Na         : constant Unicode_Char := 16#15BB#;
   Canadian_Syllabics_Blackfoot_Ke         : constant Unicode_Char := 16#15BC#;
   Canadian_Syllabics_Blackfoot_Ki         : constant Unicode_Char := 16#15BD#;
   Canadian_Syllabics_Blackfoot_Ko         : constant Unicode_Char := 16#15BE#;
   Canadian_Syllabics_Blackfoot_Ka         : constant Unicode_Char := 16#15BF#;
   Canadian_Syllabics_Sayisi_He            : constant Unicode_Char := 16#15C0#;
   Canadian_Syllabics_Sayisi_Hi            : constant Unicode_Char := 16#15C1#;
   Canadian_Syllabics_Sayisi_Ho            : constant Unicode_Char := 16#15C2#;
   Canadian_Syllabics_Sayisi_Ha            : constant Unicode_Char := 16#15C3#;
   Canadian_Syllabics_Carrier_Ghu          : constant Unicode_Char := 16#15C4#;
   Canadian_Syllabics_Carrier_Gho          : constant Unicode_Char := 16#15C5#;
   Canadian_Syllabics_Carrier_Ghe          : constant Unicode_Char := 16#15C6#;
   Canadian_Syllabics_Carrier_Ghee         : constant Unicode_Char := 16#15C7#;
   Canadian_Syllabics_Carrier_Ghi          : constant Unicode_Char := 16#15C8#;
   Canadian_Syllabics_Carrier_Gha          : constant Unicode_Char := 16#15C9#;
   Canadian_Syllabics_Carrier_Ru           : constant Unicode_Char := 16#15CA#;
   Canadian_Syllabics_Carrier_Ro           : constant Unicode_Char := 16#15CB#;
   Canadian_Syllabics_Carrier_Re           : constant Unicode_Char := 16#15CC#;
   Canadian_Syllabics_Carrier_Ree          : constant Unicode_Char := 16#15CD#;
   Canadian_Syllabics_Carrier_Ri           : constant Unicode_Char := 16#15CE#;
   Canadian_Syllabics_Carrier_Ra           : constant Unicode_Char := 16#15CF#;
   Canadian_Syllabics_Carrier_Wu           : constant Unicode_Char := 16#15D0#;
   Canadian_Syllabics_Carrier_Wo           : constant Unicode_Char := 16#15D1#;
   Canadian_Syllabics_Carrier_We           : constant Unicode_Char := 16#15D2#;
   Canadian_Syllabics_Carrier_Wee          : constant Unicode_Char := 16#15D3#;
   Canadian_Syllabics_Carrier_Wi           : constant Unicode_Char := 16#15D4#;
   Canadian_Syllabics_Carrier_Wa           : constant Unicode_Char := 16#15D5#;
   Canadian_Syllabics_Carrier_Hwu          : constant Unicode_Char := 16#15D6#;
   Canadian_Syllabics_Carrier_Hwo          : constant Unicode_Char := 16#15D7#;
   Canadian_Syllabics_Carrier_Hwe          : constant Unicode_Char := 16#15D8#;
   Canadian_Syllabics_Carrier_Hwee         : constant Unicode_Char := 16#15D9#;
   Canadian_Syllabics_Carrier_Hwi          : constant Unicode_Char := 16#15DA#;
   Canadian_Syllabics_Carrier_Hwa          : constant Unicode_Char := 16#15DB#;
   Canadian_Syllabics_Carrier_Thu          : constant Unicode_Char := 16#15DC#;
   Canadian_Syllabics_Carrier_Tho          : constant Unicode_Char := 16#15DD#;
   Canadian_Syllabics_Carrier_The          : constant Unicode_Char := 16#15DE#;
   Canadian_Syllabics_Carrier_Thee         : constant Unicode_Char := 16#15DF#;
   Canadian_Syllabics_Carrier_Thi          : constant Unicode_Char := 16#15E0#;
   Canadian_Syllabics_Carrier_Tha          : constant Unicode_Char := 16#15E1#;
   Canadian_Syllabics_Carrier_Ttu          : constant Unicode_Char := 16#15E2#;
   Canadian_Syllabics_Carrier_Tto          : constant Unicode_Char := 16#15E3#;
   Canadian_Syllabics_Carrier_Tte          : constant Unicode_Char := 16#15E4#;
   Canadian_Syllabics_Carrier_Ttee         : constant Unicode_Char := 16#15E5#;
   Canadian_Syllabics_Carrier_Tti          : constant Unicode_Char := 16#15E6#;
   Canadian_Syllabics_Carrier_Tta          : constant Unicode_Char := 16#15E7#;
   Canadian_Syllabics_Carrier_Pu           : constant Unicode_Char := 16#15E8#;
   Canadian_Syllabics_Carrier_Po           : constant Unicode_Char := 16#15E9#;
   Canadian_Syllabics_Carrier_Pe           : constant Unicode_Char := 16#15EA#;
   Canadian_Syllabics_Carrier_Pee          : constant Unicode_Char := 16#15EB#;
   Canadian_Syllabics_Carrier_Pi           : constant Unicode_Char := 16#15EC#;
   Canadian_Syllabics_Carrier_Pa           : constant Unicode_Char := 16#15ED#;
   Canadian_Syllabics_Carrier_P            : constant Unicode_Char := 16#15EE#;
   Canadian_Syllabics_Carrier_Gu           : constant Unicode_Char := 16#15EF#;
   Canadian_Syllabics_Carrier_Go           : constant Unicode_Char := 16#15F0#;
   Canadian_Syllabics_Carrier_Ge           : constant Unicode_Char := 16#15F1#;
   Canadian_Syllabics_Carrier_Gee          : constant Unicode_Char := 16#15F2#;
   Canadian_Syllabics_Carrier_Gi           : constant Unicode_Char := 16#15F3#;
   Canadian_Syllabics_Carrier_Ga           : constant Unicode_Char := 16#15F4#;
   Canadian_Syllabics_Carrier_Khu          : constant Unicode_Char := 16#15F5#;
   Canadian_Syllabics_Carrier_Kho          : constant Unicode_Char := 16#15F6#;
   Canadian_Syllabics_Carrier_Khe          : constant Unicode_Char := 16#15F7#;
   Canadian_Syllabics_Carrier_Khee         : constant Unicode_Char := 16#15F8#;
   Canadian_Syllabics_Carrier_Khi          : constant Unicode_Char := 16#15F9#;
   Canadian_Syllabics_Carrier_Kha          : constant Unicode_Char := 16#15FA#;
   Canadian_Syllabics_Carrier_Kku          : constant Unicode_Char := 16#15FB#;
   Canadian_Syllabics_Carrier_Kko          : constant Unicode_Char := 16#15FC#;
   Canadian_Syllabics_Carrier_Kke          : constant Unicode_Char := 16#15FD#;
   Canadian_Syllabics_Carrier_Kkee         : constant Unicode_Char := 16#15FE#;
   Canadian_Syllabics_Carrier_Kki          : constant Unicode_Char := 16#15FF#;
   Canadian_Syllabics_Carrier_Kka          : constant Unicode_Char := 16#1600#;
   Canadian_Syllabics_Carrier_Kk           : constant Unicode_Char := 16#1601#;
   Canadian_Syllabics_Carrier_Nu           : constant Unicode_Char := 16#1602#;
   Canadian_Syllabics_Carrier_No           : constant Unicode_Char := 16#1603#;
   Canadian_Syllabics_Carrier_Ne           : constant Unicode_Char := 16#1604#;
   Canadian_Syllabics_Carrier_Nee          : constant Unicode_Char := 16#1605#;
   Canadian_Syllabics_Carrier_Ni           : constant Unicode_Char := 16#1606#;
   Canadian_Syllabics_Carrier_Na           : constant Unicode_Char := 16#1607#;
   Canadian_Syllabics_Carrier_Mu           : constant Unicode_Char := 16#1608#;
   Canadian_Syllabics_Carrier_Mo           : constant Unicode_Char := 16#1609#;
   Canadian_Syllabics_Carrier_Me           : constant Unicode_Char := 16#160A#;
   Canadian_Syllabics_Carrier_Mee          : constant Unicode_Char := 16#160B#;
   Canadian_Syllabics_Carrier_Mi           : constant Unicode_Char := 16#160C#;
   Canadian_Syllabics_Carrier_Ma           : constant Unicode_Char := 16#160D#;
   Canadian_Syllabics_Carrier_Yu           : constant Unicode_Char := 16#160E#;
   Canadian_Syllabics_Carrier_Yo           : constant Unicode_Char := 16#160F#;
   Canadian_Syllabics_Carrier_Ye           : constant Unicode_Char := 16#1610#;
   Canadian_Syllabics_Carrier_Yee          : constant Unicode_Char := 16#1611#;
   Canadian_Syllabics_Carrier_Yi           : constant Unicode_Char := 16#1612#;
   Canadian_Syllabics_Carrier_Ya           : constant Unicode_Char := 16#1613#;
   Canadian_Syllabics_Carrier_Ju           : constant Unicode_Char := 16#1614#;
   Canadian_Syllabics_Sayisi_Ju            : constant Unicode_Char := 16#1615#;
   Canadian_Syllabics_Carrier_Jo           : constant Unicode_Char := 16#1616#;
   Canadian_Syllabics_Carrier_Je           : constant Unicode_Char := 16#1617#;
   Canadian_Syllabics_Carrier_Jee          : constant Unicode_Char := 16#1618#;
   Canadian_Syllabics_Carrier_Ji           : constant Unicode_Char := 16#1619#;
   Canadian_Syllabics_Sayisi_Ji            : constant Unicode_Char := 16#161A#;
   Canadian_Syllabics_Carrier_Ja           : constant Unicode_Char := 16#161B#;
   Canadian_Syllabics_Carrier_Jju          : constant Unicode_Char := 16#161C#;
   Canadian_Syllabics_Carrier_Jjo          : constant Unicode_Char := 16#161D#;
   Canadian_Syllabics_Carrier_Jje          : constant Unicode_Char := 16#161E#;
   Canadian_Syllabics_Carrier_Jjee         : constant Unicode_Char := 16#161F#;
   Canadian_Syllabics_Carrier_Jji          : constant Unicode_Char := 16#1620#;
   Canadian_Syllabics_Carrier_Jja          : constant Unicode_Char := 16#1621#;
   Canadian_Syllabics_Carrier_Lu           : constant Unicode_Char := 16#1622#;
   Canadian_Syllabics_Carrier_Lo           : constant Unicode_Char := 16#1623#;
   Canadian_Syllabics_Carrier_Le           : constant Unicode_Char := 16#1624#;
   Canadian_Syllabics_Carrier_Lee          : constant Unicode_Char := 16#1625#;
   Canadian_Syllabics_Carrier_Li           : constant Unicode_Char := 16#1626#;
   Canadian_Syllabics_Carrier_La           : constant Unicode_Char := 16#1627#;
   Canadian_Syllabics_Carrier_Dlu          : constant Unicode_Char := 16#1628#;
   Canadian_Syllabics_Carrier_Dlo          : constant Unicode_Char := 16#1629#;
   Canadian_Syllabics_Carrier_Dle          : constant Unicode_Char := 16#162A#;
   Canadian_Syllabics_Carrier_Dlee         : constant Unicode_Char := 16#162B#;
   Canadian_Syllabics_Carrier_Dli          : constant Unicode_Char := 16#162C#;
   Canadian_Syllabics_Carrier_Dla          : constant Unicode_Char := 16#162D#;
   Canadian_Syllabics_Carrier_Lhu          : constant Unicode_Char := 16#162E#;
   Canadian_Syllabics_Carrier_Lho          : constant Unicode_Char := 16#162F#;
   Canadian_Syllabics_Carrier_Lhe          : constant Unicode_Char := 16#1630#;
   Canadian_Syllabics_Carrier_Lhee         : constant Unicode_Char := 16#1631#;
   Canadian_Syllabics_Carrier_Lhi          : constant Unicode_Char := 16#1632#;
   Canadian_Syllabics_Carrier_Lha          : constant Unicode_Char := 16#1633#;
   Canadian_Syllabics_Carrier_Tlhu         : constant Unicode_Char := 16#1634#;
   Canadian_Syllabics_Carrier_Tlho         : constant Unicode_Char := 16#1635#;
   Canadian_Syllabics_Carrier_Tlhe         : constant Unicode_Char := 16#1636#;
   Canadian_Syllabics_Carrier_Tlhee        : constant Unicode_Char := 16#1637#;
   Canadian_Syllabics_Carrier_Tlhi         : constant Unicode_Char := 16#1638#;
   Canadian_Syllabics_Carrier_Tlha         : constant Unicode_Char := 16#1639#;
   Canadian_Syllabics_Carrier_Tlu          : constant Unicode_Char := 16#163A#;
   Canadian_Syllabics_Carrier_Tlo          : constant Unicode_Char := 16#163B#;
   Canadian_Syllabics_Carrier_Tle          : constant Unicode_Char := 16#163C#;
   Canadian_Syllabics_Carrier_Tlee         : constant Unicode_Char := 16#163D#;
   Canadian_Syllabics_Carrier_Tli          : constant Unicode_Char := 16#163E#;
   Canadian_Syllabics_Carrier_Tla          : constant Unicode_Char := 16#163F#;
   Canadian_Syllabics_Carrier_Zu           : constant Unicode_Char := 16#1640#;
   Canadian_Syllabics_Carrier_Zo           : constant Unicode_Char := 16#1641#;
   Canadian_Syllabics_Carrier_Ze           : constant Unicode_Char := 16#1642#;
   Canadian_Syllabics_Carrier_Zee          : constant Unicode_Char := 16#1643#;
   Canadian_Syllabics_Carrier_Zi           : constant Unicode_Char := 16#1644#;
   Canadian_Syllabics_Carrier_Za           : constant Unicode_Char := 16#1645#;
   Canadian_Syllabics_Carrier_Z            : constant Unicode_Char := 16#1646#;
   Canadian_Syllabics_Carrier_Initial_Z    : constant Unicode_Char := 16#1647#;
   Canadian_Syllabics_Carrier_Dzu          : constant Unicode_Char := 16#1648#;
   Canadian_Syllabics_Carrier_Dzo          : constant Unicode_Char := 16#1649#;
   Canadian_Syllabics_Carrier_Dze          : constant Unicode_Char := 16#164A#;
   Canadian_Syllabics_Carrier_Dzee         : constant Unicode_Char := 16#164B#;
   Canadian_Syllabics_Carrier_Dzi          : constant Unicode_Char := 16#164C#;
   Canadian_Syllabics_Carrier_Dza          : constant Unicode_Char := 16#164D#;
   Canadian_Syllabics_Carrier_Su           : constant Unicode_Char := 16#164E#;
   Canadian_Syllabics_Carrier_So           : constant Unicode_Char := 16#164F#;
   Canadian_Syllabics_Carrier_Se           : constant Unicode_Char := 16#1650#;
   Canadian_Syllabics_Carrier_See          : constant Unicode_Char := 16#1651#;
   Canadian_Syllabics_Carrier_Si           : constant Unicode_Char := 16#1652#;
   Canadian_Syllabics_Carrier_Sa           : constant Unicode_Char := 16#1653#;
   Canadian_Syllabics_Carrier_Shu          : constant Unicode_Char := 16#1654#;
   Canadian_Syllabics_Carrier_Sho          : constant Unicode_Char := 16#1655#;
   Canadian_Syllabics_Carrier_She          : constant Unicode_Char := 16#1656#;
   Canadian_Syllabics_Carrier_Shee         : constant Unicode_Char := 16#1657#;
   Canadian_Syllabics_Carrier_Shi          : constant Unicode_Char := 16#1658#;
   Canadian_Syllabics_Carrier_Sha          : constant Unicode_Char := 16#1659#;
   Canadian_Syllabics_Carrier_Sh           : constant Unicode_Char := 16#165A#;
   Canadian_Syllabics_Carrier_Tsu          : constant Unicode_Char := 16#165B#;
   Canadian_Syllabics_Carrier_Tso          : constant Unicode_Char := 16#165C#;
   Canadian_Syllabics_Carrier_Tse          : constant Unicode_Char := 16#165D#;
   Canadian_Syllabics_Carrier_Tsee         : constant Unicode_Char := 16#165E#;
   Canadian_Syllabics_Carrier_Tsi          : constant Unicode_Char := 16#165F#;
   Canadian_Syllabics_Carrier_Tsa          : constant Unicode_Char := 16#1660#;
   Canadian_Syllabics_Carrier_Chu          : constant Unicode_Char := 16#1661#;
   Canadian_Syllabics_Carrier_Cho          : constant Unicode_Char := 16#1662#;
   Canadian_Syllabics_Carrier_Che          : constant Unicode_Char := 16#1663#;
   Canadian_Syllabics_Carrier_Chee         : constant Unicode_Char := 16#1664#;
   Canadian_Syllabics_Carrier_Chi          : constant Unicode_Char := 16#1665#;
   Canadian_Syllabics_Carrier_Cha          : constant Unicode_Char := 16#1666#;
   Canadian_Syllabics_Carrier_Ttsu         : constant Unicode_Char := 16#1667#;
   Canadian_Syllabics_Carrier_Ttso         : constant Unicode_Char := 16#1668#;
   Canadian_Syllabics_Carrier_Ttse         : constant Unicode_Char := 16#1669#;
   Canadian_Syllabics_Carrier_Ttsee        : constant Unicode_Char := 16#166A#;
   Canadian_Syllabics_Carrier_Ttsi         : constant Unicode_Char := 16#166B#;
   Canadian_Syllabics_Carrier_Ttsa         : constant Unicode_Char := 16#166C#;
   Canadian_Syllabics_Chi_Sign             : constant Unicode_Char := 16#166D#;
   Canadian_Syllabics_Full_Stop            : constant Unicode_Char := 16#166E#;
   Canadian_Syllabics_Qai                  : constant Unicode_Char := 16#166F#;
   Canadian_Syllabics_Ngai                 : constant Unicode_Char := 16#1670#;
   Canadian_Syllabics_Nngi                 : constant Unicode_Char := 16#1671#;
   Canadian_Syllabics_Nngii                : constant Unicode_Char := 16#1672#;
   Canadian_Syllabics_Nngo                 : constant Unicode_Char := 16#1673#;
   Canadian_Syllabics_Nngoo                : constant Unicode_Char := 16#1674#;
   Canadian_Syllabics_Nnga                 : constant Unicode_Char := 16#1675#;
   Canadian_Syllabics_Nngaa                : constant Unicode_Char := 16#1676#;
   Canadian_Syllabics_Woods_Cree_Thwee     : constant Unicode_Char := 16#1677#;
   Canadian_Syllabics_Woods_Cree_Thwi      : constant Unicode_Char := 16#1678#;
   Canadian_Syllabics_Woods_Cree_Thwii     : constant Unicode_Char := 16#1679#;
   Canadian_Syllabics_Woods_Cree_Thwo      : constant Unicode_Char := 16#167A#;
   Canadian_Syllabics_Woods_Cree_Thwoo     : constant Unicode_Char := 16#167B#;
   Canadian_Syllabics_Woods_Cree_Thwa      : constant Unicode_Char := 16#167C#;
   Canadian_Syllabics_Woods_Cree_Thwaa     : constant Unicode_Char := 16#167D#;
   Canadian_Syllabics_Woods_Cree_Final_Th  : constant Unicode_Char := 16#167E#;
   Canadian_Syllabics_Blackfoot_W          : constant Unicode_Char := 16#167F#;
end Unicode.Names.Canadian_Aboriginal;
