--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Ol_Chiki is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Ol_Chiki_Digit_Zero                     : constant Unicode_Char := 16#1C50#;
   Ol_Chiki_Digit_One                      : constant Unicode_Char := 16#1C51#;
   Ol_Chiki_Digit_Two                      : constant Unicode_Char := 16#1C52#;
   Ol_Chiki_Digit_Three                    : constant Unicode_Char := 16#1C53#;
   Ol_Chiki_Digit_Four                     : constant Unicode_Char := 16#1C54#;
   Ol_Chiki_Digit_Five                     : constant Unicode_Char := 16#1C55#;
   Ol_Chiki_Digit_Six                      : constant Unicode_Char := 16#1C56#;
   Ol_Chiki_Digit_Seven                    : constant Unicode_Char := 16#1C57#;
   Ol_Chiki_Digit_Eight                    : constant Unicode_Char := 16#1C58#;
   Ol_Chiki_Digit_Nine                     : constant Unicode_Char := 16#1C59#;
   Ol_Chiki_Letter_La                      : constant Unicode_Char := 16#1C5A#;
   Ol_Chiki_Letter_At                      : constant Unicode_Char := 16#1C5B#;
   Ol_Chiki_Letter_Ag                      : constant Unicode_Char := 16#1C5C#;
   Ol_Chiki_Letter_Ang                     : constant Unicode_Char := 16#1C5D#;
   Ol_Chiki_Letter_Al                      : constant Unicode_Char := 16#1C5E#;
   Ol_Chiki_Letter_Laa                     : constant Unicode_Char := 16#1C5F#;
   Ol_Chiki_Letter_Aak                     : constant Unicode_Char := 16#1C60#;
   Ol_Chiki_Letter_Aaj                     : constant Unicode_Char := 16#1C61#;
   Ol_Chiki_Letter_Aam                     : constant Unicode_Char := 16#1C62#;
   Ol_Chiki_Letter_Aaw                     : constant Unicode_Char := 16#1C63#;
   Ol_Chiki_Letter_Li                      : constant Unicode_Char := 16#1C64#;
   Ol_Chiki_Letter_Is                      : constant Unicode_Char := 16#1C65#;
   Ol_Chiki_Letter_Ih                      : constant Unicode_Char := 16#1C66#;
   Ol_Chiki_Letter_Iny                     : constant Unicode_Char := 16#1C67#;
   Ol_Chiki_Letter_Ir                      : constant Unicode_Char := 16#1C68#;
   Ol_Chiki_Letter_Lu                      : constant Unicode_Char := 16#1C69#;
   Ol_Chiki_Letter_Uc                      : constant Unicode_Char := 16#1C6A#;
   Ol_Chiki_Letter_Ud                      : constant Unicode_Char := 16#1C6B#;
   Ol_Chiki_Letter_Unn                     : constant Unicode_Char := 16#1C6C#;
   Ol_Chiki_Letter_Uy                      : constant Unicode_Char := 16#1C6D#;
   Ol_Chiki_Letter_Le                      : constant Unicode_Char := 16#1C6E#;
   Ol_Chiki_Letter_Ep                      : constant Unicode_Char := 16#1C6F#;
   Ol_Chiki_Letter_Edd                     : constant Unicode_Char := 16#1C70#;
   Ol_Chiki_Letter_En                      : constant Unicode_Char := 16#1C71#;
   Ol_Chiki_Letter_Err                     : constant Unicode_Char := 16#1C72#;
   Ol_Chiki_Letter_Lo                      : constant Unicode_Char := 16#1C73#;
   Ol_Chiki_Letter_Ott                     : constant Unicode_Char := 16#1C74#;
   Ol_Chiki_Letter_Ob                      : constant Unicode_Char := 16#1C75#;
   Ol_Chiki_Letter_Ov                      : constant Unicode_Char := 16#1C76#;
   Ol_Chiki_Letter_Oh                      : constant Unicode_Char := 16#1C77#;
   Ol_Chiki_Mu_Ttuddag                     : constant Unicode_Char := 16#1C78#;
   Ol_Chiki_Gaahlaa_Ttuddaag               : constant Unicode_Char := 16#1C79#;
   Ol_Chiki_Mu_Gaahlaa_Ttuddaag            : constant Unicode_Char := 16#1C7A#;
   Ol_Chiki_Relaa                          : constant Unicode_Char := 16#1C7B#;
   Ol_Chiki_Phaarkaa                       : constant Unicode_Char := 16#1C7C#;
   Ol_Chiki_Ahad                           : constant Unicode_Char := 16#1C7D#;
   Ol_Chiki_Punctuation_Mucaad             : constant Unicode_Char := 16#1C7E#;
   Ol_Chiki_Punctuation_Double_Mucaad      : constant Unicode_Char := 16#1C7F#;
end Unicode.Names.Ol_Chiki;
