--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Psalter_Pahlavi is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Psalter_Pahlavi_Letter_Aleph            :
      constant Unicode_Char := 16#10B80#;
   Psalter_Pahlavi_Letter_Beth             :
      constant Unicode_Char := 16#10B81#;
   Psalter_Pahlavi_Letter_Gimel            :
      constant Unicode_Char := 16#10B82#;
   Psalter_Pahlavi_Letter_Daleth           :
      constant Unicode_Char := 16#10B83#;
   Psalter_Pahlavi_Letter_He               :
      constant Unicode_Char := 16#10B84#;
   Psalter_Pahlavi_Letter_Waw_Ayin_Resh    :
      constant Unicode_Char := 16#10B85#;
   Psalter_Pahlavi_Letter_Zayin            :
      constant Unicode_Char := 16#10B86#;
   Psalter_Pahlavi_Letter_Heth             :
      constant Unicode_Char := 16#10B87#;
   Psalter_Pahlavi_Letter_Yodh             :
      constant Unicode_Char := 16#10B88#;
   Psalter_Pahlavi_Letter_Kaph             :
      constant Unicode_Char := 16#10B89#;
   Psalter_Pahlavi_Letter_Lamedh           :
      constant Unicode_Char := 16#10B8A#;
   Psalter_Pahlavi_Letter_Mem_Qoph         :
      constant Unicode_Char := 16#10B8B#;
   Psalter_Pahlavi_Letter_Nun              :
      constant Unicode_Char := 16#10B8C#;
   Psalter_Pahlavi_Letter_Samekh           :
      constant Unicode_Char := 16#10B8D#;
   Psalter_Pahlavi_Letter_Pe               :
      constant Unicode_Char := 16#10B8E#;
   Psalter_Pahlavi_Letter_Sadhe            :
      constant Unicode_Char := 16#10B8F#;
   Psalter_Pahlavi_Letter_Shin             :
      constant Unicode_Char := 16#10B90#;
   Psalter_Pahlavi_Letter_Taw              :
      constant Unicode_Char := 16#10B91#;
   Psalter_Pahlavi_Section_Mark            :
      constant Unicode_Char := 16#10B99#;
   Psalter_Pahlavi_Turned_Section_Mark     :
      constant Unicode_Char := 16#10B9A#;
   Psalter_Pahlavi_Four_Dots_With_Cross    :
      constant Unicode_Char := 16#10B9B#;
   Psalter_Pahlavi_Four_Dots_With_Dot      :
      constant Unicode_Char := 16#10B9C#;
   Psalter_Pahlavi_Number_One              :
      constant Unicode_Char := 16#10BA9#;
   Psalter_Pahlavi_Number_Two              :
      constant Unicode_Char := 16#10BAA#;
   Psalter_Pahlavi_Number_Three            :
      constant Unicode_Char := 16#10BAB#;
   Psalter_Pahlavi_Number_Four             :
      constant Unicode_Char := 16#10BAC#;
   Psalter_Pahlavi_Number_Ten              :
      constant Unicode_Char := 16#10BAD#;
   Psalter_Pahlavi_Number_Twenty           :
      constant Unicode_Char := 16#10BAE#;
   Psalter_Pahlavi_Number_One_Hundred      :
      constant Unicode_Char := 16#10BAF#;
end Unicode.Names.Psalter_Pahlavi;
