--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Yijing_Hexagram_Symbols is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Hexagram_For_The_Creative_Heaven        : constant Unicode_Char := 16#4DC0#;
   Hexagram_For_The_Receptive_Earth        : constant Unicode_Char := 16#4DC1#;
   Hexagram_For_Difficulty_At_The_Beginning :
      constant Unicode_Char := 16#4DC2#;
   Hexagram_For_Youthful_Folly             : constant Unicode_Char := 16#4DC3#;
   Hexagram_For_Waiting                    : constant Unicode_Char := 16#4DC4#;
   Hexagram_For_Conflict                   : constant Unicode_Char := 16#4DC5#;
   Hexagram_For_The_Army                   : constant Unicode_Char := 16#4DC6#;
   Hexagram_For_Holding_Together           : constant Unicode_Char := 16#4DC7#;
   Hexagram_For_Small_Taming               : constant Unicode_Char := 16#4DC8#;
   Hexagram_For_Treading                   : constant Unicode_Char := 16#4DC9#;
   Hexagram_For_Peace                      : constant Unicode_Char := 16#4DCA#;
   Hexagram_For_Standstill                 : constant Unicode_Char := 16#4DCB#;
   Hexagram_For_Fellowship                 : constant Unicode_Char := 16#4DCC#;
   Hexagram_For_Great_Possession           : constant Unicode_Char := 16#4DCD#;
   Hexagram_For_Modesty                    : constant Unicode_Char := 16#4DCE#;
   Hexagram_For_Enthusiasm                 : constant Unicode_Char := 16#4DCF#;
   Hexagram_For_Following                  : constant Unicode_Char := 16#4DD0#;
   Hexagram_For_Work_On_The_Decayed        : constant Unicode_Char := 16#4DD1#;
   Hexagram_For_Approach                   : constant Unicode_Char := 16#4DD2#;
   Hexagram_For_Contemplation              : constant Unicode_Char := 16#4DD3#;
   Hexagram_For_Biting_Through             : constant Unicode_Char := 16#4DD4#;
   Hexagram_For_Grace                      : constant Unicode_Char := 16#4DD5#;
   Hexagram_For_Splitting_Apart            : constant Unicode_Char := 16#4DD6#;
   Hexagram_For_Return                     : constant Unicode_Char := 16#4DD7#;
   Hexagram_For_Innocence                  : constant Unicode_Char := 16#4DD8#;
   Hexagram_For_Great_Taming               : constant Unicode_Char := 16#4DD9#;
   Hexagram_For_Mouth_Corners              : constant Unicode_Char := 16#4DDA#;
   Hexagram_For_Great_Preponderance        : constant Unicode_Char := 16#4DDB#;
   Hexagram_For_The_Abysmal_Water          : constant Unicode_Char := 16#4DDC#;
   Hexagram_For_The_Clinging_Fire          : constant Unicode_Char := 16#4DDD#;
   Hexagram_For_Influence                  : constant Unicode_Char := 16#4DDE#;
   Hexagram_For_Duration                   : constant Unicode_Char := 16#4DDF#;
   Hexagram_For_Retreat                    : constant Unicode_Char := 16#4DE0#;
   Hexagram_For_Great_Power                : constant Unicode_Char := 16#4DE1#;
   Hexagram_For_Progress                   : constant Unicode_Char := 16#4DE2#;
   Hexagram_For_Darkening_Of_The_Light     : constant Unicode_Char := 16#4DE3#;
   Hexagram_For_The_Family                 : constant Unicode_Char := 16#4DE4#;
   Hexagram_For_Opposition                 : constant Unicode_Char := 16#4DE5#;
   Hexagram_For_Obstruction                : constant Unicode_Char := 16#4DE6#;
   Hexagram_For_Deliverance                : constant Unicode_Char := 16#4DE7#;
   Hexagram_For_Decrease                   : constant Unicode_Char := 16#4DE8#;
   Hexagram_For_Increase                   : constant Unicode_Char := 16#4DE9#;
   Hexagram_For_Breakthrough               : constant Unicode_Char := 16#4DEA#;
   Hexagram_For_Coming_To_Meet             : constant Unicode_Char := 16#4DEB#;
   Hexagram_For_Gathering_Together         : constant Unicode_Char := 16#4DEC#;
   Hexagram_For_Pushing_Upward             : constant Unicode_Char := 16#4DED#;
   Hexagram_For_Oppression                 : constant Unicode_Char := 16#4DEE#;
   Hexagram_For_The_Well                   : constant Unicode_Char := 16#4DEF#;
   Hexagram_For_Revolution                 : constant Unicode_Char := 16#4DF0#;
   Hexagram_For_The_Cauldron               : constant Unicode_Char := 16#4DF1#;
   Hexagram_For_The_Arousing_Thunder       : constant Unicode_Char := 16#4DF2#;
   Hexagram_For_The_Keeping_Still_Mountain : constant Unicode_Char := 16#4DF3#;
   Hexagram_For_Development                : constant Unicode_Char := 16#4DF4#;
   Hexagram_For_The_Marrying_Maiden        : constant Unicode_Char := 16#4DF5#;
   Hexagram_For_Abundance                  : constant Unicode_Char := 16#4DF6#;
   Hexagram_For_The_Wanderer               : constant Unicode_Char := 16#4DF7#;
   Hexagram_For_The_Gentle_Wind            : constant Unicode_Char := 16#4DF8#;
   Hexagram_For_The_Joyous_Lake            : constant Unicode_Char := 16#4DF9#;
   Hexagram_For_Dispersion                 : constant Unicode_Char := 16#4DFA#;
   Hexagram_For_Limitation                 : constant Unicode_Char := 16#4DFB#;
   Hexagram_For_Inner_Truth                : constant Unicode_Char := 16#4DFC#;
   Hexagram_For_Small_Preponderance        : constant Unicode_Char := 16#4DFD#;
   Hexagram_For_After_Completion           : constant Unicode_Char := 16#4DFE#;
   Hexagram_For_Before_Completion          : constant Unicode_Char := 16#4DFF#;
end Unicode.Names.Yijing_Hexagram_Symbols;
