--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Gurmukhi is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Gurmukhi_Sign_Adak_Bindi                : constant Unicode_Char := 16#0A01#;
   Gurmukhi_Sign_Bindi                     : constant Unicode_Char := 16#0A02#;
   Gurmukhi_Sign_Visarga                   : constant Unicode_Char := 16#0A03#;
   Gurmukhi_Letter_A                       : constant Unicode_Char := 16#0A05#;
   Gurmukhi_Letter_Aa                      : constant Unicode_Char := 16#0A06#;
   Gurmukhi_Letter_I                       : constant Unicode_Char := 16#0A07#;
   Gurmukhi_Letter_Ii                      : constant Unicode_Char := 16#0A08#;
   Gurmukhi_Letter_U                       : constant Unicode_Char := 16#0A09#;
   Gurmukhi_Letter_Uu                      : constant Unicode_Char := 16#0A0A#;
   Gurmukhi_Letter_Ee                      : constant Unicode_Char := 16#0A0F#;
   Gurmukhi_Letter_Ai                      : constant Unicode_Char := 16#0A10#;
   Gurmukhi_Letter_Oo                      : constant Unicode_Char := 16#0A13#;
   Gurmukhi_Letter_Au                      : constant Unicode_Char := 16#0A14#;
   Gurmukhi_Letter_Ka                      : constant Unicode_Char := 16#0A15#;
   Gurmukhi_Letter_Kha                     : constant Unicode_Char := 16#0A16#;
   Gurmukhi_Letter_Ga                      : constant Unicode_Char := 16#0A17#;
   Gurmukhi_Letter_Gha                     : constant Unicode_Char := 16#0A18#;
   Gurmukhi_Letter_Nga                     : constant Unicode_Char := 16#0A19#;
   Gurmukhi_Letter_Ca                      : constant Unicode_Char := 16#0A1A#;
   Gurmukhi_Letter_Cha                     : constant Unicode_Char := 16#0A1B#;
   Gurmukhi_Letter_Ja                      : constant Unicode_Char := 16#0A1C#;
   Gurmukhi_Letter_Jha                     : constant Unicode_Char := 16#0A1D#;
   Gurmukhi_Letter_Nya                     : constant Unicode_Char := 16#0A1E#;
   Gurmukhi_Letter_Tta                     : constant Unicode_Char := 16#0A1F#;
   Gurmukhi_Letter_Ttha                    : constant Unicode_Char := 16#0A20#;
   Gurmukhi_Letter_Dda                     : constant Unicode_Char := 16#0A21#;
   Gurmukhi_Letter_Ddha                    : constant Unicode_Char := 16#0A22#;
   Gurmukhi_Letter_Nna                     : constant Unicode_Char := 16#0A23#;
   Gurmukhi_Letter_Ta                      : constant Unicode_Char := 16#0A24#;
   Gurmukhi_Letter_Tha                     : constant Unicode_Char := 16#0A25#;
   Gurmukhi_Letter_Da                      : constant Unicode_Char := 16#0A26#;
   Gurmukhi_Letter_Dha                     : constant Unicode_Char := 16#0A27#;
   Gurmukhi_Letter_Na                      : constant Unicode_Char := 16#0A28#;
   Gurmukhi_Letter_Pa                      : constant Unicode_Char := 16#0A2A#;
   Gurmukhi_Letter_Pha                     : constant Unicode_Char := 16#0A2B#;
   Gurmukhi_Letter_Ba                      : constant Unicode_Char := 16#0A2C#;
   Gurmukhi_Letter_Bha                     : constant Unicode_Char := 16#0A2D#;
   Gurmukhi_Letter_Ma                      : constant Unicode_Char := 16#0A2E#;
   Gurmukhi_Letter_Ya                      : constant Unicode_Char := 16#0A2F#;
   Gurmukhi_Letter_Ra                      : constant Unicode_Char := 16#0A30#;
   Gurmukhi_Letter_La                      : constant Unicode_Char := 16#0A32#;
   Gurmukhi_Letter_Lla                     : constant Unicode_Char := 16#0A33#;
   Gurmukhi_Letter_Va                      : constant Unicode_Char := 16#0A35#;
   Gurmukhi_Letter_Sha                     : constant Unicode_Char := 16#0A36#;
   Gurmukhi_Letter_Sa                      : constant Unicode_Char := 16#0A38#;
   Gurmukhi_Letter_Ha                      : constant Unicode_Char := 16#0A39#;
   Gurmukhi_Sign_Nukta                     : constant Unicode_Char := 16#0A3C#;
   Gurmukhi_Vowel_Sign_Aa                  : constant Unicode_Char := 16#0A3E#;
   Gurmukhi_Vowel_Sign_I                   : constant Unicode_Char := 16#0A3F#;
   Gurmukhi_Vowel_Sign_Ii                  : constant Unicode_Char := 16#0A40#;
   Gurmukhi_Vowel_Sign_U                   : constant Unicode_Char := 16#0A41#;
   Gurmukhi_Vowel_Sign_Uu                  : constant Unicode_Char := 16#0A42#;
   Gurmukhi_Vowel_Sign_Ee                  : constant Unicode_Char := 16#0A47#;
   Gurmukhi_Vowel_Sign_Ai                  : constant Unicode_Char := 16#0A48#;
   Gurmukhi_Vowel_Sign_Oo                  : constant Unicode_Char := 16#0A4B#;
   Gurmukhi_Vowel_Sign_Au                  : constant Unicode_Char := 16#0A4C#;
   Gurmukhi_Sign_Virama                    : constant Unicode_Char := 16#0A4D#;
   Gurmukhi_Sign_Udaat                     : constant Unicode_Char := 16#0A51#;
   Gurmukhi_Letter_Khha                    : constant Unicode_Char := 16#0A59#;
   Gurmukhi_Letter_Ghha                    : constant Unicode_Char := 16#0A5A#;
   Gurmukhi_Letter_Za                      : constant Unicode_Char := 16#0A5B#;
   Gurmukhi_Letter_Rra                     : constant Unicode_Char := 16#0A5C#;
   Gurmukhi_Letter_Fa                      : constant Unicode_Char := 16#0A5E#;
   Gurmukhi_Digit_Zero                     : constant Unicode_Char := 16#0A66#;
   Gurmukhi_Digit_One                      : constant Unicode_Char := 16#0A67#;
   Gurmukhi_Digit_Two                      : constant Unicode_Char := 16#0A68#;
   Gurmukhi_Digit_Three                    : constant Unicode_Char := 16#0A69#;
   Gurmukhi_Digit_Four                     : constant Unicode_Char := 16#0A6A#;
   Gurmukhi_Digit_Five                     : constant Unicode_Char := 16#0A6B#;
   Gurmukhi_Digit_Six                      : constant Unicode_Char := 16#0A6C#;
   Gurmukhi_Digit_Seven                    : constant Unicode_Char := 16#0A6D#;
   Gurmukhi_Digit_Eight                    : constant Unicode_Char := 16#0A6E#;
   Gurmukhi_Digit_Nine                     : constant Unicode_Char := 16#0A6F#;
   Gurmukhi_Tippi                          : constant Unicode_Char := 16#0A70#;
   Gurmukhi_Addak                          : constant Unicode_Char := 16#0A71#;
   Gurmukhi_Iri                            : constant Unicode_Char := 16#0A72#;
   Gurmukhi_Ura                            : constant Unicode_Char := 16#0A73#;
   Gurmukhi_Ek_Onkar                       : constant Unicode_Char := 16#0A74#;
   Gurmukhi_Sign_Yakash                    : constant Unicode_Char := 16#0A75#;
end Unicode.Names.Gurmukhi;
