--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Latin_Extended_A is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Latin_Capital_Letter_A_With_Macron      : constant Unicode_Char := 16#0100#;
   Latin_Small_Letter_A_With_Macron        : constant Unicode_Char := 16#0101#;
   Latin_Capital_Letter_A_With_Breve       : constant Unicode_Char := 16#0102#;
   Latin_Small_Letter_A_With_Breve         : constant Unicode_Char := 16#0103#;
   Latin_Capital_Letter_A_With_Ogonek      : constant Unicode_Char := 16#0104#;
   Latin_Small_Letter_A_With_Ogonek        : constant Unicode_Char := 16#0105#;
   Latin_Capital_Letter_C_With_Acute       : constant Unicode_Char := 16#0106#;
   Latin_Small_Letter_C_With_Acute         : constant Unicode_Char := 16#0107#;
   Latin_Capital_Letter_C_With_Circumflex  : constant Unicode_Char := 16#0108#;
   Latin_Small_Letter_C_With_Circumflex    : constant Unicode_Char := 16#0109#;
   Latin_Capital_Letter_C_With_Dot_Above   : constant Unicode_Char := 16#010A#;
   Latin_Small_Letter_C_With_Dot_Above     : constant Unicode_Char := 16#010B#;
   Latin_Capital_Letter_C_With_Caron       : constant Unicode_Char := 16#010C#;
   Latin_Small_Letter_C_With_Caron         : constant Unicode_Char := 16#010D#;
   Latin_Capital_Letter_D_With_Caron       : constant Unicode_Char := 16#010E#;
   Latin_Small_Letter_D_With_Caron         : constant Unicode_Char := 16#010F#;
   Latin_Capital_Letter_D_With_Stroke      : constant Unicode_Char := 16#0110#;
   Latin_Small_Letter_D_With_Stroke        : constant Unicode_Char := 16#0111#;
   Latin_Capital_Letter_E_With_Macron      : constant Unicode_Char := 16#0112#;
   Latin_Small_Letter_E_With_Macron        : constant Unicode_Char := 16#0113#;
   Latin_Capital_Letter_E_With_Breve       : constant Unicode_Char := 16#0114#;
   Latin_Small_Letter_E_With_Breve         : constant Unicode_Char := 16#0115#;
   Latin_Capital_Letter_E_With_Dot_Above   : constant Unicode_Char := 16#0116#;
   Latin_Small_Letter_E_With_Dot_Above     : constant Unicode_Char := 16#0117#;
   Latin_Capital_Letter_E_With_Ogonek      : constant Unicode_Char := 16#0118#;
   Latin_Small_Letter_E_With_Ogonek        : constant Unicode_Char := 16#0119#;
   Latin_Capital_Letter_E_With_Caron       : constant Unicode_Char := 16#011A#;
   Latin_Small_Letter_E_With_Caron         : constant Unicode_Char := 16#011B#;
   Latin_Capital_Letter_G_With_Circumflex  : constant Unicode_Char := 16#011C#;
   Latin_Small_Letter_G_With_Circumflex    : constant Unicode_Char := 16#011D#;
   Latin_Capital_Letter_G_With_Breve       : constant Unicode_Char := 16#011E#;
   Latin_Small_Letter_G_With_Breve         : constant Unicode_Char := 16#011F#;
   Latin_Capital_Letter_G_With_Dot_Above   : constant Unicode_Char := 16#0120#;
   Latin_Small_Letter_G_With_Dot_Above     : constant Unicode_Char := 16#0121#;
   Latin_Capital_Letter_G_With_Cedilla     : constant Unicode_Char := 16#0122#;
   Latin_Small_Letter_G_With_Cedilla       : constant Unicode_Char := 16#0123#;
   Latin_Capital_Letter_H_With_Circumflex  : constant Unicode_Char := 16#0124#;
   Latin_Small_Letter_H_With_Circumflex    : constant Unicode_Char := 16#0125#;
   Latin_Capital_Letter_H_With_Stroke      : constant Unicode_Char := 16#0126#;
   Latin_Small_Letter_H_With_Stroke        : constant Unicode_Char := 16#0127#;
   Latin_Capital_Letter_I_With_Tilde       : constant Unicode_Char := 16#0128#;
   Latin_Small_Letter_I_With_Tilde         : constant Unicode_Char := 16#0129#;
   Latin_Capital_Letter_I_With_Macron      : constant Unicode_Char := 16#012A#;
   Latin_Small_Letter_I_With_Macron        : constant Unicode_Char := 16#012B#;
   Latin_Capital_Letter_I_With_Breve       : constant Unicode_Char := 16#012C#;
   Latin_Small_Letter_I_With_Breve         : constant Unicode_Char := 16#012D#;
   Latin_Capital_Letter_I_With_Ogonek      : constant Unicode_Char := 16#012E#;
   Latin_Small_Letter_I_With_Ogonek        : constant Unicode_Char := 16#012F#;
   Latin_Capital_Letter_I_With_Dot_Above   : constant Unicode_Char := 16#0130#;
   Latin_Small_Letter_Dotless_I            : constant Unicode_Char := 16#0131#;
   Latin_Capital_Ligature_Ij               : constant Unicode_Char := 16#0132#;
   Latin_Small_Ligature_Ij                 : constant Unicode_Char := 16#0133#;
   Latin_Capital_Letter_J_With_Circumflex  : constant Unicode_Char := 16#0134#;
   Latin_Small_Letter_J_With_Circumflex    : constant Unicode_Char := 16#0135#;
   Latin_Capital_Letter_K_With_Cedilla     : constant Unicode_Char := 16#0136#;
   Latin_Small_Letter_K_With_Cedilla       : constant Unicode_Char := 16#0137#;
   Latin_Small_Letter_Kra                  : constant Unicode_Char := 16#0138#;
   Latin_Capital_Letter_L_With_Acute       : constant Unicode_Char := 16#0139#;
   Latin_Small_Letter_L_With_Acute         : constant Unicode_Char := 16#013A#;
   Latin_Capital_Letter_L_With_Cedilla     : constant Unicode_Char := 16#013B#;
   Latin_Small_Letter_L_With_Cedilla       : constant Unicode_Char := 16#013C#;
   Latin_Capital_Letter_L_With_Caron       : constant Unicode_Char := 16#013D#;
   Latin_Small_Letter_L_With_Caron         : constant Unicode_Char := 16#013E#;
   Latin_Capital_Letter_L_With_Middle_Dot  : constant Unicode_Char := 16#013F#;
   Latin_Small_Letter_L_With_Middle_Dot    : constant Unicode_Char := 16#0140#;
   Latin_Capital_Letter_L_With_Stroke      : constant Unicode_Char := 16#0141#;
   Latin_Small_Letter_L_With_Stroke        : constant Unicode_Char := 16#0142#;
   Latin_Capital_Letter_N_With_Acute       : constant Unicode_Char := 16#0143#;
   Latin_Small_Letter_N_With_Acute         : constant Unicode_Char := 16#0144#;
   Latin_Capital_Letter_N_With_Cedilla     : constant Unicode_Char := 16#0145#;
   Latin_Small_Letter_N_With_Cedilla       : constant Unicode_Char := 16#0146#;
   Latin_Capital_Letter_N_With_Caron       : constant Unicode_Char := 16#0147#;
   Latin_Small_Letter_N_With_Caron         : constant Unicode_Char := 16#0148#;
   Latin_Small_Letter_N_Preceded_By_Apostrophe :
      constant Unicode_Char := 16#0149#;
   Latin_Capital_Letter_Eng                : constant Unicode_Char := 16#014A#;
   Latin_Small_Letter_Eng                  : constant Unicode_Char := 16#014B#;
   Latin_Capital_Letter_O_With_Macron      : constant Unicode_Char := 16#014C#;
   Latin_Small_Letter_O_With_Macron        : constant Unicode_Char := 16#014D#;
   Latin_Capital_Letter_O_With_Breve       : constant Unicode_Char := 16#014E#;
   Latin_Small_Letter_O_With_Breve         : constant Unicode_Char := 16#014F#;
   Latin_Capital_Letter_O_With_Double_Acute :
      constant Unicode_Char := 16#0150#;
   Latin_Small_Letter_O_With_Double_Acute  : constant Unicode_Char := 16#0151#;
   Latin_Capital_Ligature_Oe               : constant Unicode_Char := 16#0152#;
   Latin_Small_Ligature_Oe                 : constant Unicode_Char := 16#0153#;
   Latin_Capital_Letter_R_With_Acute       : constant Unicode_Char := 16#0154#;
   Latin_Small_Letter_R_With_Acute         : constant Unicode_Char := 16#0155#;
   Latin_Capital_Letter_R_With_Cedilla     : constant Unicode_Char := 16#0156#;
   Latin_Small_Letter_R_With_Cedilla       : constant Unicode_Char := 16#0157#;
   Latin_Capital_Letter_R_With_Caron       : constant Unicode_Char := 16#0158#;
   Latin_Small_Letter_R_With_Caron         : constant Unicode_Char := 16#0159#;
   Latin_Capital_Letter_S_With_Acute       : constant Unicode_Char := 16#015A#;
   Latin_Small_Letter_S_With_Acute         : constant Unicode_Char := 16#015B#;
   Latin_Capital_Letter_S_With_Circumflex  : constant Unicode_Char := 16#015C#;
   Latin_Small_Letter_S_With_Circumflex    : constant Unicode_Char := 16#015D#;
   Latin_Capital_Letter_S_With_Cedilla     : constant Unicode_Char := 16#015E#;
   Latin_Small_Letter_S_With_Cedilla       : constant Unicode_Char := 16#015F#;
   Latin_Capital_Letter_S_With_Caron       : constant Unicode_Char := 16#0160#;
   Latin_Small_Letter_S_With_Caron         : constant Unicode_Char := 16#0161#;
   Latin_Capital_Letter_T_With_Cedilla     : constant Unicode_Char := 16#0162#;
   Latin_Small_Letter_T_With_Cedilla       : constant Unicode_Char := 16#0163#;
   Latin_Capital_Letter_T_With_Caron       : constant Unicode_Char := 16#0164#;
   Latin_Small_Letter_T_With_Caron         : constant Unicode_Char := 16#0165#;
   Latin_Capital_Letter_T_With_Stroke      : constant Unicode_Char := 16#0166#;
   Latin_Small_Letter_T_With_Stroke        : constant Unicode_Char := 16#0167#;
   Latin_Capital_Letter_U_With_Tilde       : constant Unicode_Char := 16#0168#;
   Latin_Small_Letter_U_With_Tilde         : constant Unicode_Char := 16#0169#;
   Latin_Capital_Letter_U_With_Macron      : constant Unicode_Char := 16#016A#;
   Latin_Small_Letter_U_With_Macron        : constant Unicode_Char := 16#016B#;
   Latin_Capital_Letter_U_With_Breve       : constant Unicode_Char := 16#016C#;
   Latin_Small_Letter_U_With_Breve         : constant Unicode_Char := 16#016D#;
   Latin_Capital_Letter_U_With_Ring_Above  : constant Unicode_Char := 16#016E#;
   Latin_Small_Letter_U_With_Ring_Above    : constant Unicode_Char := 16#016F#;
   Latin_Capital_Letter_U_With_Double_Acute :
      constant Unicode_Char := 16#0170#;
   Latin_Small_Letter_U_With_Double_Acute  : constant Unicode_Char := 16#0171#;
   Latin_Capital_Letter_U_With_Ogonek      : constant Unicode_Char := 16#0172#;
   Latin_Small_Letter_U_With_Ogonek        : constant Unicode_Char := 16#0173#;
   Latin_Capital_Letter_W_With_Circumflex  : constant Unicode_Char := 16#0174#;
   Latin_Small_Letter_W_With_Circumflex    : constant Unicode_Char := 16#0175#;
   Latin_Capital_Letter_Y_With_Circumflex  : constant Unicode_Char := 16#0176#;
   Latin_Small_Letter_Y_With_Circumflex    : constant Unicode_Char := 16#0177#;
   Latin_Capital_Letter_Y_With_Diaeresis   : constant Unicode_Char := 16#0178#;
   Latin_Capital_Letter_Z_With_Acute       : constant Unicode_Char := 16#0179#;
   Latin_Small_Letter_Z_With_Acute         : constant Unicode_Char := 16#017A#;
   Latin_Capital_Letter_Z_With_Dot_Above   : constant Unicode_Char := 16#017B#;
   Latin_Small_Letter_Z_With_Dot_Above     : constant Unicode_Char := 16#017C#;
   Latin_Capital_Letter_Z_With_Caron       : constant Unicode_Char := 16#017D#;
   Latin_Small_Letter_Z_With_Caron         : constant Unicode_Char := 16#017E#;
   Latin_Small_Letter_Long_S               : constant Unicode_Char := 16#017F#;
end Unicode.Names.Latin_Extended_A;
