--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Box_Drawing is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Box_Drawings_Light_Horizontal           : constant Unicode_Char := 16#2500#;
   Box_Drawings_Heavy_Horizontal           : constant Unicode_Char := 16#2501#;
   Box_Drawings_Light_Vertical             : constant Unicode_Char := 16#2502#;
   Box_Drawings_Heavy_Vertical             : constant Unicode_Char := 16#2503#;
   Box_Drawings_Light_Triple_Dash_Horizontal :
      constant Unicode_Char := 16#2504#;
   Box_Drawings_Heavy_Triple_Dash_Horizontal :
      constant Unicode_Char := 16#2505#;
   Box_Drawings_Light_Triple_Dash_Vertical : constant Unicode_Char := 16#2506#;
   Box_Drawings_Heavy_Triple_Dash_Vertical : constant Unicode_Char := 16#2507#;
   Box_Drawings_Light_Quadruple_Dash_Horizontal :
      constant Unicode_Char := 16#2508#;
   Box_Drawings_Heavy_Quadruple_Dash_Horizontal :
      constant Unicode_Char := 16#2509#;
   Box_Drawings_Light_Quadruple_Dash_Vertical :
      constant Unicode_Char := 16#250A#;
   Box_Drawings_Heavy_Quadruple_Dash_Vertical :
      constant Unicode_Char := 16#250B#;
   Box_Drawings_Light_Down_And_Right       : constant Unicode_Char := 16#250C#;
   Box_Drawings_Down_Light_And_Right_Heavy : constant Unicode_Char := 16#250D#;
   Box_Drawings_Down_Heavy_And_Right_Light : constant Unicode_Char := 16#250E#;
   Box_Drawings_Heavy_Down_And_Right       : constant Unicode_Char := 16#250F#;
   Box_Drawings_Light_Down_And_Left        : constant Unicode_Char := 16#2510#;
   Box_Drawings_Down_Light_And_Left_Heavy  : constant Unicode_Char := 16#2511#;
   Box_Drawings_Down_Heavy_And_Left_Light  : constant Unicode_Char := 16#2512#;
   Box_Drawings_Heavy_Down_And_Left        : constant Unicode_Char := 16#2513#;
   Box_Drawings_Light_Up_And_Right         : constant Unicode_Char := 16#2514#;
   Box_Drawings_Up_Light_And_Right_Heavy   : constant Unicode_Char := 16#2515#;
   Box_Drawings_Up_Heavy_And_Right_Light   : constant Unicode_Char := 16#2516#;
   Box_Drawings_Heavy_Up_And_Right         : constant Unicode_Char := 16#2517#;
   Box_Drawings_Light_Up_And_Left          : constant Unicode_Char := 16#2518#;
   Box_Drawings_Up_Light_And_Left_Heavy    : constant Unicode_Char := 16#2519#;
   Box_Drawings_Up_Heavy_And_Left_Light    : constant Unicode_Char := 16#251A#;
   Box_Drawings_Heavy_Up_And_Left          : constant Unicode_Char := 16#251B#;
   Box_Drawings_Light_Vertical_And_Right   : constant Unicode_Char := 16#251C#;
   Box_Drawings_Vertical_Light_And_Right_Heavy :
      constant Unicode_Char := 16#251D#;
   Box_Drawings_Up_Heavy_And_Right_Down_Light :
      constant Unicode_Char := 16#251E#;
   Box_Drawings_Down_Heavy_And_Right_Up_Light :
      constant Unicode_Char := 16#251F#;
   Box_Drawings_Vertical_Heavy_And_Right_Light :
      constant Unicode_Char := 16#2520#;
   Box_Drawings_Down_Light_And_Right_Up_Heavy :
      constant Unicode_Char := 16#2521#;
   Box_Drawings_Up_Light_And_Right_Down_Heavy :
      constant Unicode_Char := 16#2522#;
   Box_Drawings_Heavy_Vertical_And_Right   : constant Unicode_Char := 16#2523#;
   Box_Drawings_Light_Vertical_And_Left    : constant Unicode_Char := 16#2524#;
   Box_Drawings_Vertical_Light_And_Left_Heavy :
      constant Unicode_Char := 16#2525#;
   Box_Drawings_Up_Heavy_And_Left_Down_Light :
      constant Unicode_Char := 16#2526#;
   Box_Drawings_Down_Heavy_And_Left_Up_Light :
      constant Unicode_Char := 16#2527#;
   Box_Drawings_Vertical_Heavy_And_Left_Light :
      constant Unicode_Char := 16#2528#;
   Box_Drawings_Down_Light_And_Left_Up_Heavy :
      constant Unicode_Char := 16#2529#;
   Box_Drawings_Up_Light_And_Left_Down_Heavy :
      constant Unicode_Char := 16#252A#;
   Box_Drawings_Heavy_Vertical_And_Left    : constant Unicode_Char := 16#252B#;
   Box_Drawings_Light_Down_And_Horizontal  : constant Unicode_Char := 16#252C#;
   Box_Drawings_Left_Heavy_And_Right_Down_Light :
      constant Unicode_Char := 16#252D#;
   Box_Drawings_Right_Heavy_And_Left_Down_Light :
      constant Unicode_Char := 16#252E#;
   Box_Drawings_Down_Light_And_Horizontal_Heavy :
      constant Unicode_Char := 16#252F#;
   Box_Drawings_Down_Heavy_And_Horizontal_Light :
      constant Unicode_Char := 16#2530#;
   Box_Drawings_Right_Light_And_Left_Down_Heavy :
      constant Unicode_Char := 16#2531#;
   Box_Drawings_Left_Light_And_Right_Down_Heavy :
      constant Unicode_Char := 16#2532#;
   Box_Drawings_Heavy_Down_And_Horizontal  : constant Unicode_Char := 16#2533#;
   Box_Drawings_Light_Up_And_Horizontal    : constant Unicode_Char := 16#2534#;
   Box_Drawings_Left_Heavy_And_Right_Up_Light :
      constant Unicode_Char := 16#2535#;
   Box_Drawings_Right_Heavy_And_Left_Up_Light :
      constant Unicode_Char := 16#2536#;
   Box_Drawings_Up_Light_And_Horizontal_Heavy :
      constant Unicode_Char := 16#2537#;
   Box_Drawings_Up_Heavy_And_Horizontal_Light :
      constant Unicode_Char := 16#2538#;
   Box_Drawings_Right_Light_And_Left_Up_Heavy :
      constant Unicode_Char := 16#2539#;
   Box_Drawings_Left_Light_And_Right_Up_Heavy :
      constant Unicode_Char := 16#253A#;
   Box_Drawings_Heavy_Up_And_Horizontal    : constant Unicode_Char := 16#253B#;
   Box_Drawings_Light_Vertical_And_Horizontal :
      constant Unicode_Char := 16#253C#;
   Box_Drawings_Left_Heavy_And_Right_Vertical_Light :
      constant Unicode_Char := 16#253D#;
   Box_Drawings_Right_Heavy_And_Left_Vertical_Light :
      constant Unicode_Char := 16#253E#;
   Box_Drawings_Vertical_Light_And_Horizontal_Heavy :
      constant Unicode_Char := 16#253F#;
   Box_Drawings_Up_Heavy_And_Down_Horizontal_Light :
      constant Unicode_Char := 16#2540#;
   Box_Drawings_Down_Heavy_And_Up_Horizontal_Light :
      constant Unicode_Char := 16#2541#;
   Box_Drawings_Vertical_Heavy_And_Horizontal_Light :
      constant Unicode_Char := 16#2542#;
   Box_Drawings_Left_Up_Heavy_And_Right_Down_Light :
      constant Unicode_Char := 16#2543#;
   Box_Drawings_Right_Up_Heavy_And_Left_Down_Light :
      constant Unicode_Char := 16#2544#;
   Box_Drawings_Left_Down_Heavy_And_Right_Up_Light :
      constant Unicode_Char := 16#2545#;
   Box_Drawings_Right_Down_Heavy_And_Left_Up_Light :
      constant Unicode_Char := 16#2546#;
   Box_Drawings_Down_Light_And_Up_Horizontal_Heavy :
      constant Unicode_Char := 16#2547#;
   Box_Drawings_Up_Light_And_Down_Horizontal_Heavy :
      constant Unicode_Char := 16#2548#;
   Box_Drawings_Right_Light_And_Left_Vertical_Heavy :
      constant Unicode_Char := 16#2549#;
   Box_Drawings_Left_Light_And_Right_Vertical_Heavy :
      constant Unicode_Char := 16#254A#;
   Box_Drawings_Heavy_Vertical_And_Horizontal :
      constant Unicode_Char := 16#254B#;
   Box_Drawings_Light_Double_Dash_Horizontal :
      constant Unicode_Char := 16#254C#;
   Box_Drawings_Heavy_Double_Dash_Horizontal :
      constant Unicode_Char := 16#254D#;
   Box_Drawings_Light_Double_Dash_Vertical : constant Unicode_Char := 16#254E#;
   Box_Drawings_Heavy_Double_Dash_Vertical : constant Unicode_Char := 16#254F#;
   Box_Drawings_Double_Horizontal          : constant Unicode_Char := 16#2550#;
   Box_Drawings_Double_Vertical            : constant Unicode_Char := 16#2551#;
   Box_Drawings_Down_Single_And_Right_Double :
      constant Unicode_Char := 16#2552#;
   Box_Drawings_Down_Double_And_Right_Single :
      constant Unicode_Char := 16#2553#;
   Box_Drawings_Double_Down_And_Right      : constant Unicode_Char := 16#2554#;
   Box_Drawings_Down_Single_And_Left_Double :
      constant Unicode_Char := 16#2555#;
   Box_Drawings_Down_Double_And_Left_Single :
      constant Unicode_Char := 16#2556#;
   Box_Drawings_Double_Down_And_Left       : constant Unicode_Char := 16#2557#;
   Box_Drawings_Up_Single_And_Right_Double : constant Unicode_Char := 16#2558#;
   Box_Drawings_Up_Double_And_Right_Single : constant Unicode_Char := 16#2559#;
   Box_Drawings_Double_Up_And_Right        : constant Unicode_Char := 16#255A#;
   Box_Drawings_Up_Single_And_Left_Double  : constant Unicode_Char := 16#255B#;
   Box_Drawings_Up_Double_And_Left_Single  : constant Unicode_Char := 16#255C#;
   Box_Drawings_Double_Up_And_Left         : constant Unicode_Char := 16#255D#;
   Box_Drawings_Vertical_Single_And_Right_Double :
      constant Unicode_Char := 16#255E#;
   Box_Drawings_Vertical_Double_And_Right_Single :
      constant Unicode_Char := 16#255F#;
   Box_Drawings_Double_Vertical_And_Right  : constant Unicode_Char := 16#2560#;
   Box_Drawings_Vertical_Single_And_Left_Double :
      constant Unicode_Char := 16#2561#;
   Box_Drawings_Vertical_Double_And_Left_Single :
      constant Unicode_Char := 16#2562#;
   Box_Drawings_Double_Vertical_And_Left   : constant Unicode_Char := 16#2563#;
   Box_Drawings_Down_Single_And_Horizontal_Double :
      constant Unicode_Char := 16#2564#;
   Box_Drawings_Down_Double_And_Horizontal_Single :
      constant Unicode_Char := 16#2565#;
   Box_Drawings_Double_Down_And_Horizontal : constant Unicode_Char := 16#2566#;
   Box_Drawings_Up_Single_And_Horizontal_Double :
      constant Unicode_Char := 16#2567#;
   Box_Drawings_Up_Double_And_Horizontal_Single :
      constant Unicode_Char := 16#2568#;
   Box_Drawings_Double_Up_And_Horizontal   : constant Unicode_Char := 16#2569#;
   Box_Drawings_Vertical_Single_And_Horizontal_Double :
      constant Unicode_Char := 16#256A#;
   Box_Drawings_Vertical_Double_And_Horizontal_Single :
      constant Unicode_Char := 16#256B#;
   Box_Drawings_Double_Vertical_And_Horizontal :
      constant Unicode_Char := 16#256C#;
   Box_Drawings_Light_Arc_Down_And_Right   : constant Unicode_Char := 16#256D#;
   Box_Drawings_Light_Arc_Down_And_Left    : constant Unicode_Char := 16#256E#;
   Box_Drawings_Light_Arc_Up_And_Left      : constant Unicode_Char := 16#256F#;
   Box_Drawings_Light_Arc_Up_And_Right     : constant Unicode_Char := 16#2570#;
   Box_Drawings_Light_Diagonal_Upper_Right_To_Lower_Left :
      constant Unicode_Char := 16#2571#;
   Box_Drawings_Light_Diagonal_Upper_Left_To_Lower_Right :
      constant Unicode_Char := 16#2572#;
   Box_Drawings_Light_Diagonal_Cross       : constant Unicode_Char := 16#2573#;
   Box_Drawings_Light_Left                 : constant Unicode_Char := 16#2574#;
   Box_Drawings_Light_Up                   : constant Unicode_Char := 16#2575#;
   Box_Drawings_Light_Right                : constant Unicode_Char := 16#2576#;
   Box_Drawings_Light_Down                 : constant Unicode_Char := 16#2577#;
   Box_Drawings_Heavy_Left                 : constant Unicode_Char := 16#2578#;
   Box_Drawings_Heavy_Up                   : constant Unicode_Char := 16#2579#;
   Box_Drawings_Heavy_Right                : constant Unicode_Char := 16#257A#;
   Box_Drawings_Heavy_Down                 : constant Unicode_Char := 16#257B#;
   Box_Drawings_Light_Left_And_Heavy_Right : constant Unicode_Char := 16#257C#;
   Box_Drawings_Light_Up_And_Heavy_Down    : constant Unicode_Char := 16#257D#;
   Box_Drawings_Heavy_Left_And_Light_Right : constant Unicode_Char := 16#257E#;
   Box_Drawings_Heavy_Up_And_Light_Down    : constant Unicode_Char := 16#257F#;
end Unicode.Names.Box_Drawing;
