--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.General_Punctuation is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   En_Quad                                 : constant Unicode_Char := 16#2000#;
   Em_Quad                                 : constant Unicode_Char := 16#2001#;
   En_Space                                : constant Unicode_Char := 16#2002#;
   Em_Space                                : constant Unicode_Char := 16#2003#;
   Three_Per_Em_Space                      : constant Unicode_Char := 16#2004#;
   Four_Per_Em_Space                       : constant Unicode_Char := 16#2005#;
   Six_Per_Em_Space                        : constant Unicode_Char := 16#2006#;
   Figure_Space                            : constant Unicode_Char := 16#2007#;
   Punctuation_Space                       : constant Unicode_Char := 16#2008#;
   Thin_Space                              : constant Unicode_Char := 16#2009#;
   Hair_Space                              : constant Unicode_Char := 16#200A#;
   Zero_Width_Space                        : constant Unicode_Char := 16#200B#;
   Zwsp                                    :
      Unicode_Char renames Zero_Width_Space;
   Zero_Width_Non_Joiner                   : constant Unicode_Char := 16#200C#;
   Zwnj                                    :
      Unicode_Char renames Zero_Width_Non_Joiner;
   Zero_Width_Joiner                       : constant Unicode_Char := 16#200D#;
   Zwj                                     :
      Unicode_Char renames Zero_Width_Joiner;
   Left_To_Right_Mark                      : constant Unicode_Char := 16#200E#;
   Lrm                                     :
      Unicode_Char renames Left_To_Right_Mark;
   Right_To_Left_Mark                      : constant Unicode_Char := 16#200F#;
   Rlm                                     :
      Unicode_Char renames Right_To_Left_Mark;
   Hyphen                                  : constant Unicode_Char := 16#2010#;
   Non_Breaking_Hyphen                     : constant Unicode_Char := 16#2011#;
   Figure_Dash                             : constant Unicode_Char := 16#2012#;
   En_Dash                                 : constant Unicode_Char := 16#2013#;
   Em_Dash                                 : constant Unicode_Char := 16#2014#;
   Horizontal_Bar                          : constant Unicode_Char := 16#2015#;
   Double_Vertical_Line                    : constant Unicode_Char := 16#2016#;
   Double_Low_Line                         : constant Unicode_Char := 16#2017#;
   Left_Single_Quotation_Mark              : constant Unicode_Char := 16#2018#;
   Right_Single_Quotation_Mark             : constant Unicode_Char := 16#2019#;
   Single_Low_9_Quotation_Mark             : constant Unicode_Char := 16#201A#;
   Single_High_Reversed_9_Quotation_Mark   : constant Unicode_Char := 16#201B#;
   Left_Double_Quotation_Mark              : constant Unicode_Char := 16#201C#;
   Right_Double_Quotation_Mark             : constant Unicode_Char := 16#201D#;
   Double_Low_9_Quotation_Mark             : constant Unicode_Char := 16#201E#;
   Double_High_Reversed_9_Quotation_Mark   : constant Unicode_Char := 16#201F#;
   Dagger                                  : constant Unicode_Char := 16#2020#;
   Double_Dagger                           : constant Unicode_Char := 16#2021#;
   Bullet                                  : constant Unicode_Char := 16#2022#;
   Triangular_Bullet                       : constant Unicode_Char := 16#2023#;
   One_Dot_Leader                          : constant Unicode_Char := 16#2024#;
   Two_Dot_Leader                          : constant Unicode_Char := 16#2025#;
   Horizontal_Ellipsis                     : constant Unicode_Char := 16#2026#;
   Hyphenation_Point                       : constant Unicode_Char := 16#2027#;
   Line_Separator                          : constant Unicode_Char := 16#2028#;
   Paragraph_Separator                     : constant Unicode_Char := 16#2029#;
   Left_To_Right_Embedding                 : constant Unicode_Char := 16#202A#;
   Lre                                     :
      Unicode_Char renames Left_To_Right_Embedding;
   Right_To_Left_Embedding                 : constant Unicode_Char := 16#202B#;
   Rle                                     :
      Unicode_Char renames Right_To_Left_Embedding;
   Pop_Directional_Formatting              : constant Unicode_Char := 16#202C#;
   Pdf                                     :
      Unicode_Char renames Pop_Directional_Formatting;
   Left_To_Right_Override                  : constant Unicode_Char := 16#202D#;
   Lro                                     :
      Unicode_Char renames Left_To_Right_Override;
   Right_To_Left_Override                  : constant Unicode_Char := 16#202E#;
   Rlo                                     :
      Unicode_Char renames Right_To_Left_Override;
   Narrow_No_Break_Space                   : constant Unicode_Char := 16#202F#;
   Nnbsp                                   :
      Unicode_Char renames Narrow_No_Break_Space;
   Per_Mille_Sign                          : constant Unicode_Char := 16#2030#;
   Per_Ten_Thousand_Sign                   : constant Unicode_Char := 16#2031#;
   Prime                                   : constant Unicode_Char := 16#2032#;
   Double_Prime                            : constant Unicode_Char := 16#2033#;
   Triple_Prime                            : constant Unicode_Char := 16#2034#;
   Reversed_Prime                          : constant Unicode_Char := 16#2035#;
   Reversed_Double_Prime                   : constant Unicode_Char := 16#2036#;
   Reversed_Triple_Prime                   : constant Unicode_Char := 16#2037#;
   Caret                                   : constant Unicode_Char := 16#2038#;
   Single_Left_Pointing_Angle_Quotation_Mark :
      constant Unicode_Char := 16#2039#;
   Single_Right_Pointing_Angle_Quotation_Mark :
      constant Unicode_Char := 16#203A#;
   Reference_Mark                          : constant Unicode_Char := 16#203B#;
   Double_Exclamation_Mark                 : constant Unicode_Char := 16#203C#;
   Interrobang                             : constant Unicode_Char := 16#203D#;
   Overline                                : constant Unicode_Char := 16#203E#;
   Undertie                                : constant Unicode_Char := 16#203F#;
   Character_Tie                           : constant Unicode_Char := 16#2040#;
   Caret_Insertion_Point                   : constant Unicode_Char := 16#2041#;
   Asterism                                : constant Unicode_Char := 16#2042#;
   Hyphen_Bullet                           : constant Unicode_Char := 16#2043#;
   Fraction_Slash                          : constant Unicode_Char := 16#2044#;
   Left_Square_Bracket_With_Quill          : constant Unicode_Char := 16#2045#;
   Right_Square_Bracket_With_Quill         : constant Unicode_Char := 16#2046#;
   Double_Question_Mark                    : constant Unicode_Char := 16#2047#;
   Question_Exclamation_Mark               : constant Unicode_Char := 16#2048#;
   Exclamation_Question_Mark               : constant Unicode_Char := 16#2049#;
   Tironian_Sign_Et                        : constant Unicode_Char := 16#204A#;
   Reversed_Pilcrow_Sign                   : constant Unicode_Char := 16#204B#;
   Black_Leftwards_Bullet                  : constant Unicode_Char := 16#204C#;
   Black_Rightwards_Bullet                 : constant Unicode_Char := 16#204D#;
   Low_Asterisk                            : constant Unicode_Char := 16#204E#;
   Reversed_Semicolon                      : constant Unicode_Char := 16#204F#;
   Close_Up                                : constant Unicode_Char := 16#2050#;
   Two_Asterisks_Aligned_Vertically        : constant Unicode_Char := 16#2051#;
   Commercial_Minus_Sign                   : constant Unicode_Char := 16#2052#;
   Swung_Dash                              : constant Unicode_Char := 16#2053#;
   Inverted_Undertie                       : constant Unicode_Char := 16#2054#;
   Flower_Punctuation_Mark                 : constant Unicode_Char := 16#2055#;
   Three_Dot_Punctuation                   : constant Unicode_Char := 16#2056#;
   Quadruple_Prime                         : constant Unicode_Char := 16#2057#;
   Four_Dot_Punctuation                    : constant Unicode_Char := 16#2058#;
   Five_Dot_Punctuation                    : constant Unicode_Char := 16#2059#;
   Two_Dot_Punctuation                     : constant Unicode_Char := 16#205A#;
   Four_Dot_Mark                           : constant Unicode_Char := 16#205B#;
   Dotted_Cross                            : constant Unicode_Char := 16#205C#;
   Tricolon                                : constant Unicode_Char := 16#205D#;
   Vertical_Four_Dots                      : constant Unicode_Char := 16#205E#;
   Medium_Mathematical_Space               : constant Unicode_Char := 16#205F#;
   Mmsp                                    :
      Unicode_Char renames Medium_Mathematical_Space;
   Word_Joiner                             : constant Unicode_Char := 16#2060#;
   Wj                                      : Unicode_Char renames Word_Joiner;
   Function_Application                    : constant Unicode_Char := 16#2061#;
   Invisible_Times                         : constant Unicode_Char := 16#2062#;
   Invisible_Separator                     : constant Unicode_Char := 16#2063#;
   Invisible_Plus                          : constant Unicode_Char := 16#2064#;
   Left_To_Right_Isolate                   : constant Unicode_Char := 16#2066#;
   Lri                                     :
      Unicode_Char renames Left_To_Right_Isolate;
   Right_To_Left_Isolate                   : constant Unicode_Char := 16#2067#;
   Rli                                     :
      Unicode_Char renames Right_To_Left_Isolate;
   First_Strong_Isolate                    : constant Unicode_Char := 16#2068#;
   Fsi                                     :
      Unicode_Char renames First_Strong_Isolate;
   Pop_Directional_Isolate                 : constant Unicode_Char := 16#2069#;
   Pdi                                     :
      Unicode_Char renames Pop_Directional_Isolate;
   Inhibit_Symmetric_Swapping              : constant Unicode_Char := 16#206A#;
   Activate_Symmetric_Swapping             : constant Unicode_Char := 16#206B#;
   Inhibit_Arabic_Form_Shaping             : constant Unicode_Char := 16#206C#;
   Activate_Arabic_Form_Shaping            : constant Unicode_Char := 16#206D#;
   National_Digit_Shapes                   : constant Unicode_Char := 16#206E#;
   Nominal_Digit_Shapes                    : constant Unicode_Char := 16#206F#;
end Unicode.Names.General_Punctuation;
