--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Miao is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Miao_Letter_Pa                          :
      constant Unicode_Char := 16#16F00#;
   Miao_Letter_Ba                          :
      constant Unicode_Char := 16#16F01#;
   Miao_Letter_Yi_Pa                       :
      constant Unicode_Char := 16#16F02#;
   Miao_Letter_Pla                         :
      constant Unicode_Char := 16#16F03#;
   Miao_Letter_Ma                          :
      constant Unicode_Char := 16#16F04#;
   Miao_Letter_Mha                         :
      constant Unicode_Char := 16#16F05#;
   Miao_Letter_Archaic_Ma                  :
      constant Unicode_Char := 16#16F06#;
   Miao_Letter_Fa                          :
      constant Unicode_Char := 16#16F07#;
   Miao_Letter_Va                          :
      constant Unicode_Char := 16#16F08#;
   Miao_Letter_Vfa                         :
      constant Unicode_Char := 16#16F09#;
   Miao_Letter_Ta                          :
      constant Unicode_Char := 16#16F0A#;
   Miao_Letter_Da                          :
      constant Unicode_Char := 16#16F0B#;
   Miao_Letter_Yi_Tta                      :
      constant Unicode_Char := 16#16F0C#;
   Miao_Letter_Yi_Ta                       :
      constant Unicode_Char := 16#16F0D#;
   Miao_Letter_Tta                         :
      constant Unicode_Char := 16#16F0E#;
   Miao_Letter_Dda                         :
      constant Unicode_Char := 16#16F0F#;
   Miao_Letter_Na                          :
      constant Unicode_Char := 16#16F10#;
   Miao_Letter_Nha                         :
      constant Unicode_Char := 16#16F11#;
   Miao_Letter_Yi_Nna                      :
      constant Unicode_Char := 16#16F12#;
   Miao_Letter_Archaic_Na                  :
      constant Unicode_Char := 16#16F13#;
   Miao_Letter_Nna                         :
      constant Unicode_Char := 16#16F14#;
   Miao_Letter_Nnha                        :
      constant Unicode_Char := 16#16F15#;
   Miao_Letter_La                          :
      constant Unicode_Char := 16#16F16#;
   Miao_Letter_Lya                         :
      constant Unicode_Char := 16#16F17#;
   Miao_Letter_Lha                         :
      constant Unicode_Char := 16#16F18#;
   Miao_Letter_Lhya                        :
      constant Unicode_Char := 16#16F19#;
   Miao_Letter_Tlha                        :
      constant Unicode_Char := 16#16F1A#;
   Miao_Letter_Dlha                        :
      constant Unicode_Char := 16#16F1B#;
   Miao_Letter_Tlhya                       :
      constant Unicode_Char := 16#16F1C#;
   Miao_Letter_Dlhya                       :
      constant Unicode_Char := 16#16F1D#;
   Miao_Letter_Ka                          :
      constant Unicode_Char := 16#16F1E#;
   Miao_Letter_Ga                          :
      constant Unicode_Char := 16#16F1F#;
   Miao_Letter_Yi_Ka                       :
      constant Unicode_Char := 16#16F20#;
   Miao_Letter_Qa                          :
      constant Unicode_Char := 16#16F21#;
   Miao_Letter_Qga                         :
      constant Unicode_Char := 16#16F22#;
   Miao_Letter_Nga                         :
      constant Unicode_Char := 16#16F23#;
   Miao_Letter_Ngha                        :
      constant Unicode_Char := 16#16F24#;
   Miao_Letter_Archaic_Nga                 :
      constant Unicode_Char := 16#16F25#;
   Miao_Letter_Ha                          :
      constant Unicode_Char := 16#16F26#;
   Miao_Letter_Xa                          :
      constant Unicode_Char := 16#16F27#;
   Miao_Letter_Gha                         :
      constant Unicode_Char := 16#16F28#;
   Miao_Letter_Ghha                        :
      constant Unicode_Char := 16#16F29#;
   Miao_Letter_Tssa                        :
      constant Unicode_Char := 16#16F2A#;
   Miao_Letter_Dzza                        :
      constant Unicode_Char := 16#16F2B#;
   Miao_Letter_Nya                         :
      constant Unicode_Char := 16#16F2C#;
   Miao_Letter_Nyha                        :
      constant Unicode_Char := 16#16F2D#;
   Miao_Letter_Tsha                        :
      constant Unicode_Char := 16#16F2E#;
   Miao_Letter_Dzha                        :
      constant Unicode_Char := 16#16F2F#;
   Miao_Letter_Yi_Tsha                     :
      constant Unicode_Char := 16#16F30#;
   Miao_Letter_Yi_Dzha                     :
      constant Unicode_Char := 16#16F31#;
   Miao_Letter_Reformed_Tsha               :
      constant Unicode_Char := 16#16F32#;
   Miao_Letter_Sha                         :
      constant Unicode_Char := 16#16F33#;
   Miao_Letter_Ssa                         :
      constant Unicode_Char := 16#16F34#;
   Miao_Letter_Zha                         :
      constant Unicode_Char := 16#16F35#;
   Miao_Letter_Zsha                        :
      constant Unicode_Char := 16#16F36#;
   Miao_Letter_Tsa                         :
      constant Unicode_Char := 16#16F37#;
   Miao_Letter_Dza                         :
      constant Unicode_Char := 16#16F38#;
   Miao_Letter_Yi_Tsa                      :
      constant Unicode_Char := 16#16F39#;
   Miao_Letter_Sa                          :
      constant Unicode_Char := 16#16F3A#;
   Miao_Letter_Za                          :
      constant Unicode_Char := 16#16F3B#;
   Miao_Letter_Zsa                         :
      constant Unicode_Char := 16#16F3C#;
   Miao_Letter_Zza                         :
      constant Unicode_Char := 16#16F3D#;
   Miao_Letter_Zzsa                        :
      constant Unicode_Char := 16#16F3E#;
   Miao_Letter_Archaic_Zza                 :
      constant Unicode_Char := 16#16F3F#;
   Miao_Letter_Zzya                        :
      constant Unicode_Char := 16#16F40#;
   Miao_Letter_Zzsya                       :
      constant Unicode_Char := 16#16F41#;
   Miao_Letter_Wa                          :
      constant Unicode_Char := 16#16F42#;
   Miao_Letter_Ah                          :
      constant Unicode_Char := 16#16F43#;
   Miao_Letter_Hha                         :
      constant Unicode_Char := 16#16F44#;
   Miao_Letter_Nasalization                :
      constant Unicode_Char := 16#16F50#;
   Miao_Sign_Aspiration                    :
      constant Unicode_Char := 16#16F51#;
   Miao_Sign_Reformed_Voicing              :
      constant Unicode_Char := 16#16F52#;
   Miao_Sign_Reformed_Aspiration           :
      constant Unicode_Char := 16#16F53#;
   Miao_Vowel_Sign_A                       :
      constant Unicode_Char := 16#16F54#;
   Miao_Vowel_Sign_Aa                      :
      constant Unicode_Char := 16#16F55#;
   Miao_Vowel_Sign_Ahh                     :
      constant Unicode_Char := 16#16F56#;
   Miao_Vowel_Sign_An                      :
      constant Unicode_Char := 16#16F57#;
   Miao_Vowel_Sign_Ang                     :
      constant Unicode_Char := 16#16F58#;
   Miao_Vowel_Sign_O                       :
      constant Unicode_Char := 16#16F59#;
   Miao_Vowel_Sign_Oo                      :
      constant Unicode_Char := 16#16F5A#;
   Miao_Vowel_Sign_Wo                      :
      constant Unicode_Char := 16#16F5B#;
   Miao_Vowel_Sign_W                       :
      constant Unicode_Char := 16#16F5C#;
   Miao_Vowel_Sign_E                       :
      constant Unicode_Char := 16#16F5D#;
   Miao_Vowel_Sign_En                      :
      constant Unicode_Char := 16#16F5E#;
   Miao_Vowel_Sign_Eng                     :
      constant Unicode_Char := 16#16F5F#;
   Miao_Vowel_Sign_Oey                     :
      constant Unicode_Char := 16#16F60#;
   Miao_Vowel_Sign_I                       :
      constant Unicode_Char := 16#16F61#;
   Miao_Vowel_Sign_Ia                      :
      constant Unicode_Char := 16#16F62#;
   Miao_Vowel_Sign_Ian                     :
      constant Unicode_Char := 16#16F63#;
   Miao_Vowel_Sign_Iang                    :
      constant Unicode_Char := 16#16F64#;
   Miao_Vowel_Sign_Io                      :
      constant Unicode_Char := 16#16F65#;
   Miao_Vowel_Sign_Ie                      :
      constant Unicode_Char := 16#16F66#;
   Miao_Vowel_Sign_Ii                      :
      constant Unicode_Char := 16#16F67#;
   Miao_Vowel_Sign_Iu                      :
      constant Unicode_Char := 16#16F68#;
   Miao_Vowel_Sign_Ing                     :
      constant Unicode_Char := 16#16F69#;
   Miao_Vowel_Sign_U                       :
      constant Unicode_Char := 16#16F6A#;
   Miao_Vowel_Sign_Ua                      :
      constant Unicode_Char := 16#16F6B#;
   Miao_Vowel_Sign_Uan                     :
      constant Unicode_Char := 16#16F6C#;
   Miao_Vowel_Sign_Uang                    :
      constant Unicode_Char := 16#16F6D#;
   Miao_Vowel_Sign_Uu                      :
      constant Unicode_Char := 16#16F6E#;
   Miao_Vowel_Sign_Uei                     :
      constant Unicode_Char := 16#16F6F#;
   Miao_Vowel_Sign_Ung                     :
      constant Unicode_Char := 16#16F70#;
   Miao_Vowel_Sign_Y                       :
      constant Unicode_Char := 16#16F71#;
   Miao_Vowel_Sign_Yi                      :
      constant Unicode_Char := 16#16F72#;
   Miao_Vowel_Sign_Ae                      :
      constant Unicode_Char := 16#16F73#;
   Miao_Vowel_Sign_Aee                     :
      constant Unicode_Char := 16#16F74#;
   Miao_Vowel_Sign_Err                     :
      constant Unicode_Char := 16#16F75#;
   Miao_Vowel_Sign_Rounded_Err             :
      constant Unicode_Char := 16#16F76#;
   Miao_Vowel_Sign_Er                      :
      constant Unicode_Char := 16#16F77#;
   Miao_Vowel_Sign_Rounded_Er              :
      constant Unicode_Char := 16#16F78#;
   Miao_Vowel_Sign_Ai                      :
      constant Unicode_Char := 16#16F79#;
   Miao_Vowel_Sign_Ei                      :
      constant Unicode_Char := 16#16F7A#;
   Miao_Vowel_Sign_Au                      :
      constant Unicode_Char := 16#16F7B#;
   Miao_Vowel_Sign_Ou                      :
      constant Unicode_Char := 16#16F7C#;
   Miao_Vowel_Sign_N                       :
      constant Unicode_Char := 16#16F7D#;
   Miao_Vowel_Sign_Ng                      :
      constant Unicode_Char := 16#16F7E#;
   Miao_Tone_Right                         :
      constant Unicode_Char := 16#16F8F#;
   Miao_Tone_Top_Right                     :
      constant Unicode_Char := 16#16F90#;
   Miao_Tone_Above                         :
      constant Unicode_Char := 16#16F91#;
   Miao_Tone_Below                         :
      constant Unicode_Char := 16#16F92#;
   Miao_Letter_Tone_2                      :
      constant Unicode_Char := 16#16F93#;
   Miao_Letter_Tone_3                      :
      constant Unicode_Char := 16#16F94#;
   Miao_Letter_Tone_4                      :
      constant Unicode_Char := 16#16F95#;
   Miao_Letter_Tone_5                      :
      constant Unicode_Char := 16#16F96#;
   Miao_Letter_Tone_6                      :
      constant Unicode_Char := 16#16F97#;
   Miao_Letter_Tone_7                      :
      constant Unicode_Char := 16#16F98#;
   Miao_Letter_Tone_8                      :
      constant Unicode_Char := 16#16F99#;
   Miao_Letter_Reformed_Tone_1             :
      constant Unicode_Char := 16#16F9A#;
   Miao_Letter_Reformed_Tone_2             :
      constant Unicode_Char := 16#16F9B#;
   Miao_Letter_Reformed_Tone_4             :
      constant Unicode_Char := 16#16F9C#;
   Miao_Letter_Reformed_Tone_5             :
      constant Unicode_Char := 16#16F9D#;
   Miao_Letter_Reformed_Tone_6             :
      constant Unicode_Char := 16#16F9E#;
   Miao_Letter_Reformed_Tone_8             :
      constant Unicode_Char := 16#16F9F#;
end Unicode.Names.Miao;
