--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Avestan is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Avestan_Letter_A                        :
      constant Unicode_Char := 16#10B00#;
   Avestan_Letter_Aa                       :
      constant Unicode_Char := 16#10B01#;
   Avestan_Letter_Ao                       :
      constant Unicode_Char := 16#10B02#;
   Avestan_Letter_Aao                      :
      constant Unicode_Char := 16#10B03#;
   Avestan_Letter_An                       :
      constant Unicode_Char := 16#10B04#;
   Avestan_Letter_Aan                      :
      constant Unicode_Char := 16#10B05#;
   Avestan_Letter_Ae                       :
      constant Unicode_Char := 16#10B06#;
   Avestan_Letter_Aee                      :
      constant Unicode_Char := 16#10B07#;
   Avestan_Letter_E                        :
      constant Unicode_Char := 16#10B08#;
   Avestan_Letter_Ee                       :
      constant Unicode_Char := 16#10B09#;
   Avestan_Letter_O                        :
      constant Unicode_Char := 16#10B0A#;
   Avestan_Letter_Oo                       :
      constant Unicode_Char := 16#10B0B#;
   Avestan_Letter_I                        :
      constant Unicode_Char := 16#10B0C#;
   Avestan_Letter_Ii                       :
      constant Unicode_Char := 16#10B0D#;
   Avestan_Letter_U                        :
      constant Unicode_Char := 16#10B0E#;
   Avestan_Letter_Uu                       :
      constant Unicode_Char := 16#10B0F#;
   Avestan_Letter_Ke                       :
      constant Unicode_Char := 16#10B10#;
   Avestan_Letter_Xe                       :
      constant Unicode_Char := 16#10B11#;
   Avestan_Letter_Xye                      :
      constant Unicode_Char := 16#10B12#;
   Avestan_Letter_Xve                      :
      constant Unicode_Char := 16#10B13#;
   Avestan_Letter_Ge                       :
      constant Unicode_Char := 16#10B14#;
   Avestan_Letter_Gge                      :
      constant Unicode_Char := 16#10B15#;
   Avestan_Letter_Ghe                      :
      constant Unicode_Char := 16#10B16#;
   Avestan_Letter_Ce                       :
      constant Unicode_Char := 16#10B17#;
   Avestan_Letter_Je                       :
      constant Unicode_Char := 16#10B18#;
   Avestan_Letter_Te                       :
      constant Unicode_Char := 16#10B19#;
   Avestan_Letter_The                      :
      constant Unicode_Char := 16#10B1A#;
   Avestan_Letter_De                       :
      constant Unicode_Char := 16#10B1B#;
   Avestan_Letter_Dhe                      :
      constant Unicode_Char := 16#10B1C#;
   Avestan_Letter_Tte                      :
      constant Unicode_Char := 16#10B1D#;
   Avestan_Letter_Pe                       :
      constant Unicode_Char := 16#10B1E#;
   Avestan_Letter_Fe                       :
      constant Unicode_Char := 16#10B1F#;
   Avestan_Letter_Be                       :
      constant Unicode_Char := 16#10B20#;
   Avestan_Letter_Bhe                      :
      constant Unicode_Char := 16#10B21#;
   Avestan_Letter_Nge                      :
      constant Unicode_Char := 16#10B22#;
   Avestan_Letter_Ngye                     :
      constant Unicode_Char := 16#10B23#;
   Avestan_Letter_Ngve                     :
      constant Unicode_Char := 16#10B24#;
   Avestan_Letter_Ne                       :
      constant Unicode_Char := 16#10B25#;
   Avestan_Letter_Nye                      :
      constant Unicode_Char := 16#10B26#;
   Avestan_Letter_Nne                      :
      constant Unicode_Char := 16#10B27#;
   Avestan_Letter_Me                       :
      constant Unicode_Char := 16#10B28#;
   Avestan_Letter_Hme                      :
      constant Unicode_Char := 16#10B29#;
   Avestan_Letter_Yye                      :
      constant Unicode_Char := 16#10B2A#;
   Avestan_Letter_Ye                       :
      constant Unicode_Char := 16#10B2B#;
   Avestan_Letter_Ve                       :
      constant Unicode_Char := 16#10B2C#;
   Avestan_Letter_Re                       :
      constant Unicode_Char := 16#10B2D#;
   Avestan_Letter_Le                       :
      constant Unicode_Char := 16#10B2E#;
   Avestan_Letter_Se                       :
      constant Unicode_Char := 16#10B2F#;
   Avestan_Letter_Ze                       :
      constant Unicode_Char := 16#10B30#;
   Avestan_Letter_She                      :
      constant Unicode_Char := 16#10B31#;
   Avestan_Letter_Zhe                      :
      constant Unicode_Char := 16#10B32#;
   Avestan_Letter_Shye                     :
      constant Unicode_Char := 16#10B33#;
   Avestan_Letter_Sshe                     :
      constant Unicode_Char := 16#10B34#;
   Avestan_Letter_He                       :
      constant Unicode_Char := 16#10B35#;
   Avestan_Abbreviation_Mark               :
      constant Unicode_Char := 16#10B39#;
   Tiny_Two_Dots_Over_One_Dot_Punctuation  :
      constant Unicode_Char := 16#10B3A#;
   Small_Two_Dots_Over_One_Dot_Punctuation :
      constant Unicode_Char := 16#10B3B#;
   Large_Two_Dots_Over_One_Dot_Punctuation :
      constant Unicode_Char := 16#10B3C#;
   Large_One_Dot_Over_Two_Dots_Punctuation :
      constant Unicode_Char := 16#10B3D#;
   Large_Two_Rings_Over_One_Ring_Punctuation :
      constant Unicode_Char := 16#10B3E#;
   Large_One_Ring_Over_Two_Rings_Punctuation :
      constant Unicode_Char := 16#10B3F#;
end Unicode.Names.Avestan;
