--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Hangul_Jamo_Extended_A is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Hangul_Choseong_Tikeut_Mieum            : constant Unicode_Char := 16#A960#;
   Hangul_Choseong_Tikeut_Pieup            : constant Unicode_Char := 16#A961#;
   Hangul_Choseong_Tikeut_Sios             : constant Unicode_Char := 16#A962#;
   Hangul_Choseong_Tikeut_Cieuc            : constant Unicode_Char := 16#A963#;
   Hangul_Choseong_Rieul_Kiyeok            : constant Unicode_Char := 16#A964#;
   Hangul_Choseong_Rieul_Ssangkiyeok       : constant Unicode_Char := 16#A965#;
   Hangul_Choseong_Rieul_Tikeut            : constant Unicode_Char := 16#A966#;
   Hangul_Choseong_Rieul_Ssangtikeut       : constant Unicode_Char := 16#A967#;
   Hangul_Choseong_Rieul_Mieum             : constant Unicode_Char := 16#A968#;
   Hangul_Choseong_Rieul_Pieup             : constant Unicode_Char := 16#A969#;
   Hangul_Choseong_Rieul_Ssangpieup        : constant Unicode_Char := 16#A96A#;
   Hangul_Choseong_Rieul_Kapyeounpieup     : constant Unicode_Char := 16#A96B#;
   Hangul_Choseong_Rieul_Sios              : constant Unicode_Char := 16#A96C#;
   Hangul_Choseong_Rieul_Cieuc             : constant Unicode_Char := 16#A96D#;
   Hangul_Choseong_Rieul_Khieukh           : constant Unicode_Char := 16#A96E#;
   Hangul_Choseong_Mieum_Kiyeok            : constant Unicode_Char := 16#A96F#;
   Hangul_Choseong_Mieum_Tikeut            : constant Unicode_Char := 16#A970#;
   Hangul_Choseong_Mieum_Sios              : constant Unicode_Char := 16#A971#;
   Hangul_Choseong_Pieup_Sios_Thieuth      : constant Unicode_Char := 16#A972#;
   Hangul_Choseong_Pieup_Khieukh           : constant Unicode_Char := 16#A973#;
   Hangul_Choseong_Pieup_Hieuh             : constant Unicode_Char := 16#A974#;
   Hangul_Choseong_Ssangsios_Pieup         : constant Unicode_Char := 16#A975#;
   Hangul_Choseong_Ieung_Rieul             : constant Unicode_Char := 16#A976#;
   Hangul_Choseong_Ieung_Hieuh             : constant Unicode_Char := 16#A977#;
   Hangul_Choseong_Ssangcieuc_Hieuh        : constant Unicode_Char := 16#A978#;
   Hangul_Choseong_Ssangthieuth            : constant Unicode_Char := 16#A979#;
   Hangul_Choseong_Phieuph_Hieuh           : constant Unicode_Char := 16#A97A#;
   Hangul_Choseong_Hieuh_Sios              : constant Unicode_Char := 16#A97B#;
   Hangul_Choseong_Ssangyeorinhieuh        : constant Unicode_Char := 16#A97C#;
end Unicode.Names.Hangul_Jamo_Extended_A;
