--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Ancient_Greek_Numbers is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Greek_Acrophonic_Attic_One_Quarter      :
      constant Unicode_Char := 16#10140#;
   Greek_Acrophonic_Attic_One_Half         :
      constant Unicode_Char := 16#10141#;
   Greek_Acrophonic_Attic_One_Drachma      :
      constant Unicode_Char := 16#10142#;
   Greek_Acrophonic_Attic_Five             :
      constant Unicode_Char := 16#10143#;
   Greek_Acrophonic_Attic_Fifty            :
      constant Unicode_Char := 16#10144#;
   Greek_Acrophonic_Attic_Five_Hundred     :
      constant Unicode_Char := 16#10145#;
   Greek_Acrophonic_Attic_Five_Thousand    :
      constant Unicode_Char := 16#10146#;
   Greek_Acrophonic_Attic_Fifty_Thousand   :
      constant Unicode_Char := 16#10147#;
   Greek_Acrophonic_Attic_Five_Talents     :
      constant Unicode_Char := 16#10148#;
   Greek_Acrophonic_Attic_Ten_Talents      :
      constant Unicode_Char := 16#10149#;
   Greek_Acrophonic_Attic_Fifty_Talents    :
      constant Unicode_Char := 16#1014A#;
   Greek_Acrophonic_Attic_One_Hundred_Talents :
      constant Unicode_Char := 16#1014B#;
   Greek_Acrophonic_Attic_Five_Hundred_Talents :
      constant Unicode_Char := 16#1014C#;
   Greek_Acrophonic_Attic_One_Thousand_Talents :
      constant Unicode_Char := 16#1014D#;
   Greek_Acrophonic_Attic_Five_Thousand_Talents :
      constant Unicode_Char := 16#1014E#;
   Greek_Acrophonic_Attic_Five_Staters     :
      constant Unicode_Char := 16#1014F#;
   Greek_Acrophonic_Attic_Ten_Staters      :
      constant Unicode_Char := 16#10150#;
   Greek_Acrophonic_Attic_Fifty_Staters    :
      constant Unicode_Char := 16#10151#;
   Greek_Acrophonic_Attic_One_Hundred_Staters :
      constant Unicode_Char := 16#10152#;
   Greek_Acrophonic_Attic_Five_Hundred_Staters :
      constant Unicode_Char := 16#10153#;
   Greek_Acrophonic_Attic_One_Thousand_Staters :
      constant Unicode_Char := 16#10154#;
   Greek_Acrophonic_Attic_Ten_Thousand_Staters :
      constant Unicode_Char := 16#10155#;
   Greek_Acrophonic_Attic_Fifty_Thousand_Staters :
      constant Unicode_Char := 16#10156#;
   Greek_Acrophonic_Attic_Ten_Mnas         :
      constant Unicode_Char := 16#10157#;
   Greek_Acrophonic_Heraeum_One_Plethron   :
      constant Unicode_Char := 16#10158#;
   Greek_Acrophonic_Thespian_One           :
      constant Unicode_Char := 16#10159#;
   Greek_Acrophonic_Hermionian_One         :
      constant Unicode_Char := 16#1015A#;
   Greek_Acrophonic_Epidaurean_Two         :
      constant Unicode_Char := 16#1015B#;
   Greek_Acrophonic_Thespian_Two           :
      constant Unicode_Char := 16#1015C#;
   Greek_Acrophonic_Cyrenaic_Two_Drachmas  :
      constant Unicode_Char := 16#1015D#;
   Greek_Acrophonic_Epidaurean_Two_Drachmas :
      constant Unicode_Char := 16#1015E#;
   Greek_Acrophonic_Troezenian_Five        :
      constant Unicode_Char := 16#1015F#;
   Greek_Acrophonic_Troezenian_Ten         :
      constant Unicode_Char := 16#10160#;
   Greek_Acrophonic_Troezenian_Ten_Alternate_Form :
      constant Unicode_Char := 16#10161#;
   Greek_Acrophonic_Hermionian_Ten         :
      constant Unicode_Char := 16#10162#;
   Greek_Acrophonic_Messenian_Ten          :
      constant Unicode_Char := 16#10163#;
   Greek_Acrophonic_Thespian_Ten           :
      constant Unicode_Char := 16#10164#;
   Greek_Acrophonic_Thespian_Thirty        :
      constant Unicode_Char := 16#10165#;
   Greek_Acrophonic_Troezenian_Fifty       :
      constant Unicode_Char := 16#10166#;
   Greek_Acrophonic_Troezenian_Fifty_Alternate_Form :
      constant Unicode_Char := 16#10167#;
   Greek_Acrophonic_Hermionian_Fifty       :
      constant Unicode_Char := 16#10168#;
   Greek_Acrophonic_Thespian_Fifty         :
      constant Unicode_Char := 16#10169#;
   Greek_Acrophonic_Thespian_One_Hundred   :
      constant Unicode_Char := 16#1016A#;
   Greek_Acrophonic_Thespian_Three_Hundred :
      constant Unicode_Char := 16#1016B#;
   Greek_Acrophonic_Epidaurean_Five_Hundred :
      constant Unicode_Char := 16#1016C#;
   Greek_Acrophonic_Troezenian_Five_Hundred :
      constant Unicode_Char := 16#1016D#;
   Greek_Acrophonic_Thespian_Five_Hundred  :
      constant Unicode_Char := 16#1016E#;
   Greek_Acrophonic_Carystian_Five_Hundred :
      constant Unicode_Char := 16#1016F#;
   Greek_Acrophonic_Naxian_Five_Hundred    :
      constant Unicode_Char := 16#10170#;
   Greek_Acrophonic_Thespian_One_Thousand  :
      constant Unicode_Char := 16#10171#;
   Greek_Acrophonic_Thespian_Five_Thousand :
      constant Unicode_Char := 16#10172#;
   Greek_Acrophonic_Delphic_Five_Mnas      :
      constant Unicode_Char := 16#10173#;
   Greek_Acrophonic_Stratian_Fifty_Mnas    :
      constant Unicode_Char := 16#10174#;
   Greek_One_Half_Sign                     :
      constant Unicode_Char := 16#10175#;
   Greek_One_Half_Sign_Alternate_Form      :
      constant Unicode_Char := 16#10176#;
   Greek_Two_Thirds_Sign                   :
      constant Unicode_Char := 16#10177#;
   Greek_Three_Quarters_Sign               :
      constant Unicode_Char := 16#10178#;
   Greek_Year_Sign                         :
      constant Unicode_Char := 16#10179#;
   Greek_Talent_Sign                       :
      constant Unicode_Char := 16#1017A#;
   Greek_Drachma_Sign                      :
      constant Unicode_Char := 16#1017B#;
   Greek_Obol_Sign                         :
      constant Unicode_Char := 16#1017C#;
   Greek_Two_Obols_Sign                    :
      constant Unicode_Char := 16#1017D#;
   Greek_Three_Obols_Sign                  :
      constant Unicode_Char := 16#1017E#;
   Greek_Four_Obols_Sign                   :
      constant Unicode_Char := 16#1017F#;
   Greek_Five_Obols_Sign                   :
      constant Unicode_Char := 16#10180#;
   Greek_Metretes_Sign                     :
      constant Unicode_Char := 16#10181#;
   Greek_Kyathos_Base_Sign                 :
      constant Unicode_Char := 16#10182#;
   Greek_Litra_Sign                        :
      constant Unicode_Char := 16#10183#;
   Greek_Ounkia_Sign                       :
      constant Unicode_Char := 16#10184#;
   Greek_Xestes_Sign                       :
      constant Unicode_Char := 16#10185#;
   Greek_Artabe_Sign                       :
      constant Unicode_Char := 16#10186#;
   Greek_Aroura_Sign                       :
      constant Unicode_Char := 16#10187#;
   Greek_Gramma_Sign                       :
      constant Unicode_Char := 16#10188#;
   Greek_Tryblion_Base_Sign                :
      constant Unicode_Char := 16#10189#;
   Greek_Zero_Sign                         :
      constant Unicode_Char := 16#1018A#;
   Greek_One_Quarter_Sign                  :
      constant Unicode_Char := 16#1018B#;
   Greek_Sinusoid_Sign                     :
      constant Unicode_Char := 16#1018C#;
end Unicode.Names.Ancient_Greek_Numbers;
