--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Deseret is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Deseret_Capital_Letter_Long_I           :
      constant Unicode_Char := 16#10400#;
   Deseret_Capital_Letter_Long_E           :
      constant Unicode_Char := 16#10401#;
   Deseret_Capital_Letter_Long_A           :
      constant Unicode_Char := 16#10402#;
   Deseret_Capital_Letter_Long_Ah          :
      constant Unicode_Char := 16#10403#;
   Deseret_Capital_Letter_Long_O           :
      constant Unicode_Char := 16#10404#;
   Deseret_Capital_Letter_Long_Oo          :
      constant Unicode_Char := 16#10405#;
   Deseret_Capital_Letter_Short_I          :
      constant Unicode_Char := 16#10406#;
   Deseret_Capital_Letter_Short_E          :
      constant Unicode_Char := 16#10407#;
   Deseret_Capital_Letter_Short_A          :
      constant Unicode_Char := 16#10408#;
   Deseret_Capital_Letter_Short_Ah         :
      constant Unicode_Char := 16#10409#;
   Deseret_Capital_Letter_Short_O          :
      constant Unicode_Char := 16#1040A#;
   Deseret_Capital_Letter_Short_Oo         :
      constant Unicode_Char := 16#1040B#;
   Deseret_Capital_Letter_Ay               :
      constant Unicode_Char := 16#1040C#;
   Deseret_Capital_Letter_Ow               :
      constant Unicode_Char := 16#1040D#;
   Deseret_Capital_Letter_Wu               :
      constant Unicode_Char := 16#1040E#;
   Deseret_Capital_Letter_Yee              :
      constant Unicode_Char := 16#1040F#;
   Deseret_Capital_Letter_H                :
      constant Unicode_Char := 16#10410#;
   Deseret_Capital_Letter_Pee              :
      constant Unicode_Char := 16#10411#;
   Deseret_Capital_Letter_Bee              :
      constant Unicode_Char := 16#10412#;
   Deseret_Capital_Letter_Tee              :
      constant Unicode_Char := 16#10413#;
   Deseret_Capital_Letter_Dee              :
      constant Unicode_Char := 16#10414#;
   Deseret_Capital_Letter_Chee             :
      constant Unicode_Char := 16#10415#;
   Deseret_Capital_Letter_Jee              :
      constant Unicode_Char := 16#10416#;
   Deseret_Capital_Letter_Kay              :
      constant Unicode_Char := 16#10417#;
   Deseret_Capital_Letter_Gay              :
      constant Unicode_Char := 16#10418#;
   Deseret_Capital_Letter_Ef               :
      constant Unicode_Char := 16#10419#;
   Deseret_Capital_Letter_Vee              :
      constant Unicode_Char := 16#1041A#;
   Deseret_Capital_Letter_Eth              :
      constant Unicode_Char := 16#1041B#;
   Deseret_Capital_Letter_Thee             :
      constant Unicode_Char := 16#1041C#;
   Deseret_Capital_Letter_Es               :
      constant Unicode_Char := 16#1041D#;
   Deseret_Capital_Letter_Zee              :
      constant Unicode_Char := 16#1041E#;
   Deseret_Capital_Letter_Esh              :
      constant Unicode_Char := 16#1041F#;
   Deseret_Capital_Letter_Zhee             :
      constant Unicode_Char := 16#10420#;
   Deseret_Capital_Letter_Er               :
      constant Unicode_Char := 16#10421#;
   Deseret_Capital_Letter_El               :
      constant Unicode_Char := 16#10422#;
   Deseret_Capital_Letter_Em               :
      constant Unicode_Char := 16#10423#;
   Deseret_Capital_Letter_En               :
      constant Unicode_Char := 16#10424#;
   Deseret_Capital_Letter_Eng              :
      constant Unicode_Char := 16#10425#;
   Deseret_Capital_Letter_Oi               :
      constant Unicode_Char := 16#10426#;
   Deseret_Capital_Letter_Ew               :
      constant Unicode_Char := 16#10427#;
   Deseret_Small_Letter_Long_I             :
      constant Unicode_Char := 16#10428#;
   Deseret_Small_Letter_Long_E             :
      constant Unicode_Char := 16#10429#;
   Deseret_Small_Letter_Long_A             :
      constant Unicode_Char := 16#1042A#;
   Deseret_Small_Letter_Long_Ah            :
      constant Unicode_Char := 16#1042B#;
   Deseret_Small_Letter_Long_O             :
      constant Unicode_Char := 16#1042C#;
   Deseret_Small_Letter_Long_Oo            :
      constant Unicode_Char := 16#1042D#;
   Deseret_Small_Letter_Short_I            :
      constant Unicode_Char := 16#1042E#;
   Deseret_Small_Letter_Short_E            :
      constant Unicode_Char := 16#1042F#;
   Deseret_Small_Letter_Short_A            :
      constant Unicode_Char := 16#10430#;
   Deseret_Small_Letter_Short_Ah           :
      constant Unicode_Char := 16#10431#;
   Deseret_Small_Letter_Short_O            :
      constant Unicode_Char := 16#10432#;
   Deseret_Small_Letter_Short_Oo           :
      constant Unicode_Char := 16#10433#;
   Deseret_Small_Letter_Ay                 :
      constant Unicode_Char := 16#10434#;
   Deseret_Small_Letter_Ow                 :
      constant Unicode_Char := 16#10435#;
   Deseret_Small_Letter_Wu                 :
      constant Unicode_Char := 16#10436#;
   Deseret_Small_Letter_Yee                :
      constant Unicode_Char := 16#10437#;
   Deseret_Small_Letter_H                  :
      constant Unicode_Char := 16#10438#;
   Deseret_Small_Letter_Pee                :
      constant Unicode_Char := 16#10439#;
   Deseret_Small_Letter_Bee                :
      constant Unicode_Char := 16#1043A#;
   Deseret_Small_Letter_Tee                :
      constant Unicode_Char := 16#1043B#;
   Deseret_Small_Letter_Dee                :
      constant Unicode_Char := 16#1043C#;
   Deseret_Small_Letter_Chee               :
      constant Unicode_Char := 16#1043D#;
   Deseret_Small_Letter_Jee                :
      constant Unicode_Char := 16#1043E#;
   Deseret_Small_Letter_Kay                :
      constant Unicode_Char := 16#1043F#;
   Deseret_Small_Letter_Gay                :
      constant Unicode_Char := 16#10440#;
   Deseret_Small_Letter_Ef                 :
      constant Unicode_Char := 16#10441#;
   Deseret_Small_Letter_Vee                :
      constant Unicode_Char := 16#10442#;
   Deseret_Small_Letter_Eth                :
      constant Unicode_Char := 16#10443#;
   Deseret_Small_Letter_Thee               :
      constant Unicode_Char := 16#10444#;
   Deseret_Small_Letter_Es                 :
      constant Unicode_Char := 16#10445#;
   Deseret_Small_Letter_Zee                :
      constant Unicode_Char := 16#10446#;
   Deseret_Small_Letter_Esh                :
      constant Unicode_Char := 16#10447#;
   Deseret_Small_Letter_Zhee               :
      constant Unicode_Char := 16#10448#;
   Deseret_Small_Letter_Er                 :
      constant Unicode_Char := 16#10449#;
   Deseret_Small_Letter_El                 :
      constant Unicode_Char := 16#1044A#;
   Deseret_Small_Letter_Em                 :
      constant Unicode_Char := 16#1044B#;
   Deseret_Small_Letter_En                 :
      constant Unicode_Char := 16#1044C#;
   Deseret_Small_Letter_Eng                :
      constant Unicode_Char := 16#1044D#;
   Deseret_Small_Letter_Oi                 :
      constant Unicode_Char := 16#1044E#;
   Deseret_Small_Letter_Ew                 :
      constant Unicode_Char := 16#1044F#;
end Unicode.Names.Deseret;
