--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Myanmar is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Myanmar_Letter_Ka                       : constant Unicode_Char := 16#1000#;
   Myanmar_Letter_Kha                      : constant Unicode_Char := 16#1001#;
   Myanmar_Letter_Ga                       : constant Unicode_Char := 16#1002#;
   Myanmar_Letter_Gha                      : constant Unicode_Char := 16#1003#;
   Myanmar_Letter_Nga                      : constant Unicode_Char := 16#1004#;
   Myanmar_Letter_Ca                       : constant Unicode_Char := 16#1005#;
   Myanmar_Letter_Cha                      : constant Unicode_Char := 16#1006#;
   Myanmar_Letter_Ja                       : constant Unicode_Char := 16#1007#;
   Myanmar_Letter_Jha                      : constant Unicode_Char := 16#1008#;
   Myanmar_Letter_Nya                      : constant Unicode_Char := 16#1009#;
   Myanmar_Letter_Nnya                     : constant Unicode_Char := 16#100A#;
   Myanmar_Letter_Tta                      : constant Unicode_Char := 16#100B#;
   Myanmar_Letter_Ttha                     : constant Unicode_Char := 16#100C#;
   Myanmar_Letter_Dda                      : constant Unicode_Char := 16#100D#;
   Myanmar_Letter_Ddha                     : constant Unicode_Char := 16#100E#;
   Myanmar_Letter_Nna                      : constant Unicode_Char := 16#100F#;
   Myanmar_Letter_Ta                       : constant Unicode_Char := 16#1010#;
   Myanmar_Letter_Tha                      : constant Unicode_Char := 16#1011#;
   Myanmar_Letter_Da                       : constant Unicode_Char := 16#1012#;
   Myanmar_Letter_Dha                      : constant Unicode_Char := 16#1013#;
   Myanmar_Letter_Na                       : constant Unicode_Char := 16#1014#;
   Myanmar_Letter_Pa                       : constant Unicode_Char := 16#1015#;
   Myanmar_Letter_Pha                      : constant Unicode_Char := 16#1016#;
   Myanmar_Letter_Ba                       : constant Unicode_Char := 16#1017#;
   Myanmar_Letter_Bha                      : constant Unicode_Char := 16#1018#;
   Myanmar_Letter_Ma                       : constant Unicode_Char := 16#1019#;
   Myanmar_Letter_Ya                       : constant Unicode_Char := 16#101A#;
   Myanmar_Letter_Ra                       : constant Unicode_Char := 16#101B#;
   Myanmar_Letter_La                       : constant Unicode_Char := 16#101C#;
   Myanmar_Letter_Wa                       : constant Unicode_Char := 16#101D#;
   Myanmar_Letter_Sa                       : constant Unicode_Char := 16#101E#;
   Myanmar_Letter_Ha                       : constant Unicode_Char := 16#101F#;
   Myanmar_Letter_Lla                      : constant Unicode_Char := 16#1020#;
   Myanmar_Letter_A                        : constant Unicode_Char := 16#1021#;
   Myanmar_Letter_Shan_A                   : constant Unicode_Char := 16#1022#;
   Myanmar_Letter_I                        : constant Unicode_Char := 16#1023#;
   Myanmar_Letter_Ii                       : constant Unicode_Char := 16#1024#;
   Myanmar_Letter_U                        : constant Unicode_Char := 16#1025#;
   Myanmar_Letter_Uu                       : constant Unicode_Char := 16#1026#;
   Myanmar_Letter_E                        : constant Unicode_Char := 16#1027#;
   Myanmar_Letter_Mon_E                    : constant Unicode_Char := 16#1028#;
   Myanmar_Letter_O                        : constant Unicode_Char := 16#1029#;
   Myanmar_Letter_Au                       : constant Unicode_Char := 16#102A#;
   Myanmar_Vowel_Sign_Tall_Aa              : constant Unicode_Char := 16#102B#;
   Myanmar_Vowel_Sign_Aa                   : constant Unicode_Char := 16#102C#;
   Myanmar_Vowel_Sign_I                    : constant Unicode_Char := 16#102D#;
   Myanmar_Vowel_Sign_Ii                   : constant Unicode_Char := 16#102E#;
   Myanmar_Vowel_Sign_U                    : constant Unicode_Char := 16#102F#;
   Myanmar_Vowel_Sign_Uu                   : constant Unicode_Char := 16#1030#;
   Myanmar_Vowel_Sign_E                    : constant Unicode_Char := 16#1031#;
   Myanmar_Vowel_Sign_Ai                   : constant Unicode_Char := 16#1032#;
   Myanmar_Vowel_Sign_Mon_Ii               : constant Unicode_Char := 16#1033#;
   Myanmar_Vowel_Sign_Mon_O                : constant Unicode_Char := 16#1034#;
   Myanmar_Vowel_Sign_E_Above              : constant Unicode_Char := 16#1035#;
   Myanmar_Sign_Anusvara                   : constant Unicode_Char := 16#1036#;
   Myanmar_Sign_Dot_Below                  : constant Unicode_Char := 16#1037#;
   Myanmar_Sign_Visarga                    : constant Unicode_Char := 16#1038#;
   Myanmar_Sign_Virama                     : constant Unicode_Char := 16#1039#;
   Myanmar_Sign_Asat                       : constant Unicode_Char := 16#103A#;
   Myanmar_Consonant_Sign_Medial_Ya        : constant Unicode_Char := 16#103B#;
   Myanmar_Consonant_Sign_Medial_Ra        : constant Unicode_Char := 16#103C#;
   Myanmar_Consonant_Sign_Medial_Wa        : constant Unicode_Char := 16#103D#;
   Myanmar_Consonant_Sign_Medial_Ha        : constant Unicode_Char := 16#103E#;
   Myanmar_Letter_Great_Sa                 : constant Unicode_Char := 16#103F#;
   Myanmar_Digit_Zero                      : constant Unicode_Char := 16#1040#;
   Myanmar_Digit_One                       : constant Unicode_Char := 16#1041#;
   Myanmar_Digit_Two                       : constant Unicode_Char := 16#1042#;
   Myanmar_Digit_Three                     : constant Unicode_Char := 16#1043#;
   Myanmar_Digit_Four                      : constant Unicode_Char := 16#1044#;
   Myanmar_Digit_Five                      : constant Unicode_Char := 16#1045#;
   Myanmar_Digit_Six                       : constant Unicode_Char := 16#1046#;
   Myanmar_Digit_Seven                     : constant Unicode_Char := 16#1047#;
   Myanmar_Digit_Eight                     : constant Unicode_Char := 16#1048#;
   Myanmar_Digit_Nine                      : constant Unicode_Char := 16#1049#;
   Myanmar_Sign_Little_Section             : constant Unicode_Char := 16#104A#;
   Myanmar_Sign_Section                    : constant Unicode_Char := 16#104B#;
   Myanmar_Symbol_Locative                 : constant Unicode_Char := 16#104C#;
   Myanmar_Symbol_Completed                : constant Unicode_Char := 16#104D#;
   Myanmar_Symbol_Aforementioned           : constant Unicode_Char := 16#104E#;
   Myanmar_Symbol_Genitive                 : constant Unicode_Char := 16#104F#;
   Myanmar_Letter_Sha                      : constant Unicode_Char := 16#1050#;
   Myanmar_Letter_Ssa                      : constant Unicode_Char := 16#1051#;
   Myanmar_Letter_Vocalic_R                : constant Unicode_Char := 16#1052#;
   Myanmar_Letter_Vocalic_Rr               : constant Unicode_Char := 16#1053#;
   Myanmar_Letter_Vocalic_L                : constant Unicode_Char := 16#1054#;
   Myanmar_Letter_Vocalic_Ll               : constant Unicode_Char := 16#1055#;
   Myanmar_Vowel_Sign_Vocalic_R            : constant Unicode_Char := 16#1056#;
   Myanmar_Vowel_Sign_Vocalic_Rr           : constant Unicode_Char := 16#1057#;
   Myanmar_Vowel_Sign_Vocalic_L            : constant Unicode_Char := 16#1058#;
   Myanmar_Vowel_Sign_Vocalic_Ll           : constant Unicode_Char := 16#1059#;
   Myanmar_Letter_Mon_Nga                  : constant Unicode_Char := 16#105A#;
   Myanmar_Letter_Mon_Jha                  : constant Unicode_Char := 16#105B#;
   Myanmar_Letter_Mon_Bba                  : constant Unicode_Char := 16#105C#;
   Myanmar_Letter_Mon_Bbe                  : constant Unicode_Char := 16#105D#;
   Myanmar_Consonant_Sign_Mon_Medial_Na    : constant Unicode_Char := 16#105E#;
   Myanmar_Consonant_Sign_Mon_Medial_Ma    : constant Unicode_Char := 16#105F#;
   Myanmar_Consonant_Sign_Mon_Medial_La    : constant Unicode_Char := 16#1060#;
   Myanmar_Letter_Sgaw_Karen_Sha           : constant Unicode_Char := 16#1061#;
   Myanmar_Vowel_Sign_Sgaw_Karen_Eu        : constant Unicode_Char := 16#1062#;
   Myanmar_Tone_Mark_Sgaw_Karen_Hathi      : constant Unicode_Char := 16#1063#;
   Myanmar_Tone_Mark_Sgaw_Karen_Ke_Pho     : constant Unicode_Char := 16#1064#;
   Myanmar_Letter_Western_Pwo_Karen_Tha    : constant Unicode_Char := 16#1065#;
   Myanmar_Letter_Western_Pwo_Karen_Pwa    : constant Unicode_Char := 16#1066#;
   Myanmar_Vowel_Sign_Western_Pwo_Karen_Eu : constant Unicode_Char := 16#1067#;
   Myanmar_Vowel_Sign_Western_Pwo_Karen_Ue : constant Unicode_Char := 16#1068#;
   Myanmar_Sign_Western_Pwo_Karen_Tone_1   : constant Unicode_Char := 16#1069#;
   Myanmar_Sign_Western_Pwo_Karen_Tone_2   : constant Unicode_Char := 16#106A#;
   Myanmar_Sign_Western_Pwo_Karen_Tone_3   : constant Unicode_Char := 16#106B#;
   Myanmar_Sign_Western_Pwo_Karen_Tone_4   : constant Unicode_Char := 16#106C#;
   Myanmar_Sign_Western_Pwo_Karen_Tone_5   : constant Unicode_Char := 16#106D#;
   Myanmar_Letter_Eastern_Pwo_Karen_Nna    : constant Unicode_Char := 16#106E#;
   Myanmar_Letter_Eastern_Pwo_Karen_Ywa    : constant Unicode_Char := 16#106F#;
   Myanmar_Letter_Eastern_Pwo_Karen_Ghwa   : constant Unicode_Char := 16#1070#;
   Myanmar_Vowel_Sign_Geba_Karen_I         : constant Unicode_Char := 16#1071#;
   Myanmar_Vowel_Sign_Kayah_Oe             : constant Unicode_Char := 16#1072#;
   Myanmar_Vowel_Sign_Kayah_U              : constant Unicode_Char := 16#1073#;
   Myanmar_Vowel_Sign_Kayah_Ee             : constant Unicode_Char := 16#1074#;
   Myanmar_Letter_Shan_Ka                  : constant Unicode_Char := 16#1075#;
   Myanmar_Letter_Shan_Kha                 : constant Unicode_Char := 16#1076#;
   Myanmar_Letter_Shan_Ga                  : constant Unicode_Char := 16#1077#;
   Myanmar_Letter_Shan_Ca                  : constant Unicode_Char := 16#1078#;
   Myanmar_Letter_Shan_Za                  : constant Unicode_Char := 16#1079#;
   Myanmar_Letter_Shan_Nya                 : constant Unicode_Char := 16#107A#;
   Myanmar_Letter_Shan_Da                  : constant Unicode_Char := 16#107B#;
   Myanmar_Letter_Shan_Na                  : constant Unicode_Char := 16#107C#;
   Myanmar_Letter_Shan_Pha                 : constant Unicode_Char := 16#107D#;
   Myanmar_Letter_Shan_Fa                  : constant Unicode_Char := 16#107E#;
   Myanmar_Letter_Shan_Ba                  : constant Unicode_Char := 16#107F#;
   Myanmar_Letter_Shan_Tha                 : constant Unicode_Char := 16#1080#;
   Myanmar_Letter_Shan_Ha                  : constant Unicode_Char := 16#1081#;
   Myanmar_Consonant_Sign_Shan_Medial_Wa   : constant Unicode_Char := 16#1082#;
   Myanmar_Vowel_Sign_Shan_Aa              : constant Unicode_Char := 16#1083#;
   Myanmar_Vowel_Sign_Shan_E               : constant Unicode_Char := 16#1084#;
   Myanmar_Vowel_Sign_Shan_E_Above         : constant Unicode_Char := 16#1085#;
   Myanmar_Vowel_Sign_Shan_Final_Y         : constant Unicode_Char := 16#1086#;
   Myanmar_Sign_Shan_Tone_2                : constant Unicode_Char := 16#1087#;
   Myanmar_Sign_Shan_Tone_3                : constant Unicode_Char := 16#1088#;
   Myanmar_Sign_Shan_Tone_5                : constant Unicode_Char := 16#1089#;
   Myanmar_Sign_Shan_Tone_6                : constant Unicode_Char := 16#108A#;
   Myanmar_Sign_Shan_Council_Tone_2        : constant Unicode_Char := 16#108B#;
   Myanmar_Sign_Shan_Council_Tone_3        : constant Unicode_Char := 16#108C#;
   Myanmar_Sign_Shan_Council_Emphatic_Tone : constant Unicode_Char := 16#108D#;
   Myanmar_Letter_Rumai_Palaung_Fa         : constant Unicode_Char := 16#108E#;
   Myanmar_Sign_Rumai_Palaung_Tone_5       : constant Unicode_Char := 16#108F#;
   Myanmar_Shan_Digit_Zero                 : constant Unicode_Char := 16#1090#;
   Myanmar_Shan_Digit_One                  : constant Unicode_Char := 16#1091#;
   Myanmar_Shan_Digit_Two                  : constant Unicode_Char := 16#1092#;
   Myanmar_Shan_Digit_Three                : constant Unicode_Char := 16#1093#;
   Myanmar_Shan_Digit_Four                 : constant Unicode_Char := 16#1094#;
   Myanmar_Shan_Digit_Five                 : constant Unicode_Char := 16#1095#;
   Myanmar_Shan_Digit_Six                  : constant Unicode_Char := 16#1096#;
   Myanmar_Shan_Digit_Seven                : constant Unicode_Char := 16#1097#;
   Myanmar_Shan_Digit_Eight                : constant Unicode_Char := 16#1098#;
   Myanmar_Shan_Digit_Nine                 : constant Unicode_Char := 16#1099#;
   Myanmar_Sign_Khamti_Tone_1              : constant Unicode_Char := 16#109A#;
   Myanmar_Sign_Khamti_Tone_3              : constant Unicode_Char := 16#109B#;
   Myanmar_Vowel_Sign_Aiton_A              : constant Unicode_Char := 16#109C#;
   Myanmar_Vowel_Sign_Aiton_Ai             : constant Unicode_Char := 16#109D#;
   Myanmar_Symbol_Shan_One                 : constant Unicode_Char := 16#109E#;
   Myanmar_Symbol_Shan_Exclamation         : constant Unicode_Char := 16#109F#;
end Unicode.Names.Myanmar;
