--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Tai_Le is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Tai_Le_Letter_Ka                        : constant Unicode_Char := 16#1950#;
   Tai_Le_Letter_Xa                        : constant Unicode_Char := 16#1951#;
   Tai_Le_Letter_Nga                       : constant Unicode_Char := 16#1952#;
   Tai_Le_Letter_Tsa                       : constant Unicode_Char := 16#1953#;
   Tai_Le_Letter_Sa                        : constant Unicode_Char := 16#1954#;
   Tai_Le_Letter_Ya                        : constant Unicode_Char := 16#1955#;
   Tai_Le_Letter_Ta                        : constant Unicode_Char := 16#1956#;
   Tai_Le_Letter_Tha                       : constant Unicode_Char := 16#1957#;
   Tai_Le_Letter_La                        : constant Unicode_Char := 16#1958#;
   Tai_Le_Letter_Pa                        : constant Unicode_Char := 16#1959#;
   Tai_Le_Letter_Pha                       : constant Unicode_Char := 16#195A#;
   Tai_Le_Letter_Ma                        : constant Unicode_Char := 16#195B#;
   Tai_Le_Letter_Fa                        : constant Unicode_Char := 16#195C#;
   Tai_Le_Letter_Va                        : constant Unicode_Char := 16#195D#;
   Tai_Le_Letter_Ha                        : constant Unicode_Char := 16#195E#;
   Tai_Le_Letter_Qa                        : constant Unicode_Char := 16#195F#;
   Tai_Le_Letter_Kha                       : constant Unicode_Char := 16#1960#;
   Tai_Le_Letter_Tsha                      : constant Unicode_Char := 16#1961#;
   Tai_Le_Letter_Na                        : constant Unicode_Char := 16#1962#;
   Tai_Le_Letter_A                         : constant Unicode_Char := 16#1963#;
   Tai_Le_Letter_I                         : constant Unicode_Char := 16#1964#;
   Tai_Le_Letter_Ee                        : constant Unicode_Char := 16#1965#;
   Tai_Le_Letter_Eh                        : constant Unicode_Char := 16#1966#;
   Tai_Le_Letter_U                         : constant Unicode_Char := 16#1967#;
   Tai_Le_Letter_Oo                        : constant Unicode_Char := 16#1968#;
   Tai_Le_Letter_O                         : constant Unicode_Char := 16#1969#;
   Tai_Le_Letter_Ue                        : constant Unicode_Char := 16#196A#;
   Tai_Le_Letter_E                         : constant Unicode_Char := 16#196B#;
   Tai_Le_Letter_Aue                       : constant Unicode_Char := 16#196C#;
   Tai_Le_Letter_Ai                        : constant Unicode_Char := 16#196D#;
   Tai_Le_Letter_Tone_2                    : constant Unicode_Char := 16#1970#;
   Tai_Le_Letter_Tone_3                    : constant Unicode_Char := 16#1971#;
   Tai_Le_Letter_Tone_4                    : constant Unicode_Char := 16#1972#;
   Tai_Le_Letter_Tone_5                    : constant Unicode_Char := 16#1973#;
   Tai_Le_Letter_Tone_6                    : constant Unicode_Char := 16#1974#;
end Unicode.Names.Tai_Le;
