--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Tags is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Language_Tag                            :
      constant Unicode_Char := 16#E0001#;
   Tag_Space                               :
      constant Unicode_Char := 16#E0020#;
   Tag_Exclamation_Mark                    :
      constant Unicode_Char := 16#E0021#;
   Tag_Quotation_Mark                      :
      constant Unicode_Char := 16#E0022#;
   Tag_Number_Sign                         :
      constant Unicode_Char := 16#E0023#;
   Tag_Dollar_Sign                         :
      constant Unicode_Char := 16#E0024#;
   Tag_Percent_Sign                        :
      constant Unicode_Char := 16#E0025#;
   Tag_Ampersand                           :
      constant Unicode_Char := 16#E0026#;
   Tag_Apostrophe                          :
      constant Unicode_Char := 16#E0027#;
   Tag_Left_Parenthesis                    :
      constant Unicode_Char := 16#E0028#;
   Tag_Right_Parenthesis                   :
      constant Unicode_Char := 16#E0029#;
   Tag_Asterisk                            :
      constant Unicode_Char := 16#E002A#;
   Tag_Plus_Sign                           :
      constant Unicode_Char := 16#E002B#;
   Tag_Comma                               :
      constant Unicode_Char := 16#E002C#;
   Tag_Hyphen_Minus                        :
      constant Unicode_Char := 16#E002D#;
   Tag_Full_Stop                           :
      constant Unicode_Char := 16#E002E#;
   Tag_Solidus                             :
      constant Unicode_Char := 16#E002F#;
   Tag_Digit_Zero                          :
      constant Unicode_Char := 16#E0030#;
   Tag_Digit_One                           :
      constant Unicode_Char := 16#E0031#;
   Tag_Digit_Two                           :
      constant Unicode_Char := 16#E0032#;
   Tag_Digit_Three                         :
      constant Unicode_Char := 16#E0033#;
   Tag_Digit_Four                          :
      constant Unicode_Char := 16#E0034#;
   Tag_Digit_Five                          :
      constant Unicode_Char := 16#E0035#;
   Tag_Digit_Six                           :
      constant Unicode_Char := 16#E0036#;
   Tag_Digit_Seven                         :
      constant Unicode_Char := 16#E0037#;
   Tag_Digit_Eight                         :
      constant Unicode_Char := 16#E0038#;
   Tag_Digit_Nine                          :
      constant Unicode_Char := 16#E0039#;
   Tag_Colon                               :
      constant Unicode_Char := 16#E003A#;
   Tag_Semicolon                           :
      constant Unicode_Char := 16#E003B#;
   Tag_Less_Than_Sign                      :
      constant Unicode_Char := 16#E003C#;
   Tag_Equals_Sign                         :
      constant Unicode_Char := 16#E003D#;
   Tag_Greater_Than_Sign                   :
      constant Unicode_Char := 16#E003E#;
   Tag_Question_Mark                       :
      constant Unicode_Char := 16#E003F#;
   Tag_Commercial_At                       :
      constant Unicode_Char := 16#E0040#;
   Tag_Latin_Capital_Letter_A              :
      constant Unicode_Char := 16#E0041#;
   Tag_Latin_Capital_Letter_B              :
      constant Unicode_Char := 16#E0042#;
   Tag_Latin_Capital_Letter_C              :
      constant Unicode_Char := 16#E0043#;
   Tag_Latin_Capital_Letter_D              :
      constant Unicode_Char := 16#E0044#;
   Tag_Latin_Capital_Letter_E              :
      constant Unicode_Char := 16#E0045#;
   Tag_Latin_Capital_Letter_F              :
      constant Unicode_Char := 16#E0046#;
   Tag_Latin_Capital_Letter_G              :
      constant Unicode_Char := 16#E0047#;
   Tag_Latin_Capital_Letter_H              :
      constant Unicode_Char := 16#E0048#;
   Tag_Latin_Capital_Letter_I              :
      constant Unicode_Char := 16#E0049#;
   Tag_Latin_Capital_Letter_J              :
      constant Unicode_Char := 16#E004A#;
   Tag_Latin_Capital_Letter_K              :
      constant Unicode_Char := 16#E004B#;
   Tag_Latin_Capital_Letter_L              :
      constant Unicode_Char := 16#E004C#;
   Tag_Latin_Capital_Letter_M              :
      constant Unicode_Char := 16#E004D#;
   Tag_Latin_Capital_Letter_N              :
      constant Unicode_Char := 16#E004E#;
   Tag_Latin_Capital_Letter_O              :
      constant Unicode_Char := 16#E004F#;
   Tag_Latin_Capital_Letter_P              :
      constant Unicode_Char := 16#E0050#;
   Tag_Latin_Capital_Letter_Q              :
      constant Unicode_Char := 16#E0051#;
   Tag_Latin_Capital_Letter_R              :
      constant Unicode_Char := 16#E0052#;
   Tag_Latin_Capital_Letter_S              :
      constant Unicode_Char := 16#E0053#;
   Tag_Latin_Capital_Letter_T              :
      constant Unicode_Char := 16#E0054#;
   Tag_Latin_Capital_Letter_U              :
      constant Unicode_Char := 16#E0055#;
   Tag_Latin_Capital_Letter_V              :
      constant Unicode_Char := 16#E0056#;
   Tag_Latin_Capital_Letter_W              :
      constant Unicode_Char := 16#E0057#;
   Tag_Latin_Capital_Letter_X              :
      constant Unicode_Char := 16#E0058#;
   Tag_Latin_Capital_Letter_Y              :
      constant Unicode_Char := 16#E0059#;
   Tag_Latin_Capital_Letter_Z              :
      constant Unicode_Char := 16#E005A#;
   Tag_Left_Square_Bracket                 :
      constant Unicode_Char := 16#E005B#;
   Tag_Reverse_Solidus                     :
      constant Unicode_Char := 16#E005C#;
   Tag_Right_Square_Bracket                :
      constant Unicode_Char := 16#E005D#;
   Tag_Circumflex_Accent                   :
      constant Unicode_Char := 16#E005E#;
   Tag_Low_Line                            :
      constant Unicode_Char := 16#E005F#;
   Tag_Grave_Accent                        :
      constant Unicode_Char := 16#E0060#;
   Tag_Latin_Small_Letter_A                :
      constant Unicode_Char := 16#E0061#;
   Tag_Latin_Small_Letter_B                :
      constant Unicode_Char := 16#E0062#;
   Tag_Latin_Small_Letter_C                :
      constant Unicode_Char := 16#E0063#;
   Tag_Latin_Small_Letter_D                :
      constant Unicode_Char := 16#E0064#;
   Tag_Latin_Small_Letter_E                :
      constant Unicode_Char := 16#E0065#;
   Tag_Latin_Small_Letter_F                :
      constant Unicode_Char := 16#E0066#;
   Tag_Latin_Small_Letter_G                :
      constant Unicode_Char := 16#E0067#;
   Tag_Latin_Small_Letter_H                :
      constant Unicode_Char := 16#E0068#;
   Tag_Latin_Small_Letter_I                :
      constant Unicode_Char := 16#E0069#;
   Tag_Latin_Small_Letter_J                :
      constant Unicode_Char := 16#E006A#;
   Tag_Latin_Small_Letter_K                :
      constant Unicode_Char := 16#E006B#;
   Tag_Latin_Small_Letter_L                :
      constant Unicode_Char := 16#E006C#;
   Tag_Latin_Small_Letter_M                :
      constant Unicode_Char := 16#E006D#;
   Tag_Latin_Small_Letter_N                :
      constant Unicode_Char := 16#E006E#;
   Tag_Latin_Small_Letter_O                :
      constant Unicode_Char := 16#E006F#;
   Tag_Latin_Small_Letter_P                :
      constant Unicode_Char := 16#E0070#;
   Tag_Latin_Small_Letter_Q                :
      constant Unicode_Char := 16#E0071#;
   Tag_Latin_Small_Letter_R                :
      constant Unicode_Char := 16#E0072#;
   Tag_Latin_Small_Letter_S                :
      constant Unicode_Char := 16#E0073#;
   Tag_Latin_Small_Letter_T                :
      constant Unicode_Char := 16#E0074#;
   Tag_Latin_Small_Letter_U                :
      constant Unicode_Char := 16#E0075#;
   Tag_Latin_Small_Letter_V                :
      constant Unicode_Char := 16#E0076#;
   Tag_Latin_Small_Letter_W                :
      constant Unicode_Char := 16#E0077#;
   Tag_Latin_Small_Letter_X                :
      constant Unicode_Char := 16#E0078#;
   Tag_Latin_Small_Letter_Y                :
      constant Unicode_Char := 16#E0079#;
   Tag_Latin_Small_Letter_Z                :
      constant Unicode_Char := 16#E007A#;
   Tag_Left_Curly_Bracket                  :
      constant Unicode_Char := 16#E007B#;
   Tag_Vertical_Line                       :
      constant Unicode_Char := 16#E007C#;
   Tag_Right_Curly_Bracket                 :
      constant Unicode_Char := 16#E007D#;
   Tag_Tilde                               :
      constant Unicode_Char := 16#E007E#;
   Cancel_Tag                              :
      constant Unicode_Char := 16#E007F#;
end Unicode.Names.Tags;
