--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Telugu is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Telugu_Sign_Combining_Candrabindu_Above : constant Unicode_Char := 16#0C00#;
   Telugu_Sign_Candrabindu                 : constant Unicode_Char := 16#0C01#;
   Telugu_Sign_Anusvara                    : constant Unicode_Char := 16#0C02#;
   Telugu_Sign_Visarga                     : constant Unicode_Char := 16#0C03#;
   Telugu_Letter_A                         : constant Unicode_Char := 16#0C05#;
   Telugu_Letter_Aa                        : constant Unicode_Char := 16#0C06#;
   Telugu_Letter_I                         : constant Unicode_Char := 16#0C07#;
   Telugu_Letter_Ii                        : constant Unicode_Char := 16#0C08#;
   Telugu_Letter_U                         : constant Unicode_Char := 16#0C09#;
   Telugu_Letter_Uu                        : constant Unicode_Char := 16#0C0A#;
   Telugu_Letter_Vocalic_R                 : constant Unicode_Char := 16#0C0B#;
   Telugu_Letter_Vocalic_L                 : constant Unicode_Char := 16#0C0C#;
   Telugu_Letter_E                         : constant Unicode_Char := 16#0C0E#;
   Telugu_Letter_Ee                        : constant Unicode_Char := 16#0C0F#;
   Telugu_Letter_Ai                        : constant Unicode_Char := 16#0C10#;
   Telugu_Letter_O                         : constant Unicode_Char := 16#0C12#;
   Telugu_Letter_Oo                        : constant Unicode_Char := 16#0C13#;
   Telugu_Letter_Au                        : constant Unicode_Char := 16#0C14#;
   Telugu_Letter_Ka                        : constant Unicode_Char := 16#0C15#;
   Telugu_Letter_Kha                       : constant Unicode_Char := 16#0C16#;
   Telugu_Letter_Ga                        : constant Unicode_Char := 16#0C17#;
   Telugu_Letter_Gha                       : constant Unicode_Char := 16#0C18#;
   Telugu_Letter_Nga                       : constant Unicode_Char := 16#0C19#;
   Telugu_Letter_Ca                        : constant Unicode_Char := 16#0C1A#;
   Telugu_Letter_Cha                       : constant Unicode_Char := 16#0C1B#;
   Telugu_Letter_Ja                        : constant Unicode_Char := 16#0C1C#;
   Telugu_Letter_Jha                       : constant Unicode_Char := 16#0C1D#;
   Telugu_Letter_Nya                       : constant Unicode_Char := 16#0C1E#;
   Telugu_Letter_Tta                       : constant Unicode_Char := 16#0C1F#;
   Telugu_Letter_Ttha                      : constant Unicode_Char := 16#0C20#;
   Telugu_Letter_Dda                       : constant Unicode_Char := 16#0C21#;
   Telugu_Letter_Ddha                      : constant Unicode_Char := 16#0C22#;
   Telugu_Letter_Nna                       : constant Unicode_Char := 16#0C23#;
   Telugu_Letter_Ta                        : constant Unicode_Char := 16#0C24#;
   Telugu_Letter_Tha                       : constant Unicode_Char := 16#0C25#;
   Telugu_Letter_Da                        : constant Unicode_Char := 16#0C26#;
   Telugu_Letter_Dha                       : constant Unicode_Char := 16#0C27#;
   Telugu_Letter_Na                        : constant Unicode_Char := 16#0C28#;
   Telugu_Letter_Pa                        : constant Unicode_Char := 16#0C2A#;
   Telugu_Letter_Pha                       : constant Unicode_Char := 16#0C2B#;
   Telugu_Letter_Ba                        : constant Unicode_Char := 16#0C2C#;
   Telugu_Letter_Bha                       : constant Unicode_Char := 16#0C2D#;
   Telugu_Letter_Ma                        : constant Unicode_Char := 16#0C2E#;
   Telugu_Letter_Ya                        : constant Unicode_Char := 16#0C2F#;
   Telugu_Letter_Ra                        : constant Unicode_Char := 16#0C30#;
   Telugu_Letter_Rra                       : constant Unicode_Char := 16#0C31#;
   Telugu_Letter_La                        : constant Unicode_Char := 16#0C32#;
   Telugu_Letter_Lla                       : constant Unicode_Char := 16#0C33#;
   Telugu_Letter_Llla                      : constant Unicode_Char := 16#0C34#;
   Telugu_Letter_Va                        : constant Unicode_Char := 16#0C35#;
   Telugu_Letter_Sha                       : constant Unicode_Char := 16#0C36#;
   Telugu_Letter_Ssa                       : constant Unicode_Char := 16#0C37#;
   Telugu_Letter_Sa                        : constant Unicode_Char := 16#0C38#;
   Telugu_Letter_Ha                        : constant Unicode_Char := 16#0C39#;
   Telugu_Sign_Avagraha                    : constant Unicode_Char := 16#0C3D#;
   Telugu_Vowel_Sign_Aa                    : constant Unicode_Char := 16#0C3E#;
   Telugu_Vowel_Sign_I                     : constant Unicode_Char := 16#0C3F#;
   Telugu_Vowel_Sign_Ii                    : constant Unicode_Char := 16#0C40#;
   Telugu_Vowel_Sign_U                     : constant Unicode_Char := 16#0C41#;
   Telugu_Vowel_Sign_Uu                    : constant Unicode_Char := 16#0C42#;
   Telugu_Vowel_Sign_Vocalic_R             : constant Unicode_Char := 16#0C43#;
   Telugu_Vowel_Sign_Vocalic_Rr            : constant Unicode_Char := 16#0C44#;
   Telugu_Vowel_Sign_E                     : constant Unicode_Char := 16#0C46#;
   Telugu_Vowel_Sign_Ee                    : constant Unicode_Char := 16#0C47#;
   Telugu_Vowel_Sign_Ai                    : constant Unicode_Char := 16#0C48#;
   Telugu_Vowel_Sign_O                     : constant Unicode_Char := 16#0C4A#;
   Telugu_Vowel_Sign_Oo                    : constant Unicode_Char := 16#0C4B#;
   Telugu_Vowel_Sign_Au                    : constant Unicode_Char := 16#0C4C#;
   Telugu_Sign_Virama                      : constant Unicode_Char := 16#0C4D#;
   Telugu_Length_Mark                      : constant Unicode_Char := 16#0C55#;
   Telugu_Ai_Length_Mark                   : constant Unicode_Char := 16#0C56#;
   Telugu_Letter_Tsa                       : constant Unicode_Char := 16#0C58#;
   Telugu_Letter_Dza                       : constant Unicode_Char := 16#0C59#;
   Telugu_Letter_Rrra                      : constant Unicode_Char := 16#0C5A#;
   Telugu_Letter_Vocalic_Rr                : constant Unicode_Char := 16#0C60#;
   Telugu_Letter_Vocalic_Ll                : constant Unicode_Char := 16#0C61#;
   Telugu_Vowel_Sign_Vocalic_L             : constant Unicode_Char := 16#0C62#;
   Telugu_Vowel_Sign_Vocalic_Ll            : constant Unicode_Char := 16#0C63#;
   Telugu_Digit_Zero                       : constant Unicode_Char := 16#0C66#;
   Telugu_Digit_One                        : constant Unicode_Char := 16#0C67#;
   Telugu_Digit_Two                        : constant Unicode_Char := 16#0C68#;
   Telugu_Digit_Three                      : constant Unicode_Char := 16#0C69#;
   Telugu_Digit_Four                       : constant Unicode_Char := 16#0C6A#;
   Telugu_Digit_Five                       : constant Unicode_Char := 16#0C6B#;
   Telugu_Digit_Six                        : constant Unicode_Char := 16#0C6C#;
   Telugu_Digit_Seven                      : constant Unicode_Char := 16#0C6D#;
   Telugu_Digit_Eight                      : constant Unicode_Char := 16#0C6E#;
   Telugu_Digit_Nine                       : constant Unicode_Char := 16#0C6F#;
   Telugu_Fraction_Digit_Zero_For_Odd_Powers_Of_Four :
      constant Unicode_Char := 16#0C78#;
   Telugu_Fraction_Digit_One_For_Odd_Powers_Of_Four :
      constant Unicode_Char := 16#0C79#;
   Telugu_Fraction_Digit_Two_For_Odd_Powers_Of_Four :
      constant Unicode_Char := 16#0C7A#;
   Telugu_Fraction_Digit_Three_For_Odd_Powers_Of_Four :
      constant Unicode_Char := 16#0C7B#;
   Telugu_Fraction_Digit_One_For_Even_Powers_Of_Four :
      constant Unicode_Char := 16#0C7C#;
   Telugu_Fraction_Digit_Two_For_Even_Powers_Of_Four :
      constant Unicode_Char := 16#0C7D#;
   Telugu_Fraction_Digit_Three_For_Even_Powers_Of_Four :
      constant Unicode_Char := 16#0C7E#;
   Telugu_Sign_Tuumu                       : constant Unicode_Char := 16#0C7F#;
end Unicode.Names.Telugu;
