--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Malayalam is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Malayalam_Sign_Candrabindu              : constant Unicode_Char := 16#0D01#;
   Malayalam_Sign_Anusvara                 : constant Unicode_Char := 16#0D02#;
   Malayalam_Sign_Visarga                  : constant Unicode_Char := 16#0D03#;
   Malayalam_Letter_A                      : constant Unicode_Char := 16#0D05#;
   Malayalam_Letter_Aa                     : constant Unicode_Char := 16#0D06#;
   Malayalam_Letter_I                      : constant Unicode_Char := 16#0D07#;
   Malayalam_Letter_Ii                     : constant Unicode_Char := 16#0D08#;
   Malayalam_Letter_U                      : constant Unicode_Char := 16#0D09#;
   Malayalam_Letter_Uu                     : constant Unicode_Char := 16#0D0A#;
   Malayalam_Letter_Vocalic_R              : constant Unicode_Char := 16#0D0B#;
   Malayalam_Letter_Vocalic_L              : constant Unicode_Char := 16#0D0C#;
   Malayalam_Letter_E                      : constant Unicode_Char := 16#0D0E#;
   Malayalam_Letter_Ee                     : constant Unicode_Char := 16#0D0F#;
   Malayalam_Letter_Ai                     : constant Unicode_Char := 16#0D10#;
   Malayalam_Letter_O                      : constant Unicode_Char := 16#0D12#;
   Malayalam_Letter_Oo                     : constant Unicode_Char := 16#0D13#;
   Malayalam_Letter_Au                     : constant Unicode_Char := 16#0D14#;
   Malayalam_Letter_Ka                     : constant Unicode_Char := 16#0D15#;
   Malayalam_Letter_Kha                    : constant Unicode_Char := 16#0D16#;
   Malayalam_Letter_Ga                     : constant Unicode_Char := 16#0D17#;
   Malayalam_Letter_Gha                    : constant Unicode_Char := 16#0D18#;
   Malayalam_Letter_Nga                    : constant Unicode_Char := 16#0D19#;
   Malayalam_Letter_Ca                     : constant Unicode_Char := 16#0D1A#;
   Malayalam_Letter_Cha                    : constant Unicode_Char := 16#0D1B#;
   Malayalam_Letter_Ja                     : constant Unicode_Char := 16#0D1C#;
   Malayalam_Letter_Jha                    : constant Unicode_Char := 16#0D1D#;
   Malayalam_Letter_Nya                    : constant Unicode_Char := 16#0D1E#;
   Malayalam_Letter_Tta                    : constant Unicode_Char := 16#0D1F#;
   Malayalam_Letter_Ttha                   : constant Unicode_Char := 16#0D20#;
   Malayalam_Letter_Dda                    : constant Unicode_Char := 16#0D21#;
   Malayalam_Letter_Ddha                   : constant Unicode_Char := 16#0D22#;
   Malayalam_Letter_Nna                    : constant Unicode_Char := 16#0D23#;
   Malayalam_Letter_Ta                     : constant Unicode_Char := 16#0D24#;
   Malayalam_Letter_Tha                    : constant Unicode_Char := 16#0D25#;
   Malayalam_Letter_Da                     : constant Unicode_Char := 16#0D26#;
   Malayalam_Letter_Dha                    : constant Unicode_Char := 16#0D27#;
   Malayalam_Letter_Na                     : constant Unicode_Char := 16#0D28#;
   Malayalam_Letter_Nnna                   : constant Unicode_Char := 16#0D29#;
   Malayalam_Letter_Pa                     : constant Unicode_Char := 16#0D2A#;
   Malayalam_Letter_Pha                    : constant Unicode_Char := 16#0D2B#;
   Malayalam_Letter_Ba                     : constant Unicode_Char := 16#0D2C#;
   Malayalam_Letter_Bha                    : constant Unicode_Char := 16#0D2D#;
   Malayalam_Letter_Ma                     : constant Unicode_Char := 16#0D2E#;
   Malayalam_Letter_Ya                     : constant Unicode_Char := 16#0D2F#;
   Malayalam_Letter_Ra                     : constant Unicode_Char := 16#0D30#;
   Malayalam_Letter_Rra                    : constant Unicode_Char := 16#0D31#;
   Malayalam_Letter_La                     : constant Unicode_Char := 16#0D32#;
   Malayalam_Letter_Lla                    : constant Unicode_Char := 16#0D33#;
   Malayalam_Letter_Llla                   : constant Unicode_Char := 16#0D34#;
   Malayalam_Letter_Va                     : constant Unicode_Char := 16#0D35#;
   Malayalam_Letter_Sha                    : constant Unicode_Char := 16#0D36#;
   Malayalam_Letter_Ssa                    : constant Unicode_Char := 16#0D37#;
   Malayalam_Letter_Sa                     : constant Unicode_Char := 16#0D38#;
   Malayalam_Letter_Ha                     : constant Unicode_Char := 16#0D39#;
   Malayalam_Letter_Ttta                   : constant Unicode_Char := 16#0D3A#;
   Malayalam_Sign_Avagraha                 : constant Unicode_Char := 16#0D3D#;
   Malayalam_Vowel_Sign_Aa                 : constant Unicode_Char := 16#0D3E#;
   Malayalam_Vowel_Sign_I                  : constant Unicode_Char := 16#0D3F#;
   Malayalam_Vowel_Sign_Ii                 : constant Unicode_Char := 16#0D40#;
   Malayalam_Vowel_Sign_U                  : constant Unicode_Char := 16#0D41#;
   Malayalam_Vowel_Sign_Uu                 : constant Unicode_Char := 16#0D42#;
   Malayalam_Vowel_Sign_Vocalic_R          : constant Unicode_Char := 16#0D43#;
   Malayalam_Vowel_Sign_Vocalic_Rr         : constant Unicode_Char := 16#0D44#;
   Malayalam_Vowel_Sign_E                  : constant Unicode_Char := 16#0D46#;
   Malayalam_Vowel_Sign_Ee                 : constant Unicode_Char := 16#0D47#;
   Malayalam_Vowel_Sign_Ai                 : constant Unicode_Char := 16#0D48#;
   Malayalam_Vowel_Sign_O                  : constant Unicode_Char := 16#0D4A#;
   Malayalam_Vowel_Sign_Oo                 : constant Unicode_Char := 16#0D4B#;
   Malayalam_Vowel_Sign_Au                 : constant Unicode_Char := 16#0D4C#;
   Malayalam_Sign_Virama                   : constant Unicode_Char := 16#0D4D#;
   Malayalam_Letter_Dot_Reph               : constant Unicode_Char := 16#0D4E#;
   Malayalam_Au_Length_Mark                : constant Unicode_Char := 16#0D57#;
   Malayalam_Letter_Archaic_Ii             : constant Unicode_Char := 16#0D5F#;
   Malayalam_Letter_Vocalic_Rr             : constant Unicode_Char := 16#0D60#;
   Malayalam_Letter_Vocalic_Ll             : constant Unicode_Char := 16#0D61#;
   Malayalam_Vowel_Sign_Vocalic_L          : constant Unicode_Char := 16#0D62#;
   Malayalam_Vowel_Sign_Vocalic_Ll         : constant Unicode_Char := 16#0D63#;
   Malayalam_Digit_Zero                    : constant Unicode_Char := 16#0D66#;
   Malayalam_Digit_One                     : constant Unicode_Char := 16#0D67#;
   Malayalam_Digit_Two                     : constant Unicode_Char := 16#0D68#;
   Malayalam_Digit_Three                   : constant Unicode_Char := 16#0D69#;
   Malayalam_Digit_Four                    : constant Unicode_Char := 16#0D6A#;
   Malayalam_Digit_Five                    : constant Unicode_Char := 16#0D6B#;
   Malayalam_Digit_Six                     : constant Unicode_Char := 16#0D6C#;
   Malayalam_Digit_Seven                   : constant Unicode_Char := 16#0D6D#;
   Malayalam_Digit_Eight                   : constant Unicode_Char := 16#0D6E#;
   Malayalam_Digit_Nine                    : constant Unicode_Char := 16#0D6F#;
   Malayalam_Number_Ten                    : constant Unicode_Char := 16#0D70#;
   Malayalam_Number_One_Hundred            : constant Unicode_Char := 16#0D71#;
   Malayalam_Number_One_Thousand           : constant Unicode_Char := 16#0D72#;
   Malayalam_Fraction_One_Quarter          : constant Unicode_Char := 16#0D73#;
   Malayalam_Fraction_One_Half             : constant Unicode_Char := 16#0D74#;
   Malayalam_Fraction_Three_Quarters       : constant Unicode_Char := 16#0D75#;
   Malayalam_Date_Mark                     : constant Unicode_Char := 16#0D79#;
   Malayalam_Letter_Chillu_Nn              : constant Unicode_Char := 16#0D7A#;
   Malayalam_Letter_Chillu_N               : constant Unicode_Char := 16#0D7B#;
   Malayalam_Letter_Chillu_Rr              : constant Unicode_Char := 16#0D7C#;
   Malayalam_Letter_Chillu_L               : constant Unicode_Char := 16#0D7D#;
   Malayalam_Letter_Chillu_Ll              : constant Unicode_Char := 16#0D7E#;
   Malayalam_Letter_Chillu_K               : constant Unicode_Char := 16#0D7F#;
end Unicode.Names.Malayalam;
