--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Alpha_Presentation_Forms is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Latin_Small_Ligature_Ff                 : constant Unicode_Char := 16#FB00#;
   Latin_Small_Ligature_Fi                 : constant Unicode_Char := 16#FB01#;
   Latin_Small_Ligature_Fl                 : constant Unicode_Char := 16#FB02#;
   Latin_Small_Ligature_Ffi                : constant Unicode_Char := 16#FB03#;
   Latin_Small_Ligature_Ffl                : constant Unicode_Char := 16#FB04#;
   Latin_Small_Ligature_Long_S_T           : constant Unicode_Char := 16#FB05#;
   Latin_Small_Ligature_St                 : constant Unicode_Char := 16#FB06#;
   Armenian_Small_Ligature_Men_Now         : constant Unicode_Char := 16#FB13#;
   Armenian_Small_Ligature_Men_Ech         : constant Unicode_Char := 16#FB14#;
   Armenian_Small_Ligature_Men_Ini         : constant Unicode_Char := 16#FB15#;
   Armenian_Small_Ligature_Vew_Now         : constant Unicode_Char := 16#FB16#;
   Armenian_Small_Ligature_Men_Xeh         : constant Unicode_Char := 16#FB17#;
   Hebrew_Letter_Yod_With_Hiriq            : constant Unicode_Char := 16#FB1D#;
   Hebrew_Point_Judeo_Spanish_Varika       : constant Unicode_Char := 16#FB1E#;
   Hebrew_Ligature_Yiddish_Yod_Yod_Patah   : constant Unicode_Char := 16#FB1F#;
   Hebrew_Letter_Alternative_Ayin          : constant Unicode_Char := 16#FB20#;
   Hebrew_Letter_Wide_Alef                 : constant Unicode_Char := 16#FB21#;
   Hebrew_Letter_Wide_Dalet                : constant Unicode_Char := 16#FB22#;
   Hebrew_Letter_Wide_He                   : constant Unicode_Char := 16#FB23#;
   Hebrew_Letter_Wide_Kaf                  : constant Unicode_Char := 16#FB24#;
   Hebrew_Letter_Wide_Lamed                : constant Unicode_Char := 16#FB25#;
   Hebrew_Letter_Wide_Final_Mem            : constant Unicode_Char := 16#FB26#;
   Hebrew_Letter_Wide_Resh                 : constant Unicode_Char := 16#FB27#;
   Hebrew_Letter_Wide_Tav                  : constant Unicode_Char := 16#FB28#;
   Hebrew_Letter_Alternative_Plus_Sign     : constant Unicode_Char := 16#FB29#;
   Hebrew_Letter_Shin_With_Shin_Dot        : constant Unicode_Char := 16#FB2A#;
   Hebrew_Letter_Shin_With_Sin_Dot         : constant Unicode_Char := 16#FB2B#;
   Hebrew_Letter_Shin_With_Dagesh_And_Shin_Dot :
      constant Unicode_Char := 16#FB2C#;
   Hebrew_Letter_Shin_With_Dagesh_And_Sin_Dot :
      constant Unicode_Char := 16#FB2D#;
   Hebrew_Letter_Alef_With_Patah           : constant Unicode_Char := 16#FB2E#;
   Hebrew_Letter_Alef_With_Qamats          : constant Unicode_Char := 16#FB2F#;
   Hebrew_Letter_Alef_With_Mapiq           : constant Unicode_Char := 16#FB30#;
   Hebrew_Letter_Bet_With_Dagesh           : constant Unicode_Char := 16#FB31#;
   Hebrew_Letter_Gimel_With_Dagesh         : constant Unicode_Char := 16#FB32#;
   Hebrew_Letter_Dalet_With_Dagesh         : constant Unicode_Char := 16#FB33#;
   Hebrew_Letter_He_With_Mapiq             : constant Unicode_Char := 16#FB34#;
   Hebrew_Letter_Vav_With_Dagesh           : constant Unicode_Char := 16#FB35#;
   Hebrew_Letter_Zayin_With_Dagesh         : constant Unicode_Char := 16#FB36#;
   Hebrew_Letter_Tet_With_Dagesh           : constant Unicode_Char := 16#FB38#;
   Hebrew_Letter_Yod_With_Dagesh           : constant Unicode_Char := 16#FB39#;
   Hebrew_Letter_Final_Kaf_With_Dagesh     : constant Unicode_Char := 16#FB3A#;
   Hebrew_Letter_Kaf_With_Dagesh           : constant Unicode_Char := 16#FB3B#;
   Hebrew_Letter_Lamed_With_Dagesh         : constant Unicode_Char := 16#FB3C#;
   Hebrew_Letter_Mem_With_Dagesh           : constant Unicode_Char := 16#FB3E#;
   Hebrew_Letter_Nun_With_Dagesh           : constant Unicode_Char := 16#FB40#;
   Hebrew_Letter_Samekh_With_Dagesh        : constant Unicode_Char := 16#FB41#;
   Hebrew_Letter_Final_Pe_With_Dagesh      : constant Unicode_Char := 16#FB43#;
   Hebrew_Letter_Pe_With_Dagesh            : constant Unicode_Char := 16#FB44#;
   Hebrew_Letter_Tsadi_With_Dagesh         : constant Unicode_Char := 16#FB46#;
   Hebrew_Letter_Qof_With_Dagesh           : constant Unicode_Char := 16#FB47#;
   Hebrew_Letter_Resh_With_Dagesh          : constant Unicode_Char := 16#FB48#;
   Hebrew_Letter_Shin_With_Dagesh          : constant Unicode_Char := 16#FB49#;
   Hebrew_Letter_Tav_With_Dagesh           : constant Unicode_Char := 16#FB4A#;
   Hebrew_Letter_Vav_With_Holam            : constant Unicode_Char := 16#FB4B#;
   Hebrew_Letter_Bet_With_Rafe             : constant Unicode_Char := 16#FB4C#;
   Hebrew_Letter_Kaf_With_Rafe             : constant Unicode_Char := 16#FB4D#;
   Hebrew_Letter_Pe_With_Rafe              : constant Unicode_Char := 16#FB4E#;
   Hebrew_Ligature_Alef_Lamed              : constant Unicode_Char := 16#FB4F#;
end Unicode.Names.Alpha_Presentation_Forms;
