--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Misc_Math_Symbols_A is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Three_Dimensional_Angle                 : constant Unicode_Char := 16#27C0#;
   White_Triangle_Containing_Small_White_Triangle :
      constant Unicode_Char := 16#27C1#;
   Perpendicular                           : constant Unicode_Char := 16#27C2#;
   Open_Subset                             : constant Unicode_Char := 16#27C3#;
   Open_Superset                           : constant Unicode_Char := 16#27C4#;
   Left_S_Shaped_Bag_Delimiter             : constant Unicode_Char := 16#27C5#;
   Right_S_Shaped_Bag_Delimiter            : constant Unicode_Char := 16#27C6#;
   Or_With_Dot_Inside                      : constant Unicode_Char := 16#27C7#;
   Reverse_Solidus_Preceding_Subset        : constant Unicode_Char := 16#27C8#;
   Superset_Preceding_Solidus              : constant Unicode_Char := 16#27C9#;
   Vertical_Bar_With_Horizontal_Stroke     : constant Unicode_Char := 16#27CA#;
   Mathematical_Rising_Diagonal            : constant Unicode_Char := 16#27CB#;
   Long_Division                           : constant Unicode_Char := 16#27CC#;
   Mathematical_Falling_Diagonal           : constant Unicode_Char := 16#27CD#;
   Squared_Logical_And                     : constant Unicode_Char := 16#27CE#;
   Squared_Logical_Or                      : constant Unicode_Char := 16#27CF#;
   White_Diamond_With_Centred_Dot          : constant Unicode_Char := 16#27D0#;
   And_With_Dot                            : constant Unicode_Char := 16#27D1#;
   Element_Of_Opening_Upwards              : constant Unicode_Char := 16#27D2#;
   Lower_Right_Corner_With_Dot             : constant Unicode_Char := 16#27D3#;
   Upper_Left_Corner_With_Dot              : constant Unicode_Char := 16#27D4#;
   Left_Outer_Join                         : constant Unicode_Char := 16#27D5#;
   Right_Outer_Join                        : constant Unicode_Char := 16#27D6#;
   Full_Outer_Join                         : constant Unicode_Char := 16#27D7#;
   Large_Up_Tack                           : constant Unicode_Char := 16#27D8#;
   Large_Down_Tack                         : constant Unicode_Char := 16#27D9#;
   Left_And_Right_Double_Turnstile         : constant Unicode_Char := 16#27DA#;
   Left_And_Right_Tack                     : constant Unicode_Char := 16#27DB#;
   Left_Multimap                           : constant Unicode_Char := 16#27DC#;
   Long_Right_Tack                         : constant Unicode_Char := 16#27DD#;
   Long_Left_Tack                          : constant Unicode_Char := 16#27DE#;
   Up_Tack_With_Circle_Above               : constant Unicode_Char := 16#27DF#;
   Lozenge_Divided_By_Horizontal_Rule      : constant Unicode_Char := 16#27E0#;
   White_Concave_Sided_Diamond             : constant Unicode_Char := 16#27E1#;
   White_Concave_Sided_Diamond_With_Leftwards_Tick :
      constant Unicode_Char := 16#27E2#;
   White_Concave_Sided_Diamond_With_Rightwards_Tick :
      constant Unicode_Char := 16#27E3#;
   White_Square_With_Leftwards_Tick        : constant Unicode_Char := 16#27E4#;
   White_Square_With_Rightwards_Tick       : constant Unicode_Char := 16#27E5#;
   Mathematical_Left_White_Square_Bracket  : constant Unicode_Char := 16#27E6#;
   Mathematical_Right_White_Square_Bracket : constant Unicode_Char := 16#27E7#;
   Mathematical_Left_Angle_Bracket         : constant Unicode_Char := 16#27E8#;
   Mathematical_Right_Angle_Bracket        : constant Unicode_Char := 16#27E9#;
   Mathematical_Left_Double_Angle_Bracket  : constant Unicode_Char := 16#27EA#;
   Mathematical_Right_Double_Angle_Bracket : constant Unicode_Char := 16#27EB#;
   Mathematical_Left_White_Tortoise_Shell_Bracket :
      constant Unicode_Char := 16#27EC#;
   Mathematical_Right_White_Tortoise_Shell_Bracket :
      constant Unicode_Char := 16#27ED#;
   Mathematical_Left_Flattened_Parenthesis : constant Unicode_Char := 16#27EE#;
   Mathematical_Right_Flattened_Parenthesis :
      constant Unicode_Char := 16#27EF#;
end Unicode.Names.Misc_Math_Symbols_A;
