--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Miscellaneous_Technical is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Diameter_Sign                           : constant Unicode_Char := 16#2300#;
   Electric_Arrow                          : constant Unicode_Char := 16#2301#;
   House                                   : constant Unicode_Char := 16#2302#;
   Up_Arrowhead                            : constant Unicode_Char := 16#2303#;
   Down_Arrowhead                          : constant Unicode_Char := 16#2304#;
   Projective                              : constant Unicode_Char := 16#2305#;
   Perspective                             : constant Unicode_Char := 16#2306#;
   Wavy_Line                               : constant Unicode_Char := 16#2307#;
   Left_Ceiling                            : constant Unicode_Char := 16#2308#;
   Right_Ceiling                           : constant Unicode_Char := 16#2309#;
   Left_Floor                              : constant Unicode_Char := 16#230A#;
   Right_Floor                             : constant Unicode_Char := 16#230B#;
   Bottom_Right_Crop                       : constant Unicode_Char := 16#230C#;
   Bottom_Left_Crop                        : constant Unicode_Char := 16#230D#;
   Top_Right_Crop                          : constant Unicode_Char := 16#230E#;
   Top_Left_Crop                           : constant Unicode_Char := 16#230F#;
   Reversed_Not_Sign                       : constant Unicode_Char := 16#2310#;
   Square_Lozenge                          : constant Unicode_Char := 16#2311#;
   Arc                                     : constant Unicode_Char := 16#2312#;
   Segment                                 : constant Unicode_Char := 16#2313#;
   Sector                                  : constant Unicode_Char := 16#2314#;
   Telephone_Recorder                      : constant Unicode_Char := 16#2315#;
   Position_Indicator                      : constant Unicode_Char := 16#2316#;
   Viewdata_Square                         : constant Unicode_Char := 16#2317#;
   Place_Of_Interest_Sign                  : constant Unicode_Char := 16#2318#;
   Turned_Not_Sign                         : constant Unicode_Char := 16#2319#;
   Watch                                   : constant Unicode_Char := 16#231A#;
   Hourglass                               : constant Unicode_Char := 16#231B#;
   Top_Left_Corner                         : constant Unicode_Char := 16#231C#;
   Top_Right_Corner                        : constant Unicode_Char := 16#231D#;
   Bottom_Left_Corner                      : constant Unicode_Char := 16#231E#;
   Bottom_Right_Corner                     : constant Unicode_Char := 16#231F#;
   Top_Half_Integral                       : constant Unicode_Char := 16#2320#;
   Bottom_Half_Integral                    : constant Unicode_Char := 16#2321#;
   Frown                                   : constant Unicode_Char := 16#2322#;
   Smile                                   : constant Unicode_Char := 16#2323#;
   Up_Arrowhead_Between_Two_Horizontal_Bars :
      constant Unicode_Char := 16#2324#;
   Option_Key                              : constant Unicode_Char := 16#2325#;
   Erase_To_The_Right                      : constant Unicode_Char := 16#2326#;
   X_In_A_Rectangle_Box                    : constant Unicode_Char := 16#2327#;
   Keyboard                                : constant Unicode_Char := 16#2328#;
   Left_Pointing_Angle_Bracket             : constant Unicode_Char := 16#2329#;
   Right_Pointing_Angle_Bracket            : constant Unicode_Char := 16#232A#;
   Erase_To_The_Left                       : constant Unicode_Char := 16#232B#;
   Benzene_Ring                            : constant Unicode_Char := 16#232C#;
   Cylindricity                            : constant Unicode_Char := 16#232D#;
   All_Around_Profile                      : constant Unicode_Char := 16#232E#;
   Symmetry                                : constant Unicode_Char := 16#232F#;
   Total_Runout                            : constant Unicode_Char := 16#2330#;
   Dimension_Origin                        : constant Unicode_Char := 16#2331#;
   Conical_Taper                           : constant Unicode_Char := 16#2332#;
   Slope                                   : constant Unicode_Char := 16#2333#;
   Counterbore                             : constant Unicode_Char := 16#2334#;
   Countersink                             : constant Unicode_Char := 16#2335#;
   Apl_Functional_Symbol_I_Beam            : constant Unicode_Char := 16#2336#;
   Apl_Functional_Symbol_Squish_Quad       : constant Unicode_Char := 16#2337#;
   Apl_Functional_Symbol_Quad_Equal        : constant Unicode_Char := 16#2338#;
   Apl_Functional_Symbol_Quad_Divide       : constant Unicode_Char := 16#2339#;
   Apl_Functional_Symbol_Quad_Diamond      : constant Unicode_Char := 16#233A#;
   Apl_Functional_Symbol_Quad_Jot          : constant Unicode_Char := 16#233B#;
   Apl_Functional_Symbol_Quad_Circle       : constant Unicode_Char := 16#233C#;
   Apl_Functional_Symbol_Circle_Stile      : constant Unicode_Char := 16#233D#;
   Apl_Functional_Symbol_Circle_Jot        : constant Unicode_Char := 16#233E#;
   Apl_Functional_Symbol_Slash_Bar         : constant Unicode_Char := 16#233F#;
   Apl_Functional_Symbol_Backslash_Bar     : constant Unicode_Char := 16#2340#;
   Apl_Functional_Symbol_Quad_Slash        : constant Unicode_Char := 16#2341#;
   Apl_Functional_Symbol_Quad_Backslash    : constant Unicode_Char := 16#2342#;
   Apl_Functional_Symbol_Quad_Less_Than    : constant Unicode_Char := 16#2343#;
   Apl_Functional_Symbol_Quad_Greater_Than : constant Unicode_Char := 16#2344#;
   Apl_Functional_Symbol_Leftwards_Vane    : constant Unicode_Char := 16#2345#;
   Apl_Functional_Symbol_Rightwards_Vane   : constant Unicode_Char := 16#2346#;
   Apl_Functional_Symbol_Quad_Leftwards_Arrow :
      constant Unicode_Char := 16#2347#;
   Apl_Functional_Symbol_Quad_Rightwards_Arrow :
      constant Unicode_Char := 16#2348#;
   Apl_Functional_Symbol_Circle_Backslash  : constant Unicode_Char := 16#2349#;
   Apl_Functional_Symbol_Down_Tack_Underbar :
      constant Unicode_Char := 16#234A#;
   Apl_Functional_Symbol_Delta_Stile       : constant Unicode_Char := 16#234B#;
   Apl_Functional_Symbol_Quad_Down_Caret   : constant Unicode_Char := 16#234C#;
   Apl_Functional_Symbol_Quad_Delta        : constant Unicode_Char := 16#234D#;
   Apl_Functional_Symbol_Down_Tack_Jot     : constant Unicode_Char := 16#234E#;
   Apl_Functional_Symbol_Upwards_Vane      : constant Unicode_Char := 16#234F#;
   Apl_Functional_Symbol_Quad_Upwards_Arrow :
      constant Unicode_Char := 16#2350#;
   Apl_Functional_Symbol_Up_Tack_Overbar   : constant Unicode_Char := 16#2351#;
   Apl_Functional_Symbol_Del_Stile         : constant Unicode_Char := 16#2352#;
   Apl_Functional_Symbol_Quad_Up_Caret     : constant Unicode_Char := 16#2353#;
   Apl_Functional_Symbol_Quad_Del          : constant Unicode_Char := 16#2354#;
   Apl_Functional_Symbol_Up_Tack_Jot       : constant Unicode_Char := 16#2355#;
   Apl_Functional_Symbol_Downwards_Vane    : constant Unicode_Char := 16#2356#;
   Apl_Functional_Symbol_Quad_Downwards_Arrow :
      constant Unicode_Char := 16#2357#;
   Apl_Functional_Symbol_Quote_Underbar    : constant Unicode_Char := 16#2358#;
   Apl_Functional_Symbol_Delta_Underbar    : constant Unicode_Char := 16#2359#;
   Apl_Functional_Symbol_Diamond_Underbar  : constant Unicode_Char := 16#235A#;
   Apl_Functional_Symbol_Jot_Underbar      : constant Unicode_Char := 16#235B#;
   Apl_Functional_Symbol_Circle_Underbar   : constant Unicode_Char := 16#235C#;
   Apl_Functional_Symbol_Up_Shoe_Jot       : constant Unicode_Char := 16#235D#;
   Apl_Functional_Symbol_Quote_Quad        : constant Unicode_Char := 16#235E#;
   Apl_Functional_Symbol_Circle_Star       : constant Unicode_Char := 16#235F#;
   Apl_Functional_Symbol_Quad_Colon        : constant Unicode_Char := 16#2360#;
   Apl_Functional_Symbol_Up_Tack_Diaeresis : constant Unicode_Char := 16#2361#;
   Apl_Functional_Symbol_Del_Diaeresis     : constant Unicode_Char := 16#2362#;
   Apl_Functional_Symbol_Star_Diaeresis    : constant Unicode_Char := 16#2363#;
   Apl_Functional_Symbol_Jot_Diaeresis     : constant Unicode_Char := 16#2364#;
   Apl_Functional_Symbol_Circle_Diaeresis  : constant Unicode_Char := 16#2365#;
   Apl_Functional_Symbol_Down_Shoe_Stile   : constant Unicode_Char := 16#2366#;
   Apl_Functional_Symbol_Left_Shoe_Stile   : constant Unicode_Char := 16#2367#;
   Apl_Functional_Symbol_Tilde_Diaeresis   : constant Unicode_Char := 16#2368#;
   Apl_Functional_Symbol_Greater_Than_Diaeresis :
      constant Unicode_Char := 16#2369#;
   Apl_Functional_Symbol_Comma_Bar         : constant Unicode_Char := 16#236A#;
   Apl_Functional_Symbol_Del_Tilde         : constant Unicode_Char := 16#236B#;
   Apl_Functional_Symbol_Zilde             : constant Unicode_Char := 16#236C#;
   Apl_Functional_Symbol_Stile_Tilde       : constant Unicode_Char := 16#236D#;
   Apl_Functional_Symbol_Semicolon_Underbar :
      constant Unicode_Char := 16#236E#;
   Apl_Functional_Symbol_Quad_Not_Equal    : constant Unicode_Char := 16#236F#;
   Apl_Functional_Symbol_Quad_Question     : constant Unicode_Char := 16#2370#;
   Apl_Functional_Symbol_Down_Caret_Tilde  : constant Unicode_Char := 16#2371#;
   Apl_Functional_Symbol_Up_Caret_Tilde    : constant Unicode_Char := 16#2372#;
   Apl_Functional_Symbol_Iota              : constant Unicode_Char := 16#2373#;
   Apl_Functional_Symbol_Rho               : constant Unicode_Char := 16#2374#;
   Apl_Functional_Symbol_Omega             : constant Unicode_Char := 16#2375#;
   Apl_Functional_Symbol_Alpha_Underbar    : constant Unicode_Char := 16#2376#;
   Apl_Functional_Symbol_Epsilon_Underbar  : constant Unicode_Char := 16#2377#;
   Apl_Functional_Symbol_Iota_Underbar     : constant Unicode_Char := 16#2378#;
   Apl_Functional_Symbol_Omega_Underbar    : constant Unicode_Char := 16#2379#;
   Apl_Functional_Symbol_Alpha             : constant Unicode_Char := 16#237A#;
   Not_Check_Mark                          : constant Unicode_Char := 16#237B#;
   Right_Angle_With_Downwards_Zigzag_Arrow : constant Unicode_Char := 16#237C#;
   Shouldered_Open_Box                     : constant Unicode_Char := 16#237D#;
   Bell_Symbol                             : constant Unicode_Char := 16#237E#;
   Vertical_Line_With_Middle_Dot           : constant Unicode_Char := 16#237F#;
   Insertion_Symbol                        : constant Unicode_Char := 16#2380#;
   Continuous_Underline_Symbol             : constant Unicode_Char := 16#2381#;
   Discontinuous_Underline_Symbol          : constant Unicode_Char := 16#2382#;
   Emphasis_Symbol                         : constant Unicode_Char := 16#2383#;
   Composition_Symbol                      : constant Unicode_Char := 16#2384#;
   White_Square_With_Centre_Vertical_Line  : constant Unicode_Char := 16#2385#;
   Enter_Symbol                            : constant Unicode_Char := 16#2386#;
   Alternative_Key_Symbol                  : constant Unicode_Char := 16#2387#;
   Helm_Symbol                             : constant Unicode_Char := 16#2388#;
   Circled_Horizontal_Bar_With_Notch       : constant Unicode_Char := 16#2389#;
   Circled_Triangle_Down                   : constant Unicode_Char := 16#238A#;
   Broken_Circle_With_Northwest_Arrow      : constant Unicode_Char := 16#238B#;
   Undo_Symbol                             : constant Unicode_Char := 16#238C#;
   Monostable_Symbol                       : constant Unicode_Char := 16#238D#;
   Hysteresis_Symbol                       : constant Unicode_Char := 16#238E#;
   Open_Circuit_Output_H_Type_Symbol       : constant Unicode_Char := 16#238F#;
   Open_Circuit_Output_L_Type_Symbol       : constant Unicode_Char := 16#2390#;
   Passive_Pull_Down_Output_Symbol         : constant Unicode_Char := 16#2391#;
   Passive_Pull_Up_Output_Symbol           : constant Unicode_Char := 16#2392#;
   Direct_Current_Symbol_Form_Two          : constant Unicode_Char := 16#2393#;
   Software_Function_Symbol                : constant Unicode_Char := 16#2394#;
   Apl_Functional_Symbol_Quad              : constant Unicode_Char := 16#2395#;
   Decimal_Separator_Key_Symbol            : constant Unicode_Char := 16#2396#;
   Previous_Page                           : constant Unicode_Char := 16#2397#;
   Next_Page                               : constant Unicode_Char := 16#2398#;
   Print_Screen_Symbol                     : constant Unicode_Char := 16#2399#;
   Clear_Screen_Symbol                     : constant Unicode_Char := 16#239A#;
   Left_Parenthesis_Upper_Hook             : constant Unicode_Char := 16#239B#;
   Left_Parenthesis_Extension              : constant Unicode_Char := 16#239C#;
   Left_Parenthesis_Lower_Hook             : constant Unicode_Char := 16#239D#;
   Right_Parenthesis_Upper_Hook            : constant Unicode_Char := 16#239E#;
   Right_Parenthesis_Extension             : constant Unicode_Char := 16#239F#;
   Right_Parenthesis_Lower_Hook            : constant Unicode_Char := 16#23A0#;
   Left_Square_Bracket_Upper_Corner        : constant Unicode_Char := 16#23A1#;
   Left_Square_Bracket_Extension           : constant Unicode_Char := 16#23A2#;
   Left_Square_Bracket_Lower_Corner        : constant Unicode_Char := 16#23A3#;
   Right_Square_Bracket_Upper_Corner       : constant Unicode_Char := 16#23A4#;
   Right_Square_Bracket_Extension          : constant Unicode_Char := 16#23A5#;
   Right_Square_Bracket_Lower_Corner       : constant Unicode_Char := 16#23A6#;
   Left_Curly_Bracket_Upper_Hook           : constant Unicode_Char := 16#23A7#;
   Left_Curly_Bracket_Middle_Piece         : constant Unicode_Char := 16#23A8#;
   Left_Curly_Bracket_Lower_Hook           : constant Unicode_Char := 16#23A9#;
   Curly_Bracket_Extension                 : constant Unicode_Char := 16#23AA#;
   Right_Curly_Bracket_Upper_Hook          : constant Unicode_Char := 16#23AB#;
   Right_Curly_Bracket_Middle_Piece        : constant Unicode_Char := 16#23AC#;
   Right_Curly_Bracket_Lower_Hook          : constant Unicode_Char := 16#23AD#;
   Integral_Extension                      : constant Unicode_Char := 16#23AE#;
   Horizontal_Line_Extension               : constant Unicode_Char := 16#23AF#;
   Upper_Left_Or_Lower_Right_Curly_Bracket_Section :
      constant Unicode_Char := 16#23B0#;
   Upper_Right_Or_Lower_Left_Curly_Bracket_Section :
      constant Unicode_Char := 16#23B1#;
   Summation_Top                           : constant Unicode_Char := 16#23B2#;
   Summation_Bottom                        : constant Unicode_Char := 16#23B3#;
   Top_Square_Bracket                      : constant Unicode_Char := 16#23B4#;
   Bottom_Square_Bracket                   : constant Unicode_Char := 16#23B5#;
   Bottom_Square_Bracket_Over_Top_Square_Bracket :
      constant Unicode_Char := 16#23B6#;
   Radical_Symbol_Bottom                   : constant Unicode_Char := 16#23B7#;
   Left_Vertical_Box_Line                  : constant Unicode_Char := 16#23B8#;
   Right_Vertical_Box_Line                 : constant Unicode_Char := 16#23B9#;
   Horizontal_Scan_Line_1                  : constant Unicode_Char := 16#23BA#;
   Horizontal_Scan_Line_3                  : constant Unicode_Char := 16#23BB#;
   Horizontal_Scan_Line_7                  : constant Unicode_Char := 16#23BC#;
   Horizontal_Scan_Line_9                  : constant Unicode_Char := 16#23BD#;
   Dentistry_Symbol_Light_Vertical_And_Top_Right :
      constant Unicode_Char := 16#23BE#;
   Dentistry_Symbol_Light_Vertical_And_Bottom_Right :
      constant Unicode_Char := 16#23BF#;
   Dentistry_Symbol_Light_Vertical_With_Circle :
      constant Unicode_Char := 16#23C0#;
   Dentistry_Symbol_Light_Down_And_Horizontal_With_Circle :
      constant Unicode_Char := 16#23C1#;
   Dentistry_Symbol_Light_Up_And_Horizontal_With_Circle :
      constant Unicode_Char := 16#23C2#;
   Dentistry_Symbol_Light_Vertical_With_Triangle :
      constant Unicode_Char := 16#23C3#;
   Dentistry_Symbol_Light_Down_And_Horizontal_With_Triangle :
      constant Unicode_Char := 16#23C4#;
   Dentistry_Symbol_Light_Up_And_Horizontal_With_Triangle :
      constant Unicode_Char := 16#23C5#;
   Dentistry_Symbol_Light_Vertical_And_Wave :
      constant Unicode_Char := 16#23C6#;
   Dentistry_Symbol_Light_Down_And_Horizontal_With_Wave :
      constant Unicode_Char := 16#23C7#;
   Dentistry_Symbol_Light_Up_And_Horizontal_With_Wave :
      constant Unicode_Char := 16#23C8#;
   Dentistry_Symbol_Light_Down_And_Horizontal :
      constant Unicode_Char := 16#23C9#;
   Dentistry_Symbol_Light_Up_And_Horizontal :
      constant Unicode_Char := 16#23CA#;
   Dentistry_Symbol_Light_Vertical_And_Top_Left :
      constant Unicode_Char := 16#23CB#;
   Dentistry_Symbol_Light_Vertical_And_Bottom_Left :
      constant Unicode_Char := 16#23CC#;
   Square_Foot                             : constant Unicode_Char := 16#23CD#;
   Return_Symbol                           : constant Unicode_Char := 16#23CE#;
   Eject_Symbol                            : constant Unicode_Char := 16#23CF#;
   Vertical_Line_Extension                 : constant Unicode_Char := 16#23D0#;
   Metrical_Breve                          : constant Unicode_Char := 16#23D1#;
   Metrical_Long_Over_Short                : constant Unicode_Char := 16#23D2#;
   Metrical_Short_Over_Long                : constant Unicode_Char := 16#23D3#;
   Metrical_Long_Over_Two_Shorts           : constant Unicode_Char := 16#23D4#;
   Metrical_Two_Shorts_Over_Long           : constant Unicode_Char := 16#23D5#;
   Metrical_Two_Shorts_Joined              : constant Unicode_Char := 16#23D6#;
   Metrical_Triseme                        : constant Unicode_Char := 16#23D7#;
   Metrical_Tetraseme                      : constant Unicode_Char := 16#23D8#;
   Metrical_Pentaseme                      : constant Unicode_Char := 16#23D9#;
   Earth_Ground                            : constant Unicode_Char := 16#23DA#;
   Fuse                                    : constant Unicode_Char := 16#23DB#;
   Top_Parenthesis                         : constant Unicode_Char := 16#23DC#;
   Bottom_Parenthesis                      : constant Unicode_Char := 16#23DD#;
   Top_Curly_Bracket                       : constant Unicode_Char := 16#23DE#;
   Bottom_Curly_Bracket                    : constant Unicode_Char := 16#23DF#;
   Top_Tortoise_Shell_Bracket              : constant Unicode_Char := 16#23E0#;
   Bottom_Tortoise_Shell_Bracket           : constant Unicode_Char := 16#23E1#;
   White_Trapezium                         : constant Unicode_Char := 16#23E2#;
   Benzene_Ring_With_Circle                : constant Unicode_Char := 16#23E3#;
   Straightness                            : constant Unicode_Char := 16#23E4#;
   Flatness                                : constant Unicode_Char := 16#23E5#;
   Ac_Current                              : constant Unicode_Char := 16#23E6#;
   Electrical_Intersection                 : constant Unicode_Char := 16#23E7#;
   Decimal_Exponent_Symbol                 : constant Unicode_Char := 16#23E8#;
   Black_Right_Pointing_Double_Triangle    : constant Unicode_Char := 16#23E9#;
   Black_Left_Pointing_Double_Triangle     : constant Unicode_Char := 16#23EA#;
   Black_Up_Pointing_Double_Triangle       : constant Unicode_Char := 16#23EB#;
   Black_Down_Pointing_Double_Triangle     : constant Unicode_Char := 16#23EC#;
   Black_Right_Pointing_Double_Triangle_With_Vertical_Bar :
      constant Unicode_Char := 16#23ED#;
   Black_Left_Pointing_Double_Triangle_With_Vertical_Bar :
      constant Unicode_Char := 16#23EE#;
   Black_Right_Pointing_Triangle_With_Double_Vertical_Bar :
      constant Unicode_Char := 16#23EF#;
   Alarm_Clock                             : constant Unicode_Char := 16#23F0#;
   Stopwatch                               : constant Unicode_Char := 16#23F1#;
   Timer_Clock                             : constant Unicode_Char := 16#23F2#;
   Hourglass_With_Flowing_Sand             : constant Unicode_Char := 16#23F3#;
   Black_Medium_Left_Pointing_Triangle     : constant Unicode_Char := 16#23F4#;
   Black_Medium_Right_Pointing_Triangle    : constant Unicode_Char := 16#23F5#;
   Black_Medium_Up_Pointing_Triangle       : constant Unicode_Char := 16#23F6#;
   Black_Medium_Down_Pointing_Triangle     : constant Unicode_Char := 16#23F7#;
   Double_Vertical_Bar                     : constant Unicode_Char := 16#23F8#;
   Black_Square_For_Stop                   : constant Unicode_Char := 16#23F9#;
   Black_Circle_For_Record                 : constant Unicode_Char := 16#23FA#;
end Unicode.Names.Miscellaneous_Technical;
