--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cham is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cham_Letter_A                           : constant Unicode_Char := 16#AA00#;
   Cham_Letter_I                           : constant Unicode_Char := 16#AA01#;
   Cham_Letter_U                           : constant Unicode_Char := 16#AA02#;
   Cham_Letter_E                           : constant Unicode_Char := 16#AA03#;
   Cham_Letter_Ai                          : constant Unicode_Char := 16#AA04#;
   Cham_Letter_O                           : constant Unicode_Char := 16#AA05#;
   Cham_Letter_Ka                          : constant Unicode_Char := 16#AA06#;
   Cham_Letter_Kha                         : constant Unicode_Char := 16#AA07#;
   Cham_Letter_Ga                          : constant Unicode_Char := 16#AA08#;
   Cham_Letter_Gha                         : constant Unicode_Char := 16#AA09#;
   Cham_Letter_Ngue                        : constant Unicode_Char := 16#AA0A#;
   Cham_Letter_Nga                         : constant Unicode_Char := 16#AA0B#;
   Cham_Letter_Cha                         : constant Unicode_Char := 16#AA0C#;
   Cham_Letter_Chha                        : constant Unicode_Char := 16#AA0D#;
   Cham_Letter_Ja                          : constant Unicode_Char := 16#AA0E#;
   Cham_Letter_Jha                         : constant Unicode_Char := 16#AA0F#;
   Cham_Letter_Nhue                        : constant Unicode_Char := 16#AA10#;
   Cham_Letter_Nha                         : constant Unicode_Char := 16#AA11#;
   Cham_Letter_Nhja                        : constant Unicode_Char := 16#AA12#;
   Cham_Letter_Ta                          : constant Unicode_Char := 16#AA13#;
   Cham_Letter_Tha                         : constant Unicode_Char := 16#AA14#;
   Cham_Letter_Da                          : constant Unicode_Char := 16#AA15#;
   Cham_Letter_Dha                         : constant Unicode_Char := 16#AA16#;
   Cham_Letter_Nue                         : constant Unicode_Char := 16#AA17#;
   Cham_Letter_Na                          : constant Unicode_Char := 16#AA18#;
   Cham_Letter_Dda                         : constant Unicode_Char := 16#AA19#;
   Cham_Letter_Pa                          : constant Unicode_Char := 16#AA1A#;
   Cham_Letter_Ppa                         : constant Unicode_Char := 16#AA1B#;
   Cham_Letter_Pha                         : constant Unicode_Char := 16#AA1C#;
   Cham_Letter_Ba                          : constant Unicode_Char := 16#AA1D#;
   Cham_Letter_Bha                         : constant Unicode_Char := 16#AA1E#;
   Cham_Letter_Mue                         : constant Unicode_Char := 16#AA1F#;
   Cham_Letter_Ma                          : constant Unicode_Char := 16#AA20#;
   Cham_Letter_Bba                         : constant Unicode_Char := 16#AA21#;
   Cham_Letter_Ya                          : constant Unicode_Char := 16#AA22#;
   Cham_Letter_Ra                          : constant Unicode_Char := 16#AA23#;
   Cham_Letter_La                          : constant Unicode_Char := 16#AA24#;
   Cham_Letter_Va                          : constant Unicode_Char := 16#AA25#;
   Cham_Letter_Ssa                         : constant Unicode_Char := 16#AA26#;
   Cham_Letter_Sa                          : constant Unicode_Char := 16#AA27#;
   Cham_Letter_Ha                          : constant Unicode_Char := 16#AA28#;
   Cham_Vowel_Sign_Aa                      : constant Unicode_Char := 16#AA29#;
   Cham_Vowel_Sign_I                       : constant Unicode_Char := 16#AA2A#;
   Cham_Vowel_Sign_Ii                      : constant Unicode_Char := 16#AA2B#;
   Cham_Vowel_Sign_Ei                      : constant Unicode_Char := 16#AA2C#;
   Cham_Vowel_Sign_U                       : constant Unicode_Char := 16#AA2D#;
   Cham_Vowel_Sign_Oe                      : constant Unicode_Char := 16#AA2E#;
   Cham_Vowel_Sign_O                       : constant Unicode_Char := 16#AA2F#;
   Cham_Vowel_Sign_Ai                      : constant Unicode_Char := 16#AA30#;
   Cham_Vowel_Sign_Au                      : constant Unicode_Char := 16#AA31#;
   Cham_Vowel_Sign_Ue                      : constant Unicode_Char := 16#AA32#;
   Cham_Consonant_Sign_Ya                  : constant Unicode_Char := 16#AA33#;
   Cham_Consonant_Sign_Ra                  : constant Unicode_Char := 16#AA34#;
   Cham_Consonant_Sign_La                  : constant Unicode_Char := 16#AA35#;
   Cham_Consonant_Sign_Wa                  : constant Unicode_Char := 16#AA36#;
   Cham_Letter_Final_K                     : constant Unicode_Char := 16#AA40#;
   Cham_Letter_Final_G                     : constant Unicode_Char := 16#AA41#;
   Cham_Letter_Final_Ng                    : constant Unicode_Char := 16#AA42#;
   Cham_Consonant_Sign_Final_Ng            : constant Unicode_Char := 16#AA43#;
   Cham_Letter_Final_Ch                    : constant Unicode_Char := 16#AA44#;
   Cham_Letter_Final_T                     : constant Unicode_Char := 16#AA45#;
   Cham_Letter_Final_N                     : constant Unicode_Char := 16#AA46#;
   Cham_Letter_Final_P                     : constant Unicode_Char := 16#AA47#;
   Cham_Letter_Final_Y                     : constant Unicode_Char := 16#AA48#;
   Cham_Letter_Final_R                     : constant Unicode_Char := 16#AA49#;
   Cham_Letter_Final_L                     : constant Unicode_Char := 16#AA4A#;
   Cham_Letter_Final_Ss                    : constant Unicode_Char := 16#AA4B#;
   Cham_Consonant_Sign_Final_M             : constant Unicode_Char := 16#AA4C#;
   Cham_Consonant_Sign_Final_H             : constant Unicode_Char := 16#AA4D#;
   Cham_Digit_Zero                         : constant Unicode_Char := 16#AA50#;
   Cham_Digit_One                          : constant Unicode_Char := 16#AA51#;
   Cham_Digit_Two                          : constant Unicode_Char := 16#AA52#;
   Cham_Digit_Three                        : constant Unicode_Char := 16#AA53#;
   Cham_Digit_Four                         : constant Unicode_Char := 16#AA54#;
   Cham_Digit_Five                         : constant Unicode_Char := 16#AA55#;
   Cham_Digit_Six                          : constant Unicode_Char := 16#AA56#;
   Cham_Digit_Seven                        : constant Unicode_Char := 16#AA57#;
   Cham_Digit_Eight                        : constant Unicode_Char := 16#AA58#;
   Cham_Digit_Nine                         : constant Unicode_Char := 16#AA59#;
   Cham_Punctuation_Spiral                 : constant Unicode_Char := 16#AA5C#;
   Cham_Punctuation_Danda                  : constant Unicode_Char := 16#AA5D#;
   Cham_Punctuation_Double_Danda           : constant Unicode_Char := 16#AA5E#;
   Cham_Punctuation_Triple_Danda           : constant Unicode_Char := 16#AA5F#;
end Unicode.Names.Cham;
