--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Sinhala is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Sinhala_Sign_Anusvaraya                 : constant Unicode_Char := 16#0D82#;
   Sinhala_Sign_Visargaya                  : constant Unicode_Char := 16#0D83#;
   Sinhala_Letter_Ayanna                   : constant Unicode_Char := 16#0D85#;
   Sinhala_Letter_Aayanna                  : constant Unicode_Char := 16#0D86#;
   Sinhala_Letter_Aeyanna                  : constant Unicode_Char := 16#0D87#;
   Sinhala_Letter_Aeeyanna                 : constant Unicode_Char := 16#0D88#;
   Sinhala_Letter_Iyanna                   : constant Unicode_Char := 16#0D89#;
   Sinhala_Letter_Iiyanna                  : constant Unicode_Char := 16#0D8A#;
   Sinhala_Letter_Uyanna                   : constant Unicode_Char := 16#0D8B#;
   Sinhala_Letter_Uuyanna                  : constant Unicode_Char := 16#0D8C#;
   Sinhala_Letter_Iruyanna                 : constant Unicode_Char := 16#0D8D#;
   Sinhala_Letter_Iruuyanna                : constant Unicode_Char := 16#0D8E#;
   Sinhala_Letter_Iluyanna                 : constant Unicode_Char := 16#0D8F#;
   Sinhala_Letter_Iluuyanna                : constant Unicode_Char := 16#0D90#;
   Sinhala_Letter_Eyanna                   : constant Unicode_Char := 16#0D91#;
   Sinhala_Letter_Eeyanna                  : constant Unicode_Char := 16#0D92#;
   Sinhala_Letter_Aiyanna                  : constant Unicode_Char := 16#0D93#;
   Sinhala_Letter_Oyanna                   : constant Unicode_Char := 16#0D94#;
   Sinhala_Letter_Ooyanna                  : constant Unicode_Char := 16#0D95#;
   Sinhala_Letter_Auyanna                  : constant Unicode_Char := 16#0D96#;
   Sinhala_Letter_Alpapraana_Kayanna       : constant Unicode_Char := 16#0D9A#;
   Sinhala_Letter_Mahaapraana_Kayanna      : constant Unicode_Char := 16#0D9B#;
   Sinhala_Letter_Alpapraana_Gayanna       : constant Unicode_Char := 16#0D9C#;
   Sinhala_Letter_Mahaapraana_Gayanna      : constant Unicode_Char := 16#0D9D#;
   Sinhala_Letter_Kantaja_Naasikyaya       : constant Unicode_Char := 16#0D9E#;
   Sinhala_Letter_Sanyaka_Gayanna          : constant Unicode_Char := 16#0D9F#;
   Sinhala_Letter_Alpapraana_Cayanna       : constant Unicode_Char := 16#0DA0#;
   Sinhala_Letter_Mahaapraana_Cayanna      : constant Unicode_Char := 16#0DA1#;
   Sinhala_Letter_Alpapraana_Jayanna       : constant Unicode_Char := 16#0DA2#;
   Sinhala_Letter_Mahaapraana_Jayanna      : constant Unicode_Char := 16#0DA3#;
   Sinhala_Letter_Taaluja_Naasikyaya       : constant Unicode_Char := 16#0DA4#;
   Sinhala_Letter_Taaluja_Sanyooga_Naaksikyaya :
      constant Unicode_Char := 16#0DA5#;
   Sinhala_Letter_Sanyaka_Jayanna          : constant Unicode_Char := 16#0DA6#;
   Sinhala_Letter_Alpapraana_Ttayanna      : constant Unicode_Char := 16#0DA7#;
   Sinhala_Letter_Mahaapraana_Ttayanna     : constant Unicode_Char := 16#0DA8#;
   Sinhala_Letter_Alpapraana_Ddayanna      : constant Unicode_Char := 16#0DA9#;
   Sinhala_Letter_Mahaapraana_Ddayanna     : constant Unicode_Char := 16#0DAA#;
   Sinhala_Letter_Muurdhaja_Nayanna        : constant Unicode_Char := 16#0DAB#;
   Sinhala_Letter_Sanyaka_Ddayanna         : constant Unicode_Char := 16#0DAC#;
   Sinhala_Letter_Alpapraana_Tayanna       : constant Unicode_Char := 16#0DAD#;
   Sinhala_Letter_Mahaapraana_Tayanna      : constant Unicode_Char := 16#0DAE#;
   Sinhala_Letter_Alpapraana_Dayanna       : constant Unicode_Char := 16#0DAF#;
   Sinhala_Letter_Mahaapraana_Dayanna      : constant Unicode_Char := 16#0DB0#;
   Sinhala_Letter_Dantaja_Nayanna          : constant Unicode_Char := 16#0DB1#;
   Sinhala_Letter_Sanyaka_Dayanna          : constant Unicode_Char := 16#0DB3#;
   Sinhala_Letter_Alpapraana_Payanna       : constant Unicode_Char := 16#0DB4#;
   Sinhala_Letter_Mahaapraana_Payanna      : constant Unicode_Char := 16#0DB5#;
   Sinhala_Letter_Alpapraana_Bayanna       : constant Unicode_Char := 16#0DB6#;
   Sinhala_Letter_Mahaapraana_Bayanna      : constant Unicode_Char := 16#0DB7#;
   Sinhala_Letter_Mayanna                  : constant Unicode_Char := 16#0DB8#;
   Sinhala_Letter_Amba_Bayanna             : constant Unicode_Char := 16#0DB9#;
   Sinhala_Letter_Yayanna                  : constant Unicode_Char := 16#0DBA#;
   Sinhala_Letter_Rayanna                  : constant Unicode_Char := 16#0DBB#;
   Sinhala_Letter_Dantaja_Layanna          : constant Unicode_Char := 16#0DBD#;
   Sinhala_Letter_Vayanna                  : constant Unicode_Char := 16#0DC0#;
   Sinhala_Letter_Taaluja_Sayanna          : constant Unicode_Char := 16#0DC1#;
   Sinhala_Letter_Muurdhaja_Sayanna        : constant Unicode_Char := 16#0DC2#;
   Sinhala_Letter_Dantaja_Sayanna          : constant Unicode_Char := 16#0DC3#;
   Sinhala_Letter_Hayanna                  : constant Unicode_Char := 16#0DC4#;
   Sinhala_Letter_Muurdhaja_Layanna        : constant Unicode_Char := 16#0DC5#;
   Sinhala_Letter_Fayanna                  : constant Unicode_Char := 16#0DC6#;
   Sinhala_Sign_Al_Lakuna                  : constant Unicode_Char := 16#0DCA#;
   Sinhala_Vowel_Sign_Aela_Pilla           : constant Unicode_Char := 16#0DCF#;
   Sinhala_Vowel_Sign_Ketti_Aeda_Pilla     : constant Unicode_Char := 16#0DD0#;
   Sinhala_Vowel_Sign_Diga_Aeda_Pilla      : constant Unicode_Char := 16#0DD1#;
   Sinhala_Vowel_Sign_Ketti_Is_Pilla       : constant Unicode_Char := 16#0DD2#;
   Sinhala_Vowel_Sign_Diga_Is_Pilla        : constant Unicode_Char := 16#0DD3#;
   Sinhala_Vowel_Sign_Ketti_Paa_Pilla      : constant Unicode_Char := 16#0DD4#;
   Sinhala_Vowel_Sign_Diga_Paa_Pilla       : constant Unicode_Char := 16#0DD6#;
   Sinhala_Vowel_Sign_Gaetta_Pilla         : constant Unicode_Char := 16#0DD8#;
   Sinhala_Vowel_Sign_Kombuva              : constant Unicode_Char := 16#0DD9#;
   Sinhala_Vowel_Sign_Diga_Kombuva         : constant Unicode_Char := 16#0DDA#;
   Sinhala_Vowel_Sign_Kombu_Deka           : constant Unicode_Char := 16#0DDB#;
   Sinhala_Vowel_Sign_Kombuva_Haa_Aela_Pilla :
      constant Unicode_Char := 16#0DDC#;
   Sinhala_Vowel_Sign_Kombuva_Haa_Diga_Aela_Pilla :
      constant Unicode_Char := 16#0DDD#;
   Sinhala_Vowel_Sign_Kombuva_Haa_Gayanukitta :
      constant Unicode_Char := 16#0DDE#;
   Sinhala_Vowel_Sign_Gayanukitta          : constant Unicode_Char := 16#0DDF#;
   Sinhala_Lith_Digit_Zero                 : constant Unicode_Char := 16#0DE6#;
   Sinhala_Lith_Digit_One                  : constant Unicode_Char := 16#0DE7#;
   Sinhala_Lith_Digit_Two                  : constant Unicode_Char := 16#0DE8#;
   Sinhala_Lith_Digit_Three                : constant Unicode_Char := 16#0DE9#;
   Sinhala_Lith_Digit_Four                 : constant Unicode_Char := 16#0DEA#;
   Sinhala_Lith_Digit_Five                 : constant Unicode_Char := 16#0DEB#;
   Sinhala_Lith_Digit_Six                  : constant Unicode_Char := 16#0DEC#;
   Sinhala_Lith_Digit_Seven                : constant Unicode_Char := 16#0DED#;
   Sinhala_Lith_Digit_Eight                : constant Unicode_Char := 16#0DEE#;
   Sinhala_Lith_Digit_Nine                 : constant Unicode_Char := 16#0DEF#;
   Sinhala_Vowel_Sign_Diga_Gaetta_Pilla    : constant Unicode_Char := 16#0DF2#;
   Sinhala_Vowel_Sign_Diga_Gayanukitta     : constant Unicode_Char := 16#0DF3#;
   Sinhala_Punctuation_Kunddaliya          : constant Unicode_Char := 16#0DF4#;
end Unicode.Names.Sinhala;
