--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Caucasian_Albanian is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Caucasian_Albanian_Letter_Alt           :
      constant Unicode_Char := 16#10530#;
   Caucasian_Albanian_Letter_Bet           :
      constant Unicode_Char := 16#10531#;
   Caucasian_Albanian_Letter_Gim           :
      constant Unicode_Char := 16#10532#;
   Caucasian_Albanian_Letter_Dat           :
      constant Unicode_Char := 16#10533#;
   Caucasian_Albanian_Letter_Eb            :
      constant Unicode_Char := 16#10534#;
   Caucasian_Albanian_Letter_Zarl          :
      constant Unicode_Char := 16#10535#;
   Caucasian_Albanian_Letter_Eyn           :
      constant Unicode_Char := 16#10536#;
   Caucasian_Albanian_Letter_Zhil          :
      constant Unicode_Char := 16#10537#;
   Caucasian_Albanian_Letter_Tas           :
      constant Unicode_Char := 16#10538#;
   Caucasian_Albanian_Letter_Cha           :
      constant Unicode_Char := 16#10539#;
   Caucasian_Albanian_Letter_Yowd          :
      constant Unicode_Char := 16#1053A#;
   Caucasian_Albanian_Letter_Zha           :
      constant Unicode_Char := 16#1053B#;
   Caucasian_Albanian_Letter_Irb           :
      constant Unicode_Char := 16#1053C#;
   Caucasian_Albanian_Letter_Sha           :
      constant Unicode_Char := 16#1053D#;
   Caucasian_Albanian_Letter_Lan           :
      constant Unicode_Char := 16#1053E#;
   Caucasian_Albanian_Letter_Inya          :
      constant Unicode_Char := 16#1053F#;
   Caucasian_Albanian_Letter_Xeyn          :
      constant Unicode_Char := 16#10540#;
   Caucasian_Albanian_Letter_Dyan          :
      constant Unicode_Char := 16#10541#;
   Caucasian_Albanian_Letter_Car           :
      constant Unicode_Char := 16#10542#;
   Caucasian_Albanian_Letter_Jhox          :
      constant Unicode_Char := 16#10543#;
   Caucasian_Albanian_Letter_Kar           :
      constant Unicode_Char := 16#10544#;
   Caucasian_Albanian_Letter_Lyit          :
      constant Unicode_Char := 16#10545#;
   Caucasian_Albanian_Letter_Heyt          :
      constant Unicode_Char := 16#10546#;
   Caucasian_Albanian_Letter_Qay           :
      constant Unicode_Char := 16#10547#;
   Caucasian_Albanian_Letter_Aor           :
      constant Unicode_Char := 16#10548#;
   Caucasian_Albanian_Letter_Choy          :
      constant Unicode_Char := 16#10549#;
   Caucasian_Albanian_Letter_Chi           :
      constant Unicode_Char := 16#1054A#;
   Caucasian_Albanian_Letter_Cyay          :
      constant Unicode_Char := 16#1054B#;
   Caucasian_Albanian_Letter_Maq           :
      constant Unicode_Char := 16#1054C#;
   Caucasian_Albanian_Letter_Qar           :
      constant Unicode_Char := 16#1054D#;
   Caucasian_Albanian_Letter_Nowc          :
      constant Unicode_Char := 16#1054E#;
   Caucasian_Albanian_Letter_Dzyay         :
      constant Unicode_Char := 16#1054F#;
   Caucasian_Albanian_Letter_Shak          :
      constant Unicode_Char := 16#10550#;
   Caucasian_Albanian_Letter_Jayn          :
      constant Unicode_Char := 16#10551#;
   Caucasian_Albanian_Letter_On            :
      constant Unicode_Char := 16#10552#;
   Caucasian_Albanian_Letter_Tyay          :
      constant Unicode_Char := 16#10553#;
   Caucasian_Albanian_Letter_Fam           :
      constant Unicode_Char := 16#10554#;
   Caucasian_Albanian_Letter_Dzay          :
      constant Unicode_Char := 16#10555#;
   Caucasian_Albanian_Letter_Chat          :
      constant Unicode_Char := 16#10556#;
   Caucasian_Albanian_Letter_Pen           :
      constant Unicode_Char := 16#10557#;
   Caucasian_Albanian_Letter_Gheys         :
      constant Unicode_Char := 16#10558#;
   Caucasian_Albanian_Letter_Rat           :
      constant Unicode_Char := 16#10559#;
   Caucasian_Albanian_Letter_Seyk          :
      constant Unicode_Char := 16#1055A#;
   Caucasian_Albanian_Letter_Veyz          :
      constant Unicode_Char := 16#1055B#;
   Caucasian_Albanian_Letter_Tiwr          :
      constant Unicode_Char := 16#1055C#;
   Caucasian_Albanian_Letter_Shoy          :
      constant Unicode_Char := 16#1055D#;
   Caucasian_Albanian_Letter_Iwn           :
      constant Unicode_Char := 16#1055E#;
   Caucasian_Albanian_Letter_Cyaw          :
      constant Unicode_Char := 16#1055F#;
   Caucasian_Albanian_Letter_Cayn          :
      constant Unicode_Char := 16#10560#;
   Caucasian_Albanian_Letter_Yayd          :
      constant Unicode_Char := 16#10561#;
   Caucasian_Albanian_Letter_Piwr          :
      constant Unicode_Char := 16#10562#;
   Caucasian_Albanian_Letter_Kiw           :
      constant Unicode_Char := 16#10563#;
   Caucasian_Albanian_Citation_Mark        :
      constant Unicode_Char := 16#1056F#;
end Unicode.Names.Caucasian_Albanian;
