--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Khojki is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Khojki_Letter_A                         :
      constant Unicode_Char := 16#11200#;
   Khojki_Letter_Aa                        :
      constant Unicode_Char := 16#11201#;
   Khojki_Letter_I                         :
      constant Unicode_Char := 16#11202#;
   Khojki_Letter_U                         :
      constant Unicode_Char := 16#11203#;
   Khojki_Letter_E                         :
      constant Unicode_Char := 16#11204#;
   Khojki_Letter_Ai                        :
      constant Unicode_Char := 16#11205#;
   Khojki_Letter_O                         :
      constant Unicode_Char := 16#11206#;
   Khojki_Letter_Au                        :
      constant Unicode_Char := 16#11207#;
   Khojki_Letter_Ka                        :
      constant Unicode_Char := 16#11208#;
   Khojki_Letter_Kha                       :
      constant Unicode_Char := 16#11209#;
   Khojki_Letter_Ga                        :
      constant Unicode_Char := 16#1120A#;
   Khojki_Letter_Gga                       :
      constant Unicode_Char := 16#1120B#;
   Khojki_Letter_Gha                       :
      constant Unicode_Char := 16#1120C#;
   Khojki_Letter_Nga                       :
      constant Unicode_Char := 16#1120D#;
   Khojki_Letter_Ca                        :
      constant Unicode_Char := 16#1120E#;
   Khojki_Letter_Cha                       :
      constant Unicode_Char := 16#1120F#;
   Khojki_Letter_Ja                        :
      constant Unicode_Char := 16#11210#;
   Khojki_Letter_Jja                       :
      constant Unicode_Char := 16#11211#;
   Khojki_Letter_Nya                       :
      constant Unicode_Char := 16#11213#;
   Khojki_Letter_Tta                       :
      constant Unicode_Char := 16#11214#;
   Khojki_Letter_Ttha                      :
      constant Unicode_Char := 16#11215#;
   Khojki_Letter_Dda                       :
      constant Unicode_Char := 16#11216#;
   Khojki_Letter_Ddha                      :
      constant Unicode_Char := 16#11217#;
   Khojki_Letter_Nna                       :
      constant Unicode_Char := 16#11218#;
   Khojki_Letter_Ta                        :
      constant Unicode_Char := 16#11219#;
   Khojki_Letter_Tha                       :
      constant Unicode_Char := 16#1121A#;
   Khojki_Letter_Da                        :
      constant Unicode_Char := 16#1121B#;
   Khojki_Letter_Ddda                      :
      constant Unicode_Char := 16#1121C#;
   Khojki_Letter_Dha                       :
      constant Unicode_Char := 16#1121D#;
   Khojki_Letter_Na                        :
      constant Unicode_Char := 16#1121E#;
   Khojki_Letter_Pa                        :
      constant Unicode_Char := 16#1121F#;
   Khojki_Letter_Pha                       :
      constant Unicode_Char := 16#11220#;
   Khojki_Letter_Ba                        :
      constant Unicode_Char := 16#11221#;
   Khojki_Letter_Bba                       :
      constant Unicode_Char := 16#11222#;
   Khojki_Letter_Bha                       :
      constant Unicode_Char := 16#11223#;
   Khojki_Letter_Ma                        :
      constant Unicode_Char := 16#11224#;
   Khojki_Letter_Ya                        :
      constant Unicode_Char := 16#11225#;
   Khojki_Letter_Ra                        :
      constant Unicode_Char := 16#11226#;
   Khojki_Letter_La                        :
      constant Unicode_Char := 16#11227#;
   Khojki_Letter_Va                        :
      constant Unicode_Char := 16#11228#;
   Khojki_Letter_Sa                        :
      constant Unicode_Char := 16#11229#;
   Khojki_Letter_Ha                        :
      constant Unicode_Char := 16#1122A#;
   Khojki_Letter_Lla                       :
      constant Unicode_Char := 16#1122B#;
   Khojki_Vowel_Sign_Aa                    :
      constant Unicode_Char := 16#1122C#;
   Khojki_Vowel_Sign_I                     :
      constant Unicode_Char := 16#1122D#;
   Khojki_Vowel_Sign_Ii                    :
      constant Unicode_Char := 16#1122E#;
   Khojki_Vowel_Sign_U                     :
      constant Unicode_Char := 16#1122F#;
   Khojki_Vowel_Sign_E                     :
      constant Unicode_Char := 16#11230#;
   Khojki_Vowel_Sign_Ai                    :
      constant Unicode_Char := 16#11231#;
   Khojki_Vowel_Sign_O                     :
      constant Unicode_Char := 16#11232#;
   Khojki_Vowel_Sign_Au                    :
      constant Unicode_Char := 16#11233#;
   Khojki_Sign_Anusvara                    :
      constant Unicode_Char := 16#11234#;
   Khojki_Sign_Virama                      :
      constant Unicode_Char := 16#11235#;
   Khojki_Sign_Nukta                       :
      constant Unicode_Char := 16#11236#;
   Khojki_Sign_Shadda                      :
      constant Unicode_Char := 16#11237#;
   Khojki_Danda                            :
      constant Unicode_Char := 16#11238#;
   Khojki_Double_Danda                     :
      constant Unicode_Char := 16#11239#;
   Khojki_Word_Separator                   :
      constant Unicode_Char := 16#1123A#;
   Khojki_Section_Mark                     :
      constant Unicode_Char := 16#1123B#;
   Khojki_Double_Section_Mark              :
      constant Unicode_Char := 16#1123C#;
   Khojki_Abbreviation_Sign                :
      constant Unicode_Char := 16#1123D#;
end Unicode.Names.Khojki;
