--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Chakma is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Chakma_Sign_Candrabindu                 :
      constant Unicode_Char := 16#11100#;
   Chakma_Sign_Anusvara                    :
      constant Unicode_Char := 16#11101#;
   Chakma_Sign_Visarga                     :
      constant Unicode_Char := 16#11102#;
   Chakma_Letter_Aa                        :
      constant Unicode_Char := 16#11103#;
   Chakma_Letter_I                         :
      constant Unicode_Char := 16#11104#;
   Chakma_Letter_U                         :
      constant Unicode_Char := 16#11105#;
   Chakma_Letter_E                         :
      constant Unicode_Char := 16#11106#;
   Chakma_Letter_Kaa                       :
      constant Unicode_Char := 16#11107#;
   Chakma_Letter_Khaa                      :
      constant Unicode_Char := 16#11108#;
   Chakma_Letter_Gaa                       :
      constant Unicode_Char := 16#11109#;
   Chakma_Letter_Ghaa                      :
      constant Unicode_Char := 16#1110A#;
   Chakma_Letter_Ngaa                      :
      constant Unicode_Char := 16#1110B#;
   Chakma_Letter_Caa                       :
      constant Unicode_Char := 16#1110C#;
   Chakma_Letter_Chaa                      :
      constant Unicode_Char := 16#1110D#;
   Chakma_Letter_Jaa                       :
      constant Unicode_Char := 16#1110E#;
   Chakma_Letter_Jhaa                      :
      constant Unicode_Char := 16#1110F#;
   Chakma_Letter_Nyaa                      :
      constant Unicode_Char := 16#11110#;
   Chakma_Letter_Ttaa                      :
      constant Unicode_Char := 16#11111#;
   Chakma_Letter_Tthaa                     :
      constant Unicode_Char := 16#11112#;
   Chakma_Letter_Ddaa                      :
      constant Unicode_Char := 16#11113#;
   Chakma_Letter_Ddhaa                     :
      constant Unicode_Char := 16#11114#;
   Chakma_Letter_Nnaa                      :
      constant Unicode_Char := 16#11115#;
   Chakma_Letter_Taa                       :
      constant Unicode_Char := 16#11116#;
   Chakma_Letter_Thaa                      :
      constant Unicode_Char := 16#11117#;
   Chakma_Letter_Daa                       :
      constant Unicode_Char := 16#11118#;
   Chakma_Letter_Dhaa                      :
      constant Unicode_Char := 16#11119#;
   Chakma_Letter_Naa                       :
      constant Unicode_Char := 16#1111A#;
   Chakma_Letter_Paa                       :
      constant Unicode_Char := 16#1111B#;
   Chakma_Letter_Phaa                      :
      constant Unicode_Char := 16#1111C#;
   Chakma_Letter_Baa                       :
      constant Unicode_Char := 16#1111D#;
   Chakma_Letter_Bhaa                      :
      constant Unicode_Char := 16#1111E#;
   Chakma_Letter_Maa                       :
      constant Unicode_Char := 16#1111F#;
   Chakma_Letter_Yyaa                      :
      constant Unicode_Char := 16#11120#;
   Chakma_Letter_Yaa                       :
      constant Unicode_Char := 16#11121#;
   Chakma_Letter_Raa                       :
      constant Unicode_Char := 16#11122#;
   Chakma_Letter_Laa                       :
      constant Unicode_Char := 16#11123#;
   Chakma_Letter_Waa                       :
      constant Unicode_Char := 16#11124#;
   Chakma_Letter_Saa                       :
      constant Unicode_Char := 16#11125#;
   Chakma_Letter_Haa                       :
      constant Unicode_Char := 16#11126#;
   Chakma_Vowel_Sign_A                     :
      constant Unicode_Char := 16#11127#;
   Chakma_Vowel_Sign_I                     :
      constant Unicode_Char := 16#11128#;
   Chakma_Vowel_Sign_Ii                    :
      constant Unicode_Char := 16#11129#;
   Chakma_Vowel_Sign_U                     :
      constant Unicode_Char := 16#1112A#;
   Chakma_Vowel_Sign_Uu                    :
      constant Unicode_Char := 16#1112B#;
   Chakma_Vowel_Sign_E                     :
      constant Unicode_Char := 16#1112C#;
   Chakma_Vowel_Sign_Ai                    :
      constant Unicode_Char := 16#1112D#;
   Chakma_Vowel_Sign_O                     :
      constant Unicode_Char := 16#1112E#;
   Chakma_Vowel_Sign_Au                    :
      constant Unicode_Char := 16#1112F#;
   Chakma_Vowel_Sign_Oi                    :
      constant Unicode_Char := 16#11130#;
   Chakma_O_Mark                           :
      constant Unicode_Char := 16#11131#;
   Chakma_Au_Mark                          :
      constant Unicode_Char := 16#11132#;
   Chakma_Virama                           :
      constant Unicode_Char := 16#11133#;
   Chakma_Maayyaa                          :
      constant Unicode_Char := 16#11134#;
   Chakma_Digit_Zero                       :
      constant Unicode_Char := 16#11136#;
   Chakma_Digit_One                        :
      constant Unicode_Char := 16#11137#;
   Chakma_Digit_Two                        :
      constant Unicode_Char := 16#11138#;
   Chakma_Digit_Three                      :
      constant Unicode_Char := 16#11139#;
   Chakma_Digit_Four                       :
      constant Unicode_Char := 16#1113A#;
   Chakma_Digit_Five                       :
      constant Unicode_Char := 16#1113B#;
   Chakma_Digit_Six                        :
      constant Unicode_Char := 16#1113C#;
   Chakma_Digit_Seven                      :
      constant Unicode_Char := 16#1113D#;
   Chakma_Digit_Eight                      :
      constant Unicode_Char := 16#1113E#;
   Chakma_Digit_Nine                       :
      constant Unicode_Char := 16#1113F#;
   Chakma_Section_Mark                     :
      constant Unicode_Char := 16#11140#;
   Chakma_Danda                            :
      constant Unicode_Char := 16#11141#;
   Chakma_Double_Danda                     :
      constant Unicode_Char := 16#11142#;
   Chakma_Question_Mark                    :
      constant Unicode_Char := 16#11143#;
end Unicode.Names.Chakma;
