--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Phonetic_Ext_Sup is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Latin_Small_Letter_B_With_Palatal_Hook  : constant Unicode_Char := 16#1D80#;
   Latin_Small_Letter_D_With_Palatal_Hook  : constant Unicode_Char := 16#1D81#;
   Latin_Small_Letter_F_With_Palatal_Hook  : constant Unicode_Char := 16#1D82#;
   Latin_Small_Letter_G_With_Palatal_Hook  : constant Unicode_Char := 16#1D83#;
   Latin_Small_Letter_K_With_Palatal_Hook  : constant Unicode_Char := 16#1D84#;
   Latin_Small_Letter_L_With_Palatal_Hook  : constant Unicode_Char := 16#1D85#;
   Latin_Small_Letter_M_With_Palatal_Hook  : constant Unicode_Char := 16#1D86#;
   Latin_Small_Letter_N_With_Palatal_Hook  : constant Unicode_Char := 16#1D87#;
   Latin_Small_Letter_P_With_Palatal_Hook  : constant Unicode_Char := 16#1D88#;
   Latin_Small_Letter_R_With_Palatal_Hook  : constant Unicode_Char := 16#1D89#;
   Latin_Small_Letter_S_With_Palatal_Hook  : constant Unicode_Char := 16#1D8A#;
   Latin_Small_Letter_Esh_With_Palatal_Hook :
      constant Unicode_Char := 16#1D8B#;
   Latin_Small_Letter_V_With_Palatal_Hook  : constant Unicode_Char := 16#1D8C#;
   Latin_Small_Letter_X_With_Palatal_Hook  : constant Unicode_Char := 16#1D8D#;
   Latin_Small_Letter_Z_With_Palatal_Hook  : constant Unicode_Char := 16#1D8E#;
   Latin_Small_Letter_A_With_Retroflex_Hook :
      constant Unicode_Char := 16#1D8F#;
   Latin_Small_Letter_Alpha_With_Retroflex_Hook :
      constant Unicode_Char := 16#1D90#;
   Latin_Small_Letter_D_With_Hook_And_Tail : constant Unicode_Char := 16#1D91#;
   Latin_Small_Letter_E_With_Retroflex_Hook :
      constant Unicode_Char := 16#1D92#;
   Latin_Small_Letter_Open_E_With_Retroflex_Hook :
      constant Unicode_Char := 16#1D93#;
   Latin_Small_Letter_Reversed_Open_E_With_Retroflex_Hook :
      constant Unicode_Char := 16#1D94#;
   Latin_Small_Letter_Schwa_With_Retroflex_Hook :
      constant Unicode_Char := 16#1D95#;
   Latin_Small_Letter_I_With_Retroflex_Hook :
      constant Unicode_Char := 16#1D96#;
   Latin_Small_Letter_Open_O_With_Retroflex_Hook :
      constant Unicode_Char := 16#1D97#;
   Latin_Small_Letter_Esh_With_Retroflex_Hook :
      constant Unicode_Char := 16#1D98#;
   Latin_Small_Letter_U_With_Retroflex_Hook :
      constant Unicode_Char := 16#1D99#;
   Latin_Small_Letter_Ezh_With_Retroflex_Hook :
      constant Unicode_Char := 16#1D9A#;
   Modifier_Letter_Small_Turned_Alpha      : constant Unicode_Char := 16#1D9B#;
   Modifier_Letter_Small_C                 : constant Unicode_Char := 16#1D9C#;
   Modifier_Letter_Small_C_With_Curl       : constant Unicode_Char := 16#1D9D#;
   Modifier_Letter_Small_Eth               : constant Unicode_Char := 16#1D9E#;
   Modifier_Letter_Small_Reversed_Open_E   : constant Unicode_Char := 16#1D9F#;
   Modifier_Letter_Small_F                 : constant Unicode_Char := 16#1DA0#;
   Modifier_Letter_Small_Dotless_J_With_Stroke :
      constant Unicode_Char := 16#1DA1#;
   Modifier_Letter_Small_Script_G          : constant Unicode_Char := 16#1DA2#;
   Modifier_Letter_Small_Turned_H          : constant Unicode_Char := 16#1DA3#;
   Modifier_Letter_Small_I_With_Stroke     : constant Unicode_Char := 16#1DA4#;
   Modifier_Letter_Small_Iota              : constant Unicode_Char := 16#1DA5#;
   Modifier_Letter_Small_Capital_I         : constant Unicode_Char := 16#1DA6#;
   Modifier_Letter_Small_Capital_I_With_Stroke :
      constant Unicode_Char := 16#1DA7#;
   Modifier_Letter_Small_J_With_Crossed_Tail :
      constant Unicode_Char := 16#1DA8#;
   Modifier_Letter_Small_L_With_Retroflex_Hook :
      constant Unicode_Char := 16#1DA9#;
   Modifier_Letter_Small_L_With_Palatal_Hook :
      constant Unicode_Char := 16#1DAA#;
   Modifier_Letter_Small_Capital_L         : constant Unicode_Char := 16#1DAB#;
   Modifier_Letter_Small_M_With_Hook       : constant Unicode_Char := 16#1DAC#;
   Modifier_Letter_Small_Turned_M_With_Long_Leg :
      constant Unicode_Char := 16#1DAD#;
   Modifier_Letter_Small_N_With_Left_Hook  : constant Unicode_Char := 16#1DAE#;
   Modifier_Letter_Small_N_With_Retroflex_Hook :
      constant Unicode_Char := 16#1DAF#;
   Modifier_Letter_Small_Capital_N         : constant Unicode_Char := 16#1DB0#;
   Modifier_Letter_Small_Barred_O          : constant Unicode_Char := 16#1DB1#;
   Modifier_Letter_Small_Phi               : constant Unicode_Char := 16#1DB2#;
   Modifier_Letter_Small_S_With_Hook       : constant Unicode_Char := 16#1DB3#;
   Modifier_Letter_Small_Esh               : constant Unicode_Char := 16#1DB4#;
   Modifier_Letter_Small_T_With_Palatal_Hook :
      constant Unicode_Char := 16#1DB5#;
   Modifier_Letter_Small_U_Bar             : constant Unicode_Char := 16#1DB6#;
   Modifier_Letter_Small_Upsilon           : constant Unicode_Char := 16#1DB7#;
   Modifier_Letter_Small_Capital_U         : constant Unicode_Char := 16#1DB8#;
   Modifier_Letter_Small_V_With_Hook       : constant Unicode_Char := 16#1DB9#;
   Modifier_Letter_Small_Turned_V          : constant Unicode_Char := 16#1DBA#;
   Modifier_Letter_Small_Z                 : constant Unicode_Char := 16#1DBB#;
   Modifier_Letter_Small_Z_With_Retroflex_Hook :
      constant Unicode_Char := 16#1DBC#;
   Modifier_Letter_Small_Z_With_Curl       : constant Unicode_Char := 16#1DBD#;
   Modifier_Letter_Small_Ezh               : constant Unicode_Char := 16#1DBE#;
   Modifier_Letter_Small_Theta             : constant Unicode_Char := 16#1DBF#;
end Unicode.Names.Phonetic_Ext_Sup;
