--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cypriot_Syllabary is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cypriot_Syllable_A                      :
      constant Unicode_Char := 16#10800#;
   Cypriot_Syllable_E                      :
      constant Unicode_Char := 16#10801#;
   Cypriot_Syllable_I                      :
      constant Unicode_Char := 16#10802#;
   Cypriot_Syllable_O                      :
      constant Unicode_Char := 16#10803#;
   Cypriot_Syllable_U                      :
      constant Unicode_Char := 16#10804#;
   Cypriot_Syllable_Ja                     :
      constant Unicode_Char := 16#10805#;
   Cypriot_Syllable_Jo                     :
      constant Unicode_Char := 16#10808#;
   Cypriot_Syllable_Ka                     :
      constant Unicode_Char := 16#1080A#;
   Cypriot_Syllable_Ke                     :
      constant Unicode_Char := 16#1080B#;
   Cypriot_Syllable_Ki                     :
      constant Unicode_Char := 16#1080C#;
   Cypriot_Syllable_Ko                     :
      constant Unicode_Char := 16#1080D#;
   Cypriot_Syllable_Ku                     :
      constant Unicode_Char := 16#1080E#;
   Cypriot_Syllable_La                     :
      constant Unicode_Char := 16#1080F#;
   Cypriot_Syllable_Le                     :
      constant Unicode_Char := 16#10810#;
   Cypriot_Syllable_Li                     :
      constant Unicode_Char := 16#10811#;
   Cypriot_Syllable_Lo                     :
      constant Unicode_Char := 16#10812#;
   Cypriot_Syllable_Lu                     :
      constant Unicode_Char := 16#10813#;
   Cypriot_Syllable_Ma                     :
      constant Unicode_Char := 16#10814#;
   Cypriot_Syllable_Me                     :
      constant Unicode_Char := 16#10815#;
   Cypriot_Syllable_Mi                     :
      constant Unicode_Char := 16#10816#;
   Cypriot_Syllable_Mo                     :
      constant Unicode_Char := 16#10817#;
   Cypriot_Syllable_Mu                     :
      constant Unicode_Char := 16#10818#;
   Cypriot_Syllable_Na                     :
      constant Unicode_Char := 16#10819#;
   Cypriot_Syllable_Ne                     :
      constant Unicode_Char := 16#1081A#;
   Cypriot_Syllable_Ni                     :
      constant Unicode_Char := 16#1081B#;
   Cypriot_Syllable_No                     :
      constant Unicode_Char := 16#1081C#;
   Cypriot_Syllable_Nu                     :
      constant Unicode_Char := 16#1081D#;
   Cypriot_Syllable_Pa                     :
      constant Unicode_Char := 16#1081E#;
   Cypriot_Syllable_Pe                     :
      constant Unicode_Char := 16#1081F#;
   Cypriot_Syllable_Pi                     :
      constant Unicode_Char := 16#10820#;
   Cypriot_Syllable_Po                     :
      constant Unicode_Char := 16#10821#;
   Cypriot_Syllable_Pu                     :
      constant Unicode_Char := 16#10822#;
   Cypriot_Syllable_Ra                     :
      constant Unicode_Char := 16#10823#;
   Cypriot_Syllable_Re                     :
      constant Unicode_Char := 16#10824#;
   Cypriot_Syllable_Ri                     :
      constant Unicode_Char := 16#10825#;
   Cypriot_Syllable_Ro                     :
      constant Unicode_Char := 16#10826#;
   Cypriot_Syllable_Ru                     :
      constant Unicode_Char := 16#10827#;
   Cypriot_Syllable_Sa                     :
      constant Unicode_Char := 16#10828#;
   Cypriot_Syllable_Se                     :
      constant Unicode_Char := 16#10829#;
   Cypriot_Syllable_Si                     :
      constant Unicode_Char := 16#1082A#;
   Cypriot_Syllable_So                     :
      constant Unicode_Char := 16#1082B#;
   Cypriot_Syllable_Su                     :
      constant Unicode_Char := 16#1082C#;
   Cypriot_Syllable_Ta                     :
      constant Unicode_Char := 16#1082D#;
   Cypriot_Syllable_Te                     :
      constant Unicode_Char := 16#1082E#;
   Cypriot_Syllable_Ti                     :
      constant Unicode_Char := 16#1082F#;
   Cypriot_Syllable_To                     :
      constant Unicode_Char := 16#10830#;
   Cypriot_Syllable_Tu                     :
      constant Unicode_Char := 16#10831#;
   Cypriot_Syllable_Wa                     :
      constant Unicode_Char := 16#10832#;
   Cypriot_Syllable_We                     :
      constant Unicode_Char := 16#10833#;
   Cypriot_Syllable_Wi                     :
      constant Unicode_Char := 16#10834#;
   Cypriot_Syllable_Wo                     :
      constant Unicode_Char := 16#10835#;
   Cypriot_Syllable_Xa                     :
      constant Unicode_Char := 16#10837#;
   Cypriot_Syllable_Xe                     :
      constant Unicode_Char := 16#10838#;
   Cypriot_Syllable_Za                     :
      constant Unicode_Char := 16#1083C#;
   Cypriot_Syllable_Zo                     :
      constant Unicode_Char := 16#1083F#;
end Unicode.Names.Cypriot_Syllabary;
