--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Linear_A is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Linear_A_Sign_Ab001                     :
      constant Unicode_Char := 16#10600#;
   Linear_A_Sign_Ab002                     :
      constant Unicode_Char := 16#10601#;
   Linear_A_Sign_Ab003                     :
      constant Unicode_Char := 16#10602#;
   Linear_A_Sign_Ab004                     :
      constant Unicode_Char := 16#10603#;
   Linear_A_Sign_Ab005                     :
      constant Unicode_Char := 16#10604#;
   Linear_A_Sign_Ab006                     :
      constant Unicode_Char := 16#10605#;
   Linear_A_Sign_Ab007                     :
      constant Unicode_Char := 16#10606#;
   Linear_A_Sign_Ab008                     :
      constant Unicode_Char := 16#10607#;
   Linear_A_Sign_Ab009                     :
      constant Unicode_Char := 16#10608#;
   Linear_A_Sign_Ab010                     :
      constant Unicode_Char := 16#10609#;
   Linear_A_Sign_Ab011                     :
      constant Unicode_Char := 16#1060A#;
   Linear_A_Sign_Ab013                     :
      constant Unicode_Char := 16#1060B#;
   Linear_A_Sign_Ab016                     :
      constant Unicode_Char := 16#1060C#;
   Linear_A_Sign_Ab017                     :
      constant Unicode_Char := 16#1060D#;
   Linear_A_Sign_Ab020                     :
      constant Unicode_Char := 16#1060E#;
   Linear_A_Sign_Ab021                     :
      constant Unicode_Char := 16#1060F#;
   Linear_A_Sign_Ab021f                    :
      constant Unicode_Char := 16#10610#;
   Linear_A_Sign_Ab021m                    :
      constant Unicode_Char := 16#10611#;
   Linear_A_Sign_Ab022                     :
      constant Unicode_Char := 16#10612#;
   Linear_A_Sign_Ab022f                    :
      constant Unicode_Char := 16#10613#;
   Linear_A_Sign_Ab022m                    :
      constant Unicode_Char := 16#10614#;
   Linear_A_Sign_Ab023                     :
      constant Unicode_Char := 16#10615#;
   Linear_A_Sign_Ab023m                    :
      constant Unicode_Char := 16#10616#;
   Linear_A_Sign_Ab024                     :
      constant Unicode_Char := 16#10617#;
   Linear_A_Sign_Ab026                     :
      constant Unicode_Char := 16#10618#;
   Linear_A_Sign_Ab027                     :
      constant Unicode_Char := 16#10619#;
   Linear_A_Sign_Ab028                     :
      constant Unicode_Char := 16#1061A#;
   Linear_A_Sign_A028b                     :
      constant Unicode_Char := 16#1061B#;
   Linear_A_Sign_Ab029                     :
      constant Unicode_Char := 16#1061C#;
   Linear_A_Sign_Ab030                     :
      constant Unicode_Char := 16#1061D#;
   Linear_A_Sign_Ab031                     :
      constant Unicode_Char := 16#1061E#;
   Linear_A_Sign_Ab034                     :
      constant Unicode_Char := 16#1061F#;
   Linear_A_Sign_Ab037                     :
      constant Unicode_Char := 16#10620#;
   Linear_A_Sign_Ab038                     :
      constant Unicode_Char := 16#10621#;
   Linear_A_Sign_Ab039                     :
      constant Unicode_Char := 16#10622#;
   Linear_A_Sign_Ab040                     :
      constant Unicode_Char := 16#10623#;
   Linear_A_Sign_Ab041                     :
      constant Unicode_Char := 16#10624#;
   Linear_A_Sign_Ab044                     :
      constant Unicode_Char := 16#10625#;
   Linear_A_Sign_Ab045                     :
      constant Unicode_Char := 16#10626#;
   Linear_A_Sign_Ab046                     :
      constant Unicode_Char := 16#10627#;
   Linear_A_Sign_Ab047                     :
      constant Unicode_Char := 16#10628#;
   Linear_A_Sign_Ab048                     :
      constant Unicode_Char := 16#10629#;
   Linear_A_Sign_Ab049                     :
      constant Unicode_Char := 16#1062A#;
   Linear_A_Sign_Ab050                     :
      constant Unicode_Char := 16#1062B#;
   Linear_A_Sign_Ab051                     :
      constant Unicode_Char := 16#1062C#;
   Linear_A_Sign_Ab053                     :
      constant Unicode_Char := 16#1062D#;
   Linear_A_Sign_Ab054                     :
      constant Unicode_Char := 16#1062E#;
   Linear_A_Sign_Ab055                     :
      constant Unicode_Char := 16#1062F#;
   Linear_A_Sign_Ab056                     :
      constant Unicode_Char := 16#10630#;
   Linear_A_Sign_Ab057                     :
      constant Unicode_Char := 16#10631#;
   Linear_A_Sign_Ab058                     :
      constant Unicode_Char := 16#10632#;
   Linear_A_Sign_Ab059                     :
      constant Unicode_Char := 16#10633#;
   Linear_A_Sign_Ab060                     :
      constant Unicode_Char := 16#10634#;
   Linear_A_Sign_Ab061                     :
      constant Unicode_Char := 16#10635#;
   Linear_A_Sign_Ab065                     :
      constant Unicode_Char := 16#10636#;
   Linear_A_Sign_Ab066                     :
      constant Unicode_Char := 16#10637#;
   Linear_A_Sign_Ab067                     :
      constant Unicode_Char := 16#10638#;
   Linear_A_Sign_Ab069                     :
      constant Unicode_Char := 16#10639#;
   Linear_A_Sign_Ab070                     :
      constant Unicode_Char := 16#1063A#;
   Linear_A_Sign_Ab073                     :
      constant Unicode_Char := 16#1063B#;
   Linear_A_Sign_Ab074                     :
      constant Unicode_Char := 16#1063C#;
   Linear_A_Sign_Ab076                     :
      constant Unicode_Char := 16#1063D#;
   Linear_A_Sign_Ab077                     :
      constant Unicode_Char := 16#1063E#;
   Linear_A_Sign_Ab078                     :
      constant Unicode_Char := 16#1063F#;
   Linear_A_Sign_Ab079                     :
      constant Unicode_Char := 16#10640#;
   Linear_A_Sign_Ab080                     :
      constant Unicode_Char := 16#10641#;
   Linear_A_Sign_Ab081                     :
      constant Unicode_Char := 16#10642#;
   Linear_A_Sign_Ab082                     :
      constant Unicode_Char := 16#10643#;
   Linear_A_Sign_Ab085                     :
      constant Unicode_Char := 16#10644#;
   Linear_A_Sign_Ab086                     :
      constant Unicode_Char := 16#10645#;
   Linear_A_Sign_Ab087                     :
      constant Unicode_Char := 16#10646#;
   Linear_A_Sign_A100_102                  :
      constant Unicode_Char := 16#10647#;
   Linear_A_Sign_Ab118                     :
      constant Unicode_Char := 16#10648#;
   Linear_A_Sign_Ab120                     :
      constant Unicode_Char := 16#10649#;
   Linear_A_Sign_A120b                     :
      constant Unicode_Char := 16#1064A#;
   Linear_A_Sign_Ab122                     :
      constant Unicode_Char := 16#1064B#;
   Linear_A_Sign_Ab123                     :
      constant Unicode_Char := 16#1064C#;
   Linear_A_Sign_Ab131a                    :
      constant Unicode_Char := 16#1064D#;
   Linear_A_Sign_Ab131b                    :
      constant Unicode_Char := 16#1064E#;
   Linear_A_Sign_A131c                     :
      constant Unicode_Char := 16#1064F#;
   Linear_A_Sign_Ab164                     :
      constant Unicode_Char := 16#10650#;
   Linear_A_Sign_Ab171                     :
      constant Unicode_Char := 16#10651#;
   Linear_A_Sign_Ab180                     :
      constant Unicode_Char := 16#10652#;
   Linear_A_Sign_Ab188                     :
      constant Unicode_Char := 16#10653#;
   Linear_A_Sign_Ab191                     :
      constant Unicode_Char := 16#10654#;
   Linear_A_Sign_A301                      :
      constant Unicode_Char := 16#10655#;
   Linear_A_Sign_A302                      :
      constant Unicode_Char := 16#10656#;
   Linear_A_Sign_A303                      :
      constant Unicode_Char := 16#10657#;
   Linear_A_Sign_A304                      :
      constant Unicode_Char := 16#10658#;
   Linear_A_Sign_A305                      :
      constant Unicode_Char := 16#10659#;
   Linear_A_Sign_A306                      :
      constant Unicode_Char := 16#1065A#;
   Linear_A_Sign_A307                      :
      constant Unicode_Char := 16#1065B#;
   Linear_A_Sign_A308                      :
      constant Unicode_Char := 16#1065C#;
   Linear_A_Sign_A309a                     :
      constant Unicode_Char := 16#1065D#;
   Linear_A_Sign_A309b                     :
      constant Unicode_Char := 16#1065E#;
   Linear_A_Sign_A309c                     :
      constant Unicode_Char := 16#1065F#;
   Linear_A_Sign_A310                      :
      constant Unicode_Char := 16#10660#;
   Linear_A_Sign_A311                      :
      constant Unicode_Char := 16#10661#;
   Linear_A_Sign_A312                      :
      constant Unicode_Char := 16#10662#;
   Linear_A_Sign_A313a                     :
      constant Unicode_Char := 16#10663#;
   Linear_A_Sign_A313b                     :
      constant Unicode_Char := 16#10664#;
   Linear_A_Sign_A313c                     :
      constant Unicode_Char := 16#10665#;
   Linear_A_Sign_A314                      :
      constant Unicode_Char := 16#10666#;
   Linear_A_Sign_A315                      :
      constant Unicode_Char := 16#10667#;
   Linear_A_Sign_A316                      :
      constant Unicode_Char := 16#10668#;
   Linear_A_Sign_A317                      :
      constant Unicode_Char := 16#10669#;
   Linear_A_Sign_A318                      :
      constant Unicode_Char := 16#1066A#;
   Linear_A_Sign_A319                      :
      constant Unicode_Char := 16#1066B#;
   Linear_A_Sign_A320                      :
      constant Unicode_Char := 16#1066C#;
   Linear_A_Sign_A321                      :
      constant Unicode_Char := 16#1066D#;
   Linear_A_Sign_A322                      :
      constant Unicode_Char := 16#1066E#;
   Linear_A_Sign_A323                      :
      constant Unicode_Char := 16#1066F#;
   Linear_A_Sign_A324                      :
      constant Unicode_Char := 16#10670#;
   Linear_A_Sign_A325                      :
      constant Unicode_Char := 16#10671#;
   Linear_A_Sign_A326                      :
      constant Unicode_Char := 16#10672#;
   Linear_A_Sign_A327                      :
      constant Unicode_Char := 16#10673#;
   Linear_A_Sign_A328                      :
      constant Unicode_Char := 16#10674#;
   Linear_A_Sign_A329                      :
      constant Unicode_Char := 16#10675#;
   Linear_A_Sign_A330                      :
      constant Unicode_Char := 16#10676#;
   Linear_A_Sign_A331                      :
      constant Unicode_Char := 16#10677#;
   Linear_A_Sign_A332                      :
      constant Unicode_Char := 16#10678#;
   Linear_A_Sign_A333                      :
      constant Unicode_Char := 16#10679#;
   Linear_A_Sign_A334                      :
      constant Unicode_Char := 16#1067A#;
   Linear_A_Sign_A335                      :
      constant Unicode_Char := 16#1067B#;
   Linear_A_Sign_A336                      :
      constant Unicode_Char := 16#1067C#;
   Linear_A_Sign_A337                      :
      constant Unicode_Char := 16#1067D#;
   Linear_A_Sign_A338                      :
      constant Unicode_Char := 16#1067E#;
   Linear_A_Sign_A339                      :
      constant Unicode_Char := 16#1067F#;
   Linear_A_Sign_A340                      :
      constant Unicode_Char := 16#10680#;
   Linear_A_Sign_A341                      :
      constant Unicode_Char := 16#10681#;
   Linear_A_Sign_A342                      :
      constant Unicode_Char := 16#10682#;
   Linear_A_Sign_A343                      :
      constant Unicode_Char := 16#10683#;
   Linear_A_Sign_A344                      :
      constant Unicode_Char := 16#10684#;
   Linear_A_Sign_A345                      :
      constant Unicode_Char := 16#10685#;
   Linear_A_Sign_A346                      :
      constant Unicode_Char := 16#10686#;
   Linear_A_Sign_A347                      :
      constant Unicode_Char := 16#10687#;
   Linear_A_Sign_A348                      :
      constant Unicode_Char := 16#10688#;
   Linear_A_Sign_A349                      :
      constant Unicode_Char := 16#10689#;
   Linear_A_Sign_A350                      :
      constant Unicode_Char := 16#1068A#;
   Linear_A_Sign_A351                      :
      constant Unicode_Char := 16#1068B#;
   Linear_A_Sign_A352                      :
      constant Unicode_Char := 16#1068C#;
   Linear_A_Sign_A353                      :
      constant Unicode_Char := 16#1068D#;
   Linear_A_Sign_A354                      :
      constant Unicode_Char := 16#1068E#;
   Linear_A_Sign_A355                      :
      constant Unicode_Char := 16#1068F#;
   Linear_A_Sign_A356                      :
      constant Unicode_Char := 16#10690#;
   Linear_A_Sign_A357                      :
      constant Unicode_Char := 16#10691#;
   Linear_A_Sign_A358                      :
      constant Unicode_Char := 16#10692#;
   Linear_A_Sign_A359                      :
      constant Unicode_Char := 16#10693#;
   Linear_A_Sign_A360                      :
      constant Unicode_Char := 16#10694#;
   Linear_A_Sign_A361                      :
      constant Unicode_Char := 16#10695#;
   Linear_A_Sign_A362                      :
      constant Unicode_Char := 16#10696#;
   Linear_A_Sign_A363                      :
      constant Unicode_Char := 16#10697#;
   Linear_A_Sign_A364                      :
      constant Unicode_Char := 16#10698#;
   Linear_A_Sign_A365                      :
      constant Unicode_Char := 16#10699#;
   Linear_A_Sign_A366                      :
      constant Unicode_Char := 16#1069A#;
   Linear_A_Sign_A367                      :
      constant Unicode_Char := 16#1069B#;
   Linear_A_Sign_A368                      :
      constant Unicode_Char := 16#1069C#;
   Linear_A_Sign_A369                      :
      constant Unicode_Char := 16#1069D#;
   Linear_A_Sign_A370                      :
      constant Unicode_Char := 16#1069E#;
   Linear_A_Sign_A371                      :
      constant Unicode_Char := 16#1069F#;
   Linear_A_Sign_A400_Vas                  :
      constant Unicode_Char := 16#106A0#;
   Linear_A_Sign_A401_Vas                  :
      constant Unicode_Char := 16#106A1#;
   Linear_A_Sign_A402_Vas                  :
      constant Unicode_Char := 16#106A2#;
   Linear_A_Sign_A403_Vas                  :
      constant Unicode_Char := 16#106A3#;
   Linear_A_Sign_A404_Vas                  :
      constant Unicode_Char := 16#106A4#;
   Linear_A_Sign_A405_Vas                  :
      constant Unicode_Char := 16#106A5#;
   Linear_A_Sign_A406_Vas                  :
      constant Unicode_Char := 16#106A6#;
   Linear_A_Sign_A407_Vas                  :
      constant Unicode_Char := 16#106A7#;
   Linear_A_Sign_A408_Vas                  :
      constant Unicode_Char := 16#106A8#;
   Linear_A_Sign_A409_Vas                  :
      constant Unicode_Char := 16#106A9#;
   Linear_A_Sign_A410_Vas                  :
      constant Unicode_Char := 16#106AA#;
   Linear_A_Sign_A411_Vas                  :
      constant Unicode_Char := 16#106AB#;
   Linear_A_Sign_A412_Vas                  :
      constant Unicode_Char := 16#106AC#;
   Linear_A_Sign_A413_Vas                  :
      constant Unicode_Char := 16#106AD#;
   Linear_A_Sign_A414_Vas                  :
      constant Unicode_Char := 16#106AE#;
   Linear_A_Sign_A415_Vas                  :
      constant Unicode_Char := 16#106AF#;
   Linear_A_Sign_A416_Vas                  :
      constant Unicode_Char := 16#106B0#;
   Linear_A_Sign_A417_Vas                  :
      constant Unicode_Char := 16#106B1#;
   Linear_A_Sign_A418_Vas                  :
      constant Unicode_Char := 16#106B2#;
   Linear_A_Sign_A501                      :
      constant Unicode_Char := 16#106B3#;
   Linear_A_Sign_A502                      :
      constant Unicode_Char := 16#106B4#;
   Linear_A_Sign_A503                      :
      constant Unicode_Char := 16#106B5#;
   Linear_A_Sign_A504                      :
      constant Unicode_Char := 16#106B6#;
   Linear_A_Sign_A505                      :
      constant Unicode_Char := 16#106B7#;
   Linear_A_Sign_A506                      :
      constant Unicode_Char := 16#106B8#;
   Linear_A_Sign_A508                      :
      constant Unicode_Char := 16#106B9#;
   Linear_A_Sign_A509                      :
      constant Unicode_Char := 16#106BA#;
   Linear_A_Sign_A510                      :
      constant Unicode_Char := 16#106BB#;
   Linear_A_Sign_A511                      :
      constant Unicode_Char := 16#106BC#;
   Linear_A_Sign_A512                      :
      constant Unicode_Char := 16#106BD#;
   Linear_A_Sign_A513                      :
      constant Unicode_Char := 16#106BE#;
   Linear_A_Sign_A515                      :
      constant Unicode_Char := 16#106BF#;
   Linear_A_Sign_A516                      :
      constant Unicode_Char := 16#106C0#;
   Linear_A_Sign_A520                      :
      constant Unicode_Char := 16#106C1#;
   Linear_A_Sign_A521                      :
      constant Unicode_Char := 16#106C2#;
   Linear_A_Sign_A523                      :
      constant Unicode_Char := 16#106C3#;
   Linear_A_Sign_A524                      :
      constant Unicode_Char := 16#106C4#;
   Linear_A_Sign_A525                      :
      constant Unicode_Char := 16#106C5#;
   Linear_A_Sign_A526                      :
      constant Unicode_Char := 16#106C6#;
   Linear_A_Sign_A527                      :
      constant Unicode_Char := 16#106C7#;
   Linear_A_Sign_A528                      :
      constant Unicode_Char := 16#106C8#;
   Linear_A_Sign_A529                      :
      constant Unicode_Char := 16#106C9#;
   Linear_A_Sign_A530                      :
      constant Unicode_Char := 16#106CA#;
   Linear_A_Sign_A531                      :
      constant Unicode_Char := 16#106CB#;
   Linear_A_Sign_A532                      :
      constant Unicode_Char := 16#106CC#;
   Linear_A_Sign_A534                      :
      constant Unicode_Char := 16#106CD#;
   Linear_A_Sign_A535                      :
      constant Unicode_Char := 16#106CE#;
   Linear_A_Sign_A536                      :
      constant Unicode_Char := 16#106CF#;
   Linear_A_Sign_A537                      :
      constant Unicode_Char := 16#106D0#;
   Linear_A_Sign_A538                      :
      constant Unicode_Char := 16#106D1#;
   Linear_A_Sign_A539                      :
      constant Unicode_Char := 16#106D2#;
   Linear_A_Sign_A540                      :
      constant Unicode_Char := 16#106D3#;
   Linear_A_Sign_A541                      :
      constant Unicode_Char := 16#106D4#;
   Linear_A_Sign_A542                      :
      constant Unicode_Char := 16#106D5#;
   Linear_A_Sign_A545                      :
      constant Unicode_Char := 16#106D6#;
   Linear_A_Sign_A547                      :
      constant Unicode_Char := 16#106D7#;
   Linear_A_Sign_A548                      :
      constant Unicode_Char := 16#106D8#;
   Linear_A_Sign_A549                      :
      constant Unicode_Char := 16#106D9#;
   Linear_A_Sign_A550                      :
      constant Unicode_Char := 16#106DA#;
   Linear_A_Sign_A551                      :
      constant Unicode_Char := 16#106DB#;
   Linear_A_Sign_A552                      :
      constant Unicode_Char := 16#106DC#;
   Linear_A_Sign_A553                      :
      constant Unicode_Char := 16#106DD#;
   Linear_A_Sign_A554                      :
      constant Unicode_Char := 16#106DE#;
   Linear_A_Sign_A555                      :
      constant Unicode_Char := 16#106DF#;
   Linear_A_Sign_A556                      :
      constant Unicode_Char := 16#106E0#;
   Linear_A_Sign_A557                      :
      constant Unicode_Char := 16#106E1#;
   Linear_A_Sign_A559                      :
      constant Unicode_Char := 16#106E2#;
   Linear_A_Sign_A563                      :
      constant Unicode_Char := 16#106E3#;
   Linear_A_Sign_A564                      :
      constant Unicode_Char := 16#106E4#;
   Linear_A_Sign_A565                      :
      constant Unicode_Char := 16#106E5#;
   Linear_A_Sign_A566                      :
      constant Unicode_Char := 16#106E6#;
   Linear_A_Sign_A568                      :
      constant Unicode_Char := 16#106E7#;
   Linear_A_Sign_A569                      :
      constant Unicode_Char := 16#106E8#;
   Linear_A_Sign_A570                      :
      constant Unicode_Char := 16#106E9#;
   Linear_A_Sign_A571                      :
      constant Unicode_Char := 16#106EA#;
   Linear_A_Sign_A572                      :
      constant Unicode_Char := 16#106EB#;
   Linear_A_Sign_A573                      :
      constant Unicode_Char := 16#106EC#;
   Linear_A_Sign_A574                      :
      constant Unicode_Char := 16#106ED#;
   Linear_A_Sign_A575                      :
      constant Unicode_Char := 16#106EE#;
   Linear_A_Sign_A576                      :
      constant Unicode_Char := 16#106EF#;
   Linear_A_Sign_A577                      :
      constant Unicode_Char := 16#106F0#;
   Linear_A_Sign_A578                      :
      constant Unicode_Char := 16#106F1#;
   Linear_A_Sign_A579                      :
      constant Unicode_Char := 16#106F2#;
   Linear_A_Sign_A580                      :
      constant Unicode_Char := 16#106F3#;
   Linear_A_Sign_A581                      :
      constant Unicode_Char := 16#106F4#;
   Linear_A_Sign_A582                      :
      constant Unicode_Char := 16#106F5#;
   Linear_A_Sign_A583                      :
      constant Unicode_Char := 16#106F6#;
   Linear_A_Sign_A584                      :
      constant Unicode_Char := 16#106F7#;
   Linear_A_Sign_A585                      :
      constant Unicode_Char := 16#106F8#;
   Linear_A_Sign_A586                      :
      constant Unicode_Char := 16#106F9#;
   Linear_A_Sign_A587                      :
      constant Unicode_Char := 16#106FA#;
   Linear_A_Sign_A588                      :
      constant Unicode_Char := 16#106FB#;
   Linear_A_Sign_A589                      :
      constant Unicode_Char := 16#106FC#;
   Linear_A_Sign_A591                      :
      constant Unicode_Char := 16#106FD#;
   Linear_A_Sign_A592                      :
      constant Unicode_Char := 16#106FE#;
   Linear_A_Sign_A594                      :
      constant Unicode_Char := 16#106FF#;
   Linear_A_Sign_A595                      :
      constant Unicode_Char := 16#10700#;
   Linear_A_Sign_A596                      :
      constant Unicode_Char := 16#10701#;
   Linear_A_Sign_A598                      :
      constant Unicode_Char := 16#10702#;
   Linear_A_Sign_A600                      :
      constant Unicode_Char := 16#10703#;
   Linear_A_Sign_A601                      :
      constant Unicode_Char := 16#10704#;
   Linear_A_Sign_A602                      :
      constant Unicode_Char := 16#10705#;
   Linear_A_Sign_A603                      :
      constant Unicode_Char := 16#10706#;
   Linear_A_Sign_A604                      :
      constant Unicode_Char := 16#10707#;
   Linear_A_Sign_A606                      :
      constant Unicode_Char := 16#10708#;
   Linear_A_Sign_A608                      :
      constant Unicode_Char := 16#10709#;
   Linear_A_Sign_A609                      :
      constant Unicode_Char := 16#1070A#;
   Linear_A_Sign_A610                      :
      constant Unicode_Char := 16#1070B#;
   Linear_A_Sign_A611                      :
      constant Unicode_Char := 16#1070C#;
   Linear_A_Sign_A612                      :
      constant Unicode_Char := 16#1070D#;
   Linear_A_Sign_A613                      :
      constant Unicode_Char := 16#1070E#;
   Linear_A_Sign_A614                      :
      constant Unicode_Char := 16#1070F#;
   Linear_A_Sign_A615                      :
      constant Unicode_Char := 16#10710#;
   Linear_A_Sign_A616                      :
      constant Unicode_Char := 16#10711#;
   Linear_A_Sign_A617                      :
      constant Unicode_Char := 16#10712#;
   Linear_A_Sign_A618                      :
      constant Unicode_Char := 16#10713#;
   Linear_A_Sign_A619                      :
      constant Unicode_Char := 16#10714#;
   Linear_A_Sign_A620                      :
      constant Unicode_Char := 16#10715#;
   Linear_A_Sign_A621                      :
      constant Unicode_Char := 16#10716#;
   Linear_A_Sign_A622                      :
      constant Unicode_Char := 16#10717#;
   Linear_A_Sign_A623                      :
      constant Unicode_Char := 16#10718#;
   Linear_A_Sign_A624                      :
      constant Unicode_Char := 16#10719#;
   Linear_A_Sign_A626                      :
      constant Unicode_Char := 16#1071A#;
   Linear_A_Sign_A627                      :
      constant Unicode_Char := 16#1071B#;
   Linear_A_Sign_A628                      :
      constant Unicode_Char := 16#1071C#;
   Linear_A_Sign_A629                      :
      constant Unicode_Char := 16#1071D#;
   Linear_A_Sign_A634                      :
      constant Unicode_Char := 16#1071E#;
   Linear_A_Sign_A637                      :
      constant Unicode_Char := 16#1071F#;
   Linear_A_Sign_A638                      :
      constant Unicode_Char := 16#10720#;
   Linear_A_Sign_A640                      :
      constant Unicode_Char := 16#10721#;
   Linear_A_Sign_A642                      :
      constant Unicode_Char := 16#10722#;
   Linear_A_Sign_A643                      :
      constant Unicode_Char := 16#10723#;
   Linear_A_Sign_A644                      :
      constant Unicode_Char := 16#10724#;
   Linear_A_Sign_A645                      :
      constant Unicode_Char := 16#10725#;
   Linear_A_Sign_A646                      :
      constant Unicode_Char := 16#10726#;
   Linear_A_Sign_A648                      :
      constant Unicode_Char := 16#10727#;
   Linear_A_Sign_A649                      :
      constant Unicode_Char := 16#10728#;
   Linear_A_Sign_A651                      :
      constant Unicode_Char := 16#10729#;
   Linear_A_Sign_A652                      :
      constant Unicode_Char := 16#1072A#;
   Linear_A_Sign_A653                      :
      constant Unicode_Char := 16#1072B#;
   Linear_A_Sign_A654                      :
      constant Unicode_Char := 16#1072C#;
   Linear_A_Sign_A655                      :
      constant Unicode_Char := 16#1072D#;
   Linear_A_Sign_A656                      :
      constant Unicode_Char := 16#1072E#;
   Linear_A_Sign_A657                      :
      constant Unicode_Char := 16#1072F#;
   Linear_A_Sign_A658                      :
      constant Unicode_Char := 16#10730#;
   Linear_A_Sign_A659                      :
      constant Unicode_Char := 16#10731#;
   Linear_A_Sign_A660                      :
      constant Unicode_Char := 16#10732#;
   Linear_A_Sign_A661                      :
      constant Unicode_Char := 16#10733#;
   Linear_A_Sign_A662                      :
      constant Unicode_Char := 16#10734#;
   Linear_A_Sign_A663                      :
      constant Unicode_Char := 16#10735#;
   Linear_A_Sign_A664                      :
      constant Unicode_Char := 16#10736#;
   Linear_A_Sign_A701_A                    :
      constant Unicode_Char := 16#10740#;
   Linear_A_Sign_A702_B                    :
      constant Unicode_Char := 16#10741#;
   Linear_A_Sign_A703_D                    :
      constant Unicode_Char := 16#10742#;
   Linear_A_Sign_A704_E                    :
      constant Unicode_Char := 16#10743#;
   Linear_A_Sign_A705_F                    :
      constant Unicode_Char := 16#10744#;
   Linear_A_Sign_A706_H                    :
      constant Unicode_Char := 16#10745#;
   Linear_A_Sign_A707_J                    :
      constant Unicode_Char := 16#10746#;
   Linear_A_Sign_A708_K                    :
      constant Unicode_Char := 16#10747#;
   Linear_A_Sign_A709_L                    :
      constant Unicode_Char := 16#10748#;
   Linear_A_Sign_A709_2_L2                 :
      constant Unicode_Char := 16#10749#;
   Linear_A_Sign_A709_3_L3                 :
      constant Unicode_Char := 16#1074A#;
   Linear_A_Sign_A709_4_L4                 :
      constant Unicode_Char := 16#1074B#;
   Linear_A_Sign_A709_6_L6                 :
      constant Unicode_Char := 16#1074C#;
   Linear_A_Sign_A710_W                    :
      constant Unicode_Char := 16#1074D#;
   Linear_A_Sign_A711_X                    :
      constant Unicode_Char := 16#1074E#;
   Linear_A_Sign_A712_Y                    :
      constant Unicode_Char := 16#1074F#;
   Linear_A_Sign_A713_Omega                :
      constant Unicode_Char := 16#10750#;
   Linear_A_Sign_A714_Abb                  :
      constant Unicode_Char := 16#10751#;
   Linear_A_Sign_A715_Bb                   :
      constant Unicode_Char := 16#10752#;
   Linear_A_Sign_A717_Dd                   :
      constant Unicode_Char := 16#10753#;
   Linear_A_Sign_A726_Eyyy                 :
      constant Unicode_Char := 16#10754#;
   Linear_A_Sign_A732_Je                   :
      constant Unicode_Char := 16#10755#;
   Linear_A_Sign_A800                      :
      constant Unicode_Char := 16#10760#;
   Linear_A_Sign_A801                      :
      constant Unicode_Char := 16#10761#;
   Linear_A_Sign_A802                      :
      constant Unicode_Char := 16#10762#;
   Linear_A_Sign_A803                      :
      constant Unicode_Char := 16#10763#;
   Linear_A_Sign_A804                      :
      constant Unicode_Char := 16#10764#;
   Linear_A_Sign_A805                      :
      constant Unicode_Char := 16#10765#;
   Linear_A_Sign_A806                      :
      constant Unicode_Char := 16#10766#;
   Linear_A_Sign_A807                      :
      constant Unicode_Char := 16#10767#;
end Unicode.Names.Linear_A;
