--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cuneiform is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cuneiform_Sign_A                        :
      constant Unicode_Char := 16#12000#;
   Cuneiform_Sign_A_Times_A                :
      constant Unicode_Char := 16#12001#;
   Cuneiform_Sign_A_Times_Bad              :
      constant Unicode_Char := 16#12002#;
   Cuneiform_Sign_A_Times_Gan2_Tenu        :
      constant Unicode_Char := 16#12003#;
   Cuneiform_Sign_A_Times_Ha               :
      constant Unicode_Char := 16#12004#;
   Cuneiform_Sign_A_Times_Igi              :
      constant Unicode_Char := 16#12005#;
   Cuneiform_Sign_A_Times_Lagar_Gunu       :
      constant Unicode_Char := 16#12006#;
   Cuneiform_Sign_A_Times_Mush             :
      constant Unicode_Char := 16#12007#;
   Cuneiform_Sign_A_Times_Sag              :
      constant Unicode_Char := 16#12008#;
   Cuneiform_Sign_A2                       :
      constant Unicode_Char := 16#12009#;
   Cuneiform_Sign_Ab                       :
      constant Unicode_Char := 16#1200A#;
   Cuneiform_Sign_Ab_Times_Ash2            :
      constant Unicode_Char := 16#1200B#;
   Cuneiform_Sign_Ab_Times_Dun3_Gunu       :
      constant Unicode_Char := 16#1200C#;
   Cuneiform_Sign_Ab_Times_Gal             :
      constant Unicode_Char := 16#1200D#;
   Cuneiform_Sign_Ab_Times_Gan2_Tenu       :
      constant Unicode_Char := 16#1200E#;
   Cuneiform_Sign_Ab_Times_Ha              :
      constant Unicode_Char := 16#1200F#;
   Cuneiform_Sign_Ab_Times_Igi_Gunu        :
      constant Unicode_Char := 16#12010#;
   Cuneiform_Sign_Ab_Times_Imin            :
      constant Unicode_Char := 16#12011#;
   Cuneiform_Sign_Ab_Times_Lagab           :
      constant Unicode_Char := 16#12012#;
   Cuneiform_Sign_Ab_Times_Shesh           :
      constant Unicode_Char := 16#12013#;
   Cuneiform_Sign_Ab_Times_U_Plus_U_Plus_U :
      constant Unicode_Char := 16#12014#;
   Cuneiform_Sign_Ab_Gunu                  :
      constant Unicode_Char := 16#12015#;
   Cuneiform_Sign_Ab2                      :
      constant Unicode_Char := 16#12016#;
   Cuneiform_Sign_Ab2_Times_Balag          :
      constant Unicode_Char := 16#12017#;
   Cuneiform_Sign_Ab2_Times_Gan2_Tenu      :
      constant Unicode_Char := 16#12018#;
   Cuneiform_Sign_Ab2_Times_Me_Plus_En     :
      constant Unicode_Char := 16#12019#;
   Cuneiform_Sign_Ab2_Times_Sha3           :
      constant Unicode_Char := 16#1201A#;
   Cuneiform_Sign_Ab2_Times_Tak4           :
      constant Unicode_Char := 16#1201B#;
   Cuneiform_Sign_Ad                       :
      constant Unicode_Char := 16#1201C#;
   Cuneiform_Sign_Ak                       :
      constant Unicode_Char := 16#1201D#;
   Cuneiform_Sign_Ak_Times_Erin2           :
      constant Unicode_Char := 16#1201E#;
   Cuneiform_Sign_Ak_Times_Shita_Plus_Gish :
      constant Unicode_Char := 16#1201F#;
   Cuneiform_Sign_Al                       :
      constant Unicode_Char := 16#12020#;
   Cuneiform_Sign_Al_Times_Al              :
      constant Unicode_Char := 16#12021#;
   Cuneiform_Sign_Al_Times_Dim2            :
      constant Unicode_Char := 16#12022#;
   Cuneiform_Sign_Al_Times_Gish            :
      constant Unicode_Char := 16#12023#;
   Cuneiform_Sign_Al_Times_Ha              :
      constant Unicode_Char := 16#12024#;
   Cuneiform_Sign_Al_Times_Kad3            :
      constant Unicode_Char := 16#12025#;
   Cuneiform_Sign_Al_Times_Ki              :
      constant Unicode_Char := 16#12026#;
   Cuneiform_Sign_Al_Times_She             :
      constant Unicode_Char := 16#12027#;
   Cuneiform_Sign_Al_Times_Ush             :
      constant Unicode_Char := 16#12028#;
   Cuneiform_Sign_Alan                     :
      constant Unicode_Char := 16#12029#;
   Cuneiform_Sign_Aleph                    :
      constant Unicode_Char := 16#1202A#;
   Cuneiform_Sign_Amar                     :
      constant Unicode_Char := 16#1202B#;
   Cuneiform_Sign_Amar_Times_She           :
      constant Unicode_Char := 16#1202C#;
   Cuneiform_Sign_An                       :
      constant Unicode_Char := 16#1202D#;
   Cuneiform_Sign_An_Over_An               :
      constant Unicode_Char := 16#1202E#;
   Cuneiform_Sign_An_Three_Times           :
      constant Unicode_Char := 16#1202F#;
   Cuneiform_Sign_An_Plus_Naga_Opposing_An_Plus_Naga :
      constant Unicode_Char := 16#12030#;
   Cuneiform_Sign_An_Plus_Naga_Squared     :
      constant Unicode_Char := 16#12031#;
   Cuneiform_Sign_Anshe                    :
      constant Unicode_Char := 16#12032#;
   Cuneiform_Sign_Apin                     :
      constant Unicode_Char := 16#12033#;
   Cuneiform_Sign_Arad                     :
      constant Unicode_Char := 16#12034#;
   Cuneiform_Sign_Arad_Times_Kur           :
      constant Unicode_Char := 16#12035#;
   Cuneiform_Sign_Arkab                    :
      constant Unicode_Char := 16#12036#;
   Cuneiform_Sign_Asal2                    :
      constant Unicode_Char := 16#12037#;
   Cuneiform_Sign_Ash                      :
      constant Unicode_Char := 16#12038#;
   Cuneiform_Sign_Ash_Zida_Tenu            :
      constant Unicode_Char := 16#12039#;
   Cuneiform_Sign_Ash_Kaba_Tenu            :
      constant Unicode_Char := 16#1203A#;
   Cuneiform_Sign_Ash_Over_Ash_Tug2_Over_Tug2_Tug2_Over_Tug2_Pap :
      constant Unicode_Char := 16#1203B#;
   Cuneiform_Sign_Ash_Over_Ash_Over_Ash    :
      constant Unicode_Char := 16#1203C#;
   Cuneiform_Sign_Ash_Over_Ash_Over_Ash_Crossing_Ash_Over_Ash_Over_Ash :
      constant Unicode_Char := 16#1203D#;
   Cuneiform_Sign_Ash2                     :
      constant Unicode_Char := 16#1203E#;
   Cuneiform_Sign_Ashgab                   :
      constant Unicode_Char := 16#1203F#;
   Cuneiform_Sign_Ba                       :
      constant Unicode_Char := 16#12040#;
   Cuneiform_Sign_Bad                      :
      constant Unicode_Char := 16#12041#;
   Cuneiform_Sign_Bag3                     :
      constant Unicode_Char := 16#12042#;
   Cuneiform_Sign_Bahar2                   :
      constant Unicode_Char := 16#12043#;
   Cuneiform_Sign_Bal                      :
      constant Unicode_Char := 16#12044#;
   Cuneiform_Sign_Bal_Over_Bal             :
      constant Unicode_Char := 16#12045#;
   Cuneiform_Sign_Balag                    :
      constant Unicode_Char := 16#12046#;
   Cuneiform_Sign_Bar                      :
      constant Unicode_Char := 16#12047#;
   Cuneiform_Sign_Bara2                    :
      constant Unicode_Char := 16#12048#;
   Cuneiform_Sign_Bi                       :
      constant Unicode_Char := 16#12049#;
   Cuneiform_Sign_Bi_Times_A               :
      constant Unicode_Char := 16#1204A#;
   Cuneiform_Sign_Bi_Times_Gar             :
      constant Unicode_Char := 16#1204B#;
   Cuneiform_Sign_Bi_Times_Igi_Gunu        :
      constant Unicode_Char := 16#1204C#;
   Cuneiform_Sign_Bu                       :
      constant Unicode_Char := 16#1204D#;
   Cuneiform_Sign_Bu_Over_Bu_Ab            :
      constant Unicode_Char := 16#1204E#;
   Cuneiform_Sign_Bu_Over_Bu_Un            :
      constant Unicode_Char := 16#1204F#;
   Cuneiform_Sign_Bu_Crossing_Bu           :
      constant Unicode_Char := 16#12050#;
   Cuneiform_Sign_Bulug                    :
      constant Unicode_Char := 16#12051#;
   Cuneiform_Sign_Bulug_Over_Bulug         :
      constant Unicode_Char := 16#12052#;
   Cuneiform_Sign_Bur                      :
      constant Unicode_Char := 16#12053#;
   Cuneiform_Sign_Bur2                     :
      constant Unicode_Char := 16#12054#;
   Cuneiform_Sign_Da                       :
      constant Unicode_Char := 16#12055#;
   Cuneiform_Sign_Dag                      :
      constant Unicode_Char := 16#12056#;
   Cuneiform_Sign_Dag_Kisim5_Times_A_Plus_Mash :
      constant Unicode_Char := 16#12057#;
   Cuneiform_Sign_Dag_Kisim5_Times_Amar    :
      constant Unicode_Char := 16#12058#;
   Cuneiform_Sign_Dag_Kisim5_Times_Balag   :
      constant Unicode_Char := 16#12059#;
   Cuneiform_Sign_Dag_Kisim5_Times_Bi      :
      constant Unicode_Char := 16#1205A#;
   Cuneiform_Sign_Dag_Kisim5_Times_Ga      :
      constant Unicode_Char := 16#1205B#;
   Cuneiform_Sign_Dag_Kisim5_Times_Ga_Plus_Mash :
      constant Unicode_Char := 16#1205C#;
   Cuneiform_Sign_Dag_Kisim5_Times_Gi      :
      constant Unicode_Char := 16#1205D#;
   Cuneiform_Sign_Dag_Kisim5_Times_Gir2    :
      constant Unicode_Char := 16#1205E#;
   Cuneiform_Sign_Dag_Kisim5_Times_Gud     :
      constant Unicode_Char := 16#1205F#;
   Cuneiform_Sign_Dag_Kisim5_Times_Ha      :
      constant Unicode_Char := 16#12060#;
   Cuneiform_Sign_Dag_Kisim5_Times_Ir      :
      constant Unicode_Char := 16#12061#;
   Cuneiform_Sign_Dag_Kisim5_Times_Ir_Plus_Lu :
      constant Unicode_Char := 16#12062#;
   Cuneiform_Sign_Dag_Kisim5_Times_Kak     :
      constant Unicode_Char := 16#12063#;
   Cuneiform_Sign_Dag_Kisim5_Times_La      :
      constant Unicode_Char := 16#12064#;
   Cuneiform_Sign_Dag_Kisim5_Times_Lu      :
      constant Unicode_Char := 16#12065#;
   Cuneiform_Sign_Dag_Kisim5_Times_Lu_Plus_Mash2 :
      constant Unicode_Char := 16#12066#;
   Cuneiform_Sign_Dag_Kisim5_Times_Lum     :
      constant Unicode_Char := 16#12067#;
   Cuneiform_Sign_Dag_Kisim5_Times_Ne      :
      constant Unicode_Char := 16#12068#;
   Cuneiform_Sign_Dag_Kisim5_Times_Pap_Plus_Pap :
      constant Unicode_Char := 16#12069#;
   Cuneiform_Sign_Dag_Kisim5_Times_Si      :
      constant Unicode_Char := 16#1206A#;
   Cuneiform_Sign_Dag_Kisim5_Times_Tak4    :
      constant Unicode_Char := 16#1206B#;
   Cuneiform_Sign_Dag_Kisim5_Times_U2_Plus_Gir2 :
      constant Unicode_Char := 16#1206C#;
   Cuneiform_Sign_Dag_Kisim5_Times_Ush     :
      constant Unicode_Char := 16#1206D#;
   Cuneiform_Sign_Dam                      :
      constant Unicode_Char := 16#1206E#;
   Cuneiform_Sign_Dar                      :
      constant Unicode_Char := 16#1206F#;
   Cuneiform_Sign_Dara3                    :
      constant Unicode_Char := 16#12070#;
   Cuneiform_Sign_Dara4                    :
      constant Unicode_Char := 16#12071#;
   Cuneiform_Sign_Di                       :
      constant Unicode_Char := 16#12072#;
   Cuneiform_Sign_Dib                      :
      constant Unicode_Char := 16#12073#;
   Cuneiform_Sign_Dim                      :
      constant Unicode_Char := 16#12074#;
   Cuneiform_Sign_Dim_Times_She            :
      constant Unicode_Char := 16#12075#;
   Cuneiform_Sign_Dim2                     :
      constant Unicode_Char := 16#12076#;
   Cuneiform_Sign_Din                      :
      constant Unicode_Char := 16#12077#;
   Cuneiform_Sign_Din_Kaskal_U_Gunu_Dish   :
      constant Unicode_Char := 16#12078#;
   Cuneiform_Sign_Dish                     :
      constant Unicode_Char := 16#12079#;
   Cuneiform_Sign_Du                       :
      constant Unicode_Char := 16#1207A#;
   Cuneiform_Sign_Du_Over_Du               :
      constant Unicode_Char := 16#1207B#;
   Cuneiform_Sign_Du_Gunu                  :
      constant Unicode_Char := 16#1207C#;
   Cuneiform_Sign_Du_Sheshig               :
      constant Unicode_Char := 16#1207D#;
   Cuneiform_Sign_Dub                      :
      constant Unicode_Char := 16#1207E#;
   Cuneiform_Sign_Dub_Times_Esh2           :
      constant Unicode_Char := 16#1207F#;
   Cuneiform_Sign_Dub2                     :
      constant Unicode_Char := 16#12080#;
   Cuneiform_Sign_Dug                      :
      constant Unicode_Char := 16#12081#;
   Cuneiform_Sign_Dugud                    :
      constant Unicode_Char := 16#12082#;
   Cuneiform_Sign_Duh                      :
      constant Unicode_Char := 16#12083#;
   Cuneiform_Sign_Dun                      :
      constant Unicode_Char := 16#12084#;
   Cuneiform_Sign_Dun3                     :
      constant Unicode_Char := 16#12085#;
   Cuneiform_Sign_Dun3_Gunu                :
      constant Unicode_Char := 16#12086#;
   Cuneiform_Sign_Dun3_Gunu_Gunu           :
      constant Unicode_Char := 16#12087#;
   Cuneiform_Sign_Dun4                     :
      constant Unicode_Char := 16#12088#;
   Cuneiform_Sign_Dur2                     :
      constant Unicode_Char := 16#12089#;
   Cuneiform_Sign_E                        :
      constant Unicode_Char := 16#1208A#;
   Cuneiform_Sign_E_Times_Pap              :
      constant Unicode_Char := 16#1208B#;
   Cuneiform_Sign_E_Over_E_Nun_Over_Nun    :
      constant Unicode_Char := 16#1208C#;
   Cuneiform_Sign_E2                       :
      constant Unicode_Char := 16#1208D#;
   Cuneiform_Sign_E2_Times_A_Plus_Ha_Plus_Da :
      constant Unicode_Char := 16#1208E#;
   Cuneiform_Sign_E2_Times_Gar             :
      constant Unicode_Char := 16#1208F#;
   Cuneiform_Sign_E2_Times_Mi              :
      constant Unicode_Char := 16#12090#;
   Cuneiform_Sign_E2_Times_Sal             :
      constant Unicode_Char := 16#12091#;
   Cuneiform_Sign_E2_Times_She             :
      constant Unicode_Char := 16#12092#;
   Cuneiform_Sign_E2_Times_U               :
      constant Unicode_Char := 16#12093#;
   Cuneiform_Sign_Edin                     :
      constant Unicode_Char := 16#12094#;
   Cuneiform_Sign_Egir                     :
      constant Unicode_Char := 16#12095#;
   Cuneiform_Sign_El                       :
      constant Unicode_Char := 16#12096#;
   Cuneiform_Sign_En                       :
      constant Unicode_Char := 16#12097#;
   Cuneiform_Sign_En_Times_Gan2            :
      constant Unicode_Char := 16#12098#;
   Cuneiform_Sign_En_Times_Gan2_Tenu       :
      constant Unicode_Char := 16#12099#;
   Cuneiform_Sign_En_Times_Me              :
      constant Unicode_Char := 16#1209A#;
   Cuneiform_Sign_En_Crossing_En           :
      constant Unicode_Char := 16#1209B#;
   Cuneiform_Sign_En_Opposing_En           :
      constant Unicode_Char := 16#1209C#;
   Cuneiform_Sign_En_Squared               :
      constant Unicode_Char := 16#1209D#;
   Cuneiform_Sign_Eren                     :
      constant Unicode_Char := 16#1209E#;
   Cuneiform_Sign_Erin2                    :
      constant Unicode_Char := 16#1209F#;
   Cuneiform_Sign_Esh2                     :
      constant Unicode_Char := 16#120A0#;
   Cuneiform_Sign_Ezen                     :
      constant Unicode_Char := 16#120A1#;
   Cuneiform_Sign_Ezen_Times_A             :
      constant Unicode_Char := 16#120A2#;
   Cuneiform_Sign_Ezen_Times_A_Plus_Lal    :
      constant Unicode_Char := 16#120A3#;
   Cuneiform_Sign_Ezen_Times_A_Plus_Lal_Times_Lal :
      constant Unicode_Char := 16#120A4#;
   Cuneiform_Sign_Ezen_Times_An            :
      constant Unicode_Char := 16#120A5#;
   Cuneiform_Sign_Ezen_Times_Bad           :
      constant Unicode_Char := 16#120A6#;
   Cuneiform_Sign_Ezen_Times_Dun3_Gunu     :
      constant Unicode_Char := 16#120A7#;
   Cuneiform_Sign_Ezen_Times_Dun3_Gunu_Gunu :
      constant Unicode_Char := 16#120A8#;
   Cuneiform_Sign_Ezen_Times_Ha            :
      constant Unicode_Char := 16#120A9#;
   Cuneiform_Sign_Ezen_Times_Ha_Gunu       :
      constant Unicode_Char := 16#120AA#;
   Cuneiform_Sign_Ezen_Times_Igi_Gunu      :
      constant Unicode_Char := 16#120AB#;
   Cuneiform_Sign_Ezen_Times_Kaskal        :
      constant Unicode_Char := 16#120AC#;
   Cuneiform_Sign_Ezen_Times_Kaskal_Squared :
      constant Unicode_Char := 16#120AD#;
   Cuneiform_Sign_Ezen_Times_Ku3           :
      constant Unicode_Char := 16#120AE#;
   Cuneiform_Sign_Ezen_Times_La            :
      constant Unicode_Char := 16#120AF#;
   Cuneiform_Sign_Ezen_Times_Lal_Times_Lal :
      constant Unicode_Char := 16#120B0#;
   Cuneiform_Sign_Ezen_Times_Li            :
      constant Unicode_Char := 16#120B1#;
   Cuneiform_Sign_Ezen_Times_Lu            :
      constant Unicode_Char := 16#120B2#;
   Cuneiform_Sign_Ezen_Times_U2            :
      constant Unicode_Char := 16#120B3#;
   Cuneiform_Sign_Ezen_Times_Ud            :
      constant Unicode_Char := 16#120B4#;
   Cuneiform_Sign_Ga                       :
      constant Unicode_Char := 16#120B5#;
   Cuneiform_Sign_Ga_Gunu                  :
      constant Unicode_Char := 16#120B6#;
   Cuneiform_Sign_Ga2                      :
      constant Unicode_Char := 16#120B7#;
   Cuneiform_Sign_Ga2_Times_A_Plus_Da_Plus_Ha :
      constant Unicode_Char := 16#120B8#;
   Cuneiform_Sign_Ga2_Times_A_Plus_Ha      :
      constant Unicode_Char := 16#120B9#;
   Cuneiform_Sign_Ga2_Times_A_Plus_Igi     :
      constant Unicode_Char := 16#120BA#;
   Cuneiform_Sign_Ga2_Times_Ab2_Tenu_Plus_Tab :
      constant Unicode_Char := 16#120BB#;
   Cuneiform_Sign_Ga2_Times_An             :
      constant Unicode_Char := 16#120BC#;
   Cuneiform_Sign_Ga2_Times_Ash            :
      constant Unicode_Char := 16#120BD#;
   Cuneiform_Sign_Ga2_Times_Ash2_Plus_Gal  :
      constant Unicode_Char := 16#120BE#;
   Cuneiform_Sign_Ga2_Times_Bad            :
      constant Unicode_Char := 16#120BF#;
   Cuneiform_Sign_Ga2_Times_Bar_Plus_Ra    :
      constant Unicode_Char := 16#120C0#;
   Cuneiform_Sign_Ga2_Times_Bur            :
      constant Unicode_Char := 16#120C1#;
   Cuneiform_Sign_Ga2_Times_Bur_Plus_Ra    :
      constant Unicode_Char := 16#120C2#;
   Cuneiform_Sign_Ga2_Times_Da             :
      constant Unicode_Char := 16#120C3#;
   Cuneiform_Sign_Ga2_Times_Di             :
      constant Unicode_Char := 16#120C4#;
   Cuneiform_Sign_Ga2_Times_Dim_Times_She  :
      constant Unicode_Char := 16#120C5#;
   Cuneiform_Sign_Ga2_Times_Dub            :
      constant Unicode_Char := 16#120C6#;
   Cuneiform_Sign_Ga2_Times_El             :
      constant Unicode_Char := 16#120C7#;
   Cuneiform_Sign_Ga2_Times_El_Plus_La     :
      constant Unicode_Char := 16#120C8#;
   Cuneiform_Sign_Ga2_Times_En             :
      constant Unicode_Char := 16#120C9#;
   Cuneiform_Sign_Ga2_Times_En_Times_Gan2_Tenu :
      constant Unicode_Char := 16#120CA#;
   Cuneiform_Sign_Ga2_Times_Gan2_Tenu      :
      constant Unicode_Char := 16#120CB#;
   Cuneiform_Sign_Ga2_Times_Gar            :
      constant Unicode_Char := 16#120CC#;
   Cuneiform_Sign_Ga2_Times_Gi             :
      constant Unicode_Char := 16#120CD#;
   Cuneiform_Sign_Ga2_Times_Gi4            :
      constant Unicode_Char := 16#120CE#;
   Cuneiform_Sign_Ga2_Times_Gi4_Plus_A     :
      constant Unicode_Char := 16#120CF#;
   Cuneiform_Sign_Ga2_Times_Gir2_Plus_Su   :
      constant Unicode_Char := 16#120D0#;
   Cuneiform_Sign_Ga2_Times_Ha_Plus_Lu_Plus_Esh2 :
      constant Unicode_Char := 16#120D1#;
   Cuneiform_Sign_Ga2_Times_Hal            :
      constant Unicode_Char := 16#120D2#;
   Cuneiform_Sign_Ga2_Times_Hal_Plus_La    :
      constant Unicode_Char := 16#120D3#;
   Cuneiform_Sign_Ga2_Times_Hi_Plus_Li     :
      constant Unicode_Char := 16#120D4#;
   Cuneiform_Sign_Ga2_Times_Hub2           :
      constant Unicode_Char := 16#120D5#;
   Cuneiform_Sign_Ga2_Times_Igi_Gunu       :
      constant Unicode_Char := 16#120D6#;
   Cuneiform_Sign_Ga2_Times_Ish_Plus_Hu_Plus_Ash :
      constant Unicode_Char := 16#120D7#;
   Cuneiform_Sign_Ga2_Times_Kak            :
      constant Unicode_Char := 16#120D8#;
   Cuneiform_Sign_Ga2_Times_Kaskal         :
      constant Unicode_Char := 16#120D9#;
   Cuneiform_Sign_Ga2_Times_Kid            :
      constant Unicode_Char := 16#120DA#;
   Cuneiform_Sign_Ga2_Times_Kid_Plus_Lal   :
      constant Unicode_Char := 16#120DB#;
   Cuneiform_Sign_Ga2_Times_Ku3_Plus_An    :
      constant Unicode_Char := 16#120DC#;
   Cuneiform_Sign_Ga2_Times_La             :
      constant Unicode_Char := 16#120DD#;
   Cuneiform_Sign_Ga2_Times_Me_Plus_En     :
      constant Unicode_Char := 16#120DE#;
   Cuneiform_Sign_Ga2_Times_Mi             :
      constant Unicode_Char := 16#120DF#;
   Cuneiform_Sign_Ga2_Times_Nun            :
      constant Unicode_Char := 16#120E0#;
   Cuneiform_Sign_Ga2_Times_Nun_Over_Nun   :
      constant Unicode_Char := 16#120E1#;
   Cuneiform_Sign_Ga2_Times_Pa             :
      constant Unicode_Char := 16#120E2#;
   Cuneiform_Sign_Ga2_Times_Sal            :
      constant Unicode_Char := 16#120E3#;
   Cuneiform_Sign_Ga2_Times_Sar            :
      constant Unicode_Char := 16#120E4#;
   Cuneiform_Sign_Ga2_Times_She            :
      constant Unicode_Char := 16#120E5#;
   Cuneiform_Sign_Ga2_Times_She_Plus_Tur   :
      constant Unicode_Char := 16#120E6#;
   Cuneiform_Sign_Ga2_Times_Shid           :
      constant Unicode_Char := 16#120E7#;
   Cuneiform_Sign_Ga2_Times_Sum            :
      constant Unicode_Char := 16#120E8#;
   Cuneiform_Sign_Ga2_Times_Tak4           :
      constant Unicode_Char := 16#120E9#;
   Cuneiform_Sign_Ga2_Times_U              :
      constant Unicode_Char := 16#120EA#;
   Cuneiform_Sign_Ga2_Times_Ud             :
      constant Unicode_Char := 16#120EB#;
   Cuneiform_Sign_Ga2_Times_Ud_Plus_Du     :
      constant Unicode_Char := 16#120EC#;
   Cuneiform_Sign_Ga2_Over_Ga2             :
      constant Unicode_Char := 16#120ED#;
   Cuneiform_Sign_Gaba                     :
      constant Unicode_Char := 16#120EE#;
   Cuneiform_Sign_Gaba_Crossing_Gaba       :
      constant Unicode_Char := 16#120EF#;
   Cuneiform_Sign_Gad                      :
      constant Unicode_Char := 16#120F0#;
   Cuneiform_Sign_Gad_Over_Gad_Gar_Over_Gar :
      constant Unicode_Char := 16#120F1#;
   Cuneiform_Sign_Gal                      :
      constant Unicode_Char := 16#120F2#;
   Cuneiform_Sign_Gal_Gad_Over_Gad_Gar_Over_Gar :
      constant Unicode_Char := 16#120F3#;
   Cuneiform_Sign_Galam                    :
      constant Unicode_Char := 16#120F4#;
   Cuneiform_Sign_Gam                      :
      constant Unicode_Char := 16#120F5#;
   Cuneiform_Sign_Gan                      :
      constant Unicode_Char := 16#120F6#;
   Cuneiform_Sign_Gan2                     :
      constant Unicode_Char := 16#120F7#;
   Cuneiform_Sign_Gan2_Tenu                :
      constant Unicode_Char := 16#120F8#;
   Cuneiform_Sign_Gan2_Over_Gan2           :
      constant Unicode_Char := 16#120F9#;
   Cuneiform_Sign_Gan2_Crossing_Gan2       :
      constant Unicode_Char := 16#120FA#;
   Cuneiform_Sign_Gar                      :
      constant Unicode_Char := 16#120FB#;
   Cuneiform_Sign_Gar3                     :
      constant Unicode_Char := 16#120FC#;
   Cuneiform_Sign_Gashan                   :
      constant Unicode_Char := 16#120FD#;
   Cuneiform_Sign_Geshtin                  :
      constant Unicode_Char := 16#120FE#;
   Cuneiform_Sign_Geshtin_Times_Kur        :
      constant Unicode_Char := 16#120FF#;
   Cuneiform_Sign_Gi                       :
      constant Unicode_Char := 16#12100#;
   Cuneiform_Sign_Gi_Times_E               :
      constant Unicode_Char := 16#12101#;
   Cuneiform_Sign_Gi_Times_U               :
      constant Unicode_Char := 16#12102#;
   Cuneiform_Sign_Gi_Crossing_Gi           :
      constant Unicode_Char := 16#12103#;
   Cuneiform_Sign_Gi4                      :
      constant Unicode_Char := 16#12104#;
   Cuneiform_Sign_Gi4_Over_Gi4             :
      constant Unicode_Char := 16#12105#;
   Cuneiform_Sign_Gi4_Crossing_Gi4         :
      constant Unicode_Char := 16#12106#;
   Cuneiform_Sign_Gidim                    :
      constant Unicode_Char := 16#12107#;
   Cuneiform_Sign_Gir2                     :
      constant Unicode_Char := 16#12108#;
   Cuneiform_Sign_Gir2_Gunu                :
      constant Unicode_Char := 16#12109#;
   Cuneiform_Sign_Gir3                     :
      constant Unicode_Char := 16#1210A#;
   Cuneiform_Sign_Gir3_Times_A_Plus_Igi    :
      constant Unicode_Char := 16#1210B#;
   Cuneiform_Sign_Gir3_Times_Gan2_Tenu     :
      constant Unicode_Char := 16#1210C#;
   Cuneiform_Sign_Gir3_Times_Igi           :
      constant Unicode_Char := 16#1210D#;
   Cuneiform_Sign_Gir3_Times_Lu_Plus_Igi   :
      constant Unicode_Char := 16#1210E#;
   Cuneiform_Sign_Gir3_Times_Pa            :
      constant Unicode_Char := 16#1210F#;
   Cuneiform_Sign_Gisal                    :
      constant Unicode_Char := 16#12110#;
   Cuneiform_Sign_Gish                     :
      constant Unicode_Char := 16#12111#;
   Cuneiform_Sign_Gish_Crossing_Gish       :
      constant Unicode_Char := 16#12112#;
   Cuneiform_Sign_Gish_Times_Bad           :
      constant Unicode_Char := 16#12113#;
   Cuneiform_Sign_Gish_Times_Tak4          :
      constant Unicode_Char := 16#12114#;
   Cuneiform_Sign_Gish_Tenu                :
      constant Unicode_Char := 16#12115#;
   Cuneiform_Sign_Gu                       :
      constant Unicode_Char := 16#12116#;
   Cuneiform_Sign_Gu_Crossing_Gu           :
      constant Unicode_Char := 16#12117#;
   Cuneiform_Sign_Gu2                      :
      constant Unicode_Char := 16#12118#;
   Cuneiform_Sign_Gu2_Times_Kak            :
      constant Unicode_Char := 16#12119#;
   Cuneiform_Sign_Gu2_Times_Kak_Times_Igi_Gunu :
      constant Unicode_Char := 16#1211A#;
   Cuneiform_Sign_Gu2_Times_Nun            :
      constant Unicode_Char := 16#1211B#;
   Cuneiform_Sign_Gu2_Times_Sal_Plus_Tug2  :
      constant Unicode_Char := 16#1211C#;
   Cuneiform_Sign_Gu2_Gunu                 :
      constant Unicode_Char := 16#1211D#;
   Cuneiform_Sign_Gud                      :
      constant Unicode_Char := 16#1211E#;
   Cuneiform_Sign_Gud_Times_A_Plus_Kur     :
      constant Unicode_Char := 16#1211F#;
   Cuneiform_Sign_Gud_Times_Kur            :
      constant Unicode_Char := 16#12120#;
   Cuneiform_Sign_Gud_Over_Gud_Lugal       :
      constant Unicode_Char := 16#12121#;
   Cuneiform_Sign_Gul                      :
      constant Unicode_Char := 16#12122#;
   Cuneiform_Sign_Gum                      :
      constant Unicode_Char := 16#12123#;
   Cuneiform_Sign_Gum_Times_She            :
      constant Unicode_Char := 16#12124#;
   Cuneiform_Sign_Gur                      :
      constant Unicode_Char := 16#12125#;
   Cuneiform_Sign_Gur7                     :
      constant Unicode_Char := 16#12126#;
   Cuneiform_Sign_Gurun                    :
      constant Unicode_Char := 16#12127#;
   Cuneiform_Sign_Gurush                   :
      constant Unicode_Char := 16#12128#;
   Cuneiform_Sign_Ha                       :
      constant Unicode_Char := 16#12129#;
   Cuneiform_Sign_Ha_Tenu                  :
      constant Unicode_Char := 16#1212A#;
   Cuneiform_Sign_Ha_Gunu                  :
      constant Unicode_Char := 16#1212B#;
   Cuneiform_Sign_Hal                      :
      constant Unicode_Char := 16#1212C#;
   Cuneiform_Sign_Hi                       :
      constant Unicode_Char := 16#1212D#;
   Cuneiform_Sign_Hi_Times_Ash             :
      constant Unicode_Char := 16#1212E#;
   Cuneiform_Sign_Hi_Times_Ash2            :
      constant Unicode_Char := 16#1212F#;
   Cuneiform_Sign_Hi_Times_Bad             :
      constant Unicode_Char := 16#12130#;
   Cuneiform_Sign_Hi_Times_Dish            :
      constant Unicode_Char := 16#12131#;
   Cuneiform_Sign_Hi_Times_Gad             :
      constant Unicode_Char := 16#12132#;
   Cuneiform_Sign_Hi_Times_Kin             :
      constant Unicode_Char := 16#12133#;
   Cuneiform_Sign_Hi_Times_Nun             :
      constant Unicode_Char := 16#12134#;
   Cuneiform_Sign_Hi_Times_She             :
      constant Unicode_Char := 16#12135#;
   Cuneiform_Sign_Hi_Times_U               :
      constant Unicode_Char := 16#12136#;
   Cuneiform_Sign_Hu                       :
      constant Unicode_Char := 16#12137#;
   Cuneiform_Sign_Hub2                     :
      constant Unicode_Char := 16#12138#;
   Cuneiform_Sign_Hub2_Times_An            :
      constant Unicode_Char := 16#12139#;
   Cuneiform_Sign_Hub2_Times_Hal           :
      constant Unicode_Char := 16#1213A#;
   Cuneiform_Sign_Hub2_Times_Kaskal        :
      constant Unicode_Char := 16#1213B#;
   Cuneiform_Sign_Hub2_Times_Lish          :
      constant Unicode_Char := 16#1213C#;
   Cuneiform_Sign_Hub2_Times_Ud            :
      constant Unicode_Char := 16#1213D#;
   Cuneiform_Sign_Hul2                     :
      constant Unicode_Char := 16#1213E#;
   Cuneiform_Sign_I                        :
      constant Unicode_Char := 16#1213F#;
   Cuneiform_Sign_I_A                      :
      constant Unicode_Char := 16#12140#;
   Cuneiform_Sign_Ib                       :
      constant Unicode_Char := 16#12141#;
   Cuneiform_Sign_Idim                     :
      constant Unicode_Char := 16#12142#;
   Cuneiform_Sign_Idim_Over_Idim_Bur       :
      constant Unicode_Char := 16#12143#;
   Cuneiform_Sign_Idim_Over_Idim_Squared   :
      constant Unicode_Char := 16#12144#;
   Cuneiform_Sign_Ig                       :
      constant Unicode_Char := 16#12145#;
   Cuneiform_Sign_Igi                      :
      constant Unicode_Char := 16#12146#;
   Cuneiform_Sign_Igi_Dib                  :
      constant Unicode_Char := 16#12147#;
   Cuneiform_Sign_Igi_Ri                   :
      constant Unicode_Char := 16#12148#;
   Cuneiform_Sign_Igi_Over_Igi_Shir_Over_Shir_Ud_Over_Ud :
      constant Unicode_Char := 16#12149#;
   Cuneiform_Sign_Igi_Gunu                 :
      constant Unicode_Char := 16#1214A#;
   Cuneiform_Sign_Il                       :
      constant Unicode_Char := 16#1214B#;
   Cuneiform_Sign_Il_Times_Gan2_Tenu       :
      constant Unicode_Char := 16#1214C#;
   Cuneiform_Sign_Il2                      :
      constant Unicode_Char := 16#1214D#;
   Cuneiform_Sign_Im                       :
      constant Unicode_Char := 16#1214E#;
   Cuneiform_Sign_Im_Times_Tak4            :
      constant Unicode_Char := 16#1214F#;
   Cuneiform_Sign_Im_Crossing_Im           :
      constant Unicode_Char := 16#12150#;
   Cuneiform_Sign_Im_Opposing_Im           :
      constant Unicode_Char := 16#12151#;
   Cuneiform_Sign_Im_Squared               :
      constant Unicode_Char := 16#12152#;
   Cuneiform_Sign_Imin                     :
      constant Unicode_Char := 16#12153#;
   Cuneiform_Sign_In                       :
      constant Unicode_Char := 16#12154#;
   Cuneiform_Sign_Ir                       :
      constant Unicode_Char := 16#12155#;
   Cuneiform_Sign_Ish                      :
      constant Unicode_Char := 16#12156#;
   Cuneiform_Sign_Ka                       :
      constant Unicode_Char := 16#12157#;
   Cuneiform_Sign_Ka_Times_A               :
      constant Unicode_Char := 16#12158#;
   Cuneiform_Sign_Ka_Times_Ad              :
      constant Unicode_Char := 16#12159#;
   Cuneiform_Sign_Ka_Times_Ad_Plus_Ku3     :
      constant Unicode_Char := 16#1215A#;
   Cuneiform_Sign_Ka_Times_Ash2            :
      constant Unicode_Char := 16#1215B#;
   Cuneiform_Sign_Ka_Times_Bad             :
      constant Unicode_Char := 16#1215C#;
   Cuneiform_Sign_Ka_Times_Balag           :
      constant Unicode_Char := 16#1215D#;
   Cuneiform_Sign_Ka_Times_Bar             :
      constant Unicode_Char := 16#1215E#;
   Cuneiform_Sign_Ka_Times_Bi              :
      constant Unicode_Char := 16#1215F#;
   Cuneiform_Sign_Ka_Times_Erin2           :
      constant Unicode_Char := 16#12160#;
   Cuneiform_Sign_Ka_Times_Esh2            :
      constant Unicode_Char := 16#12161#;
   Cuneiform_Sign_Ka_Times_Ga              :
      constant Unicode_Char := 16#12162#;
   Cuneiform_Sign_Ka_Times_Gal             :
      constant Unicode_Char := 16#12163#;
   Cuneiform_Sign_Ka_Times_Gan2_Tenu       :
      constant Unicode_Char := 16#12164#;
   Cuneiform_Sign_Ka_Times_Gar             :
      constant Unicode_Char := 16#12165#;
   Cuneiform_Sign_Ka_Times_Gar_Plus_Sha3_Plus_A :
      constant Unicode_Char := 16#12166#;
   Cuneiform_Sign_Ka_Times_Gi              :
      constant Unicode_Char := 16#12167#;
   Cuneiform_Sign_Ka_Times_Gir2            :
      constant Unicode_Char := 16#12168#;
   Cuneiform_Sign_Ka_Times_Gish_Plus_Sar   :
      constant Unicode_Char := 16#12169#;
   Cuneiform_Sign_Ka_Times_Gish_Crossing_Gish :
      constant Unicode_Char := 16#1216A#;
   Cuneiform_Sign_Ka_Times_Gu              :
      constant Unicode_Char := 16#1216B#;
   Cuneiform_Sign_Ka_Times_Gur7            :
      constant Unicode_Char := 16#1216C#;
   Cuneiform_Sign_Ka_Times_Igi             :
      constant Unicode_Char := 16#1216D#;
   Cuneiform_Sign_Ka_Times_Im              :
      constant Unicode_Char := 16#1216E#;
   Cuneiform_Sign_Ka_Times_Kak             :
      constant Unicode_Char := 16#1216F#;
   Cuneiform_Sign_Ka_Times_Ki              :
      constant Unicode_Char := 16#12170#;
   Cuneiform_Sign_Ka_Times_Kid             :
      constant Unicode_Char := 16#12171#;
   Cuneiform_Sign_Ka_Times_Li              :
      constant Unicode_Char := 16#12172#;
   Cuneiform_Sign_Ka_Times_Lu              :
      constant Unicode_Char := 16#12173#;
   Cuneiform_Sign_Ka_Times_Me              :
      constant Unicode_Char := 16#12174#;
   Cuneiform_Sign_Ka_Times_Me_Plus_Du      :
      constant Unicode_Char := 16#12175#;
   Cuneiform_Sign_Ka_Times_Me_Plus_Gi      :
      constant Unicode_Char := 16#12176#;
   Cuneiform_Sign_Ka_Times_Me_Plus_Te      :
      constant Unicode_Char := 16#12177#;
   Cuneiform_Sign_Ka_Times_Mi              :
      constant Unicode_Char := 16#12178#;
   Cuneiform_Sign_Ka_Times_Mi_Plus_Nunuz   :
      constant Unicode_Char := 16#12179#;
   Cuneiform_Sign_Ka_Times_Ne              :
      constant Unicode_Char := 16#1217A#;
   Cuneiform_Sign_Ka_Times_Nun             :
      constant Unicode_Char := 16#1217B#;
   Cuneiform_Sign_Ka_Times_Pi              :
      constant Unicode_Char := 16#1217C#;
   Cuneiform_Sign_Ka_Times_Ru              :
      constant Unicode_Char := 16#1217D#;
   Cuneiform_Sign_Ka_Times_Sa              :
      constant Unicode_Char := 16#1217E#;
   Cuneiform_Sign_Ka_Times_Sar             :
      constant Unicode_Char := 16#1217F#;
   Cuneiform_Sign_Ka_Times_Sha             :
      constant Unicode_Char := 16#12180#;
   Cuneiform_Sign_Ka_Times_She             :
      constant Unicode_Char := 16#12181#;
   Cuneiform_Sign_Ka_Times_Shid            :
      constant Unicode_Char := 16#12182#;
   Cuneiform_Sign_Ka_Times_Shu             :
      constant Unicode_Char := 16#12183#;
   Cuneiform_Sign_Ka_Times_Sig             :
      constant Unicode_Char := 16#12184#;
   Cuneiform_Sign_Ka_Times_Suhur           :
      constant Unicode_Char := 16#12185#;
   Cuneiform_Sign_Ka_Times_Tar             :
      constant Unicode_Char := 16#12186#;
   Cuneiform_Sign_Ka_Times_U               :
      constant Unicode_Char := 16#12187#;
   Cuneiform_Sign_Ka_Times_U2              :
      constant Unicode_Char := 16#12188#;
   Cuneiform_Sign_Ka_Times_Ud              :
      constant Unicode_Char := 16#12189#;
   Cuneiform_Sign_Ka_Times_Umum_Times_Pa   :
      constant Unicode_Char := 16#1218A#;
   Cuneiform_Sign_Ka_Times_Ush             :
      constant Unicode_Char := 16#1218B#;
   Cuneiform_Sign_Ka_Times_Zi              :
      constant Unicode_Char := 16#1218C#;
   Cuneiform_Sign_Ka2                      :
      constant Unicode_Char := 16#1218D#;
   Cuneiform_Sign_Ka2_Crossing_Ka2         :
      constant Unicode_Char := 16#1218E#;
   Cuneiform_Sign_Kab                      :
      constant Unicode_Char := 16#1218F#;
   Cuneiform_Sign_Kad2                     :
      constant Unicode_Char := 16#12190#;
   Cuneiform_Sign_Kad3                     :
      constant Unicode_Char := 16#12191#;
   Cuneiform_Sign_Kad4                     :
      constant Unicode_Char := 16#12192#;
   Cuneiform_Sign_Kad5                     :
      constant Unicode_Char := 16#12193#;
   Cuneiform_Sign_Kad5_Over_Kad5           :
      constant Unicode_Char := 16#12194#;
   Cuneiform_Sign_Kak                      :
      constant Unicode_Char := 16#12195#;
   Cuneiform_Sign_Kak_Times_Igi_Gunu       :
      constant Unicode_Char := 16#12196#;
   Cuneiform_Sign_Kal                      :
      constant Unicode_Char := 16#12197#;
   Cuneiform_Sign_Kal_Times_Bad            :
      constant Unicode_Char := 16#12198#;
   Cuneiform_Sign_Kal_Crossing_Kal         :
      constant Unicode_Char := 16#12199#;
   Cuneiform_Sign_Kam2                     :
      constant Unicode_Char := 16#1219A#;
   Cuneiform_Sign_Kam4                     :
      constant Unicode_Char := 16#1219B#;
   Cuneiform_Sign_Kaskal                   :
      constant Unicode_Char := 16#1219C#;
   Cuneiform_Sign_Kaskal_Lagab_Times_U_Over_Lagab_Times_U :
      constant Unicode_Char := 16#1219D#;
   Cuneiform_Sign_Kaskal_Over_Kaskal_Lagab_Times_U_Over_Lagab_Times_U :
      constant Unicode_Char := 16#1219E#;
   Cuneiform_Sign_Kesh2                    :
      constant Unicode_Char := 16#1219F#;
   Cuneiform_Sign_Ki                       :
      constant Unicode_Char := 16#121A0#;
   Cuneiform_Sign_Ki_Times_Bad             :
      constant Unicode_Char := 16#121A1#;
   Cuneiform_Sign_Ki_Times_U               :
      constant Unicode_Char := 16#121A2#;
   Cuneiform_Sign_Ki_Times_Ud              :
      constant Unicode_Char := 16#121A3#;
   Cuneiform_Sign_Kid                      :
      constant Unicode_Char := 16#121A4#;
   Cuneiform_Sign_Kin                      :
      constant Unicode_Char := 16#121A5#;
   Cuneiform_Sign_Kisal                    :
      constant Unicode_Char := 16#121A6#;
   Cuneiform_Sign_Kish                     :
      constant Unicode_Char := 16#121A7#;
   Cuneiform_Sign_Kisim5                   :
      constant Unicode_Char := 16#121A8#;
   Cuneiform_Sign_Kisim5_Over_Kisim5       :
      constant Unicode_Char := 16#121A9#;
   Cuneiform_Sign_Ku                       :
      constant Unicode_Char := 16#121AA#;
   Cuneiform_Sign_Ku_Over_Hi_Times_Ash2_Ku_Over_Hi_Times_Ash2 :
      constant Unicode_Char := 16#121AB#;
   Cuneiform_Sign_Ku3                      :
      constant Unicode_Char := 16#121AC#;
   Cuneiform_Sign_Ku4                      :
      constant Unicode_Char := 16#121AD#;
   Cuneiform_Sign_Ku4_Variant_Form         :
      constant Unicode_Char := 16#121AE#;
   Cuneiform_Sign_Ku7                      :
      constant Unicode_Char := 16#121AF#;
   Cuneiform_Sign_Kul                      :
      constant Unicode_Char := 16#121B0#;
   Cuneiform_Sign_Kul_Gunu                 :
      constant Unicode_Char := 16#121B1#;
   Cuneiform_Sign_Kun                      :
      constant Unicode_Char := 16#121B2#;
   Cuneiform_Sign_Kur                      :
      constant Unicode_Char := 16#121B3#;
   Cuneiform_Sign_Kur_Opposing_Kur         :
      constant Unicode_Char := 16#121B4#;
   Cuneiform_Sign_Kushu2                   :
      constant Unicode_Char := 16#121B5#;
   Cuneiform_Sign_Kwu318                   :
      constant Unicode_Char := 16#121B6#;
   Cuneiform_Sign_La                       :
      constant Unicode_Char := 16#121B7#;
   Cuneiform_Sign_Lagab                    :
      constant Unicode_Char := 16#121B8#;
   Cuneiform_Sign_Lagab_Times_A            :
      constant Unicode_Char := 16#121B9#;
   Cuneiform_Sign_Lagab_Times_A_Plus_Da_Plus_Ha :
      constant Unicode_Char := 16#121BA#;
   Cuneiform_Sign_Lagab_Times_A_Plus_Gar   :
      constant Unicode_Char := 16#121BB#;
   Cuneiform_Sign_Lagab_Times_A_Plus_Lal   :
      constant Unicode_Char := 16#121BC#;
   Cuneiform_Sign_Lagab_Times_Al           :
      constant Unicode_Char := 16#121BD#;
   Cuneiform_Sign_Lagab_Times_An           :
      constant Unicode_Char := 16#121BE#;
   Cuneiform_Sign_Lagab_Times_Ash_Zida_Tenu :
      constant Unicode_Char := 16#121BF#;
   Cuneiform_Sign_Lagab_Times_Bad          :
      constant Unicode_Char := 16#121C0#;
   Cuneiform_Sign_Lagab_Times_Bi           :
      constant Unicode_Char := 16#121C1#;
   Cuneiform_Sign_Lagab_Times_Dar          :
      constant Unicode_Char := 16#121C2#;
   Cuneiform_Sign_Lagab_Times_En           :
      constant Unicode_Char := 16#121C3#;
   Cuneiform_Sign_Lagab_Times_Ga           :
      constant Unicode_Char := 16#121C4#;
   Cuneiform_Sign_Lagab_Times_Gar          :
      constant Unicode_Char := 16#121C5#;
   Cuneiform_Sign_Lagab_Times_Gud          :
      constant Unicode_Char := 16#121C6#;
   Cuneiform_Sign_Lagab_Times_Gud_Plus_Gud :
      constant Unicode_Char := 16#121C7#;
   Cuneiform_Sign_Lagab_Times_Ha           :
      constant Unicode_Char := 16#121C8#;
   Cuneiform_Sign_Lagab_Times_Hal          :
      constant Unicode_Char := 16#121C9#;
   Cuneiform_Sign_Lagab_Times_Hi_Times_Nun :
      constant Unicode_Char := 16#121CA#;
   Cuneiform_Sign_Lagab_Times_Igi_Gunu     :
      constant Unicode_Char := 16#121CB#;
   Cuneiform_Sign_Lagab_Times_Im           :
      constant Unicode_Char := 16#121CC#;
   Cuneiform_Sign_Lagab_Times_Im_Plus_Ha   :
      constant Unicode_Char := 16#121CD#;
   Cuneiform_Sign_Lagab_Times_Im_Plus_Lu   :
      constant Unicode_Char := 16#121CE#;
   Cuneiform_Sign_Lagab_Times_Ki           :
      constant Unicode_Char := 16#121CF#;
   Cuneiform_Sign_Lagab_Times_Kin          :
      constant Unicode_Char := 16#121D0#;
   Cuneiform_Sign_Lagab_Times_Ku3          :
      constant Unicode_Char := 16#121D1#;
   Cuneiform_Sign_Lagab_Times_Kul          :
      constant Unicode_Char := 16#121D2#;
   Cuneiform_Sign_Lagab_Times_Kul_Plus_Hi_Plus_A :
      constant Unicode_Char := 16#121D3#;
   Cuneiform_Sign_Lagab_Times_Lagab        :
      constant Unicode_Char := 16#121D4#;
   Cuneiform_Sign_Lagab_Times_Lish         :
      constant Unicode_Char := 16#121D5#;
   Cuneiform_Sign_Lagab_Times_Lu           :
      constant Unicode_Char := 16#121D6#;
   Cuneiform_Sign_Lagab_Times_Lul          :
      constant Unicode_Char := 16#121D7#;
   Cuneiform_Sign_Lagab_Times_Me           :
      constant Unicode_Char := 16#121D8#;
   Cuneiform_Sign_Lagab_Times_Me_Plus_En   :
      constant Unicode_Char := 16#121D9#;
   Cuneiform_Sign_Lagab_Times_Mush         :
      constant Unicode_Char := 16#121DA#;
   Cuneiform_Sign_Lagab_Times_Ne           :
      constant Unicode_Char := 16#121DB#;
   Cuneiform_Sign_Lagab_Times_She_Plus_Sum :
      constant Unicode_Char := 16#121DC#;
   Cuneiform_Sign_Lagab_Times_Shita_Plus_Gish_Plus_Erin2 :
      constant Unicode_Char := 16#121DD#;
   Cuneiform_Sign_Lagab_Times_Shita_Plus_Gish_Tenu :
      constant Unicode_Char := 16#121DE#;
   Cuneiform_Sign_Lagab_Times_Shu2         :
      constant Unicode_Char := 16#121DF#;
   Cuneiform_Sign_Lagab_Times_Shu2_Plus_Shu2 :
      constant Unicode_Char := 16#121E0#;
   Cuneiform_Sign_Lagab_Times_Sum          :
      constant Unicode_Char := 16#121E1#;
   Cuneiform_Sign_Lagab_Times_Tag          :
      constant Unicode_Char := 16#121E2#;
   Cuneiform_Sign_Lagab_Times_Tak4         :
      constant Unicode_Char := 16#121E3#;
   Cuneiform_Sign_Lagab_Times_Te_Plus_A_Plus_Su_Plus_Na :
      constant Unicode_Char := 16#121E4#;
   Cuneiform_Sign_Lagab_Times_U            :
      constant Unicode_Char := 16#121E5#;
   Cuneiform_Sign_Lagab_Times_U_Plus_A     :
      constant Unicode_Char := 16#121E6#;
   Cuneiform_Sign_Lagab_Times_U_Plus_U_Plus_U :
      constant Unicode_Char := 16#121E7#;
   Cuneiform_Sign_Lagab_Times_U2_Plus_Ash  :
      constant Unicode_Char := 16#121E8#;
   Cuneiform_Sign_Lagab_Times_Ud           :
      constant Unicode_Char := 16#121E9#;
   Cuneiform_Sign_Lagab_Times_Ush          :
      constant Unicode_Char := 16#121EA#;
   Cuneiform_Sign_Lagab_Squared            :
      constant Unicode_Char := 16#121EB#;
   Cuneiform_Sign_Lagar                    :
      constant Unicode_Char := 16#121EC#;
   Cuneiform_Sign_Lagar_Times_She          :
      constant Unicode_Char := 16#121ED#;
   Cuneiform_Sign_Lagar_Times_She_Plus_Sum :
      constant Unicode_Char := 16#121EE#;
   Cuneiform_Sign_Lagar_Gunu               :
      constant Unicode_Char := 16#121EF#;
   Cuneiform_Sign_Lagar_Gunu_Over_Lagar_Gunu_She :
      constant Unicode_Char := 16#121F0#;
   Cuneiform_Sign_Lahshu                   :
      constant Unicode_Char := 16#121F1#;
   Cuneiform_Sign_Lal                      :
      constant Unicode_Char := 16#121F2#;
   Cuneiform_Sign_Lal_Times_Lal            :
      constant Unicode_Char := 16#121F3#;
   Cuneiform_Sign_Lam                      :
      constant Unicode_Char := 16#121F4#;
   Cuneiform_Sign_Lam_Times_Kur            :
      constant Unicode_Char := 16#121F5#;
   Cuneiform_Sign_Lam_Times_Kur_Plus_Ru    :
      constant Unicode_Char := 16#121F6#;
   Cuneiform_Sign_Li                       :
      constant Unicode_Char := 16#121F7#;
   Cuneiform_Sign_Lil                      :
      constant Unicode_Char := 16#121F8#;
   Cuneiform_Sign_Limmu2                   :
      constant Unicode_Char := 16#121F9#;
   Cuneiform_Sign_Lish                     :
      constant Unicode_Char := 16#121FA#;
   Cuneiform_Sign_Lu                       :
      constant Unicode_Char := 16#121FB#;
   Cuneiform_Sign_Lu_Times_Bad             :
      constant Unicode_Char := 16#121FC#;
   Cuneiform_Sign_Lu2                      :
      constant Unicode_Char := 16#121FD#;
   Cuneiform_Sign_Lu2_Times_Al             :
      constant Unicode_Char := 16#121FE#;
   Cuneiform_Sign_Lu2_Times_Bad            :
      constant Unicode_Char := 16#121FF#;
   Cuneiform_Sign_Lu2_Times_Esh2           :
      constant Unicode_Char := 16#12200#;
   Cuneiform_Sign_Lu2_Times_Esh2_Tenu      :
      constant Unicode_Char := 16#12201#;
   Cuneiform_Sign_Lu2_Times_Gan2_Tenu      :
      constant Unicode_Char := 16#12202#;
   Cuneiform_Sign_Lu2_Times_Hi_Times_Bad   :
      constant Unicode_Char := 16#12203#;
   Cuneiform_Sign_Lu2_Times_Im             :
      constant Unicode_Char := 16#12204#;
   Cuneiform_Sign_Lu2_Times_Kad2           :
      constant Unicode_Char := 16#12205#;
   Cuneiform_Sign_Lu2_Times_Kad3           :
      constant Unicode_Char := 16#12206#;
   Cuneiform_Sign_Lu2_Times_Kad3_Plus_Ash  :
      constant Unicode_Char := 16#12207#;
   Cuneiform_Sign_Lu2_Times_Ki             :
      constant Unicode_Char := 16#12208#;
   Cuneiform_Sign_Lu2_Times_La_Plus_Ash    :
      constant Unicode_Char := 16#12209#;
   Cuneiform_Sign_Lu2_Times_Lagab          :
      constant Unicode_Char := 16#1220A#;
   Cuneiform_Sign_Lu2_Times_Me_Plus_En     :
      constant Unicode_Char := 16#1220B#;
   Cuneiform_Sign_Lu2_Times_Ne             :
      constant Unicode_Char := 16#1220C#;
   Cuneiform_Sign_Lu2_Times_Nu             :
      constant Unicode_Char := 16#1220D#;
   Cuneiform_Sign_Lu2_Times_Si_Plus_Ash    :
      constant Unicode_Char := 16#1220E#;
   Cuneiform_Sign_Lu2_Times_Sik2_Plus_Bu   :
      constant Unicode_Char := 16#1220F#;
   Cuneiform_Sign_Lu2_Times_Tug2           :
      constant Unicode_Char := 16#12210#;
   Cuneiform_Sign_Lu2_Tenu                 :
      constant Unicode_Char := 16#12211#;
   Cuneiform_Sign_Lu2_Crossing_Lu2         :
      constant Unicode_Char := 16#12212#;
   Cuneiform_Sign_Lu2_Opposing_Lu2         :
      constant Unicode_Char := 16#12213#;
   Cuneiform_Sign_Lu2_Squared              :
      constant Unicode_Char := 16#12214#;
   Cuneiform_Sign_Lu2_Sheshig              :
      constant Unicode_Char := 16#12215#;
   Cuneiform_Sign_Lu3                      :
      constant Unicode_Char := 16#12216#;
   Cuneiform_Sign_Lugal                    :
      constant Unicode_Char := 16#12217#;
   Cuneiform_Sign_Lugal_Over_Lugal         :
      constant Unicode_Char := 16#12218#;
   Cuneiform_Sign_Lugal_Opposing_Lugal     :
      constant Unicode_Char := 16#12219#;
   Cuneiform_Sign_Lugal_Sheshig            :
      constant Unicode_Char := 16#1221A#;
   Cuneiform_Sign_Luh                      :
      constant Unicode_Char := 16#1221B#;
   Cuneiform_Sign_Lul                      :
      constant Unicode_Char := 16#1221C#;
   Cuneiform_Sign_Lum                      :
      constant Unicode_Char := 16#1221D#;
   Cuneiform_Sign_Lum_Over_Lum             :
      constant Unicode_Char := 16#1221E#;
   Cuneiform_Sign_Lum_Over_Lum_Gar_Over_Gar :
      constant Unicode_Char := 16#1221F#;
   Cuneiform_Sign_Ma                       :
      constant Unicode_Char := 16#12220#;
   Cuneiform_Sign_Ma_Times_Tak4            :
      constant Unicode_Char := 16#12221#;
   Cuneiform_Sign_Ma_Gunu                  :
      constant Unicode_Char := 16#12222#;
   Cuneiform_Sign_Ma2                      :
      constant Unicode_Char := 16#12223#;
   Cuneiform_Sign_Mah                      :
      constant Unicode_Char := 16#12224#;
   Cuneiform_Sign_Mar                      :
      constant Unicode_Char := 16#12225#;
   Cuneiform_Sign_Mash                     :
      constant Unicode_Char := 16#12226#;
   Cuneiform_Sign_Mash2                    :
      constant Unicode_Char := 16#12227#;
   Cuneiform_Sign_Me                       :
      constant Unicode_Char := 16#12228#;
   Cuneiform_Sign_Mes                      :
      constant Unicode_Char := 16#12229#;
   Cuneiform_Sign_Mi                       :
      constant Unicode_Char := 16#1222A#;
   Cuneiform_Sign_Min                      :
      constant Unicode_Char := 16#1222B#;
   Cuneiform_Sign_Mu                       :
      constant Unicode_Char := 16#1222C#;
   Cuneiform_Sign_Mu_Over_Mu               :
      constant Unicode_Char := 16#1222D#;
   Cuneiform_Sign_Mug                      :
      constant Unicode_Char := 16#1222E#;
   Cuneiform_Sign_Mug_Gunu                 :
      constant Unicode_Char := 16#1222F#;
   Cuneiform_Sign_Munsub                   :
      constant Unicode_Char := 16#12230#;
   Cuneiform_Sign_Murgu2                   :
      constant Unicode_Char := 16#12231#;
   Cuneiform_Sign_Mush                     :
      constant Unicode_Char := 16#12232#;
   Cuneiform_Sign_Mush_Times_A             :
      constant Unicode_Char := 16#12233#;
   Cuneiform_Sign_Mush_Times_Kur           :
      constant Unicode_Char := 16#12234#;
   Cuneiform_Sign_Mush_Times_Za            :
      constant Unicode_Char := 16#12235#;
   Cuneiform_Sign_Mush_Over_Mush           :
      constant Unicode_Char := 16#12236#;
   Cuneiform_Sign_Mush_Over_Mush_Times_A_Plus_Na :
      constant Unicode_Char := 16#12237#;
   Cuneiform_Sign_Mush_Crossing_Mush       :
      constant Unicode_Char := 16#12238#;
   Cuneiform_Sign_Mush3                    :
      constant Unicode_Char := 16#12239#;
   Cuneiform_Sign_Mush3_Times_A            :
      constant Unicode_Char := 16#1223A#;
   Cuneiform_Sign_Mush3_Times_A_Plus_Di    :
      constant Unicode_Char := 16#1223B#;
   Cuneiform_Sign_Mush3_Times_Di           :
      constant Unicode_Char := 16#1223C#;
   Cuneiform_Sign_Mush3_Gunu               :
      constant Unicode_Char := 16#1223D#;
   Cuneiform_Sign_Na                       :
      constant Unicode_Char := 16#1223E#;
   Cuneiform_Sign_Na2                      :
      constant Unicode_Char := 16#1223F#;
   Cuneiform_Sign_Naga                     :
      constant Unicode_Char := 16#12240#;
   Cuneiform_Sign_Naga_Inverted            :
      constant Unicode_Char := 16#12241#;
   Cuneiform_Sign_Naga_Times_Shu_Tenu      :
      constant Unicode_Char := 16#12242#;
   Cuneiform_Sign_Naga_Opposing_Naga       :
      constant Unicode_Char := 16#12243#;
   Cuneiform_Sign_Nagar                    :
      constant Unicode_Char := 16#12244#;
   Cuneiform_Sign_Nam_Nutillu              :
      constant Unicode_Char := 16#12245#;
   Cuneiform_Sign_Nam                      :
      constant Unicode_Char := 16#12246#;
   Cuneiform_Sign_Nam2                     :
      constant Unicode_Char := 16#12247#;
   Cuneiform_Sign_Ne                       :
      constant Unicode_Char := 16#12248#;
   Cuneiform_Sign_Ne_Times_A               :
      constant Unicode_Char := 16#12249#;
   Cuneiform_Sign_Ne_Times_Ud              :
      constant Unicode_Char := 16#1224A#;
   Cuneiform_Sign_Ne_Sheshig               :
      constant Unicode_Char := 16#1224B#;
   Cuneiform_Sign_Ni                       :
      constant Unicode_Char := 16#1224C#;
   Cuneiform_Sign_Ni_Times_E               :
      constant Unicode_Char := 16#1224D#;
   Cuneiform_Sign_Ni2                      :
      constant Unicode_Char := 16#1224E#;
   Cuneiform_Sign_Nim                      :
      constant Unicode_Char := 16#1224F#;
   Cuneiform_Sign_Nim_Times_Gan2_Tenu      :
      constant Unicode_Char := 16#12250#;
   Cuneiform_Sign_Nim_Times_Gar_Plus_Gan2_Tenu :
      constant Unicode_Char := 16#12251#;
   Cuneiform_Sign_Ninda2                   :
      constant Unicode_Char := 16#12252#;
   Cuneiform_Sign_Ninda2_Times_An          :
      constant Unicode_Char := 16#12253#;
   Cuneiform_Sign_Ninda2_Times_Ash         :
      constant Unicode_Char := 16#12254#;
   Cuneiform_Sign_Ninda2_Times_Ash_Plus_Ash :
      constant Unicode_Char := 16#12255#;
   Cuneiform_Sign_Ninda2_Times_Gud         :
      constant Unicode_Char := 16#12256#;
   Cuneiform_Sign_Ninda2_Times_Me_Plus_Gan2_Tenu :
      constant Unicode_Char := 16#12257#;
   Cuneiform_Sign_Ninda2_Times_Ne          :
      constant Unicode_Char := 16#12258#;
   Cuneiform_Sign_Ninda2_Times_Nun         :
      constant Unicode_Char := 16#12259#;
   Cuneiform_Sign_Ninda2_Times_She         :
      constant Unicode_Char := 16#1225A#;
   Cuneiform_Sign_Ninda2_Times_She_Plus_A_An :
      constant Unicode_Char := 16#1225B#;
   Cuneiform_Sign_Ninda2_Times_She_Plus_Ash :
      constant Unicode_Char := 16#1225C#;
   Cuneiform_Sign_Ninda2_Times_She_Plus_Ash_Plus_Ash :
      constant Unicode_Char := 16#1225D#;
   Cuneiform_Sign_Ninda2_Times_U2_Plus_Ash :
      constant Unicode_Char := 16#1225E#;
   Cuneiform_Sign_Ninda2_Times_Ush         :
      constant Unicode_Char := 16#1225F#;
   Cuneiform_Sign_Nisag                    :
      constant Unicode_Char := 16#12260#;
   Cuneiform_Sign_Nu                       :
      constant Unicode_Char := 16#12261#;
   Cuneiform_Sign_Nu11                     :
      constant Unicode_Char := 16#12262#;
   Cuneiform_Sign_Nun                      :
      constant Unicode_Char := 16#12263#;
   Cuneiform_Sign_Nun_Lagar_Times_Gar      :
      constant Unicode_Char := 16#12264#;
   Cuneiform_Sign_Nun_Lagar_Times_Mash     :
      constant Unicode_Char := 16#12265#;
   Cuneiform_Sign_Nun_Lagar_Times_Sal      :
      constant Unicode_Char := 16#12266#;
   Cuneiform_Sign_Nun_Lagar_Times_Sal_Over_Nun_Lagar_Times_Sal :
      constant Unicode_Char := 16#12267#;
   Cuneiform_Sign_Nun_Lagar_Times_Ush      :
      constant Unicode_Char := 16#12268#;
   Cuneiform_Sign_Nun_Tenu                 :
      constant Unicode_Char := 16#12269#;
   Cuneiform_Sign_Nun_Over_Nun             :
      constant Unicode_Char := 16#1226A#;
   Cuneiform_Sign_Nun_Crossing_Nun         :
      constant Unicode_Char := 16#1226B#;
   Cuneiform_Sign_Nun_Crossing_Nun_Lagar_Over_Lagar :
      constant Unicode_Char := 16#1226C#;
   Cuneiform_Sign_Nunuz                    :
      constant Unicode_Char := 16#1226D#;
   Cuneiform_Sign_Nunuz_Ab2_Times_Ashgab   :
      constant Unicode_Char := 16#1226E#;
   Cuneiform_Sign_Nunuz_Ab2_Times_Bi       :
      constant Unicode_Char := 16#1226F#;
   Cuneiform_Sign_Nunuz_Ab2_Times_Dug      :
      constant Unicode_Char := 16#12270#;
   Cuneiform_Sign_Nunuz_Ab2_Times_Gud      :
      constant Unicode_Char := 16#12271#;
   Cuneiform_Sign_Nunuz_Ab2_Times_Igi_Gunu :
      constant Unicode_Char := 16#12272#;
   Cuneiform_Sign_Nunuz_Ab2_Times_Kad3     :
      constant Unicode_Char := 16#12273#;
   Cuneiform_Sign_Nunuz_Ab2_Times_La       :
      constant Unicode_Char := 16#12274#;
   Cuneiform_Sign_Nunuz_Ab2_Times_Ne       :
      constant Unicode_Char := 16#12275#;
   Cuneiform_Sign_Nunuz_Ab2_Times_Sila3    :
      constant Unicode_Char := 16#12276#;
   Cuneiform_Sign_Nunuz_Ab2_Times_U2       :
      constant Unicode_Char := 16#12277#;
   Cuneiform_Sign_Nunuz_Kisim5_Times_Bi    :
      constant Unicode_Char := 16#12278#;
   Cuneiform_Sign_Nunuz_Kisim5_Times_Bi_U  :
      constant Unicode_Char := 16#12279#;
   Cuneiform_Sign_Pa                       :
      constant Unicode_Char := 16#1227A#;
   Cuneiform_Sign_Pad                      :
      constant Unicode_Char := 16#1227B#;
   Cuneiform_Sign_Pan                      :
      constant Unicode_Char := 16#1227C#;
   Cuneiform_Sign_Pap                      :
      constant Unicode_Char := 16#1227D#;
   Cuneiform_Sign_Pesh2                    :
      constant Unicode_Char := 16#1227E#;
   Cuneiform_Sign_Pi                       :
      constant Unicode_Char := 16#1227F#;
   Cuneiform_Sign_Pi_Times_A               :
      constant Unicode_Char := 16#12280#;
   Cuneiform_Sign_Pi_Times_Ab              :
      constant Unicode_Char := 16#12281#;
   Cuneiform_Sign_Pi_Times_Bi              :
      constant Unicode_Char := 16#12282#;
   Cuneiform_Sign_Pi_Times_Bu              :
      constant Unicode_Char := 16#12283#;
   Cuneiform_Sign_Pi_Times_E               :
      constant Unicode_Char := 16#12284#;
   Cuneiform_Sign_Pi_Times_I               :
      constant Unicode_Char := 16#12285#;
   Cuneiform_Sign_Pi_Times_Ib              :
      constant Unicode_Char := 16#12286#;
   Cuneiform_Sign_Pi_Times_U               :
      constant Unicode_Char := 16#12287#;
   Cuneiform_Sign_Pi_Times_U2              :
      constant Unicode_Char := 16#12288#;
   Cuneiform_Sign_Pi_Crossing_Pi           :
      constant Unicode_Char := 16#12289#;
   Cuneiform_Sign_Pirig                    :
      constant Unicode_Char := 16#1228A#;
   Cuneiform_Sign_Pirig_Times_Kal          :
      constant Unicode_Char := 16#1228B#;
   Cuneiform_Sign_Pirig_Times_Ud           :
      constant Unicode_Char := 16#1228C#;
   Cuneiform_Sign_Pirig_Times_Za           :
      constant Unicode_Char := 16#1228D#;
   Cuneiform_Sign_Pirig_Opposing_Pirig     :
      constant Unicode_Char := 16#1228E#;
   Cuneiform_Sign_Ra                       :
      constant Unicode_Char := 16#1228F#;
   Cuneiform_Sign_Rab                      :
      constant Unicode_Char := 16#12290#;
   Cuneiform_Sign_Ri                       :
      constant Unicode_Char := 16#12291#;
   Cuneiform_Sign_Ru                       :
      constant Unicode_Char := 16#12292#;
   Cuneiform_Sign_Sa                       :
      constant Unicode_Char := 16#12293#;
   Cuneiform_Sign_Sag_Nutillu              :
      constant Unicode_Char := 16#12294#;
   Cuneiform_Sign_Sag                      :
      constant Unicode_Char := 16#12295#;
   Cuneiform_Sign_Sag_Times_A              :
      constant Unicode_Char := 16#12296#;
   Cuneiform_Sign_Sag_Times_Du             :
      constant Unicode_Char := 16#12297#;
   Cuneiform_Sign_Sag_Times_Dub            :
      constant Unicode_Char := 16#12298#;
   Cuneiform_Sign_Sag_Times_Ha             :
      constant Unicode_Char := 16#12299#;
   Cuneiform_Sign_Sag_Times_Kak            :
      constant Unicode_Char := 16#1229A#;
   Cuneiform_Sign_Sag_Times_Kur            :
      constant Unicode_Char := 16#1229B#;
   Cuneiform_Sign_Sag_Times_Lum            :
      constant Unicode_Char := 16#1229C#;
   Cuneiform_Sign_Sag_Times_Mi             :
      constant Unicode_Char := 16#1229D#;
   Cuneiform_Sign_Sag_Times_Nun            :
      constant Unicode_Char := 16#1229E#;
   Cuneiform_Sign_Sag_Times_Sal            :
      constant Unicode_Char := 16#1229F#;
   Cuneiform_Sign_Sag_Times_Shid           :
      constant Unicode_Char := 16#122A0#;
   Cuneiform_Sign_Sag_Times_Tab            :
      constant Unicode_Char := 16#122A1#;
   Cuneiform_Sign_Sag_Times_U2             :
      constant Unicode_Char := 16#122A2#;
   Cuneiform_Sign_Sag_Times_Ub             :
      constant Unicode_Char := 16#122A3#;
   Cuneiform_Sign_Sag_Times_Um             :
      constant Unicode_Char := 16#122A4#;
   Cuneiform_Sign_Sag_Times_Ur             :
      constant Unicode_Char := 16#122A5#;
   Cuneiform_Sign_Sag_Times_Ush            :
      constant Unicode_Char := 16#122A6#;
   Cuneiform_Sign_Sag_Over_Sag             :
      constant Unicode_Char := 16#122A7#;
   Cuneiform_Sign_Sag_Gunu                 :
      constant Unicode_Char := 16#122A8#;
   Cuneiform_Sign_Sal                      :
      constant Unicode_Char := 16#122A9#;
   Cuneiform_Sign_Sal_Lagab_Times_Ash2     :
      constant Unicode_Char := 16#122AA#;
   Cuneiform_Sign_Sanga2                   :
      constant Unicode_Char := 16#122AB#;
   Cuneiform_Sign_Sar                      :
      constant Unicode_Char := 16#122AC#;
   Cuneiform_Sign_Sha                      :
      constant Unicode_Char := 16#122AD#;
   Cuneiform_Sign_Sha3                     :
      constant Unicode_Char := 16#122AE#;
   Cuneiform_Sign_Sha3_Times_A             :
      constant Unicode_Char := 16#122AF#;
   Cuneiform_Sign_Sha3_Times_Bad           :
      constant Unicode_Char := 16#122B0#;
   Cuneiform_Sign_Sha3_Times_Gish          :
      constant Unicode_Char := 16#122B1#;
   Cuneiform_Sign_Sha3_Times_Ne            :
      constant Unicode_Char := 16#122B2#;
   Cuneiform_Sign_Sha3_Times_Shu2          :
      constant Unicode_Char := 16#122B3#;
   Cuneiform_Sign_Sha3_Times_Tur           :
      constant Unicode_Char := 16#122B4#;
   Cuneiform_Sign_Sha3_Times_U             :
      constant Unicode_Char := 16#122B5#;
   Cuneiform_Sign_Sha3_Times_U_Plus_A      :
      constant Unicode_Char := 16#122B6#;
   Cuneiform_Sign_Sha6                     :
      constant Unicode_Char := 16#122B7#;
   Cuneiform_Sign_Shab6                    :
      constant Unicode_Char := 16#122B8#;
   Cuneiform_Sign_Shar2                    :
      constant Unicode_Char := 16#122B9#;
   Cuneiform_Sign_She                      :
      constant Unicode_Char := 16#122BA#;
   Cuneiform_Sign_She_Hu                   :
      constant Unicode_Char := 16#122BB#;
   Cuneiform_Sign_She_Over_She_Gad_Over_Gad_Gar_Over_Gar :
      constant Unicode_Char := 16#122BC#;
   Cuneiform_Sign_She_Over_She_Tab_Over_Tab_Gar_Over_Gar :
      constant Unicode_Char := 16#122BD#;
   Cuneiform_Sign_Sheg9                    :
      constant Unicode_Char := 16#122BE#;
   Cuneiform_Sign_Shen                     :
      constant Unicode_Char := 16#122BF#;
   Cuneiform_Sign_Shesh                    :
      constant Unicode_Char := 16#122C0#;
   Cuneiform_Sign_Shesh2                   :
      constant Unicode_Char := 16#122C1#;
   Cuneiform_Sign_Sheshlam                 :
      constant Unicode_Char := 16#122C2#;
   Cuneiform_Sign_Shid                     :
      constant Unicode_Char := 16#122C3#;
   Cuneiform_Sign_Shid_Times_A             :
      constant Unicode_Char := 16#122C4#;
   Cuneiform_Sign_Shid_Times_Im            :
      constant Unicode_Char := 16#122C5#;
   Cuneiform_Sign_Shim                     :
      constant Unicode_Char := 16#122C6#;
   Cuneiform_Sign_Shim_Times_A             :
      constant Unicode_Char := 16#122C7#;
   Cuneiform_Sign_Shim_Times_Bal           :
      constant Unicode_Char := 16#122C8#;
   Cuneiform_Sign_Shim_Times_Bulug         :
      constant Unicode_Char := 16#122C9#;
   Cuneiform_Sign_Shim_Times_Din           :
      constant Unicode_Char := 16#122CA#;
   Cuneiform_Sign_Shim_Times_Gar           :
      constant Unicode_Char := 16#122CB#;
   Cuneiform_Sign_Shim_Times_Igi           :
      constant Unicode_Char := 16#122CC#;
   Cuneiform_Sign_Shim_Times_Igi_Gunu      :
      constant Unicode_Char := 16#122CD#;
   Cuneiform_Sign_Shim_Times_Kushu2        :
      constant Unicode_Char := 16#122CE#;
   Cuneiform_Sign_Shim_Times_Lul           :
      constant Unicode_Char := 16#122CF#;
   Cuneiform_Sign_Shim_Times_Mug           :
      constant Unicode_Char := 16#122D0#;
   Cuneiform_Sign_Shim_Times_Sal           :
      constant Unicode_Char := 16#122D1#;
   Cuneiform_Sign_Shinig                   :
      constant Unicode_Char := 16#122D2#;
   Cuneiform_Sign_Shir                     :
      constant Unicode_Char := 16#122D3#;
   Cuneiform_Sign_Shir_Tenu                :
      constant Unicode_Char := 16#122D4#;
   Cuneiform_Sign_Nu11_Tenu                :
      Unicode_Char renames Cuneiform_Sign_Shir_Tenu;
   Cuneiform_Sign_Shir_Over_Shir_Bur_Over_Bur :
      constant Unicode_Char := 16#122D5#;
   Cuneiform_Sign_Nu11_Over_Nu11_Bur_Over_Bur :
      Unicode_Char renames Cuneiform_Sign_Shir_Over_Shir_Bur_Over_Bur;
   Cuneiform_Sign_Shita                    :
      constant Unicode_Char := 16#122D6#;
   Cuneiform_Sign_Shu                      :
      constant Unicode_Char := 16#122D7#;
   Cuneiform_Sign_Shu_Over_Inverted_Shu    :
      constant Unicode_Char := 16#122D8#;
   Cuneiform_Sign_Shu2                     :
      constant Unicode_Char := 16#122D9#;
   Cuneiform_Sign_Shubur                   :
      constant Unicode_Char := 16#122DA#;
   Cuneiform_Sign_Si                       :
      constant Unicode_Char := 16#122DB#;
   Cuneiform_Sign_Si_Gunu                  :
      constant Unicode_Char := 16#122DC#;
   Cuneiform_Sign_Sig                      :
      constant Unicode_Char := 16#122DD#;
   Cuneiform_Sign_Sig4                     :
      constant Unicode_Char := 16#122DE#;
   Cuneiform_Sign_Sig4_Over_Sig4_Shu2      :
      constant Unicode_Char := 16#122DF#;
   Cuneiform_Sign_Sik2                     :
      constant Unicode_Char := 16#122E0#;
   Cuneiform_Sign_Sila3                    :
      constant Unicode_Char := 16#122E1#;
   Cuneiform_Sign_Su                       :
      constant Unicode_Char := 16#122E2#;
   Cuneiform_Sign_Su_Over_Su               :
      constant Unicode_Char := 16#122E3#;
   Cuneiform_Sign_Sud                      :
      constant Unicode_Char := 16#122E4#;
   Cuneiform_Sign_Sud2                     :
      constant Unicode_Char := 16#122E5#;
   Cuneiform_Sign_Suhur                    :
      constant Unicode_Char := 16#122E6#;
   Cuneiform_Sign_Sum                      :
      constant Unicode_Char := 16#122E7#;
   Cuneiform_Sign_Sumash                   :
      constant Unicode_Char := 16#122E8#;
   Cuneiform_Sign_Sur                      :
      constant Unicode_Char := 16#122E9#;
   Cuneiform_Sign_Sur9                     :
      constant Unicode_Char := 16#122EA#;
   Cuneiform_Sign_Ta                       :
      constant Unicode_Char := 16#122EB#;
   Cuneiform_Sign_Ta_Asterisk              :
      constant Unicode_Char := 16#122EC#;
   Cuneiform_Sign_Ta_Times_Hi              :
      constant Unicode_Char := 16#122ED#;
   Cuneiform_Sign_Ta_Times_Mi              :
      constant Unicode_Char := 16#122EE#;
   Cuneiform_Sign_Ta_Gunu                  :
      constant Unicode_Char := 16#122EF#;
   Cuneiform_Sign_Tab                      :
      constant Unicode_Char := 16#122F0#;
   Cuneiform_Sign_Tab_Over_Tab_Ni_Over_Ni_Dish_Over_Dish :
      constant Unicode_Char := 16#122F1#;
   Cuneiform_Sign_Tab_Squared              :
      constant Unicode_Char := 16#122F2#;
   Cuneiform_Sign_Tag                      :
      constant Unicode_Char := 16#122F3#;
   Cuneiform_Sign_Tag_Times_Bi             :
      constant Unicode_Char := 16#122F4#;
   Cuneiform_Sign_Tag_Times_Gud            :
      constant Unicode_Char := 16#122F5#;
   Cuneiform_Sign_Tag_Times_She            :
      constant Unicode_Char := 16#122F6#;
   Cuneiform_Sign_Tag_Times_Shu            :
      constant Unicode_Char := 16#122F7#;
   Cuneiform_Sign_Tag_Times_Tug2           :
      constant Unicode_Char := 16#122F8#;
   Cuneiform_Sign_Tag_Times_Ud             :
      constant Unicode_Char := 16#122F9#;
   Cuneiform_Sign_Tak4                     :
      constant Unicode_Char := 16#122FA#;
   Cuneiform_Sign_Tar                      :
      constant Unicode_Char := 16#122FB#;
   Cuneiform_Sign_Te                       :
      constant Unicode_Char := 16#122FC#;
   Cuneiform_Sign_Te_Gunu                  :
      constant Unicode_Char := 16#122FD#;
   Cuneiform_Sign_Ti                       :
      constant Unicode_Char := 16#122FE#;
   Cuneiform_Sign_Ti_Tenu                  :
      constant Unicode_Char := 16#122FF#;
   Cuneiform_Sign_Til                      :
      constant Unicode_Char := 16#12300#;
   Cuneiform_Sign_Tir                      :
      constant Unicode_Char := 16#12301#;
   Cuneiform_Sign_Tir_Times_Tak4           :
      constant Unicode_Char := 16#12302#;
   Cuneiform_Sign_Tir_Over_Tir             :
      constant Unicode_Char := 16#12303#;
   Cuneiform_Sign_Tir_Over_Tir_Gad_Over_Gad_Gar_Over_Gar :
      constant Unicode_Char := 16#12304#;
   Cuneiform_Sign_Tu                       :
      constant Unicode_Char := 16#12305#;
   Cuneiform_Sign_Tug2                     :
      constant Unicode_Char := 16#12306#;
   Cuneiform_Sign_Tuk                      :
      constant Unicode_Char := 16#12307#;
   Cuneiform_Sign_Tum                      :
      constant Unicode_Char := 16#12308#;
   Cuneiform_Sign_Tur                      :
      constant Unicode_Char := 16#12309#;
   Cuneiform_Sign_Tur_Over_Tur_Za_Over_Za  :
      constant Unicode_Char := 16#1230A#;
   Cuneiform_Sign_U                        :
      constant Unicode_Char := 16#1230B#;
   Cuneiform_Sign_U_Gud                    :
      constant Unicode_Char := 16#1230C#;
   Cuneiform_Sign_U_U_U                    :
      constant Unicode_Char := 16#1230D#;
   Cuneiform_Sign_U_Over_U_Pa_Over_Pa_Gar_Over_Gar :
      constant Unicode_Char := 16#1230E#;
   Cuneiform_Sign_U_Over_U_Sur_Over_Sur    :
      constant Unicode_Char := 16#1230F#;
   Cuneiform_Sign_U_Over_U_U_Reversed_Over_U_Reversed :
      constant Unicode_Char := 16#12310#;
   Cuneiform_Sign_U2                       :
      constant Unicode_Char := 16#12311#;
   Cuneiform_Sign_Ub                       :
      constant Unicode_Char := 16#12312#;
   Cuneiform_Sign_Ud                       :
      constant Unicode_Char := 16#12313#;
   Cuneiform_Sign_Ud_Kushu2                :
      constant Unicode_Char := 16#12314#;
   Cuneiform_Sign_Ud_Times_Bad             :
      constant Unicode_Char := 16#12315#;
   Cuneiform_Sign_Ud_Times_Mi              :
      constant Unicode_Char := 16#12316#;
   Cuneiform_Sign_Ud_Times_U_Plus_U_Plus_U :
      constant Unicode_Char := 16#12317#;
   Cuneiform_Sign_Ud_Times_U_Plus_U_Plus_U_Gunu :
      constant Unicode_Char := 16#12318#;
   Cuneiform_Sign_Ud_Gunu                  :
      constant Unicode_Char := 16#12319#;
   Cuneiform_Sign_Ud_Sheshig               :
      constant Unicode_Char := 16#1231A#;
   Cuneiform_Sign_Ud_Sheshig_Times_Bad     :
      constant Unicode_Char := 16#1231B#;
   Cuneiform_Sign_Udug                     :
      constant Unicode_Char := 16#1231C#;
   Cuneiform_Sign_Um                       :
      constant Unicode_Char := 16#1231D#;
   Cuneiform_Sign_Um_Times_Lagab           :
      constant Unicode_Char := 16#1231E#;
   Cuneiform_Sign_Um_Times_Me_Plus_Da      :
      constant Unicode_Char := 16#1231F#;
   Cuneiform_Sign_Um_Times_Sha3            :
      constant Unicode_Char := 16#12320#;
   Cuneiform_Sign_Um_Times_U               :
      constant Unicode_Char := 16#12321#;
   Cuneiform_Sign_Umbin                    :
      constant Unicode_Char := 16#12322#;
   Cuneiform_Sign_Umum                     :
      constant Unicode_Char := 16#12323#;
   Cuneiform_Sign_Umum_Times_Kaskal        :
      constant Unicode_Char := 16#12324#;
   Cuneiform_Sign_Umum_Times_Pa            :
      constant Unicode_Char := 16#12325#;
   Cuneiform_Sign_Un                       :
      constant Unicode_Char := 16#12326#;
   Cuneiform_Sign_Un_Gunu                  :
      constant Unicode_Char := 16#12327#;
   Cuneiform_Sign_Ur                       :
      constant Unicode_Char := 16#12328#;
   Cuneiform_Sign_Ur_Crossing_Ur           :
      constant Unicode_Char := 16#12329#;
   Cuneiform_Sign_Ur_Sheshig               :
      constant Unicode_Char := 16#1232A#;
   Cuneiform_Sign_Ur2                      :
      constant Unicode_Char := 16#1232B#;
   Cuneiform_Sign_Ur2_Times_A_Plus_Ha      :
      constant Unicode_Char := 16#1232C#;
   Cuneiform_Sign_Ur2_Times_A_Plus_Na      :
      constant Unicode_Char := 16#1232D#;
   Cuneiform_Sign_Ur2_Times_Al             :
      constant Unicode_Char := 16#1232E#;
   Cuneiform_Sign_Ur2_Times_Ha             :
      constant Unicode_Char := 16#1232F#;
   Cuneiform_Sign_Ur2_Times_Nun            :
      constant Unicode_Char := 16#12330#;
   Cuneiform_Sign_Ur2_Times_U2             :
      constant Unicode_Char := 16#12331#;
   Cuneiform_Sign_Ur2_Times_U2_Plus_Ash    :
      constant Unicode_Char := 16#12332#;
   Cuneiform_Sign_Ur2_Times_U2_Plus_Bi     :
      constant Unicode_Char := 16#12333#;
   Cuneiform_Sign_Ur4                      :
      constant Unicode_Char := 16#12334#;
   Cuneiform_Sign_Uri                      :
      constant Unicode_Char := 16#12335#;
   Cuneiform_Sign_Uri3                     :
      constant Unicode_Char := 16#12336#;
   Cuneiform_Sign_Uru                      :
      constant Unicode_Char := 16#12337#;
   Cuneiform_Sign_Uru_Times_A              :
      constant Unicode_Char := 16#12338#;
   Cuneiform_Sign_Uru_Times_Ashgab         :
      constant Unicode_Char := 16#12339#;
   Cuneiform_Sign_Uru_Times_Bar            :
      constant Unicode_Char := 16#1233A#;
   Cuneiform_Sign_Uru_Times_Dun            :
      constant Unicode_Char := 16#1233B#;
   Cuneiform_Sign_Uru_Times_Ga             :
      constant Unicode_Char := 16#1233C#;
   Cuneiform_Sign_Uru_Times_Gal            :
      constant Unicode_Char := 16#1233D#;
   Cuneiform_Sign_Uru_Times_Gan2_Tenu      :
      constant Unicode_Char := 16#1233E#;
   Cuneiform_Sign_Uru_Times_Gar            :
      constant Unicode_Char := 16#1233F#;
   Cuneiform_Sign_Uru_Times_Gu             :
      constant Unicode_Char := 16#12340#;
   Cuneiform_Sign_Uru_Times_Ha             :
      constant Unicode_Char := 16#12341#;
   Cuneiform_Sign_Uru_Times_Igi            :
      constant Unicode_Char := 16#12342#;
   Cuneiform_Sign_Uru_Times_Im             :
      constant Unicode_Char := 16#12343#;
   Cuneiform_Sign_Uru_Times_Ish            :
      constant Unicode_Char := 16#12344#;
   Cuneiform_Sign_Uru_Times_Ki             :
      constant Unicode_Char := 16#12345#;
   Cuneiform_Sign_Uru_Times_Lum            :
      constant Unicode_Char := 16#12346#;
   Cuneiform_Sign_Uru_Times_Min            :
      constant Unicode_Char := 16#12347#;
   Cuneiform_Sign_Uru_Times_Pa             :
      constant Unicode_Char := 16#12348#;
   Cuneiform_Sign_Uru_Times_She            :
      constant Unicode_Char := 16#12349#;
   Cuneiform_Sign_Uru_Times_Sig4           :
      constant Unicode_Char := 16#1234A#;
   Cuneiform_Sign_Uru_Times_Tu             :
      constant Unicode_Char := 16#1234B#;
   Cuneiform_Sign_Uru_Times_U_Plus_Gud     :
      constant Unicode_Char := 16#1234C#;
   Cuneiform_Sign_Uru_Times_Ud             :
      constant Unicode_Char := 16#1234D#;
   Cuneiform_Sign_Uru_Times_Uruda          :
      constant Unicode_Char := 16#1234E#;
   Cuneiform_Sign_Uruda                    :
      constant Unicode_Char := 16#1234F#;
   Cuneiform_Sign_Uruda_Times_U            :
      constant Unicode_Char := 16#12350#;
   Cuneiform_Sign_Ush                      :
      constant Unicode_Char := 16#12351#;
   Cuneiform_Sign_Ush_Times_A              :
      constant Unicode_Char := 16#12352#;
   Cuneiform_Sign_Ush_Times_Ku             :
      constant Unicode_Char := 16#12353#;
   Cuneiform_Sign_Ush_Times_Kur            :
      constant Unicode_Char := 16#12354#;
   Cuneiform_Sign_Ush_Times_Tak4           :
      constant Unicode_Char := 16#12355#;
   Cuneiform_Sign_Ushx                     :
      constant Unicode_Char := 16#12356#;
   Cuneiform_Sign_Ush2                     :
      constant Unicode_Char := 16#12357#;
   Cuneiform_Sign_Ushumx                   :
      constant Unicode_Char := 16#12358#;
   Cuneiform_Sign_Utuki                    :
      constant Unicode_Char := 16#12359#;
   Cuneiform_Sign_Uz3                      :
      constant Unicode_Char := 16#1235A#;
   Cuneiform_Sign_Uz3_Times_Kaskal         :
      constant Unicode_Char := 16#1235B#;
   Cuneiform_Sign_Uzu                      :
      constant Unicode_Char := 16#1235C#;
   Cuneiform_Sign_Za                       :
      constant Unicode_Char := 16#1235D#;
   Cuneiform_Sign_Za_Tenu                  :
      constant Unicode_Char := 16#1235E#;
   Cuneiform_Sign_Za_Squared_Times_Kur     :
      constant Unicode_Char := 16#1235F#;
   Cuneiform_Sign_Zag                      :
      constant Unicode_Char := 16#12360#;
   Cuneiform_Sign_Zamx                     :
      constant Unicode_Char := 16#12361#;
   Cuneiform_Sign_Ze2                      :
      constant Unicode_Char := 16#12362#;
   Cuneiform_Sign_Zi                       :
      constant Unicode_Char := 16#12363#;
   Cuneiform_Sign_Zi_Over_Zi               :
      constant Unicode_Char := 16#12364#;
   Cuneiform_Sign_Zi3                      :
      constant Unicode_Char := 16#12365#;
   Cuneiform_Sign_Zib                      :
      constant Unicode_Char := 16#12366#;
   Cuneiform_Sign_Zib_Kaba_Tenu            :
      constant Unicode_Char := 16#12367#;
   Cuneiform_Sign_Zig                      :
      constant Unicode_Char := 16#12368#;
   Cuneiform_Sign_Ziz2                     :
      constant Unicode_Char := 16#12369#;
   Cuneiform_Sign_Zu                       :
      constant Unicode_Char := 16#1236A#;
   Cuneiform_Sign_Zu5                      :
      constant Unicode_Char := 16#1236B#;
   Cuneiform_Sign_Zu5_Times_A              :
      constant Unicode_Char := 16#1236C#;
   Cuneiform_Sign_Zubur                    :
      constant Unicode_Char := 16#1236D#;
   Cuneiform_Sign_Zum                      :
      constant Unicode_Char := 16#1236E#;
   Cuneiform_Sign_Kap_Elamite              :
      constant Unicode_Char := 16#1236F#;
   Cuneiform_Sign_Ab_Times_Nun             :
      constant Unicode_Char := 16#12370#;
   Cuneiform_Sign_Ab2_Times_A              :
      constant Unicode_Char := 16#12371#;
   Cuneiform_Sign_Amar_Times_Kug           :
      constant Unicode_Char := 16#12372#;
   Cuneiform_Sign_Dag_Kisim5_Times_U2_Plus_Mash :
      constant Unicode_Char := 16#12373#;
   Cuneiform_Sign_Dag3                     :
      constant Unicode_Char := 16#12374#;
   Cuneiform_Sign_Dish_Plus_Shu            :
      constant Unicode_Char := 16#12375#;
   Cuneiform_Sign_Dub_Times_She            :
      constant Unicode_Char := 16#12376#;
   Cuneiform_Sign_Ezen_Times_Gud           :
      constant Unicode_Char := 16#12377#;
   Cuneiform_Sign_Ezen_Times_She           :
      constant Unicode_Char := 16#12378#;
   Cuneiform_Sign_Ga2_Times_An_Plus_Kak_Plus_A :
      constant Unicode_Char := 16#12379#;
   Cuneiform_Sign_Ga2_Times_Ash2           :
      constant Unicode_Char := 16#1237A#;
   Cuneiform_Sign_Ge22                     :
      constant Unicode_Char := 16#1237B#;
   Cuneiform_Sign_Gig                      :
      constant Unicode_Char := 16#1237C#;
   Cuneiform_Sign_Hush                     :
      constant Unicode_Char := 16#1237D#;
   Cuneiform_Sign_Ka_Times_Anshe           :
      constant Unicode_Char := 16#1237E#;
   Cuneiform_Sign_Ka_Times_Ash3            :
      constant Unicode_Char := 16#1237F#;
   Cuneiform_Sign_Ka_Times_Gish            :
      constant Unicode_Char := 16#12380#;
   Cuneiform_Sign_Ka_Times_Gud             :
      constant Unicode_Char := 16#12381#;
   Cuneiform_Sign_Ka_Times_Hi_Times_Ash2   :
      constant Unicode_Char := 16#12382#;
   Cuneiform_Sign_Ka_Times_Lum             :
      constant Unicode_Char := 16#12383#;
   Cuneiform_Sign_Ka_Times_Pa              :
      constant Unicode_Char := 16#12384#;
   Cuneiform_Sign_Ka_Times_Shul            :
      constant Unicode_Char := 16#12385#;
   Cuneiform_Sign_Ka_Times_Tu              :
      constant Unicode_Char := 16#12386#;
   Cuneiform_Sign_Ka_Times_Ur2             :
      constant Unicode_Char := 16#12387#;
   Cuneiform_Sign_Lagab_Times_Gi           :
      constant Unicode_Char := 16#12388#;
   Cuneiform_Sign_Lu2_Sheshig_Times_Bad    :
      constant Unicode_Char := 16#12389#;
   Cuneiform_Sign_Lu2_Times_Esh2_Plus_Lal  :
      constant Unicode_Char := 16#1238A#;
   Cuneiform_Sign_Lu2_Times_Shu            :
      constant Unicode_Char := 16#1238B#;
   Cuneiform_Sign_Mesh                     :
      constant Unicode_Char := 16#1238C#;
   Cuneiform_Sign_Mush3_Times_Za           :
      constant Unicode_Char := 16#1238D#;
   Cuneiform_Sign_Na4                      :
      constant Unicode_Char := 16#1238E#;
   Cuneiform_Sign_Nin                      :
      constant Unicode_Char := 16#1238F#;
   Cuneiform_Sign_Nin9                     :
      constant Unicode_Char := 16#12390#;
   Cuneiform_Sign_Ninda2_Times_Bal         :
      constant Unicode_Char := 16#12391#;
   Cuneiform_Sign_Ninda2_Times_Gi          :
      constant Unicode_Char := 16#12392#;
   Cuneiform_Sign_Nu11_Rotated_Ninety_Degrees :
      constant Unicode_Char := 16#12393#;
   Cuneiform_Sign_Pesh2_Asterisk           :
      constant Unicode_Char := 16#12394#;
   Cuneiform_Sign_Pir2                     :
      constant Unicode_Char := 16#12395#;
   Cuneiform_Sign_Sag_Times_Igi_Gunu       :
      constant Unicode_Char := 16#12396#;
   Cuneiform_Sign_Ti2                      :
      constant Unicode_Char := 16#12397#;
   Cuneiform_Sign_Um_Times_Me              :
      constant Unicode_Char := 16#12398#;
   Cuneiform_Sign_U_U                      :
      constant Unicode_Char := 16#12399#;
end Unicode.Names.Cuneiform;
