--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Hiragana is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Hiragana_Letter_Small_A                 : constant Unicode_Char := 16#3041#;
   Hiragana_Letter_A                       : constant Unicode_Char := 16#3042#;
   Hiragana_Letter_Small_I                 : constant Unicode_Char := 16#3043#;
   Hiragana_Letter_I                       : constant Unicode_Char := 16#3044#;
   Hiragana_Letter_Small_U                 : constant Unicode_Char := 16#3045#;
   Hiragana_Letter_U                       : constant Unicode_Char := 16#3046#;
   Hiragana_Letter_Small_E                 : constant Unicode_Char := 16#3047#;
   Hiragana_Letter_E                       : constant Unicode_Char := 16#3048#;
   Hiragana_Letter_Small_O                 : constant Unicode_Char := 16#3049#;
   Hiragana_Letter_O                       : constant Unicode_Char := 16#304A#;
   Hiragana_Letter_Ka                      : constant Unicode_Char := 16#304B#;
   Hiragana_Letter_Ga                      : constant Unicode_Char := 16#304C#;
   Hiragana_Letter_Ki                      : constant Unicode_Char := 16#304D#;
   Hiragana_Letter_Gi                      : constant Unicode_Char := 16#304E#;
   Hiragana_Letter_Ku                      : constant Unicode_Char := 16#304F#;
   Hiragana_Letter_Gu                      : constant Unicode_Char := 16#3050#;
   Hiragana_Letter_Ke                      : constant Unicode_Char := 16#3051#;
   Hiragana_Letter_Ge                      : constant Unicode_Char := 16#3052#;
   Hiragana_Letter_Ko                      : constant Unicode_Char := 16#3053#;
   Hiragana_Letter_Go                      : constant Unicode_Char := 16#3054#;
   Hiragana_Letter_Sa                      : constant Unicode_Char := 16#3055#;
   Hiragana_Letter_Za                      : constant Unicode_Char := 16#3056#;
   Hiragana_Letter_Si                      : constant Unicode_Char := 16#3057#;
   Hiragana_Letter_Zi                      : constant Unicode_Char := 16#3058#;
   Hiragana_Letter_Su                      : constant Unicode_Char := 16#3059#;
   Hiragana_Letter_Zu                      : constant Unicode_Char := 16#305A#;
   Hiragana_Letter_Se                      : constant Unicode_Char := 16#305B#;
   Hiragana_Letter_Ze                      : constant Unicode_Char := 16#305C#;
   Hiragana_Letter_So                      : constant Unicode_Char := 16#305D#;
   Hiragana_Letter_Zo                      : constant Unicode_Char := 16#305E#;
   Hiragana_Letter_Ta                      : constant Unicode_Char := 16#305F#;
   Hiragana_Letter_Da                      : constant Unicode_Char := 16#3060#;
   Hiragana_Letter_Ti                      : constant Unicode_Char := 16#3061#;
   Hiragana_Letter_Di                      : constant Unicode_Char := 16#3062#;
   Hiragana_Letter_Small_Tu                : constant Unicode_Char := 16#3063#;
   Hiragana_Letter_Tu                      : constant Unicode_Char := 16#3064#;
   Hiragana_Letter_Du                      : constant Unicode_Char := 16#3065#;
   Hiragana_Letter_Te                      : constant Unicode_Char := 16#3066#;
   Hiragana_Letter_De                      : constant Unicode_Char := 16#3067#;
   Hiragana_Letter_To                      : constant Unicode_Char := 16#3068#;
   Hiragana_Letter_Do                      : constant Unicode_Char := 16#3069#;
   Hiragana_Letter_Na                      : constant Unicode_Char := 16#306A#;
   Hiragana_Letter_Ni                      : constant Unicode_Char := 16#306B#;
   Hiragana_Letter_Nu                      : constant Unicode_Char := 16#306C#;
   Hiragana_Letter_Ne                      : constant Unicode_Char := 16#306D#;
   Hiragana_Letter_No                      : constant Unicode_Char := 16#306E#;
   Hiragana_Letter_Ha                      : constant Unicode_Char := 16#306F#;
   Hiragana_Letter_Ba                      : constant Unicode_Char := 16#3070#;
   Hiragana_Letter_Pa                      : constant Unicode_Char := 16#3071#;
   Hiragana_Letter_Hi                      : constant Unicode_Char := 16#3072#;
   Hiragana_Letter_Bi                      : constant Unicode_Char := 16#3073#;
   Hiragana_Letter_Pi                      : constant Unicode_Char := 16#3074#;
   Hiragana_Letter_Hu                      : constant Unicode_Char := 16#3075#;
   Hiragana_Letter_Bu                      : constant Unicode_Char := 16#3076#;
   Hiragana_Letter_Pu                      : constant Unicode_Char := 16#3077#;
   Hiragana_Letter_He                      : constant Unicode_Char := 16#3078#;
   Hiragana_Letter_Be                      : constant Unicode_Char := 16#3079#;
   Hiragana_Letter_Pe                      : constant Unicode_Char := 16#307A#;
   Hiragana_Letter_Ho                      : constant Unicode_Char := 16#307B#;
   Hiragana_Letter_Bo                      : constant Unicode_Char := 16#307C#;
   Hiragana_Letter_Po                      : constant Unicode_Char := 16#307D#;
   Hiragana_Letter_Ma                      : constant Unicode_Char := 16#307E#;
   Hiragana_Letter_Mi                      : constant Unicode_Char := 16#307F#;
   Hiragana_Letter_Mu                      : constant Unicode_Char := 16#3080#;
   Hiragana_Letter_Me                      : constant Unicode_Char := 16#3081#;
   Hiragana_Letter_Mo                      : constant Unicode_Char := 16#3082#;
   Hiragana_Letter_Small_Ya                : constant Unicode_Char := 16#3083#;
   Hiragana_Letter_Ya                      : constant Unicode_Char := 16#3084#;
   Hiragana_Letter_Small_Yu                : constant Unicode_Char := 16#3085#;
   Hiragana_Letter_Yu                      : constant Unicode_Char := 16#3086#;
   Hiragana_Letter_Small_Yo                : constant Unicode_Char := 16#3087#;
   Hiragana_Letter_Yo                      : constant Unicode_Char := 16#3088#;
   Hiragana_Letter_Ra                      : constant Unicode_Char := 16#3089#;
   Hiragana_Letter_Ri                      : constant Unicode_Char := 16#308A#;
   Hiragana_Letter_Ru                      : constant Unicode_Char := 16#308B#;
   Hiragana_Letter_Re                      : constant Unicode_Char := 16#308C#;
   Hiragana_Letter_Ro                      : constant Unicode_Char := 16#308D#;
   Hiragana_Letter_Small_Wa                : constant Unicode_Char := 16#308E#;
   Hiragana_Letter_Wa                      : constant Unicode_Char := 16#308F#;
   Hiragana_Letter_Wi                      : constant Unicode_Char := 16#3090#;
   Hiragana_Letter_We                      : constant Unicode_Char := 16#3091#;
   Hiragana_Letter_Wo                      : constant Unicode_Char := 16#3092#;
   Hiragana_Letter_N                       : constant Unicode_Char := 16#3093#;
   Hiragana_Letter_Vu                      : constant Unicode_Char := 16#3094#;
   Hiragana_Letter_Small_Ka                : constant Unicode_Char := 16#3095#;
   Hiragana_Letter_Small_Ke                : constant Unicode_Char := 16#3096#;
   Combining_Katakana_Hiragana_Voiced_Sound_Mark :
      constant Unicode_Char := 16#3099#;
   Combining_Katakana_Hiragana_Semi_Voiced_Sound_Mark :
      constant Unicode_Char := 16#309A#;
   Katakana_Hiragana_Voiced_Sound_Mark     : constant Unicode_Char := 16#309B#;
   Katakana_Hiragana_Semi_Voiced_Sound_Mark :
      constant Unicode_Char := 16#309C#;
   Hiragana_Iteration_Mark                 : constant Unicode_Char := 16#309D#;
   Hiragana_Voiced_Iteration_Mark          : constant Unicode_Char := 16#309E#;
   Hiragana_Digraph_Yori                   : constant Unicode_Char := 16#309F#;
end Unicode.Names.Hiragana;
