--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Mahajani is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Mahajani_Letter_A                       :
      constant Unicode_Char := 16#11150#;
   Mahajani_Letter_I                       :
      constant Unicode_Char := 16#11151#;
   Mahajani_Letter_U                       :
      constant Unicode_Char := 16#11152#;
   Mahajani_Letter_E                       :
      constant Unicode_Char := 16#11153#;
   Mahajani_Letter_O                       :
      constant Unicode_Char := 16#11154#;
   Mahajani_Letter_Ka                      :
      constant Unicode_Char := 16#11155#;
   Mahajani_Letter_Kha                     :
      constant Unicode_Char := 16#11156#;
   Mahajani_Letter_Ga                      :
      constant Unicode_Char := 16#11157#;
   Mahajani_Letter_Gha                     :
      constant Unicode_Char := 16#11158#;
   Mahajani_Letter_Ca                      :
      constant Unicode_Char := 16#11159#;
   Mahajani_Letter_Cha                     :
      constant Unicode_Char := 16#1115A#;
   Mahajani_Letter_Ja                      :
      constant Unicode_Char := 16#1115B#;
   Mahajani_Letter_Jha                     :
      constant Unicode_Char := 16#1115C#;
   Mahajani_Letter_Nya                     :
      constant Unicode_Char := 16#1115D#;
   Mahajani_Letter_Tta                     :
      constant Unicode_Char := 16#1115E#;
   Mahajani_Letter_Ttha                    :
      constant Unicode_Char := 16#1115F#;
   Mahajani_Letter_Dda                     :
      constant Unicode_Char := 16#11160#;
   Mahajani_Letter_Ddha                    :
      constant Unicode_Char := 16#11161#;
   Mahajani_Letter_Nna                     :
      constant Unicode_Char := 16#11162#;
   Mahajani_Letter_Ta                      :
      constant Unicode_Char := 16#11163#;
   Mahajani_Letter_Tha                     :
      constant Unicode_Char := 16#11164#;
   Mahajani_Letter_Da                      :
      constant Unicode_Char := 16#11165#;
   Mahajani_Letter_Dha                     :
      constant Unicode_Char := 16#11166#;
   Mahajani_Letter_Na                      :
      constant Unicode_Char := 16#11167#;
   Mahajani_Letter_Pa                      :
      constant Unicode_Char := 16#11168#;
   Mahajani_Letter_Pha                     :
      constant Unicode_Char := 16#11169#;
   Mahajani_Letter_Ba                      :
      constant Unicode_Char := 16#1116A#;
   Mahajani_Letter_Bha                     :
      constant Unicode_Char := 16#1116B#;
   Mahajani_Letter_Ma                      :
      constant Unicode_Char := 16#1116C#;
   Mahajani_Letter_Ra                      :
      constant Unicode_Char := 16#1116D#;
   Mahajani_Letter_La                      :
      constant Unicode_Char := 16#1116E#;
   Mahajani_Letter_Va                      :
      constant Unicode_Char := 16#1116F#;
   Mahajani_Letter_Sa                      :
      constant Unicode_Char := 16#11170#;
   Mahajani_Letter_Ha                      :
      constant Unicode_Char := 16#11171#;
   Mahajani_Letter_Rra                     :
      constant Unicode_Char := 16#11172#;
   Mahajani_Sign_Nukta                     :
      constant Unicode_Char := 16#11173#;
   Mahajani_Abbreviation_Sign              :
      constant Unicode_Char := 16#11174#;
   Mahajani_Section_Mark                   :
      constant Unicode_Char := 16#11175#;
   Mahajani_Ligature_Shri                  :
      constant Unicode_Char := 16#11176#;
end Unicode.Names.Mahajani;
