--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Sup_Math_Operators is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   N_Ary_Circled_Dot_Operator              : constant Unicode_Char := 16#2A00#;
   N_Ary_Circled_Plus_Operator             : constant Unicode_Char := 16#2A01#;
   N_Ary_Circled_Times_Operator            : constant Unicode_Char := 16#2A02#;
   N_Ary_Union_Operator_With_Dot           : constant Unicode_Char := 16#2A03#;
   N_Ary_Union_Operator_With_Plus          : constant Unicode_Char := 16#2A04#;
   N_Ary_Square_Intersection_Operator      : constant Unicode_Char := 16#2A05#;
   N_Ary_Square_Union_Operator             : constant Unicode_Char := 16#2A06#;
   Two_Logical_And_Operator                : constant Unicode_Char := 16#2A07#;
   Two_Logical_Or_Operator                 : constant Unicode_Char := 16#2A08#;
   N_Ary_Times_Operator                    : constant Unicode_Char := 16#2A09#;
   Modulo_Two_Sum                          : constant Unicode_Char := 16#2A0A#;
   Summation_With_Integral                 : constant Unicode_Char := 16#2A0B#;
   Quadruple_Integral_Operator             : constant Unicode_Char := 16#2A0C#;
   Finite_Part_Integral                    : constant Unicode_Char := 16#2A0D#;
   Integral_With_Double_Stroke             : constant Unicode_Char := 16#2A0E#;
   Integral_Average_With_Slash             : constant Unicode_Char := 16#2A0F#;
   Circulation_Function                    : constant Unicode_Char := 16#2A10#;
   Anticlockwise_Integration               : constant Unicode_Char := 16#2A11#;
   Line_Integration_With_Rectangular_Path_Around_Pole :
      constant Unicode_Char := 16#2A12#;
   Line_Integration_With_Semicircular_Path_Around_Pole :
      constant Unicode_Char := 16#2A13#;
   Line_Integration_Not_Including_The_Pole : constant Unicode_Char := 16#2A14#;
   Integral_Around_A_Point_Operator        : constant Unicode_Char := 16#2A15#;
   Quaternion_Integral_Operator            : constant Unicode_Char := 16#2A16#;
   Integral_With_Leftwards_Arrow_With_Hook : constant Unicode_Char := 16#2A17#;
   Integral_With_Times_Sign                : constant Unicode_Char := 16#2A18#;
   Integral_With_Intersection              : constant Unicode_Char := 16#2A19#;
   Integral_With_Union                     : constant Unicode_Char := 16#2A1A#;
   Integral_With_Overbar                   : constant Unicode_Char := 16#2A1B#;
   Integral_With_Underbar                  : constant Unicode_Char := 16#2A1C#;
   Join                                    : constant Unicode_Char := 16#2A1D#;
   Large_Left_Triangle_Operator            : constant Unicode_Char := 16#2A1E#;
   Z_Notation_Schema_Composition           : constant Unicode_Char := 16#2A1F#;
   Z_Notation_Schema_Piping                : constant Unicode_Char := 16#2A20#;
   Z_Notation_Schema_Projection            : constant Unicode_Char := 16#2A21#;
   Plus_Sign_With_Small_Circle_Above       : constant Unicode_Char := 16#2A22#;
   Plus_Sign_With_Circumflex_Accent_Above  : constant Unicode_Char := 16#2A23#;
   Plus_Sign_With_Tilde_Above              : constant Unicode_Char := 16#2A24#;
   Plus_Sign_With_Dot_Below                : constant Unicode_Char := 16#2A25#;
   Plus_Sign_With_Tilde_Below              : constant Unicode_Char := 16#2A26#;
   Plus_Sign_With_Subscript_Two            : constant Unicode_Char := 16#2A27#;
   Plus_Sign_With_Black_Triangle           : constant Unicode_Char := 16#2A28#;
   Minus_Sign_With_Comma_Above             : constant Unicode_Char := 16#2A29#;
   Minus_Sign_With_Dot_Below               : constant Unicode_Char := 16#2A2A#;
   Minus_Sign_With_Falling_Dots            : constant Unicode_Char := 16#2A2B#;
   Minus_Sign_With_Rising_Dots             : constant Unicode_Char := 16#2A2C#;
   Plus_Sign_In_Left_Half_Circle           : constant Unicode_Char := 16#2A2D#;
   Plus_Sign_In_Right_Half_Circle          : constant Unicode_Char := 16#2A2E#;
   Vector_Or_Cross_Product                 : constant Unicode_Char := 16#2A2F#;
   Multiplication_Sign_With_Dot_Above      : constant Unicode_Char := 16#2A30#;
   Multiplication_Sign_With_Underbar       : constant Unicode_Char := 16#2A31#;
   Semidirect_Product_With_Bottom_Closed   : constant Unicode_Char := 16#2A32#;
   Smash_Product                           : constant Unicode_Char := 16#2A33#;
   Multiplication_Sign_In_Left_Half_Circle : constant Unicode_Char := 16#2A34#;
   Multiplication_Sign_In_Right_Half_Circle :
      constant Unicode_Char := 16#2A35#;
   Circled_Multiplication_Sign_With_Circumflex_Accent :
      constant Unicode_Char := 16#2A36#;
   Multiplication_Sign_In_Double_Circle    : constant Unicode_Char := 16#2A37#;
   Circled_Division_Sign                   : constant Unicode_Char := 16#2A38#;
   Plus_Sign_In_Triangle                   : constant Unicode_Char := 16#2A39#;
   Minus_Sign_In_Triangle                  : constant Unicode_Char := 16#2A3A#;
   Multiplication_Sign_In_Triangle         : constant Unicode_Char := 16#2A3B#;
   Interior_Product                        : constant Unicode_Char := 16#2A3C#;
   Righthand_Interior_Product              : constant Unicode_Char := 16#2A3D#;
   Z_Notation_Relational_Composition       : constant Unicode_Char := 16#2A3E#;
   Amalgamation_Or_Coproduct               : constant Unicode_Char := 16#2A3F#;
   Intersection_With_Dot                   : constant Unicode_Char := 16#2A40#;
   Union_With_Minus_Sign                   : constant Unicode_Char := 16#2A41#;
   Union_With_Overbar                      : constant Unicode_Char := 16#2A42#;
   Intersection_With_Overbar               : constant Unicode_Char := 16#2A43#;
   Intersection_With_Logical_And           : constant Unicode_Char := 16#2A44#;
   Union_With_Logical_Or                   : constant Unicode_Char := 16#2A45#;
   Union_Above_Intersection                : constant Unicode_Char := 16#2A46#;
   Intersection_Above_Union                : constant Unicode_Char := 16#2A47#;
   Union_Above_Bar_Above_Intersection      : constant Unicode_Char := 16#2A48#;
   Intersection_Above_Bar_Above_Union      : constant Unicode_Char := 16#2A49#;
   Union_Beside_And_Joined_With_Union      : constant Unicode_Char := 16#2A4A#;
   Intersection_Beside_And_Joined_With_Intersection :
      constant Unicode_Char := 16#2A4B#;
   Closed_Union_With_Serifs                : constant Unicode_Char := 16#2A4C#;
   Closed_Intersection_With_Serifs         : constant Unicode_Char := 16#2A4D#;
   Double_Square_Intersection              : constant Unicode_Char := 16#2A4E#;
   Double_Square_Union                     : constant Unicode_Char := 16#2A4F#;
   Closed_Union_With_Serifs_And_Smash_Product :
      constant Unicode_Char := 16#2A50#;
   Logical_And_With_Dot_Above              : constant Unicode_Char := 16#2A51#;
   Logical_Or_With_Dot_Above               : constant Unicode_Char := 16#2A52#;
   Double_Logical_And                      : constant Unicode_Char := 16#2A53#;
   Double_Logical_Or                       : constant Unicode_Char := 16#2A54#;
   Two_Intersecting_Logical_And            : constant Unicode_Char := 16#2A55#;
   Two_Intersecting_Logical_Or             : constant Unicode_Char := 16#2A56#;
   Sloping_Large_Or                        : constant Unicode_Char := 16#2A57#;
   Sloping_Large_And                       : constant Unicode_Char := 16#2A58#;
   Logical_Or_Overlapping_Logical_And      : constant Unicode_Char := 16#2A59#;
   Logical_And_With_Middle_Stem            : constant Unicode_Char := 16#2A5A#;
   Logical_Or_With_Middle_Stem             : constant Unicode_Char := 16#2A5B#;
   Logical_And_With_Horizontal_Dash        : constant Unicode_Char := 16#2A5C#;
   Logical_Or_With_Horizontal_Dash         : constant Unicode_Char := 16#2A5D#;
   Logical_And_With_Double_Overbar         : constant Unicode_Char := 16#2A5E#;
   Logical_And_With_Underbar               : constant Unicode_Char := 16#2A5F#;
   Logical_And_With_Double_Underbar        : constant Unicode_Char := 16#2A60#;
   Small_Vee_With_Underbar                 : constant Unicode_Char := 16#2A61#;
   Logical_Or_With_Double_Overbar          : constant Unicode_Char := 16#2A62#;
   Logical_Or_With_Double_Underbar         : constant Unicode_Char := 16#2A63#;
   Z_Notation_Domain_Antirestriction       : constant Unicode_Char := 16#2A64#;
   Z_Notation_Range_Antirestriction        : constant Unicode_Char := 16#2A65#;
   Equals_Sign_With_Dot_Below              : constant Unicode_Char := 16#2A66#;
   Identical_With_Dot_Above                : constant Unicode_Char := 16#2A67#;
   Triple_Horizontal_Bar_With_Double_Vertical_Stroke :
      constant Unicode_Char := 16#2A68#;
   Triple_Horizontal_Bar_With_Triple_Vertical_Stroke :
      constant Unicode_Char := 16#2A69#;
   Tilde_Operator_With_Dot_Above           : constant Unicode_Char := 16#2A6A#;
   Tilde_Operator_With_Rising_Dots         : constant Unicode_Char := 16#2A6B#;
   Similar_Minus_Similar                   : constant Unicode_Char := 16#2A6C#;
   Congruent_With_Dot_Above                : constant Unicode_Char := 16#2A6D#;
   Equals_With_Asterisk                    : constant Unicode_Char := 16#2A6E#;
   Almost_Equal_To_With_Circumflex_Accent  : constant Unicode_Char := 16#2A6F#;
   Approximately_Equal_Or_Equal_To         : constant Unicode_Char := 16#2A70#;
   Equals_Sign_Above_Plus_Sign             : constant Unicode_Char := 16#2A71#;
   Plus_Sign_Above_Equals_Sign             : constant Unicode_Char := 16#2A72#;
   Equals_Sign_Above_Tilde_Operator        : constant Unicode_Char := 16#2A73#;
   Double_Colon_Equal                      : constant Unicode_Char := 16#2A74#;
   Two_Consecutive_Equals_Signs            : constant Unicode_Char := 16#2A75#;
   Three_Consecutive_Equals_Signs          : constant Unicode_Char := 16#2A76#;
   Equals_Sign_With_Two_Dots_Above_And_Two_Dots_Below :
      constant Unicode_Char := 16#2A77#;
   Equivalent_With_Four_Dots_Above         : constant Unicode_Char := 16#2A78#;
   Less_Than_With_Circle_Inside            : constant Unicode_Char := 16#2A79#;
   Greater_Than_With_Circle_Inside         : constant Unicode_Char := 16#2A7A#;
   Less_Than_With_Question_Mark_Above      : constant Unicode_Char := 16#2A7B#;
   Greater_Than_With_Question_Mark_Above   : constant Unicode_Char := 16#2A7C#;
   Less_Than_Or_Slanted_Equal_To           : constant Unicode_Char := 16#2A7D#;
   Greater_Than_Or_Slanted_Equal_To        : constant Unicode_Char := 16#2A7E#;
   Less_Than_Or_Slanted_Equal_To_With_Dot_Inside :
      constant Unicode_Char := 16#2A7F#;
   Greater_Than_Or_Slanted_Equal_To_With_Dot_Inside :
      constant Unicode_Char := 16#2A80#;
   Less_Than_Or_Slanted_Equal_To_With_Dot_Above :
      constant Unicode_Char := 16#2A81#;
   Greater_Than_Or_Slanted_Equal_To_With_Dot_Above :
      constant Unicode_Char := 16#2A82#;
   Less_Than_Or_Slanted_Equal_To_With_Dot_Above_Right :
      constant Unicode_Char := 16#2A83#;
   Greater_Than_Or_Slanted_Equal_To_With_Dot_Above_Left :
      constant Unicode_Char := 16#2A84#;
   Less_Than_Or_Approximate                : constant Unicode_Char := 16#2A85#;
   Greater_Than_Or_Approximate             : constant Unicode_Char := 16#2A86#;
   Less_Than_And_Single_Line_Not_Equal_To  : constant Unicode_Char := 16#2A87#;
   Greater_Than_And_Single_Line_Not_Equal_To :
      constant Unicode_Char := 16#2A88#;
   Less_Than_And_Not_Approximate           : constant Unicode_Char := 16#2A89#;
   Greater_Than_And_Not_Approximate        : constant Unicode_Char := 16#2A8A#;
   Less_Than_Above_Double_Line_Equal_Above_Greater_Than :
      constant Unicode_Char := 16#2A8B#;
   Greater_Than_Above_Double_Line_Equal_Above_Less_Than :
      constant Unicode_Char := 16#2A8C#;
   Less_Than_Above_Similar_Or_Equal        : constant Unicode_Char := 16#2A8D#;
   Greater_Than_Above_Similar_Or_Equal     : constant Unicode_Char := 16#2A8E#;
   Less_Than_Above_Similar_Above_Greater_Than :
      constant Unicode_Char := 16#2A8F#;
   Greater_Than_Above_Similar_Above_Less_Than :
      constant Unicode_Char := 16#2A90#;
   Less_Than_Above_Greater_Than_Above_Double_Line_Equal :
      constant Unicode_Char := 16#2A91#;
   Greater_Than_Above_Less_Than_Above_Double_Line_Equal :
      constant Unicode_Char := 16#2A92#;
   Less_Than_Above_Slanted_Equal_Above_Greater_Than_Above_Slanted_Equal :
      constant Unicode_Char := 16#2A93#;
   Greater_Than_Above_Slanted_Equal_Above_Less_Than_Above_Slanted_Equal :
      constant Unicode_Char := 16#2A94#;
   Slanted_Equal_To_Or_Less_Than           : constant Unicode_Char := 16#2A95#;
   Slanted_Equal_To_Or_Greater_Than        : constant Unicode_Char := 16#2A96#;
   Slanted_Equal_To_Or_Less_Than_With_Dot_Inside :
      constant Unicode_Char := 16#2A97#;
   Slanted_Equal_To_Or_Greater_Than_With_Dot_Inside :
      constant Unicode_Char := 16#2A98#;
   Double_Line_Equal_To_Or_Less_Than       : constant Unicode_Char := 16#2A99#;
   Double_Line_Equal_To_Or_Greater_Than    : constant Unicode_Char := 16#2A9A#;
   Double_Line_Slanted_Equal_To_Or_Less_Than :
      constant Unicode_Char := 16#2A9B#;
   Double_Line_Slanted_Equal_To_Or_Greater_Than :
      constant Unicode_Char := 16#2A9C#;
   Similar_Or_Less_Than                    : constant Unicode_Char := 16#2A9D#;
   Similar_Or_Greater_Than                 : constant Unicode_Char := 16#2A9E#;
   Similar_Above_Less_Than_Above_Equals_Sign :
      constant Unicode_Char := 16#2A9F#;
   Similar_Above_Greater_Than_Above_Equals_Sign :
      constant Unicode_Char := 16#2AA0#;
   Double_Nested_Less_Than                 : constant Unicode_Char := 16#2AA1#;
   Double_Nested_Greater_Than              : constant Unicode_Char := 16#2AA2#;
   Double_Nested_Less_Than_With_Underbar   : constant Unicode_Char := 16#2AA3#;
   Greater_Than_Overlapping_Less_Than      : constant Unicode_Char := 16#2AA4#;
   Greater_Than_Beside_Less_Than           : constant Unicode_Char := 16#2AA5#;
   Less_Than_Closed_By_Curve               : constant Unicode_Char := 16#2AA6#;
   Greater_Than_Closed_By_Curve            : constant Unicode_Char := 16#2AA7#;
   Less_Than_Closed_By_Curve_Above_Slanted_Equal :
      constant Unicode_Char := 16#2AA8#;
   Greater_Than_Closed_By_Curve_Above_Slanted_Equal :
      constant Unicode_Char := 16#2AA9#;
   Smaller_Than                            : constant Unicode_Char := 16#2AAA#;
   Larger_Than                             : constant Unicode_Char := 16#2AAB#;
   Smaller_Than_Or_Equal_To                : constant Unicode_Char := 16#2AAC#;
   Larger_Than_Or_Equal_To                 : constant Unicode_Char := 16#2AAD#;
   Equals_Sign_With_Bumpy_Above            : constant Unicode_Char := 16#2AAE#;
   Precedes_Above_Single_Line_Equals_Sign  : constant Unicode_Char := 16#2AAF#;
   Succeeds_Above_Single_Line_Equals_Sign  : constant Unicode_Char := 16#2AB0#;
   Precedes_Above_Single_Line_Not_Equal_To : constant Unicode_Char := 16#2AB1#;
   Succeeds_Above_Single_Line_Not_Equal_To : constant Unicode_Char := 16#2AB2#;
   Precedes_Above_Equals_Sign              : constant Unicode_Char := 16#2AB3#;
   Succeeds_Above_Equals_Sign              : constant Unicode_Char := 16#2AB4#;
   Precedes_Above_Not_Equal_To             : constant Unicode_Char := 16#2AB5#;
   Succeeds_Above_Not_Equal_To             : constant Unicode_Char := 16#2AB6#;
   Precedes_Above_Almost_Equal_To          : constant Unicode_Char := 16#2AB7#;
   Succeeds_Above_Almost_Equal_To          : constant Unicode_Char := 16#2AB8#;
   Precedes_Above_Not_Almost_Equal_To      : constant Unicode_Char := 16#2AB9#;
   Succeeds_Above_Not_Almost_Equal_To      : constant Unicode_Char := 16#2ABA#;
   Double_Precedes                         : constant Unicode_Char := 16#2ABB#;
   Double_Succeeds                         : constant Unicode_Char := 16#2ABC#;
   Subset_With_Dot                         : constant Unicode_Char := 16#2ABD#;
   Superset_With_Dot                       : constant Unicode_Char := 16#2ABE#;
   Subset_With_Plus_Sign_Below             : constant Unicode_Char := 16#2ABF#;
   Superset_With_Plus_Sign_Below           : constant Unicode_Char := 16#2AC0#;
   Subset_With_Multiplication_Sign_Below   : constant Unicode_Char := 16#2AC1#;
   Superset_With_Multiplication_Sign_Below : constant Unicode_Char := 16#2AC2#;
   Subset_Of_Or_Equal_To_With_Dot_Above    : constant Unicode_Char := 16#2AC3#;
   Superset_Of_Or_Equal_To_With_Dot_Above  : constant Unicode_Char := 16#2AC4#;
   Subset_Of_Above_Equals_Sign             : constant Unicode_Char := 16#2AC5#;
   Superset_Of_Above_Equals_Sign           : constant Unicode_Char := 16#2AC6#;
   Subset_Of_Above_Tilde_Operator          : constant Unicode_Char := 16#2AC7#;
   Superset_Of_Above_Tilde_Operator        : constant Unicode_Char := 16#2AC8#;
   Subset_Of_Above_Almost_Equal_To         : constant Unicode_Char := 16#2AC9#;
   Superset_Of_Above_Almost_Equal_To       : constant Unicode_Char := 16#2ACA#;
   Subset_Of_Above_Not_Equal_To            : constant Unicode_Char := 16#2ACB#;
   Superset_Of_Above_Not_Equal_To          : constant Unicode_Char := 16#2ACC#;
   Square_Left_Open_Box_Operator           : constant Unicode_Char := 16#2ACD#;
   Square_Right_Open_Box_Operator          : constant Unicode_Char := 16#2ACE#;
   Closed_Subset                           : constant Unicode_Char := 16#2ACF#;
   Closed_Superset                         : constant Unicode_Char := 16#2AD0#;
   Closed_Subset_Or_Equal_To               : constant Unicode_Char := 16#2AD1#;
   Closed_Superset_Or_Equal_To             : constant Unicode_Char := 16#2AD2#;
   Subset_Above_Superset                   : constant Unicode_Char := 16#2AD3#;
   Superset_Above_Subset                   : constant Unicode_Char := 16#2AD4#;
   Subset_Above_Subset                     : constant Unicode_Char := 16#2AD5#;
   Superset_Above_Superset                 : constant Unicode_Char := 16#2AD6#;
   Superset_Beside_Subset                  : constant Unicode_Char := 16#2AD7#;
   Superset_Beside_And_Joined_By_Dash_With_Subset :
      constant Unicode_Char := 16#2AD8#;
   Element_Of_Opening_Downwards            : constant Unicode_Char := 16#2AD9#;
   Pitchfork_With_Tee_Top                  : constant Unicode_Char := 16#2ADA#;
   Transversal_Intersection                : constant Unicode_Char := 16#2ADB#;
   Forking                                 : constant Unicode_Char := 16#2ADC#;
   Nonforking                              : constant Unicode_Char := 16#2ADD#;
   Short_Left_Tack                         : constant Unicode_Char := 16#2ADE#;
   Short_Down_Tack                         : constant Unicode_Char := 16#2ADF#;
   Short_Up_Tack                           : constant Unicode_Char := 16#2AE0#;
   Perpendicular_With_S                    : constant Unicode_Char := 16#2AE1#;
   Vertical_Bar_Triple_Right_Turnstile     : constant Unicode_Char := 16#2AE2#;
   Double_Vertical_Bar_Left_Turnstile      : constant Unicode_Char := 16#2AE3#;
   Vertical_Bar_Double_Left_Turnstile      : constant Unicode_Char := 16#2AE4#;
   Double_Vertical_Bar_Double_Left_Turnstile :
      constant Unicode_Char := 16#2AE5#;
   Long_Dash_From_Left_Member_Of_Double_Vertical :
      constant Unicode_Char := 16#2AE6#;
   Short_Down_Tack_With_Overbar            : constant Unicode_Char := 16#2AE7#;
   Short_Up_Tack_With_Underbar             : constant Unicode_Char := 16#2AE8#;
   Short_Up_Tack_Above_Short_Down_Tack     : constant Unicode_Char := 16#2AE9#;
   Double_Down_Tack                        : constant Unicode_Char := 16#2AEA#;
   Double_Up_Tack                          : constant Unicode_Char := 16#2AEB#;
   Double_Stroke_Not_Sign                  : constant Unicode_Char := 16#2AEC#;
   Reversed_Double_Stroke_Not_Sign         : constant Unicode_Char := 16#2AED#;
   Does_Not_Divide_With_Reversed_Negation_Slash :
      constant Unicode_Char := 16#2AEE#;
   Vertical_Line_With_Circle_Above         : constant Unicode_Char := 16#2AEF#;
   Vertical_Line_With_Circle_Below         : constant Unicode_Char := 16#2AF0#;
   Down_Tack_With_Circle_Below             : constant Unicode_Char := 16#2AF1#;
   Parallel_With_Horizontal_Stroke         : constant Unicode_Char := 16#2AF2#;
   Parallel_With_Tilde_Operator            : constant Unicode_Char := 16#2AF3#;
   Triple_Vertical_Bar_Binary_Relation     : constant Unicode_Char := 16#2AF4#;
   Triple_Vertical_Bar_With_Horizontal_Stroke :
      constant Unicode_Char := 16#2AF5#;
   Triple_Colon_Operator                   : constant Unicode_Char := 16#2AF6#;
   Triple_Nested_Less_Than                 : constant Unicode_Char := 16#2AF7#;
   Triple_Nested_Greater_Than              : constant Unicode_Char := 16#2AF8#;
   Double_Line_Slanted_Less_Than_Or_Equal_To :
      constant Unicode_Char := 16#2AF9#;
   Double_Line_Slanted_Greater_Than_Or_Equal_To :
      constant Unicode_Char := 16#2AFA#;
   Triple_Solidus_Binary_Relation          : constant Unicode_Char := 16#2AFB#;
   Large_Triple_Vertical_Bar_Operator      : constant Unicode_Char := 16#2AFC#;
   Double_Solidus_Operator                 : constant Unicode_Char := 16#2AFD#;
   White_Vertical_Bar                      : constant Unicode_Char := 16#2AFE#;
   N_Ary_White_Vertical_Bar                : constant Unicode_Char := 16#2AFF#;
end Unicode.Names.Sup_Math_Operators;
