--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Old_Hungarian is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Old_Hungarian_Capital_Letter_A          :
      constant Unicode_Char := 16#10C80#;
   Old_Hungarian_Capital_Letter_Aa         :
      constant Unicode_Char := 16#10C81#;
   Old_Hungarian_Capital_Letter_Eb         :
      constant Unicode_Char := 16#10C82#;
   Old_Hungarian_Capital_Letter_Amb        :
      constant Unicode_Char := 16#10C83#;
   Old_Hungarian_Capital_Letter_Ec         :
      constant Unicode_Char := 16#10C84#;
   Old_Hungarian_Capital_Letter_Enc        :
      constant Unicode_Char := 16#10C85#;
   Old_Hungarian_Capital_Letter_Ecs        :
      constant Unicode_Char := 16#10C86#;
   Old_Hungarian_Capital_Letter_Ed         :
      constant Unicode_Char := 16#10C87#;
   Old_Hungarian_Capital_Letter_And        :
      constant Unicode_Char := 16#10C88#;
   Old_Hungarian_Capital_Letter_E          :
      constant Unicode_Char := 16#10C89#;
   Old_Hungarian_Capital_Letter_Close_E    :
      constant Unicode_Char := 16#10C8A#;
   Old_Hungarian_Capital_Letter_Ee         :
      constant Unicode_Char := 16#10C8B#;
   Old_Hungarian_Capital_Letter_Ef         :
      constant Unicode_Char := 16#10C8C#;
   Old_Hungarian_Capital_Letter_Eg         :
      constant Unicode_Char := 16#10C8D#;
   Old_Hungarian_Capital_Letter_Egy        :
      constant Unicode_Char := 16#10C8E#;
   Old_Hungarian_Capital_Letter_Eh         :
      constant Unicode_Char := 16#10C8F#;
   Old_Hungarian_Capital_Letter_I          :
      constant Unicode_Char := 16#10C90#;
   Old_Hungarian_Capital_Letter_Ii         :
      constant Unicode_Char := 16#10C91#;
   Old_Hungarian_Capital_Letter_Ej         :
      constant Unicode_Char := 16#10C92#;
   Old_Hungarian_Capital_Letter_Ek         :
      constant Unicode_Char := 16#10C93#;
   Old_Hungarian_Capital_Letter_Ak         :
      constant Unicode_Char := 16#10C94#;
   Old_Hungarian_Capital_Letter_Unk        :
      constant Unicode_Char := 16#10C95#;
   Old_Hungarian_Capital_Letter_El         :
      constant Unicode_Char := 16#10C96#;
   Old_Hungarian_Capital_Letter_Ely        :
      constant Unicode_Char := 16#10C97#;
   Old_Hungarian_Capital_Letter_Em         :
      constant Unicode_Char := 16#10C98#;
   Old_Hungarian_Capital_Letter_En         :
      constant Unicode_Char := 16#10C99#;
   Old_Hungarian_Capital_Letter_Eny        :
      constant Unicode_Char := 16#10C9A#;
   Old_Hungarian_Capital_Letter_O          :
      constant Unicode_Char := 16#10C9B#;
   Old_Hungarian_Capital_Letter_Oo         :
      constant Unicode_Char := 16#10C9C#;
   Old_Hungarian_Capital_Letter_Nikolsburg_Oe :
      constant Unicode_Char := 16#10C9D#;
   Old_Hungarian_Capital_Letter_Rudimenta_Oe :
      constant Unicode_Char := 16#10C9E#;
   Old_Hungarian_Capital_Letter_Oee        :
      constant Unicode_Char := 16#10C9F#;
   Old_Hungarian_Capital_Letter_Ep         :
      constant Unicode_Char := 16#10CA0#;
   Old_Hungarian_Capital_Letter_Emp        :
      constant Unicode_Char := 16#10CA1#;
   Old_Hungarian_Capital_Letter_Er         :
      constant Unicode_Char := 16#10CA2#;
   Old_Hungarian_Capital_Letter_Short_Er   :
      constant Unicode_Char := 16#10CA3#;
   Old_Hungarian_Capital_Letter_Es         :
      constant Unicode_Char := 16#10CA4#;
   Old_Hungarian_Capital_Letter_Esz        :
      constant Unicode_Char := 16#10CA5#;
   Old_Hungarian_Capital_Letter_Et         :
      constant Unicode_Char := 16#10CA6#;
   Old_Hungarian_Capital_Letter_Ent        :
      constant Unicode_Char := 16#10CA7#;
   Old_Hungarian_Capital_Letter_Ety        :
      constant Unicode_Char := 16#10CA8#;
   Old_Hungarian_Capital_Letter_Ech        :
      constant Unicode_Char := 16#10CA9#;
   Old_Hungarian_Capital_Letter_U          :
      constant Unicode_Char := 16#10CAA#;
   Old_Hungarian_Capital_Letter_Uu         :
      constant Unicode_Char := 16#10CAB#;
   Old_Hungarian_Capital_Letter_Nikolsburg_Ue :
      constant Unicode_Char := 16#10CAC#;
   Old_Hungarian_Capital_Letter_Rudimenta_Ue :
      constant Unicode_Char := 16#10CAD#;
   Old_Hungarian_Capital_Letter_Ev         :
      constant Unicode_Char := 16#10CAE#;
   Old_Hungarian_Capital_Letter_Ez         :
      constant Unicode_Char := 16#10CAF#;
   Old_Hungarian_Capital_Letter_Ezs        :
      constant Unicode_Char := 16#10CB0#;
   Old_Hungarian_Capital_Letter_Ent_Shaped_Sign :
      constant Unicode_Char := 16#10CB1#;
   Old_Hungarian_Capital_Letter_Us         :
      constant Unicode_Char := 16#10CB2#;
   Old_Hungarian_Small_Letter_A            :
      constant Unicode_Char := 16#10CC0#;
   Old_Hungarian_Small_Letter_Aa           :
      constant Unicode_Char := 16#10CC1#;
   Old_Hungarian_Small_Letter_Eb           :
      constant Unicode_Char := 16#10CC2#;
   Old_Hungarian_Small_Letter_Amb          :
      constant Unicode_Char := 16#10CC3#;
   Old_Hungarian_Small_Letter_Ec           :
      constant Unicode_Char := 16#10CC4#;
   Old_Hungarian_Small_Letter_Enc          :
      constant Unicode_Char := 16#10CC5#;
   Old_Hungarian_Small_Letter_Ecs          :
      constant Unicode_Char := 16#10CC6#;
   Old_Hungarian_Small_Letter_Ed           :
      constant Unicode_Char := 16#10CC7#;
   Old_Hungarian_Small_Letter_And          :
      constant Unicode_Char := 16#10CC8#;
   Old_Hungarian_Small_Letter_E            :
      constant Unicode_Char := 16#10CC9#;
   Old_Hungarian_Small_Letter_Close_E      :
      constant Unicode_Char := 16#10CCA#;
   Old_Hungarian_Small_Letter_Ee           :
      constant Unicode_Char := 16#10CCB#;
   Old_Hungarian_Small_Letter_Ef           :
      constant Unicode_Char := 16#10CCC#;
   Old_Hungarian_Small_Letter_Eg           :
      constant Unicode_Char := 16#10CCD#;
   Old_Hungarian_Small_Letter_Egy          :
      constant Unicode_Char := 16#10CCE#;
   Old_Hungarian_Small_Letter_Eh           :
      constant Unicode_Char := 16#10CCF#;
   Old_Hungarian_Small_Letter_I            :
      constant Unicode_Char := 16#10CD0#;
   Old_Hungarian_Small_Letter_Ii           :
      constant Unicode_Char := 16#10CD1#;
   Old_Hungarian_Small_Letter_Ej           :
      constant Unicode_Char := 16#10CD2#;
   Old_Hungarian_Small_Letter_Ek           :
      constant Unicode_Char := 16#10CD3#;
   Old_Hungarian_Small_Letter_Ak           :
      constant Unicode_Char := 16#10CD4#;
   Old_Hungarian_Small_Letter_Unk          :
      constant Unicode_Char := 16#10CD5#;
   Old_Hungarian_Small_Letter_El           :
      constant Unicode_Char := 16#10CD6#;
   Old_Hungarian_Small_Letter_Ely          :
      constant Unicode_Char := 16#10CD7#;
   Old_Hungarian_Small_Letter_Em           :
      constant Unicode_Char := 16#10CD8#;
   Old_Hungarian_Small_Letter_En           :
      constant Unicode_Char := 16#10CD9#;
   Old_Hungarian_Small_Letter_Eny          :
      constant Unicode_Char := 16#10CDA#;
   Old_Hungarian_Small_Letter_O            :
      constant Unicode_Char := 16#10CDB#;
   Old_Hungarian_Small_Letter_Oo           :
      constant Unicode_Char := 16#10CDC#;
   Old_Hungarian_Small_Letter_Nikolsburg_Oe :
      constant Unicode_Char := 16#10CDD#;
   Old_Hungarian_Small_Letter_Rudimenta_Oe :
      constant Unicode_Char := 16#10CDE#;
   Old_Hungarian_Small_Letter_Oee          :
      constant Unicode_Char := 16#10CDF#;
   Old_Hungarian_Small_Letter_Ep           :
      constant Unicode_Char := 16#10CE0#;
   Old_Hungarian_Small_Letter_Emp          :
      constant Unicode_Char := 16#10CE1#;
   Old_Hungarian_Small_Letter_Er           :
      constant Unicode_Char := 16#10CE2#;
   Old_Hungarian_Small_Letter_Short_Er     :
      constant Unicode_Char := 16#10CE3#;
   Old_Hungarian_Small_Letter_Es           :
      constant Unicode_Char := 16#10CE4#;
   Old_Hungarian_Small_Letter_Esz          :
      constant Unicode_Char := 16#10CE5#;
   Old_Hungarian_Small_Letter_Et           :
      constant Unicode_Char := 16#10CE6#;
   Old_Hungarian_Small_Letter_Ent          :
      constant Unicode_Char := 16#10CE7#;
   Old_Hungarian_Small_Letter_Ety          :
      constant Unicode_Char := 16#10CE8#;
   Old_Hungarian_Small_Letter_Ech          :
      constant Unicode_Char := 16#10CE9#;
   Old_Hungarian_Small_Letter_U            :
      constant Unicode_Char := 16#10CEA#;
   Old_Hungarian_Small_Letter_Uu           :
      constant Unicode_Char := 16#10CEB#;
   Old_Hungarian_Small_Letter_Nikolsburg_Ue :
      constant Unicode_Char := 16#10CEC#;
   Old_Hungarian_Small_Letter_Rudimenta_Ue :
      constant Unicode_Char := 16#10CED#;
   Old_Hungarian_Small_Letter_Ev           :
      constant Unicode_Char := 16#10CEE#;
   Old_Hungarian_Small_Letter_Ez           :
      constant Unicode_Char := 16#10CEF#;
   Old_Hungarian_Small_Letter_Ezs          :
      constant Unicode_Char := 16#10CF0#;
   Old_Hungarian_Small_Letter_Ent_Shaped_Sign :
      constant Unicode_Char := 16#10CF1#;
   Old_Hungarian_Small_Letter_Us           :
      constant Unicode_Char := 16#10CF2#;
   Old_Hungarian_Number_One                :
      constant Unicode_Char := 16#10CFA#;
   Old_Hungarian_Number_Five               :
      constant Unicode_Char := 16#10CFB#;
   Old_Hungarian_Number_Ten                :
      constant Unicode_Char := 16#10CFC#;
   Old_Hungarian_Number_Fifty              :
      constant Unicode_Char := 16#10CFD#;
   Old_Hungarian_Number_One_Hundred        :
      constant Unicode_Char := 16#10CFE#;
   Old_Hungarian_Number_One_Thousand       :
      constant Unicode_Char := 16#10CFF#;
end Unicode.Names.Old_Hungarian;
