--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Meroitic_Cursive is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Meroitic_Cursive_Letter_A               :
      constant Unicode_Char := 16#109A0#;
   Meroitic_Cursive_Letter_E               :
      constant Unicode_Char := 16#109A1#;
   Meroitic_Cursive_Letter_I               :
      constant Unicode_Char := 16#109A2#;
   Meroitic_Cursive_Letter_O               :
      constant Unicode_Char := 16#109A3#;
   Meroitic_Cursive_Letter_Ya              :
      constant Unicode_Char := 16#109A4#;
   Meroitic_Cursive_Letter_Wa              :
      constant Unicode_Char := 16#109A5#;
   Meroitic_Cursive_Letter_Ba              :
      constant Unicode_Char := 16#109A6#;
   Meroitic_Cursive_Letter_Pa              :
      constant Unicode_Char := 16#109A7#;
   Meroitic_Cursive_Letter_Ma              :
      constant Unicode_Char := 16#109A8#;
   Meroitic_Cursive_Letter_Na              :
      constant Unicode_Char := 16#109A9#;
   Meroitic_Cursive_Letter_Ne              :
      constant Unicode_Char := 16#109AA#;
   Meroitic_Cursive_Letter_Ra              :
      constant Unicode_Char := 16#109AB#;
   Meroitic_Cursive_Letter_La              :
      constant Unicode_Char := 16#109AC#;
   Meroitic_Cursive_Letter_Kha             :
      constant Unicode_Char := 16#109AD#;
   Meroitic_Cursive_Letter_Hha             :
      constant Unicode_Char := 16#109AE#;
   Meroitic_Cursive_Letter_Sa              :
      constant Unicode_Char := 16#109AF#;
   Meroitic_Cursive_Letter_Archaic_Sa      :
      constant Unicode_Char := 16#109B0#;
   Meroitic_Cursive_Letter_Se              :
      constant Unicode_Char := 16#109B1#;
   Meroitic_Cursive_Letter_Ka              :
      constant Unicode_Char := 16#109B2#;
   Meroitic_Cursive_Letter_Qa              :
      constant Unicode_Char := 16#109B3#;
   Meroitic_Cursive_Letter_Ta              :
      constant Unicode_Char := 16#109B4#;
   Meroitic_Cursive_Letter_Te              :
      constant Unicode_Char := 16#109B5#;
   Meroitic_Cursive_Letter_To              :
      constant Unicode_Char := 16#109B6#;
   Meroitic_Cursive_Letter_Da              :
      constant Unicode_Char := 16#109B7#;
   Meroitic_Cursive_Fraction_Eleven_Twelfths :
      constant Unicode_Char := 16#109BC#;
   Meroitic_Cursive_Fraction_One_Half      :
      constant Unicode_Char := 16#109BD#;
   Meroitic_Cursive_Logogram_Rmt           :
      constant Unicode_Char := 16#109BE#;
   Meroitic_Cursive_Logogram_Imn           :
      constant Unicode_Char := 16#109BF#;
   Meroitic_Cursive_Number_One             :
      constant Unicode_Char := 16#109C0#;
   Meroitic_Cursive_Number_Two             :
      constant Unicode_Char := 16#109C1#;
   Meroitic_Cursive_Number_Three           :
      constant Unicode_Char := 16#109C2#;
   Meroitic_Cursive_Number_Four            :
      constant Unicode_Char := 16#109C3#;
   Meroitic_Cursive_Number_Five            :
      constant Unicode_Char := 16#109C4#;
   Meroitic_Cursive_Number_Six             :
      constant Unicode_Char := 16#109C5#;
   Meroitic_Cursive_Number_Seven           :
      constant Unicode_Char := 16#109C6#;
   Meroitic_Cursive_Number_Eight           :
      constant Unicode_Char := 16#109C7#;
   Meroitic_Cursive_Number_Nine            :
      constant Unicode_Char := 16#109C8#;
   Meroitic_Cursive_Number_Ten             :
      constant Unicode_Char := 16#109C9#;
   Meroitic_Cursive_Number_Twenty          :
      constant Unicode_Char := 16#109CA#;
   Meroitic_Cursive_Number_Thirty          :
      constant Unicode_Char := 16#109CB#;
   Meroitic_Cursive_Number_Forty           :
      constant Unicode_Char := 16#109CC#;
   Meroitic_Cursive_Number_Fifty           :
      constant Unicode_Char := 16#109CD#;
   Meroitic_Cursive_Number_Sixty           :
      constant Unicode_Char := 16#109CE#;
   Meroitic_Cursive_Number_Seventy         :
      constant Unicode_Char := 16#109CF#;
   Meroitic_Cursive_Number_One_Hundred     :
      constant Unicode_Char := 16#109D2#;
   Meroitic_Cursive_Number_Two_Hundred     :
      constant Unicode_Char := 16#109D3#;
   Meroitic_Cursive_Number_Three_Hundred   :
      constant Unicode_Char := 16#109D4#;
   Meroitic_Cursive_Number_Four_Hundred    :
      constant Unicode_Char := 16#109D5#;
   Meroitic_Cursive_Number_Five_Hundred    :
      constant Unicode_Char := 16#109D6#;
   Meroitic_Cursive_Number_Six_Hundred     :
      constant Unicode_Char := 16#109D7#;
   Meroitic_Cursive_Number_Seven_Hundred   :
      constant Unicode_Char := 16#109D8#;
   Meroitic_Cursive_Number_Eight_Hundred   :
      constant Unicode_Char := 16#109D9#;
   Meroitic_Cursive_Number_Nine_Hundred    :
      constant Unicode_Char := 16#109DA#;
   Meroitic_Cursive_Number_One_Thousand    :
      constant Unicode_Char := 16#109DB#;
   Meroitic_Cursive_Number_Two_Thousand    :
      constant Unicode_Char := 16#109DC#;
   Meroitic_Cursive_Number_Three_Thousand  :
      constant Unicode_Char := 16#109DD#;
   Meroitic_Cursive_Number_Four_Thousand   :
      constant Unicode_Char := 16#109DE#;
   Meroitic_Cursive_Number_Five_Thousand   :
      constant Unicode_Char := 16#109DF#;
   Meroitic_Cursive_Number_Six_Thousand    :
      constant Unicode_Char := 16#109E0#;
   Meroitic_Cursive_Number_Seven_Thousand  :
      constant Unicode_Char := 16#109E1#;
   Meroitic_Cursive_Number_Eight_Thousand  :
      constant Unicode_Char := 16#109E2#;
   Meroitic_Cursive_Number_Nine_Thousand   :
      constant Unicode_Char := 16#109E3#;
   Meroitic_Cursive_Number_Ten_Thousand    :
      constant Unicode_Char := 16#109E4#;
   Meroitic_Cursive_Number_Twenty_Thousand :
      constant Unicode_Char := 16#109E5#;
   Meroitic_Cursive_Number_Thirty_Thousand :
      constant Unicode_Char := 16#109E6#;
   Meroitic_Cursive_Number_Forty_Thousand  :
      constant Unicode_Char := 16#109E7#;
   Meroitic_Cursive_Number_Fifty_Thousand  :
      constant Unicode_Char := 16#109E8#;
   Meroitic_Cursive_Number_Sixty_Thousand  :
      constant Unicode_Char := 16#109E9#;
   Meroitic_Cursive_Number_Seventy_Thousand :
      constant Unicode_Char := 16#109EA#;
   Meroitic_Cursive_Number_Eighty_Thousand :
      constant Unicode_Char := 16#109EB#;
   Meroitic_Cursive_Number_Ninety_Thousand :
      constant Unicode_Char := 16#109EC#;
   Meroitic_Cursive_Number_One_Hundred_Thousand :
      constant Unicode_Char := 16#109ED#;
   Meroitic_Cursive_Number_Two_Hundred_Thousand :
      constant Unicode_Char := 16#109EE#;
   Meroitic_Cursive_Number_Three_Hundred_Thousand :
      constant Unicode_Char := 16#109EF#;
   Meroitic_Cursive_Number_Four_Hundred_Thousand :
      constant Unicode_Char := 16#109F0#;
   Meroitic_Cursive_Number_Five_Hundred_Thousand :
      constant Unicode_Char := 16#109F1#;
   Meroitic_Cursive_Number_Six_Hundred_Thousand :
      constant Unicode_Char := 16#109F2#;
   Meroitic_Cursive_Number_Seven_Hundred_Thousand :
      constant Unicode_Char := 16#109F3#;
   Meroitic_Cursive_Number_Eight_Hundred_Thousand :
      constant Unicode_Char := 16#109F4#;
   Meroitic_Cursive_Number_Nine_Hundred_Thousand :
      constant Unicode_Char := 16#109F5#;
   Meroitic_Cursive_Fraction_One_Twelfth   :
      constant Unicode_Char := 16#109F6#;
   Meroitic_Cursive_Fraction_Two_Twelfths  :
      constant Unicode_Char := 16#109F7#;
   Meroitic_Cursive_Fraction_Three_Twelfths :
      constant Unicode_Char := 16#109F8#;
   Meroitic_Cursive_Fraction_Four_Twelfths :
      constant Unicode_Char := 16#109F9#;
   Meroitic_Cursive_Fraction_Five_Twelfths :
      constant Unicode_Char := 16#109FA#;
   Meroitic_Cursive_Fraction_Six_Twelfths  :
      constant Unicode_Char := 16#109FB#;
   Meroitic_Cursive_Fraction_Seven_Twelfths :
      constant Unicode_Char := 16#109FC#;
   Meroitic_Cursive_Fraction_Eight_Twelfths :
      constant Unicode_Char := 16#109FD#;
   Meroitic_Cursive_Fraction_Nine_Twelfths :
      constant Unicode_Char := 16#109FE#;
   Meroitic_Cursive_Fraction_Ten_Twelfths  :
      constant Unicode_Char := 16#109FF#;
end Unicode.Names.Meroitic_Cursive;
