--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cjk_Symbols_And_Punct is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Ideographic_Space                       : constant Unicode_Char := 16#3000#;
   Ideographic_Comma                       : constant Unicode_Char := 16#3001#;
   Ideographic_Full_Stop                   : constant Unicode_Char := 16#3002#;
   Ditto_Mark                              : constant Unicode_Char := 16#3003#;
   Japanese_Industrial_Standard_Symbol     : constant Unicode_Char := 16#3004#;
   Ideographic_Iteration_Mark              : constant Unicode_Char := 16#3005#;
   Ideographic_Closing_Mark                : constant Unicode_Char := 16#3006#;
   Ideographic_Number_Zero                 : constant Unicode_Char := 16#3007#;
   Left_Angle_Bracket                      : constant Unicode_Char := 16#3008#;
   Right_Angle_Bracket                     : constant Unicode_Char := 16#3009#;
   Left_Double_Angle_Bracket               : constant Unicode_Char := 16#300A#;
   Right_Double_Angle_Bracket              : constant Unicode_Char := 16#300B#;
   Left_Corner_Bracket                     : constant Unicode_Char := 16#300C#;
   Right_Corner_Bracket                    : constant Unicode_Char := 16#300D#;
   Left_White_Corner_Bracket               : constant Unicode_Char := 16#300E#;
   Right_White_Corner_Bracket              : constant Unicode_Char := 16#300F#;
   Left_Black_Lenticular_Bracket           : constant Unicode_Char := 16#3010#;
   Right_Black_Lenticular_Bracket          : constant Unicode_Char := 16#3011#;
   Postal_Mark                             : constant Unicode_Char := 16#3012#;
   Geta_Mark                               : constant Unicode_Char := 16#3013#;
   Left_Tortoise_Shell_Bracket             : constant Unicode_Char := 16#3014#;
   Right_Tortoise_Shell_Bracket            : constant Unicode_Char := 16#3015#;
   Left_White_Lenticular_Bracket           : constant Unicode_Char := 16#3016#;
   Right_White_Lenticular_Bracket          : constant Unicode_Char := 16#3017#;
   Left_White_Tortoise_Shell_Bracket       : constant Unicode_Char := 16#3018#;
   Right_White_Tortoise_Shell_Bracket      : constant Unicode_Char := 16#3019#;
   Left_White_Square_Bracket               : constant Unicode_Char := 16#301A#;
   Right_White_Square_Bracket              : constant Unicode_Char := 16#301B#;
   Wave_Dash                               : constant Unicode_Char := 16#301C#;
   Reversed_Double_Prime_Quotation_Mark    : constant Unicode_Char := 16#301D#;
   Double_Prime_Quotation_Mark             : constant Unicode_Char := 16#301E#;
   Low_Double_Prime_Quotation_Mark         : constant Unicode_Char := 16#301F#;
   Postal_Mark_Face                        : constant Unicode_Char := 16#3020#;
   Hangzhou_Numeral_One                    : constant Unicode_Char := 16#3021#;
   Hangzhou_Numeral_Two                    : constant Unicode_Char := 16#3022#;
   Hangzhou_Numeral_Three                  : constant Unicode_Char := 16#3023#;
   Hangzhou_Numeral_Four                   : constant Unicode_Char := 16#3024#;
   Hangzhou_Numeral_Five                   : constant Unicode_Char := 16#3025#;
   Hangzhou_Numeral_Six                    : constant Unicode_Char := 16#3026#;
   Hangzhou_Numeral_Seven                  : constant Unicode_Char := 16#3027#;
   Hangzhou_Numeral_Eight                  : constant Unicode_Char := 16#3028#;
   Hangzhou_Numeral_Nine                   : constant Unicode_Char := 16#3029#;
   Ideographic_Level_Tone_Mark             : constant Unicode_Char := 16#302A#;
   Ideographic_Rising_Tone_Mark            : constant Unicode_Char := 16#302B#;
   Ideographic_Departing_Tone_Mark         : constant Unicode_Char := 16#302C#;
   Ideographic_Entering_Tone_Mark          : constant Unicode_Char := 16#302D#;
   Hangul_Single_Dot_Tone_Mark             : constant Unicode_Char := 16#302E#;
   Hangul_Double_Dot_Tone_Mark             : constant Unicode_Char := 16#302F#;
   Wavy_Dash                               : constant Unicode_Char := 16#3030#;
   Vertical_Kana_Repeat_Mark               : constant Unicode_Char := 16#3031#;
   Vertical_Kana_Repeat_With_Voiced_Sound_Mark :
      constant Unicode_Char := 16#3032#;
   Vertical_Kana_Repeat_Mark_Upper_Half    : constant Unicode_Char := 16#3033#;
   Vertical_Kana_Repeat_With_Voiced_Sound_Mark_Upper_Half :
      constant Unicode_Char := 16#3034#;
   Vertical_Kana_Repeat_Mark_Lower_Half    : constant Unicode_Char := 16#3035#;
   Circled_Postal_Mark                     : constant Unicode_Char := 16#3036#;
   Ideographic_Telegraph_Line_Feed_Separator_Symbol :
      constant Unicode_Char := 16#3037#;
   Hangzhou_Numeral_Ten                    : constant Unicode_Char := 16#3038#;
   Hangzhou_Numeral_Twenty                 : constant Unicode_Char := 16#3039#;
   Hangzhou_Numeral_Thirty                 : constant Unicode_Char := 16#303A#;
   Vertical_Ideographic_Iteration_Mark     : constant Unicode_Char := 16#303B#;
   Masu_Mark                               : constant Unicode_Char := 16#303C#;
   Part_Alternation_Mark                   : constant Unicode_Char := 16#303D#;
   Ideographic_Variation_Indicator         : constant Unicode_Char := 16#303E#;
   Ideographic_Half_Fill_Space             : constant Unicode_Char := 16#303F#;
end Unicode.Names.Cjk_Symbols_And_Punct;
