--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Letterlike_Symbols is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Account_Of                              : constant Unicode_Char := 16#2100#;
   Addressed_To_The_Subject                : constant Unicode_Char := 16#2101#;
   Double_Struck_Capital_C                 : constant Unicode_Char := 16#2102#;
   Degree_Celsius                          : constant Unicode_Char := 16#2103#;
   Centre_Line_Symbol                      : constant Unicode_Char := 16#2104#;
   Care_Of                                 : constant Unicode_Char := 16#2105#;
   Cada_Una                                : constant Unicode_Char := 16#2106#;
   Euler_Constant                          : constant Unicode_Char := 16#2107#;
   Scruple                                 : constant Unicode_Char := 16#2108#;
   Degree_Fahrenheit                       : constant Unicode_Char := 16#2109#;
   Script_Small_G                          : constant Unicode_Char := 16#210A#;
   Script_Capital_H                        : constant Unicode_Char := 16#210B#;
   Black_Letter_Capital_H                  : constant Unicode_Char := 16#210C#;
   Double_Struck_Capital_H                 : constant Unicode_Char := 16#210D#;
   Planck_Constant                         : constant Unicode_Char := 16#210E#;
   Planck_Constant_Over_Two_Pi             : constant Unicode_Char := 16#210F#;
   Script_Capital_I                        : constant Unicode_Char := 16#2110#;
   Black_Letter_Capital_I                  : constant Unicode_Char := 16#2111#;
   Script_Capital_L                        : constant Unicode_Char := 16#2112#;
   Script_Small_L                          : constant Unicode_Char := 16#2113#;
   L_B_Bar_Symbol                          : constant Unicode_Char := 16#2114#;
   Double_Struck_Capital_N                 : constant Unicode_Char := 16#2115#;
   Numero_Sign                             : constant Unicode_Char := 16#2116#;
   Sound_Recording_Copyright               : constant Unicode_Char := 16#2117#;
   Script_Capital_P                        : constant Unicode_Char := 16#2118#;
   Weierstrass_Elliptic_Function           :
      Unicode_Char renames Script_Capital_P;
   Double_Struck_Capital_P                 : constant Unicode_Char := 16#2119#;
   Double_Struck_Capital_Q                 : constant Unicode_Char := 16#211A#;
   Script_Capital_R                        : constant Unicode_Char := 16#211B#;
   Black_Letter_Capital_R                  : constant Unicode_Char := 16#211C#;
   Double_Struck_Capital_R                 : constant Unicode_Char := 16#211D#;
   Prescription_Take                       : constant Unicode_Char := 16#211E#;
   Response                                : constant Unicode_Char := 16#211F#;
   Service_Mark                            : constant Unicode_Char := 16#2120#;
   Telephone_Sign                          : constant Unicode_Char := 16#2121#;
   Trade_Mark_Sign                         : constant Unicode_Char := 16#2122#;
   Versicle                                : constant Unicode_Char := 16#2123#;
   Double_Struck_Capital_Z                 : constant Unicode_Char := 16#2124#;
   Ounce_Sign                              : constant Unicode_Char := 16#2125#;
   Ohm_Sign                                : constant Unicode_Char := 16#2126#;
   Inverted_Ohm_Sign                       : constant Unicode_Char := 16#2127#;
   Black_Letter_Capital_Z                  : constant Unicode_Char := 16#2128#;
   Turned_Greek_Small_Letter_Iota          : constant Unicode_Char := 16#2129#;
   Kelvin_Sign                             : constant Unicode_Char := 16#212A#;
   Angstrom_Sign                           : constant Unicode_Char := 16#212B#;
   Script_Capital_B                        : constant Unicode_Char := 16#212C#;
   Black_Letter_Capital_C                  : constant Unicode_Char := 16#212D#;
   Estimated_Symbol                        : constant Unicode_Char := 16#212E#;
   Script_Small_E                          : constant Unicode_Char := 16#212F#;
   Script_Capital_E                        : constant Unicode_Char := 16#2130#;
   Script_Capital_F                        : constant Unicode_Char := 16#2131#;
   Turned_Capital_F                        : constant Unicode_Char := 16#2132#;
   Script_Capital_M                        : constant Unicode_Char := 16#2133#;
   Script_Small_O                          : constant Unicode_Char := 16#2134#;
   Alef_Symbol                             : constant Unicode_Char := 16#2135#;
   Bet_Symbol                              : constant Unicode_Char := 16#2136#;
   Gimel_Symbol                            : constant Unicode_Char := 16#2137#;
   Dalet_Symbol                            : constant Unicode_Char := 16#2138#;
   Information_Source                      : constant Unicode_Char := 16#2139#;
   Rotated_Capital_Q                       : constant Unicode_Char := 16#213A#;
   Facsimile_Sign                          : constant Unicode_Char := 16#213B#;
   Double_Struck_Small_Pi                  : constant Unicode_Char := 16#213C#;
   Double_Struck_Small_Gamma               : constant Unicode_Char := 16#213D#;
   Double_Struck_Capital_Gamma             : constant Unicode_Char := 16#213E#;
   Double_Struck_Capital_Pi                : constant Unicode_Char := 16#213F#;
   Double_Struck_N_Ary_Summation           : constant Unicode_Char := 16#2140#;
   Turned_Sans_Serif_Capital_G             : constant Unicode_Char := 16#2141#;
   Turned_Sans_Serif_Capital_L             : constant Unicode_Char := 16#2142#;
   Reversed_Sans_Serif_Capital_L           : constant Unicode_Char := 16#2143#;
   Turned_Sans_Serif_Capital_Y             : constant Unicode_Char := 16#2144#;
   Double_Struck_Italic_Capital_D          : constant Unicode_Char := 16#2145#;
   Double_Struck_Italic_Small_D            : constant Unicode_Char := 16#2146#;
   Double_Struck_Italic_Small_E            : constant Unicode_Char := 16#2147#;
   Double_Struck_Italic_Small_I            : constant Unicode_Char := 16#2148#;
   Double_Struck_Italic_Small_J            : constant Unicode_Char := 16#2149#;
   Property_Line                           : constant Unicode_Char := 16#214A#;
   Turned_Ampersand                        : constant Unicode_Char := 16#214B#;
   Per_Sign                                : constant Unicode_Char := 16#214C#;
   Aktieselskab                            : constant Unicode_Char := 16#214D#;
   Turned_Small_F                          : constant Unicode_Char := 16#214E#;
   Symbol_For_Samaritan_Source             : constant Unicode_Char := 16#214F#;
end Unicode.Names.Letterlike_Symbols;
