--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Mro is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Mro_Letter_Ta                           :
      constant Unicode_Char := 16#16A40#;
   Mro_Letter_Ngi                          :
      constant Unicode_Char := 16#16A41#;
   Mro_Letter_Yo                           :
      constant Unicode_Char := 16#16A42#;
   Mro_Letter_Mim                          :
      constant Unicode_Char := 16#16A43#;
   Mro_Letter_Ba                           :
      constant Unicode_Char := 16#16A44#;
   Mro_Letter_Da                           :
      constant Unicode_Char := 16#16A45#;
   Mro_Letter_A                            :
      constant Unicode_Char := 16#16A46#;
   Mro_Letter_Phi                          :
      constant Unicode_Char := 16#16A47#;
   Mro_Letter_Khai                         :
      constant Unicode_Char := 16#16A48#;
   Mro_Letter_Hao                          :
      constant Unicode_Char := 16#16A49#;
   Mro_Letter_Dai                          :
      constant Unicode_Char := 16#16A4A#;
   Mro_Letter_Chu                          :
      constant Unicode_Char := 16#16A4B#;
   Mro_Letter_Keaae                        :
      constant Unicode_Char := 16#16A4C#;
   Mro_Letter_Ol                           :
      constant Unicode_Char := 16#16A4D#;
   Mro_Letter_Maem                         :
      constant Unicode_Char := 16#16A4E#;
   Mro_Letter_Nin                          :
      constant Unicode_Char := 16#16A4F#;
   Mro_Letter_Pa                           :
      constant Unicode_Char := 16#16A50#;
   Mro_Letter_Oo                           :
      constant Unicode_Char := 16#16A51#;
   Mro_Letter_O                            :
      constant Unicode_Char := 16#16A52#;
   Mro_Letter_Ro                           :
      constant Unicode_Char := 16#16A53#;
   Mro_Letter_Shi                          :
      constant Unicode_Char := 16#16A54#;
   Mro_Letter_Thea                         :
      constant Unicode_Char := 16#16A55#;
   Mro_Letter_Ea                           :
      constant Unicode_Char := 16#16A56#;
   Mro_Letter_Wa                           :
      constant Unicode_Char := 16#16A57#;
   Mro_Letter_E                            :
      constant Unicode_Char := 16#16A58#;
   Mro_Letter_Ko                           :
      constant Unicode_Char := 16#16A59#;
   Mro_Letter_Lan                          :
      constant Unicode_Char := 16#16A5A#;
   Mro_Letter_La                           :
      constant Unicode_Char := 16#16A5B#;
   Mro_Letter_Hai                          :
      constant Unicode_Char := 16#16A5C#;
   Mro_Letter_Ri                           :
      constant Unicode_Char := 16#16A5D#;
   Mro_Letter_Tek                          :
      constant Unicode_Char := 16#16A5E#;
   Mro_Digit_Zero                          :
      constant Unicode_Char := 16#16A60#;
   Mro_Digit_One                           :
      constant Unicode_Char := 16#16A61#;
   Mro_Digit_Two                           :
      constant Unicode_Char := 16#16A62#;
   Mro_Digit_Three                         :
      constant Unicode_Char := 16#16A63#;
   Mro_Digit_Four                          :
      constant Unicode_Char := 16#16A64#;
   Mro_Digit_Five                          :
      constant Unicode_Char := 16#16A65#;
   Mro_Digit_Six                           :
      constant Unicode_Char := 16#16A66#;
   Mro_Digit_Seven                         :
      constant Unicode_Char := 16#16A67#;
   Mro_Digit_Eight                         :
      constant Unicode_Char := 16#16A68#;
   Mro_Digit_Nine                          :
      constant Unicode_Char := 16#16A69#;
   Mro_Danda                               :
      constant Unicode_Char := 16#16A6E#;
   Mro_Double_Danda                        :
      constant Unicode_Char := 16#16A6F#;
end Unicode.Names.Mro;
