
--  This is the root of the hierarchy that provides named characters
--  The standard Unicode names have been kept wherever possible. The only
--  exception is the NULL character, which has been spelled NUL

package Unicode.Names is
   pragma Preelaborate (Unicode.Names);
end Unicode.Names;
