--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Ipa_Extensions is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Latin_Small_Letter_Turned_A             : constant Unicode_Char := 16#0250#;
   Latin_Small_Letter_Alpha                : constant Unicode_Char := 16#0251#;
   Latin_Small_Letter_Turned_Alpha         : constant Unicode_Char := 16#0252#;
   Latin_Small_Letter_B_With_Hook          : constant Unicode_Char := 16#0253#;
   Latin_Small_Letter_Open_O               : constant Unicode_Char := 16#0254#;
   Latin_Small_Letter_C_With_Curl          : constant Unicode_Char := 16#0255#;
   Latin_Small_Letter_D_With_Tail          : constant Unicode_Char := 16#0256#;
   Latin_Small_Letter_D_With_Hook          : constant Unicode_Char := 16#0257#;
   Latin_Small_Letter_Reversed_E           : constant Unicode_Char := 16#0258#;
   Latin_Small_Letter_Schwa                : constant Unicode_Char := 16#0259#;
   Latin_Small_Letter_Schwa_With_Hook      : constant Unicode_Char := 16#025A#;
   Latin_Small_Letter_Open_E               : constant Unicode_Char := 16#025B#;
   Latin_Small_Letter_Reversed_Open_E      : constant Unicode_Char := 16#025C#;
   Latin_Small_Letter_Reversed_Open_E_With_Hook :
      constant Unicode_Char := 16#025D#;
   Latin_Small_Letter_Closed_Reversed_Open_E :
      constant Unicode_Char := 16#025E#;
   Latin_Small_Letter_Dotless_J_With_Stroke :
      constant Unicode_Char := 16#025F#;
   Latin_Small_Letter_G_With_Hook          : constant Unicode_Char := 16#0260#;
   Latin_Small_Letter_Script_G             : constant Unicode_Char := 16#0261#;
   Latin_Letter_Small_Capital_G            : constant Unicode_Char := 16#0262#;
   Latin_Small_Letter_Gamma                : constant Unicode_Char := 16#0263#;
   Latin_Small_Letter_Rams_Horn            : constant Unicode_Char := 16#0264#;
   Latin_Small_Letter_Turned_H             : constant Unicode_Char := 16#0265#;
   Latin_Small_Letter_H_With_Hook          : constant Unicode_Char := 16#0266#;
   Latin_Small_Letter_Heng_With_Hook       : constant Unicode_Char := 16#0267#;
   Latin_Small_Letter_I_With_Stroke        : constant Unicode_Char := 16#0268#;
   Latin_Small_Letter_Iota                 : constant Unicode_Char := 16#0269#;
   Latin_Letter_Small_Capital_I            : constant Unicode_Char := 16#026A#;
   Latin_Small_Letter_L_With_Middle_Tilde  : constant Unicode_Char := 16#026B#;
   Latin_Small_Letter_L_With_Belt          : constant Unicode_Char := 16#026C#;
   Latin_Small_Letter_L_With_Retroflex_Hook :
      constant Unicode_Char := 16#026D#;
   Latin_Small_Letter_Lezh                 : constant Unicode_Char := 16#026E#;
   Latin_Small_Letter_Turned_M             : constant Unicode_Char := 16#026F#;
   Latin_Small_Letter_Turned_M_With_Long_Leg :
      constant Unicode_Char := 16#0270#;
   Latin_Small_Letter_M_With_Hook          : constant Unicode_Char := 16#0271#;
   Latin_Small_Letter_N_With_Left_Hook     : constant Unicode_Char := 16#0272#;
   Latin_Small_Letter_N_With_Retroflex_Hook :
      constant Unicode_Char := 16#0273#;
   Latin_Letter_Small_Capital_N            : constant Unicode_Char := 16#0274#;
   Latin_Small_Letter_Barred_O             : constant Unicode_Char := 16#0275#;
   Latin_Letter_Small_Capital_Oe           : constant Unicode_Char := 16#0276#;
   Latin_Small_Letter_Closed_Omega         : constant Unicode_Char := 16#0277#;
   Latin_Small_Letter_Phi                  : constant Unicode_Char := 16#0278#;
   Latin_Small_Letter_Turned_R             : constant Unicode_Char := 16#0279#;
   Latin_Small_Letter_Turned_R_With_Long_Leg :
      constant Unicode_Char := 16#027A#;
   Latin_Small_Letter_Turned_R_With_Hook   : constant Unicode_Char := 16#027B#;
   Latin_Small_Letter_R_With_Long_Leg      : constant Unicode_Char := 16#027C#;
   Latin_Small_Letter_R_With_Tail          : constant Unicode_Char := 16#027D#;
   Latin_Small_Letter_R_With_Fishhook      : constant Unicode_Char := 16#027E#;
   Latin_Small_Letter_Reversed_R_With_Fishhook :
      constant Unicode_Char := 16#027F#;
   Latin_Letter_Small_Capital_R            : constant Unicode_Char := 16#0280#;
   Latin_Letter_Small_Capital_Inverted_R   : constant Unicode_Char := 16#0281#;
   Latin_Small_Letter_S_With_Hook          : constant Unicode_Char := 16#0282#;
   Latin_Small_Letter_Esh                  : constant Unicode_Char := 16#0283#;
   Latin_Small_Letter_Dotless_J_With_Stroke_And_Hook :
      constant Unicode_Char := 16#0284#;
   Latin_Small_Letter_Squat_Reversed_Esh   : constant Unicode_Char := 16#0285#;
   Latin_Small_Letter_Esh_With_Curl        : constant Unicode_Char := 16#0286#;
   Latin_Small_Letter_Turned_T             : constant Unicode_Char := 16#0287#;
   Latin_Small_Letter_T_With_Retroflex_Hook :
      constant Unicode_Char := 16#0288#;
   Latin_Small_Letter_U_Bar                : constant Unicode_Char := 16#0289#;
   Latin_Small_Letter_Upsilon              : constant Unicode_Char := 16#028A#;
   Latin_Small_Letter_V_With_Hook          : constant Unicode_Char := 16#028B#;
   Latin_Small_Letter_Turned_V             : constant Unicode_Char := 16#028C#;
   Latin_Small_Letter_Turned_W             : constant Unicode_Char := 16#028D#;
   Latin_Small_Letter_Turned_Y             : constant Unicode_Char := 16#028E#;
   Latin_Letter_Small_Capital_Y            : constant Unicode_Char := 16#028F#;
   Latin_Small_Letter_Z_With_Retroflex_Hook :
      constant Unicode_Char := 16#0290#;
   Latin_Small_Letter_Z_With_Curl          : constant Unicode_Char := 16#0291#;
   Latin_Small_Letter_Ezh                  : constant Unicode_Char := 16#0292#;
   Latin_Small_Letter_Ezh_With_Curl        : constant Unicode_Char := 16#0293#;
   Latin_Letter_Glottal_Stop               : constant Unicode_Char := 16#0294#;
   Latin_Letter_Pharyngeal_Voiced_Fricative :
      constant Unicode_Char := 16#0295#;
   Latin_Letter_Inverted_Glottal_Stop      : constant Unicode_Char := 16#0296#;
   Latin_Letter_Stretched_C                : constant Unicode_Char := 16#0297#;
   Latin_Letter_Bilabial_Click             : constant Unicode_Char := 16#0298#;
   Latin_Letter_Small_Capital_B            : constant Unicode_Char := 16#0299#;
   Latin_Small_Letter_Closed_Open_E        : constant Unicode_Char := 16#029A#;
   Latin_Letter_Small_Capital_G_With_Hook  : constant Unicode_Char := 16#029B#;
   Latin_Letter_Small_Capital_H            : constant Unicode_Char := 16#029C#;
   Latin_Small_Letter_J_With_Crossed_Tail  : constant Unicode_Char := 16#029D#;
   Latin_Small_Letter_Turned_K             : constant Unicode_Char := 16#029E#;
   Latin_Letter_Small_Capital_L            : constant Unicode_Char := 16#029F#;
   Latin_Small_Letter_Q_With_Hook          : constant Unicode_Char := 16#02A0#;
   Latin_Letter_Glottal_Stop_With_Stroke   : constant Unicode_Char := 16#02A1#;
   Latin_Letter_Reversed_Glottal_Stop_With_Stroke :
      constant Unicode_Char := 16#02A2#;
   Latin_Small_Letter_Dz_Digraph           : constant Unicode_Char := 16#02A3#;
   Latin_Small_Letter_Dezh_Digraph         : constant Unicode_Char := 16#02A4#;
   Latin_Small_Letter_Dz_Digraph_With_Curl : constant Unicode_Char := 16#02A5#;
   Latin_Small_Letter_Ts_Digraph           : constant Unicode_Char := 16#02A6#;
   Latin_Small_Letter_Tesh_Digraph         : constant Unicode_Char := 16#02A7#;
   Latin_Small_Letter_Tc_Digraph_With_Curl : constant Unicode_Char := 16#02A8#;
   Latin_Small_Letter_Feng_Digraph         : constant Unicode_Char := 16#02A9#;
   Latin_Small_Letter_Ls_Digraph           : constant Unicode_Char := 16#02AA#;
   Latin_Small_Letter_Lz_Digraph           : constant Unicode_Char := 16#02AB#;
   Latin_Letter_Bilabial_Percussive        : constant Unicode_Char := 16#02AC#;
   Latin_Letter_Bidental_Percussive        : constant Unicode_Char := 16#02AD#;
   Latin_Small_Letter_Turned_H_With_Fishhook :
      constant Unicode_Char := 16#02AE#;
   Latin_Small_Letter_Turned_H_With_Fishhook_And_Tail :
      constant Unicode_Char := 16#02AF#;
end Unicode.Names.Ipa_Extensions;
