--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Variation_Selectors_Sup is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Variation_Selector_17                   :
      constant Unicode_Char := 16#E0100#;
   Vs17                                    :
      Unicode_Char renames Variation_Selector_17;
   Variation_Selector_18                   :
      constant Unicode_Char := 16#E0101#;
   Vs18                                    :
      Unicode_Char renames Variation_Selector_18;
   Variation_Selector_19                   :
      constant Unicode_Char := 16#E0102#;
   Vs19                                    :
      Unicode_Char renames Variation_Selector_19;
   Variation_Selector_20                   :
      constant Unicode_Char := 16#E0103#;
   Vs20                                    :
      Unicode_Char renames Variation_Selector_20;
   Variation_Selector_21                   :
      constant Unicode_Char := 16#E0104#;
   Vs21                                    :
      Unicode_Char renames Variation_Selector_21;
   Variation_Selector_22                   :
      constant Unicode_Char := 16#E0105#;
   Vs22                                    :
      Unicode_Char renames Variation_Selector_22;
   Variation_Selector_23                   :
      constant Unicode_Char := 16#E0106#;
   Vs23                                    :
      Unicode_Char renames Variation_Selector_23;
   Variation_Selector_24                   :
      constant Unicode_Char := 16#E0107#;
   Vs24                                    :
      Unicode_Char renames Variation_Selector_24;
   Variation_Selector_25                   :
      constant Unicode_Char := 16#E0108#;
   Vs25                                    :
      Unicode_Char renames Variation_Selector_25;
   Variation_Selector_26                   :
      constant Unicode_Char := 16#E0109#;
   Vs26                                    :
      Unicode_Char renames Variation_Selector_26;
   Variation_Selector_27                   :
      constant Unicode_Char := 16#E010A#;
   Vs27                                    :
      Unicode_Char renames Variation_Selector_27;
   Variation_Selector_28                   :
      constant Unicode_Char := 16#E010B#;
   Vs28                                    :
      Unicode_Char renames Variation_Selector_28;
   Variation_Selector_29                   :
      constant Unicode_Char := 16#E010C#;
   Vs29                                    :
      Unicode_Char renames Variation_Selector_29;
   Variation_Selector_30                   :
      constant Unicode_Char := 16#E010D#;
   Vs30                                    :
      Unicode_Char renames Variation_Selector_30;
   Variation_Selector_31                   :
      constant Unicode_Char := 16#E010E#;
   Vs31                                    :
      Unicode_Char renames Variation_Selector_31;
   Variation_Selector_32                   :
      constant Unicode_Char := 16#E010F#;
   Vs32                                    :
      Unicode_Char renames Variation_Selector_32;
   Variation_Selector_33                   :
      constant Unicode_Char := 16#E0110#;
   Vs33                                    :
      Unicode_Char renames Variation_Selector_33;
   Variation_Selector_34                   :
      constant Unicode_Char := 16#E0111#;
   Vs34                                    :
      Unicode_Char renames Variation_Selector_34;
   Variation_Selector_35                   :
      constant Unicode_Char := 16#E0112#;
   Vs35                                    :
      Unicode_Char renames Variation_Selector_35;
   Variation_Selector_36                   :
      constant Unicode_Char := 16#E0113#;
   Vs36                                    :
      Unicode_Char renames Variation_Selector_36;
   Variation_Selector_37                   :
      constant Unicode_Char := 16#E0114#;
   Vs37                                    :
      Unicode_Char renames Variation_Selector_37;
   Variation_Selector_38                   :
      constant Unicode_Char := 16#E0115#;
   Vs38                                    :
      Unicode_Char renames Variation_Selector_38;
   Variation_Selector_39                   :
      constant Unicode_Char := 16#E0116#;
   Vs39                                    :
      Unicode_Char renames Variation_Selector_39;
   Variation_Selector_40                   :
      constant Unicode_Char := 16#E0117#;
   Vs40                                    :
      Unicode_Char renames Variation_Selector_40;
   Variation_Selector_41                   :
      constant Unicode_Char := 16#E0118#;
   Vs41                                    :
      Unicode_Char renames Variation_Selector_41;
   Variation_Selector_42                   :
      constant Unicode_Char := 16#E0119#;
   Vs42                                    :
      Unicode_Char renames Variation_Selector_42;
   Variation_Selector_43                   :
      constant Unicode_Char := 16#E011A#;
   Vs43                                    :
      Unicode_Char renames Variation_Selector_43;
   Variation_Selector_44                   :
      constant Unicode_Char := 16#E011B#;
   Vs44                                    :
      Unicode_Char renames Variation_Selector_44;
   Variation_Selector_45                   :
      constant Unicode_Char := 16#E011C#;
   Vs45                                    :
      Unicode_Char renames Variation_Selector_45;
   Variation_Selector_46                   :
      constant Unicode_Char := 16#E011D#;
   Vs46                                    :
      Unicode_Char renames Variation_Selector_46;
   Variation_Selector_47                   :
      constant Unicode_Char := 16#E011E#;
   Vs47                                    :
      Unicode_Char renames Variation_Selector_47;
   Variation_Selector_48                   :
      constant Unicode_Char := 16#E011F#;
   Vs48                                    :
      Unicode_Char renames Variation_Selector_48;
   Variation_Selector_49                   :
      constant Unicode_Char := 16#E0120#;
   Vs49                                    :
      Unicode_Char renames Variation_Selector_49;
   Variation_Selector_50                   :
      constant Unicode_Char := 16#E0121#;
   Vs50                                    :
      Unicode_Char renames Variation_Selector_50;
   Variation_Selector_51                   :
      constant Unicode_Char := 16#E0122#;
   Vs51                                    :
      Unicode_Char renames Variation_Selector_51;
   Variation_Selector_52                   :
      constant Unicode_Char := 16#E0123#;
   Vs52                                    :
      Unicode_Char renames Variation_Selector_52;
   Variation_Selector_53                   :
      constant Unicode_Char := 16#E0124#;
   Vs53                                    :
      Unicode_Char renames Variation_Selector_53;
   Variation_Selector_54                   :
      constant Unicode_Char := 16#E0125#;
   Vs54                                    :
      Unicode_Char renames Variation_Selector_54;
   Variation_Selector_55                   :
      constant Unicode_Char := 16#E0126#;
   Vs55                                    :
      Unicode_Char renames Variation_Selector_55;
   Variation_Selector_56                   :
      constant Unicode_Char := 16#E0127#;
   Vs56                                    :
      Unicode_Char renames Variation_Selector_56;
   Variation_Selector_57                   :
      constant Unicode_Char := 16#E0128#;
   Vs57                                    :
      Unicode_Char renames Variation_Selector_57;
   Variation_Selector_58                   :
      constant Unicode_Char := 16#E0129#;
   Vs58                                    :
      Unicode_Char renames Variation_Selector_58;
   Variation_Selector_59                   :
      constant Unicode_Char := 16#E012A#;
   Vs59                                    :
      Unicode_Char renames Variation_Selector_59;
   Variation_Selector_60                   :
      constant Unicode_Char := 16#E012B#;
   Vs60                                    :
      Unicode_Char renames Variation_Selector_60;
   Variation_Selector_61                   :
      constant Unicode_Char := 16#E012C#;
   Vs61                                    :
      Unicode_Char renames Variation_Selector_61;
   Variation_Selector_62                   :
      constant Unicode_Char := 16#E012D#;
   Vs62                                    :
      Unicode_Char renames Variation_Selector_62;
   Variation_Selector_63                   :
      constant Unicode_Char := 16#E012E#;
   Vs63                                    :
      Unicode_Char renames Variation_Selector_63;
   Variation_Selector_64                   :
      constant Unicode_Char := 16#E012F#;
   Vs64                                    :
      Unicode_Char renames Variation_Selector_64;
   Variation_Selector_65                   :
      constant Unicode_Char := 16#E0130#;
   Vs65                                    :
      Unicode_Char renames Variation_Selector_65;
   Variation_Selector_66                   :
      constant Unicode_Char := 16#E0131#;
   Vs66                                    :
      Unicode_Char renames Variation_Selector_66;
   Variation_Selector_67                   :
      constant Unicode_Char := 16#E0132#;
   Vs67                                    :
      Unicode_Char renames Variation_Selector_67;
   Variation_Selector_68                   :
      constant Unicode_Char := 16#E0133#;
   Vs68                                    :
      Unicode_Char renames Variation_Selector_68;
   Variation_Selector_69                   :
      constant Unicode_Char := 16#E0134#;
   Vs69                                    :
      Unicode_Char renames Variation_Selector_69;
   Variation_Selector_70                   :
      constant Unicode_Char := 16#E0135#;
   Vs70                                    :
      Unicode_Char renames Variation_Selector_70;
   Variation_Selector_71                   :
      constant Unicode_Char := 16#E0136#;
   Vs71                                    :
      Unicode_Char renames Variation_Selector_71;
   Variation_Selector_72                   :
      constant Unicode_Char := 16#E0137#;
   Vs72                                    :
      Unicode_Char renames Variation_Selector_72;
   Variation_Selector_73                   :
      constant Unicode_Char := 16#E0138#;
   Vs73                                    :
      Unicode_Char renames Variation_Selector_73;
   Variation_Selector_74                   :
      constant Unicode_Char := 16#E0139#;
   Vs74                                    :
      Unicode_Char renames Variation_Selector_74;
   Variation_Selector_75                   :
      constant Unicode_Char := 16#E013A#;
   Vs75                                    :
      Unicode_Char renames Variation_Selector_75;
   Variation_Selector_76                   :
      constant Unicode_Char := 16#E013B#;
   Vs76                                    :
      Unicode_Char renames Variation_Selector_76;
   Variation_Selector_77                   :
      constant Unicode_Char := 16#E013C#;
   Vs77                                    :
      Unicode_Char renames Variation_Selector_77;
   Variation_Selector_78                   :
      constant Unicode_Char := 16#E013D#;
   Vs78                                    :
      Unicode_Char renames Variation_Selector_78;
   Variation_Selector_79                   :
      constant Unicode_Char := 16#E013E#;
   Vs79                                    :
      Unicode_Char renames Variation_Selector_79;
   Variation_Selector_80                   :
      constant Unicode_Char := 16#E013F#;
   Vs80                                    :
      Unicode_Char renames Variation_Selector_80;
   Variation_Selector_81                   :
      constant Unicode_Char := 16#E0140#;
   Vs81                                    :
      Unicode_Char renames Variation_Selector_81;
   Variation_Selector_82                   :
      constant Unicode_Char := 16#E0141#;
   Vs82                                    :
      Unicode_Char renames Variation_Selector_82;
   Variation_Selector_83                   :
      constant Unicode_Char := 16#E0142#;
   Vs83                                    :
      Unicode_Char renames Variation_Selector_83;
   Variation_Selector_84                   :
      constant Unicode_Char := 16#E0143#;
   Vs84                                    :
      Unicode_Char renames Variation_Selector_84;
   Variation_Selector_85                   :
      constant Unicode_Char := 16#E0144#;
   Vs85                                    :
      Unicode_Char renames Variation_Selector_85;
   Variation_Selector_86                   :
      constant Unicode_Char := 16#E0145#;
   Vs86                                    :
      Unicode_Char renames Variation_Selector_86;
   Variation_Selector_87                   :
      constant Unicode_Char := 16#E0146#;
   Vs87                                    :
      Unicode_Char renames Variation_Selector_87;
   Variation_Selector_88                   :
      constant Unicode_Char := 16#E0147#;
   Vs88                                    :
      Unicode_Char renames Variation_Selector_88;
   Variation_Selector_89                   :
      constant Unicode_Char := 16#E0148#;
   Vs89                                    :
      Unicode_Char renames Variation_Selector_89;
   Variation_Selector_90                   :
      constant Unicode_Char := 16#E0149#;
   Vs90                                    :
      Unicode_Char renames Variation_Selector_90;
   Variation_Selector_91                   :
      constant Unicode_Char := 16#E014A#;
   Vs91                                    :
      Unicode_Char renames Variation_Selector_91;
   Variation_Selector_92                   :
      constant Unicode_Char := 16#E014B#;
   Vs92                                    :
      Unicode_Char renames Variation_Selector_92;
   Variation_Selector_93                   :
      constant Unicode_Char := 16#E014C#;
   Vs93                                    :
      Unicode_Char renames Variation_Selector_93;
   Variation_Selector_94                   :
      constant Unicode_Char := 16#E014D#;
   Vs94                                    :
      Unicode_Char renames Variation_Selector_94;
   Variation_Selector_95                   :
      constant Unicode_Char := 16#E014E#;
   Vs95                                    :
      Unicode_Char renames Variation_Selector_95;
   Variation_Selector_96                   :
      constant Unicode_Char := 16#E014F#;
   Vs96                                    :
      Unicode_Char renames Variation_Selector_96;
   Variation_Selector_97                   :
      constant Unicode_Char := 16#E0150#;
   Vs97                                    :
      Unicode_Char renames Variation_Selector_97;
   Variation_Selector_98                   :
      constant Unicode_Char := 16#E0151#;
   Vs98                                    :
      Unicode_Char renames Variation_Selector_98;
   Variation_Selector_99                   :
      constant Unicode_Char := 16#E0152#;
   Vs99                                    :
      Unicode_Char renames Variation_Selector_99;
   Variation_Selector_100                  :
      constant Unicode_Char := 16#E0153#;
   Vs100                                   :
      Unicode_Char renames Variation_Selector_100;
   Variation_Selector_101                  :
      constant Unicode_Char := 16#E0154#;
   Vs101                                   :
      Unicode_Char renames Variation_Selector_101;
   Variation_Selector_102                  :
      constant Unicode_Char := 16#E0155#;
   Vs102                                   :
      Unicode_Char renames Variation_Selector_102;
   Variation_Selector_103                  :
      constant Unicode_Char := 16#E0156#;
   Vs103                                   :
      Unicode_Char renames Variation_Selector_103;
   Variation_Selector_104                  :
      constant Unicode_Char := 16#E0157#;
   Vs104                                   :
      Unicode_Char renames Variation_Selector_104;
   Variation_Selector_105                  :
      constant Unicode_Char := 16#E0158#;
   Vs105                                   :
      Unicode_Char renames Variation_Selector_105;
   Variation_Selector_106                  :
      constant Unicode_Char := 16#E0159#;
   Vs106                                   :
      Unicode_Char renames Variation_Selector_106;
   Variation_Selector_107                  :
      constant Unicode_Char := 16#E015A#;
   Vs107                                   :
      Unicode_Char renames Variation_Selector_107;
   Variation_Selector_108                  :
      constant Unicode_Char := 16#E015B#;
   Vs108                                   :
      Unicode_Char renames Variation_Selector_108;
   Variation_Selector_109                  :
      constant Unicode_Char := 16#E015C#;
   Vs109                                   :
      Unicode_Char renames Variation_Selector_109;
   Variation_Selector_110                  :
      constant Unicode_Char := 16#E015D#;
   Vs110                                   :
      Unicode_Char renames Variation_Selector_110;
   Variation_Selector_111                  :
      constant Unicode_Char := 16#E015E#;
   Vs111                                   :
      Unicode_Char renames Variation_Selector_111;
   Variation_Selector_112                  :
      constant Unicode_Char := 16#E015F#;
   Vs112                                   :
      Unicode_Char renames Variation_Selector_112;
   Variation_Selector_113                  :
      constant Unicode_Char := 16#E0160#;
   Vs113                                   :
      Unicode_Char renames Variation_Selector_113;
   Variation_Selector_114                  :
      constant Unicode_Char := 16#E0161#;
   Vs114                                   :
      Unicode_Char renames Variation_Selector_114;
   Variation_Selector_115                  :
      constant Unicode_Char := 16#E0162#;
   Vs115                                   :
      Unicode_Char renames Variation_Selector_115;
   Variation_Selector_116                  :
      constant Unicode_Char := 16#E0163#;
   Vs116                                   :
      Unicode_Char renames Variation_Selector_116;
   Variation_Selector_117                  :
      constant Unicode_Char := 16#E0164#;
   Vs117                                   :
      Unicode_Char renames Variation_Selector_117;
   Variation_Selector_118                  :
      constant Unicode_Char := 16#E0165#;
   Vs118                                   :
      Unicode_Char renames Variation_Selector_118;
   Variation_Selector_119                  :
      constant Unicode_Char := 16#E0166#;
   Vs119                                   :
      Unicode_Char renames Variation_Selector_119;
   Variation_Selector_120                  :
      constant Unicode_Char := 16#E0167#;
   Vs120                                   :
      Unicode_Char renames Variation_Selector_120;
   Variation_Selector_121                  :
      constant Unicode_Char := 16#E0168#;
   Vs121                                   :
      Unicode_Char renames Variation_Selector_121;
   Variation_Selector_122                  :
      constant Unicode_Char := 16#E0169#;
   Vs122                                   :
      Unicode_Char renames Variation_Selector_122;
   Variation_Selector_123                  :
      constant Unicode_Char := 16#E016A#;
   Vs123                                   :
      Unicode_Char renames Variation_Selector_123;
   Variation_Selector_124                  :
      constant Unicode_Char := 16#E016B#;
   Vs124                                   :
      Unicode_Char renames Variation_Selector_124;
   Variation_Selector_125                  :
      constant Unicode_Char := 16#E016C#;
   Vs125                                   :
      Unicode_Char renames Variation_Selector_125;
   Variation_Selector_126                  :
      constant Unicode_Char := 16#E016D#;
   Vs126                                   :
      Unicode_Char renames Variation_Selector_126;
   Variation_Selector_127                  :
      constant Unicode_Char := 16#E016E#;
   Vs127                                   :
      Unicode_Char renames Variation_Selector_127;
   Variation_Selector_128                  :
      constant Unicode_Char := 16#E016F#;
   Vs128                                   :
      Unicode_Char renames Variation_Selector_128;
   Variation_Selector_129                  :
      constant Unicode_Char := 16#E0170#;
   Vs129                                   :
      Unicode_Char renames Variation_Selector_129;
   Variation_Selector_130                  :
      constant Unicode_Char := 16#E0171#;
   Vs130                                   :
      Unicode_Char renames Variation_Selector_130;
   Variation_Selector_131                  :
      constant Unicode_Char := 16#E0172#;
   Vs131                                   :
      Unicode_Char renames Variation_Selector_131;
   Variation_Selector_132                  :
      constant Unicode_Char := 16#E0173#;
   Vs132                                   :
      Unicode_Char renames Variation_Selector_132;
   Variation_Selector_133                  :
      constant Unicode_Char := 16#E0174#;
   Vs133                                   :
      Unicode_Char renames Variation_Selector_133;
   Variation_Selector_134                  :
      constant Unicode_Char := 16#E0175#;
   Vs134                                   :
      Unicode_Char renames Variation_Selector_134;
   Variation_Selector_135                  :
      constant Unicode_Char := 16#E0176#;
   Vs135                                   :
      Unicode_Char renames Variation_Selector_135;
   Variation_Selector_136                  :
      constant Unicode_Char := 16#E0177#;
   Vs136                                   :
      Unicode_Char renames Variation_Selector_136;
   Variation_Selector_137                  :
      constant Unicode_Char := 16#E0178#;
   Vs137                                   :
      Unicode_Char renames Variation_Selector_137;
   Variation_Selector_138                  :
      constant Unicode_Char := 16#E0179#;
   Vs138                                   :
      Unicode_Char renames Variation_Selector_138;
   Variation_Selector_139                  :
      constant Unicode_Char := 16#E017A#;
   Vs139                                   :
      Unicode_Char renames Variation_Selector_139;
   Variation_Selector_140                  :
      constant Unicode_Char := 16#E017B#;
   Vs140                                   :
      Unicode_Char renames Variation_Selector_140;
   Variation_Selector_141                  :
      constant Unicode_Char := 16#E017C#;
   Vs141                                   :
      Unicode_Char renames Variation_Selector_141;
   Variation_Selector_142                  :
      constant Unicode_Char := 16#E017D#;
   Vs142                                   :
      Unicode_Char renames Variation_Selector_142;
   Variation_Selector_143                  :
      constant Unicode_Char := 16#E017E#;
   Vs143                                   :
      Unicode_Char renames Variation_Selector_143;
   Variation_Selector_144                  :
      constant Unicode_Char := 16#E017F#;
   Vs144                                   :
      Unicode_Char renames Variation_Selector_144;
   Variation_Selector_145                  :
      constant Unicode_Char := 16#E0180#;
   Vs145                                   :
      Unicode_Char renames Variation_Selector_145;
   Variation_Selector_146                  :
      constant Unicode_Char := 16#E0181#;
   Vs146                                   :
      Unicode_Char renames Variation_Selector_146;
   Variation_Selector_147                  :
      constant Unicode_Char := 16#E0182#;
   Vs147                                   :
      Unicode_Char renames Variation_Selector_147;
   Variation_Selector_148                  :
      constant Unicode_Char := 16#E0183#;
   Vs148                                   :
      Unicode_Char renames Variation_Selector_148;
   Variation_Selector_149                  :
      constant Unicode_Char := 16#E0184#;
   Vs149                                   :
      Unicode_Char renames Variation_Selector_149;
   Variation_Selector_150                  :
      constant Unicode_Char := 16#E0185#;
   Vs150                                   :
      Unicode_Char renames Variation_Selector_150;
   Variation_Selector_151                  :
      constant Unicode_Char := 16#E0186#;
   Vs151                                   :
      Unicode_Char renames Variation_Selector_151;
   Variation_Selector_152                  :
      constant Unicode_Char := 16#E0187#;
   Vs152                                   :
      Unicode_Char renames Variation_Selector_152;
   Variation_Selector_153                  :
      constant Unicode_Char := 16#E0188#;
   Vs153                                   :
      Unicode_Char renames Variation_Selector_153;
   Variation_Selector_154                  :
      constant Unicode_Char := 16#E0189#;
   Vs154                                   :
      Unicode_Char renames Variation_Selector_154;
   Variation_Selector_155                  :
      constant Unicode_Char := 16#E018A#;
   Vs155                                   :
      Unicode_Char renames Variation_Selector_155;
   Variation_Selector_156                  :
      constant Unicode_Char := 16#E018B#;
   Vs156                                   :
      Unicode_Char renames Variation_Selector_156;
   Variation_Selector_157                  :
      constant Unicode_Char := 16#E018C#;
   Vs157                                   :
      Unicode_Char renames Variation_Selector_157;
   Variation_Selector_158                  :
      constant Unicode_Char := 16#E018D#;
   Vs158                                   :
      Unicode_Char renames Variation_Selector_158;
   Variation_Selector_159                  :
      constant Unicode_Char := 16#E018E#;
   Vs159                                   :
      Unicode_Char renames Variation_Selector_159;
   Variation_Selector_160                  :
      constant Unicode_Char := 16#E018F#;
   Vs160                                   :
      Unicode_Char renames Variation_Selector_160;
   Variation_Selector_161                  :
      constant Unicode_Char := 16#E0190#;
   Vs161                                   :
      Unicode_Char renames Variation_Selector_161;
   Variation_Selector_162                  :
      constant Unicode_Char := 16#E0191#;
   Vs162                                   :
      Unicode_Char renames Variation_Selector_162;
   Variation_Selector_163                  :
      constant Unicode_Char := 16#E0192#;
   Vs163                                   :
      Unicode_Char renames Variation_Selector_163;
   Variation_Selector_164                  :
      constant Unicode_Char := 16#E0193#;
   Vs164                                   :
      Unicode_Char renames Variation_Selector_164;
   Variation_Selector_165                  :
      constant Unicode_Char := 16#E0194#;
   Vs165                                   :
      Unicode_Char renames Variation_Selector_165;
   Variation_Selector_166                  :
      constant Unicode_Char := 16#E0195#;
   Vs166                                   :
      Unicode_Char renames Variation_Selector_166;
   Variation_Selector_167                  :
      constant Unicode_Char := 16#E0196#;
   Vs167                                   :
      Unicode_Char renames Variation_Selector_167;
   Variation_Selector_168                  :
      constant Unicode_Char := 16#E0197#;
   Vs168                                   :
      Unicode_Char renames Variation_Selector_168;
   Variation_Selector_169                  :
      constant Unicode_Char := 16#E0198#;
   Vs169                                   :
      Unicode_Char renames Variation_Selector_169;
   Variation_Selector_170                  :
      constant Unicode_Char := 16#E0199#;
   Vs170                                   :
      Unicode_Char renames Variation_Selector_170;
   Variation_Selector_171                  :
      constant Unicode_Char := 16#E019A#;
   Vs171                                   :
      Unicode_Char renames Variation_Selector_171;
   Variation_Selector_172                  :
      constant Unicode_Char := 16#E019B#;
   Vs172                                   :
      Unicode_Char renames Variation_Selector_172;
   Variation_Selector_173                  :
      constant Unicode_Char := 16#E019C#;
   Vs173                                   :
      Unicode_Char renames Variation_Selector_173;
   Variation_Selector_174                  :
      constant Unicode_Char := 16#E019D#;
   Vs174                                   :
      Unicode_Char renames Variation_Selector_174;
   Variation_Selector_175                  :
      constant Unicode_Char := 16#E019E#;
   Vs175                                   :
      Unicode_Char renames Variation_Selector_175;
   Variation_Selector_176                  :
      constant Unicode_Char := 16#E019F#;
   Vs176                                   :
      Unicode_Char renames Variation_Selector_176;
   Variation_Selector_177                  :
      constant Unicode_Char := 16#E01A0#;
   Vs177                                   :
      Unicode_Char renames Variation_Selector_177;
   Variation_Selector_178                  :
      constant Unicode_Char := 16#E01A1#;
   Vs178                                   :
      Unicode_Char renames Variation_Selector_178;
   Variation_Selector_179                  :
      constant Unicode_Char := 16#E01A2#;
   Vs179                                   :
      Unicode_Char renames Variation_Selector_179;
   Variation_Selector_180                  :
      constant Unicode_Char := 16#E01A3#;
   Vs180                                   :
      Unicode_Char renames Variation_Selector_180;
   Variation_Selector_181                  :
      constant Unicode_Char := 16#E01A4#;
   Vs181                                   :
      Unicode_Char renames Variation_Selector_181;
   Variation_Selector_182                  :
      constant Unicode_Char := 16#E01A5#;
   Vs182                                   :
      Unicode_Char renames Variation_Selector_182;
   Variation_Selector_183                  :
      constant Unicode_Char := 16#E01A6#;
   Vs183                                   :
      Unicode_Char renames Variation_Selector_183;
   Variation_Selector_184                  :
      constant Unicode_Char := 16#E01A7#;
   Vs184                                   :
      Unicode_Char renames Variation_Selector_184;
   Variation_Selector_185                  :
      constant Unicode_Char := 16#E01A8#;
   Vs185                                   :
      Unicode_Char renames Variation_Selector_185;
   Variation_Selector_186                  :
      constant Unicode_Char := 16#E01A9#;
   Vs186                                   :
      Unicode_Char renames Variation_Selector_186;
   Variation_Selector_187                  :
      constant Unicode_Char := 16#E01AA#;
   Vs187                                   :
      Unicode_Char renames Variation_Selector_187;
   Variation_Selector_188                  :
      constant Unicode_Char := 16#E01AB#;
   Vs188                                   :
      Unicode_Char renames Variation_Selector_188;
   Variation_Selector_189                  :
      constant Unicode_Char := 16#E01AC#;
   Vs189                                   :
      Unicode_Char renames Variation_Selector_189;
   Variation_Selector_190                  :
      constant Unicode_Char := 16#E01AD#;
   Vs190                                   :
      Unicode_Char renames Variation_Selector_190;
   Variation_Selector_191                  :
      constant Unicode_Char := 16#E01AE#;
   Vs191                                   :
      Unicode_Char renames Variation_Selector_191;
   Variation_Selector_192                  :
      constant Unicode_Char := 16#E01AF#;
   Vs192                                   :
      Unicode_Char renames Variation_Selector_192;
   Variation_Selector_193                  :
      constant Unicode_Char := 16#E01B0#;
   Vs193                                   :
      Unicode_Char renames Variation_Selector_193;
   Variation_Selector_194                  :
      constant Unicode_Char := 16#E01B1#;
   Vs194                                   :
      Unicode_Char renames Variation_Selector_194;
   Variation_Selector_195                  :
      constant Unicode_Char := 16#E01B2#;
   Vs195                                   :
      Unicode_Char renames Variation_Selector_195;
   Variation_Selector_196                  :
      constant Unicode_Char := 16#E01B3#;
   Vs196                                   :
      Unicode_Char renames Variation_Selector_196;
   Variation_Selector_197                  :
      constant Unicode_Char := 16#E01B4#;
   Vs197                                   :
      Unicode_Char renames Variation_Selector_197;
   Variation_Selector_198                  :
      constant Unicode_Char := 16#E01B5#;
   Vs198                                   :
      Unicode_Char renames Variation_Selector_198;
   Variation_Selector_199                  :
      constant Unicode_Char := 16#E01B6#;
   Vs199                                   :
      Unicode_Char renames Variation_Selector_199;
   Variation_Selector_200                  :
      constant Unicode_Char := 16#E01B7#;
   Vs200                                   :
      Unicode_Char renames Variation_Selector_200;
   Variation_Selector_201                  :
      constant Unicode_Char := 16#E01B8#;
   Vs201                                   :
      Unicode_Char renames Variation_Selector_201;
   Variation_Selector_202                  :
      constant Unicode_Char := 16#E01B9#;
   Vs202                                   :
      Unicode_Char renames Variation_Selector_202;
   Variation_Selector_203                  :
      constant Unicode_Char := 16#E01BA#;
   Vs203                                   :
      Unicode_Char renames Variation_Selector_203;
   Variation_Selector_204                  :
      constant Unicode_Char := 16#E01BB#;
   Vs204                                   :
      Unicode_Char renames Variation_Selector_204;
   Variation_Selector_205                  :
      constant Unicode_Char := 16#E01BC#;
   Vs205                                   :
      Unicode_Char renames Variation_Selector_205;
   Variation_Selector_206                  :
      constant Unicode_Char := 16#E01BD#;
   Vs206                                   :
      Unicode_Char renames Variation_Selector_206;
   Variation_Selector_207                  :
      constant Unicode_Char := 16#E01BE#;
   Vs207                                   :
      Unicode_Char renames Variation_Selector_207;
   Variation_Selector_208                  :
      constant Unicode_Char := 16#E01BF#;
   Vs208                                   :
      Unicode_Char renames Variation_Selector_208;
   Variation_Selector_209                  :
      constant Unicode_Char := 16#E01C0#;
   Vs209                                   :
      Unicode_Char renames Variation_Selector_209;
   Variation_Selector_210                  :
      constant Unicode_Char := 16#E01C1#;
   Vs210                                   :
      Unicode_Char renames Variation_Selector_210;
   Variation_Selector_211                  :
      constant Unicode_Char := 16#E01C2#;
   Vs211                                   :
      Unicode_Char renames Variation_Selector_211;
   Variation_Selector_212                  :
      constant Unicode_Char := 16#E01C3#;
   Vs212                                   :
      Unicode_Char renames Variation_Selector_212;
   Variation_Selector_213                  :
      constant Unicode_Char := 16#E01C4#;
   Vs213                                   :
      Unicode_Char renames Variation_Selector_213;
   Variation_Selector_214                  :
      constant Unicode_Char := 16#E01C5#;
   Vs214                                   :
      Unicode_Char renames Variation_Selector_214;
   Variation_Selector_215                  :
      constant Unicode_Char := 16#E01C6#;
   Vs215                                   :
      Unicode_Char renames Variation_Selector_215;
   Variation_Selector_216                  :
      constant Unicode_Char := 16#E01C7#;
   Vs216                                   :
      Unicode_Char renames Variation_Selector_216;
   Variation_Selector_217                  :
      constant Unicode_Char := 16#E01C8#;
   Vs217                                   :
      Unicode_Char renames Variation_Selector_217;
   Variation_Selector_218                  :
      constant Unicode_Char := 16#E01C9#;
   Vs218                                   :
      Unicode_Char renames Variation_Selector_218;
   Variation_Selector_219                  :
      constant Unicode_Char := 16#E01CA#;
   Vs219                                   :
      Unicode_Char renames Variation_Selector_219;
   Variation_Selector_220                  :
      constant Unicode_Char := 16#E01CB#;
   Vs220                                   :
      Unicode_Char renames Variation_Selector_220;
   Variation_Selector_221                  :
      constant Unicode_Char := 16#E01CC#;
   Vs221                                   :
      Unicode_Char renames Variation_Selector_221;
   Variation_Selector_222                  :
      constant Unicode_Char := 16#E01CD#;
   Vs222                                   :
      Unicode_Char renames Variation_Selector_222;
   Variation_Selector_223                  :
      constant Unicode_Char := 16#E01CE#;
   Vs223                                   :
      Unicode_Char renames Variation_Selector_223;
   Variation_Selector_224                  :
      constant Unicode_Char := 16#E01CF#;
   Vs224                                   :
      Unicode_Char renames Variation_Selector_224;
   Variation_Selector_225                  :
      constant Unicode_Char := 16#E01D0#;
   Vs225                                   :
      Unicode_Char renames Variation_Selector_225;
   Variation_Selector_226                  :
      constant Unicode_Char := 16#E01D1#;
   Vs226                                   :
      Unicode_Char renames Variation_Selector_226;
   Variation_Selector_227                  :
      constant Unicode_Char := 16#E01D2#;
   Vs227                                   :
      Unicode_Char renames Variation_Selector_227;
   Variation_Selector_228                  :
      constant Unicode_Char := 16#E01D3#;
   Vs228                                   :
      Unicode_Char renames Variation_Selector_228;
   Variation_Selector_229                  :
      constant Unicode_Char := 16#E01D4#;
   Vs229                                   :
      Unicode_Char renames Variation_Selector_229;
   Variation_Selector_230                  :
      constant Unicode_Char := 16#E01D5#;
   Vs230                                   :
      Unicode_Char renames Variation_Selector_230;
   Variation_Selector_231                  :
      constant Unicode_Char := 16#E01D6#;
   Vs231                                   :
      Unicode_Char renames Variation_Selector_231;
   Variation_Selector_232                  :
      constant Unicode_Char := 16#E01D7#;
   Vs232                                   :
      Unicode_Char renames Variation_Selector_232;
   Variation_Selector_233                  :
      constant Unicode_Char := 16#E01D8#;
   Vs233                                   :
      Unicode_Char renames Variation_Selector_233;
   Variation_Selector_234                  :
      constant Unicode_Char := 16#E01D9#;
   Vs234                                   :
      Unicode_Char renames Variation_Selector_234;
   Variation_Selector_235                  :
      constant Unicode_Char := 16#E01DA#;
   Vs235                                   :
      Unicode_Char renames Variation_Selector_235;
   Variation_Selector_236                  :
      constant Unicode_Char := 16#E01DB#;
   Vs236                                   :
      Unicode_Char renames Variation_Selector_236;
   Variation_Selector_237                  :
      constant Unicode_Char := 16#E01DC#;
   Vs237                                   :
      Unicode_Char renames Variation_Selector_237;
   Variation_Selector_238                  :
      constant Unicode_Char := 16#E01DD#;
   Vs238                                   :
      Unicode_Char renames Variation_Selector_238;
   Variation_Selector_239                  :
      constant Unicode_Char := 16#E01DE#;
   Vs239                                   :
      Unicode_Char renames Variation_Selector_239;
   Variation_Selector_240                  :
      constant Unicode_Char := 16#E01DF#;
   Vs240                                   :
      Unicode_Char renames Variation_Selector_240;
   Variation_Selector_241                  :
      constant Unicode_Char := 16#E01E0#;
   Vs241                                   :
      Unicode_Char renames Variation_Selector_241;
   Variation_Selector_242                  :
      constant Unicode_Char := 16#E01E1#;
   Vs242                                   :
      Unicode_Char renames Variation_Selector_242;
   Variation_Selector_243                  :
      constant Unicode_Char := 16#E01E2#;
   Vs243                                   :
      Unicode_Char renames Variation_Selector_243;
   Variation_Selector_244                  :
      constant Unicode_Char := 16#E01E3#;
   Vs244                                   :
      Unicode_Char renames Variation_Selector_244;
   Variation_Selector_245                  :
      constant Unicode_Char := 16#E01E4#;
   Vs245                                   :
      Unicode_Char renames Variation_Selector_245;
   Variation_Selector_246                  :
      constant Unicode_Char := 16#E01E5#;
   Vs246                                   :
      Unicode_Char renames Variation_Selector_246;
   Variation_Selector_247                  :
      constant Unicode_Char := 16#E01E6#;
   Vs247                                   :
      Unicode_Char renames Variation_Selector_247;
   Variation_Selector_248                  :
      constant Unicode_Char := 16#E01E7#;
   Vs248                                   :
      Unicode_Char renames Variation_Selector_248;
   Variation_Selector_249                  :
      constant Unicode_Char := 16#E01E8#;
   Vs249                                   :
      Unicode_Char renames Variation_Selector_249;
   Variation_Selector_250                  :
      constant Unicode_Char := 16#E01E9#;
   Vs250                                   :
      Unicode_Char renames Variation_Selector_250;
   Variation_Selector_251                  :
      constant Unicode_Char := 16#E01EA#;
   Vs251                                   :
      Unicode_Char renames Variation_Selector_251;
   Variation_Selector_252                  :
      constant Unicode_Char := 16#E01EB#;
   Vs252                                   :
      Unicode_Char renames Variation_Selector_252;
   Variation_Selector_253                  :
      constant Unicode_Char := 16#E01EC#;
   Vs253                                   :
      Unicode_Char renames Variation_Selector_253;
   Variation_Selector_254                  :
      constant Unicode_Char := 16#E01ED#;
   Vs254                                   :
      Unicode_Char renames Variation_Selector_254;
   Variation_Selector_255                  :
      constant Unicode_Char := 16#E01EE#;
   Vs255                                   :
      Unicode_Char renames Variation_Selector_255;
   Variation_Selector_256                  :
      constant Unicode_Char := 16#E01EF#;
   Vs256                                   :
      Unicode_Char renames Variation_Selector_256;
end Unicode.Names.Variation_Selectors_Sup;
