--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Modi is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Modi_Letter_A                           :
      constant Unicode_Char := 16#11600#;
   Modi_Letter_Aa                          :
      constant Unicode_Char := 16#11601#;
   Modi_Letter_I                           :
      constant Unicode_Char := 16#11602#;
   Modi_Letter_Ii                          :
      constant Unicode_Char := 16#11603#;
   Modi_Letter_U                           :
      constant Unicode_Char := 16#11604#;
   Modi_Letter_Uu                          :
      constant Unicode_Char := 16#11605#;
   Modi_Letter_Vocalic_R                   :
      constant Unicode_Char := 16#11606#;
   Modi_Letter_Vocalic_Rr                  :
      constant Unicode_Char := 16#11607#;
   Modi_Letter_Vocalic_L                   :
      constant Unicode_Char := 16#11608#;
   Modi_Letter_Vocalic_Ll                  :
      constant Unicode_Char := 16#11609#;
   Modi_Letter_E                           :
      constant Unicode_Char := 16#1160A#;
   Modi_Letter_Ai                          :
      constant Unicode_Char := 16#1160B#;
   Modi_Letter_O                           :
      constant Unicode_Char := 16#1160C#;
   Modi_Letter_Au                          :
      constant Unicode_Char := 16#1160D#;
   Modi_Letter_Ka                          :
      constant Unicode_Char := 16#1160E#;
   Modi_Letter_Kha                         :
      constant Unicode_Char := 16#1160F#;
   Modi_Letter_Ga                          :
      constant Unicode_Char := 16#11610#;
   Modi_Letter_Gha                         :
      constant Unicode_Char := 16#11611#;
   Modi_Letter_Nga                         :
      constant Unicode_Char := 16#11612#;
   Modi_Letter_Ca                          :
      constant Unicode_Char := 16#11613#;
   Modi_Letter_Cha                         :
      constant Unicode_Char := 16#11614#;
   Modi_Letter_Ja                          :
      constant Unicode_Char := 16#11615#;
   Modi_Letter_Jha                         :
      constant Unicode_Char := 16#11616#;
   Modi_Letter_Nya                         :
      constant Unicode_Char := 16#11617#;
   Modi_Letter_Tta                         :
      constant Unicode_Char := 16#11618#;
   Modi_Letter_Ttha                        :
      constant Unicode_Char := 16#11619#;
   Modi_Letter_Dda                         :
      constant Unicode_Char := 16#1161A#;
   Modi_Letter_Ddha                        :
      constant Unicode_Char := 16#1161B#;
   Modi_Letter_Nna                         :
      constant Unicode_Char := 16#1161C#;
   Modi_Letter_Ta                          :
      constant Unicode_Char := 16#1161D#;
   Modi_Letter_Tha                         :
      constant Unicode_Char := 16#1161E#;
   Modi_Letter_Da                          :
      constant Unicode_Char := 16#1161F#;
   Modi_Letter_Dha                         :
      constant Unicode_Char := 16#11620#;
   Modi_Letter_Na                          :
      constant Unicode_Char := 16#11621#;
   Modi_Letter_Pa                          :
      constant Unicode_Char := 16#11622#;
   Modi_Letter_Pha                         :
      constant Unicode_Char := 16#11623#;
   Modi_Letter_Ba                          :
      constant Unicode_Char := 16#11624#;
   Modi_Letter_Bha                         :
      constant Unicode_Char := 16#11625#;
   Modi_Letter_Ma                          :
      constant Unicode_Char := 16#11626#;
   Modi_Letter_Ya                          :
      constant Unicode_Char := 16#11627#;
   Modi_Letter_Ra                          :
      constant Unicode_Char := 16#11628#;
   Modi_Letter_La                          :
      constant Unicode_Char := 16#11629#;
   Modi_Letter_Va                          :
      constant Unicode_Char := 16#1162A#;
   Modi_Letter_Sha                         :
      constant Unicode_Char := 16#1162B#;
   Modi_Letter_Ssa                         :
      constant Unicode_Char := 16#1162C#;
   Modi_Letter_Sa                          :
      constant Unicode_Char := 16#1162D#;
   Modi_Letter_Ha                          :
      constant Unicode_Char := 16#1162E#;
   Modi_Letter_Lla                         :
      constant Unicode_Char := 16#1162F#;
   Modi_Vowel_Sign_Aa                      :
      constant Unicode_Char := 16#11630#;
   Modi_Vowel_Sign_I                       :
      constant Unicode_Char := 16#11631#;
   Modi_Vowel_Sign_Ii                      :
      constant Unicode_Char := 16#11632#;
   Modi_Vowel_Sign_U                       :
      constant Unicode_Char := 16#11633#;
   Modi_Vowel_Sign_Uu                      :
      constant Unicode_Char := 16#11634#;
   Modi_Vowel_Sign_Vocalic_R               :
      constant Unicode_Char := 16#11635#;
   Modi_Vowel_Sign_Vocalic_Rr              :
      constant Unicode_Char := 16#11636#;
   Modi_Vowel_Sign_Vocalic_L               :
      constant Unicode_Char := 16#11637#;
   Modi_Vowel_Sign_Vocalic_Ll              :
      constant Unicode_Char := 16#11638#;
   Modi_Vowel_Sign_E                       :
      constant Unicode_Char := 16#11639#;
   Modi_Vowel_Sign_Ai                      :
      constant Unicode_Char := 16#1163A#;
   Modi_Vowel_Sign_O                       :
      constant Unicode_Char := 16#1163B#;
   Modi_Vowel_Sign_Au                      :
      constant Unicode_Char := 16#1163C#;
   Modi_Sign_Anusvara                      :
      constant Unicode_Char := 16#1163D#;
   Modi_Sign_Visarga                       :
      constant Unicode_Char := 16#1163E#;
   Modi_Sign_Virama                        :
      constant Unicode_Char := 16#1163F#;
   Modi_Sign_Ardhacandra                   :
      constant Unicode_Char := 16#11640#;
   Modi_Danda                              :
      constant Unicode_Char := 16#11641#;
   Modi_Double_Danda                       :
      constant Unicode_Char := 16#11642#;
   Modi_Abbreviation_Sign                  :
      constant Unicode_Char := 16#11643#;
   Modi_Sign_Huva                          :
      constant Unicode_Char := 16#11644#;
   Modi_Digit_Zero                         :
      constant Unicode_Char := 16#11650#;
   Modi_Digit_One                          :
      constant Unicode_Char := 16#11651#;
   Modi_Digit_Two                          :
      constant Unicode_Char := 16#11652#;
   Modi_Digit_Three                        :
      constant Unicode_Char := 16#11653#;
   Modi_Digit_Four                         :
      constant Unicode_Char := 16#11654#;
   Modi_Digit_Five                         :
      constant Unicode_Char := 16#11655#;
   Modi_Digit_Six                          :
      constant Unicode_Char := 16#11656#;
   Modi_Digit_Seven                        :
      constant Unicode_Char := 16#11657#;
   Modi_Digit_Eight                        :
      constant Unicode_Char := 16#11658#;
   Modi_Digit_Nine                         :
      constant Unicode_Char := 16#11659#;
end Unicode.Names.Modi;
