--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Bengali is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Bengali_Anji                            : constant Unicode_Char := 16#0980#;
   Bengali_Sign_Candrabindu                : constant Unicode_Char := 16#0981#;
   Bengali_Sign_Anusvara                   : constant Unicode_Char := 16#0982#;
   Bengali_Sign_Visarga                    : constant Unicode_Char := 16#0983#;
   Bengali_Letter_A                        : constant Unicode_Char := 16#0985#;
   Bengali_Letter_Aa                       : constant Unicode_Char := 16#0986#;
   Bengali_Letter_I                        : constant Unicode_Char := 16#0987#;
   Bengali_Letter_Ii                       : constant Unicode_Char := 16#0988#;
   Bengali_Letter_U                        : constant Unicode_Char := 16#0989#;
   Bengali_Letter_Uu                       : constant Unicode_Char := 16#098A#;
   Bengali_Letter_Vocalic_R                : constant Unicode_Char := 16#098B#;
   Bengali_Letter_Vocalic_L                : constant Unicode_Char := 16#098C#;
   Bengali_Letter_E                        : constant Unicode_Char := 16#098F#;
   Bengali_Letter_Ai                       : constant Unicode_Char := 16#0990#;
   Bengali_Letter_O                        : constant Unicode_Char := 16#0993#;
   Bengali_Letter_Au                       : constant Unicode_Char := 16#0994#;
   Bengali_Letter_Ka                       : constant Unicode_Char := 16#0995#;
   Bengali_Letter_Kha                      : constant Unicode_Char := 16#0996#;
   Bengali_Letter_Ga                       : constant Unicode_Char := 16#0997#;
   Bengali_Letter_Gha                      : constant Unicode_Char := 16#0998#;
   Bengali_Letter_Nga                      : constant Unicode_Char := 16#0999#;
   Bengali_Letter_Ca                       : constant Unicode_Char := 16#099A#;
   Bengali_Letter_Cha                      : constant Unicode_Char := 16#099B#;
   Bengali_Letter_Ja                       : constant Unicode_Char := 16#099C#;
   Bengali_Letter_Jha                      : constant Unicode_Char := 16#099D#;
   Bengali_Letter_Nya                      : constant Unicode_Char := 16#099E#;
   Bengali_Letter_Tta                      : constant Unicode_Char := 16#099F#;
   Bengali_Letter_Ttha                     : constant Unicode_Char := 16#09A0#;
   Bengali_Letter_Dda                      : constant Unicode_Char := 16#09A1#;
   Bengali_Letter_Ddha                     : constant Unicode_Char := 16#09A2#;
   Bengali_Letter_Nna                      : constant Unicode_Char := 16#09A3#;
   Bengali_Letter_Ta                       : constant Unicode_Char := 16#09A4#;
   Bengali_Letter_Tha                      : constant Unicode_Char := 16#09A5#;
   Bengali_Letter_Da                       : constant Unicode_Char := 16#09A6#;
   Bengali_Letter_Dha                      : constant Unicode_Char := 16#09A7#;
   Bengali_Letter_Na                       : constant Unicode_Char := 16#09A8#;
   Bengali_Letter_Pa                       : constant Unicode_Char := 16#09AA#;
   Bengali_Letter_Pha                      : constant Unicode_Char := 16#09AB#;
   Bengali_Letter_Ba                       : constant Unicode_Char := 16#09AC#;
   Bengali_Letter_Bha                      : constant Unicode_Char := 16#09AD#;
   Bengali_Letter_Ma                       : constant Unicode_Char := 16#09AE#;
   Bengali_Letter_Ya                       : constant Unicode_Char := 16#09AF#;
   Bengali_Letter_Ra                       : constant Unicode_Char := 16#09B0#;
   Bengali_Letter_La                       : constant Unicode_Char := 16#09B2#;
   Bengali_Letter_Sha                      : constant Unicode_Char := 16#09B6#;
   Bengali_Letter_Ssa                      : constant Unicode_Char := 16#09B7#;
   Bengali_Letter_Sa                       : constant Unicode_Char := 16#09B8#;
   Bengali_Letter_Ha                       : constant Unicode_Char := 16#09B9#;
   Bengali_Sign_Nukta                      : constant Unicode_Char := 16#09BC#;
   Bengali_Sign_Avagraha                   : constant Unicode_Char := 16#09BD#;
   Bengali_Vowel_Sign_Aa                   : constant Unicode_Char := 16#09BE#;
   Bengali_Vowel_Sign_I                    : constant Unicode_Char := 16#09BF#;
   Bengali_Vowel_Sign_Ii                   : constant Unicode_Char := 16#09C0#;
   Bengali_Vowel_Sign_U                    : constant Unicode_Char := 16#09C1#;
   Bengali_Vowel_Sign_Uu                   : constant Unicode_Char := 16#09C2#;
   Bengali_Vowel_Sign_Vocalic_R            : constant Unicode_Char := 16#09C3#;
   Bengali_Vowel_Sign_Vocalic_Rr           : constant Unicode_Char := 16#09C4#;
   Bengali_Vowel_Sign_E                    : constant Unicode_Char := 16#09C7#;
   Bengali_Vowel_Sign_Ai                   : constant Unicode_Char := 16#09C8#;
   Bengali_Vowel_Sign_O                    : constant Unicode_Char := 16#09CB#;
   Bengali_Vowel_Sign_Au                   : constant Unicode_Char := 16#09CC#;
   Bengali_Sign_Virama                     : constant Unicode_Char := 16#09CD#;
   Bengali_Letter_Khanda_Ta                : constant Unicode_Char := 16#09CE#;
   Bengali_Au_Length_Mark                  : constant Unicode_Char := 16#09D7#;
   Bengali_Letter_Rra                      : constant Unicode_Char := 16#09DC#;
   Bengali_Letter_Rha                      : constant Unicode_Char := 16#09DD#;
   Bengali_Letter_Yya                      : constant Unicode_Char := 16#09DF#;
   Bengali_Letter_Vocalic_Rr               : constant Unicode_Char := 16#09E0#;
   Bengali_Letter_Vocalic_Ll               : constant Unicode_Char := 16#09E1#;
   Bengali_Vowel_Sign_Vocalic_L            : constant Unicode_Char := 16#09E2#;
   Bengali_Vowel_Sign_Vocalic_Ll           : constant Unicode_Char := 16#09E3#;
   Bengali_Digit_Zero                      : constant Unicode_Char := 16#09E6#;
   Bengali_Digit_One                       : constant Unicode_Char := 16#09E7#;
   Bengali_Digit_Two                       : constant Unicode_Char := 16#09E8#;
   Bengali_Digit_Three                     : constant Unicode_Char := 16#09E9#;
   Bengali_Digit_Four                      : constant Unicode_Char := 16#09EA#;
   Bengali_Digit_Five                      : constant Unicode_Char := 16#09EB#;
   Bengali_Digit_Six                       : constant Unicode_Char := 16#09EC#;
   Bengali_Digit_Seven                     : constant Unicode_Char := 16#09ED#;
   Bengali_Digit_Eight                     : constant Unicode_Char := 16#09EE#;
   Bengali_Digit_Nine                      : constant Unicode_Char := 16#09EF#;
   Bengali_Letter_Ra_With_Middle_Diagonal  : constant Unicode_Char := 16#09F0#;
   Bengali_Letter_Ra_With_Lower_Diagonal   : constant Unicode_Char := 16#09F1#;
   Bengali_Rupee_Mark                      : constant Unicode_Char := 16#09F2#;
   Bengali_Rupee_Sign                      : constant Unicode_Char := 16#09F3#;
   Bengali_Currency_Numerator_One          : constant Unicode_Char := 16#09F4#;
   Bengali_Currency_Numerator_Two          : constant Unicode_Char := 16#09F5#;
   Bengali_Currency_Numerator_Three        : constant Unicode_Char := 16#09F6#;
   Bengali_Currency_Numerator_Four         : constant Unicode_Char := 16#09F7#;
   Bengali_Currency_Numerator_One_Less_Than_The_Denominator :
      constant Unicode_Char := 16#09F8#;
   Bengali_Currency_Denominator_Sixteen    : constant Unicode_Char := 16#09F9#;
   Bengali_Isshar                          : constant Unicode_Char := 16#09FA#;
   Bengali_Ganda_Mark                      : constant Unicode_Char := 16#09FB#;
end Unicode.Names.Bengali;
