--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Thai is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Thai_Character_Ko_Kai                   : constant Unicode_Char := 16#0E01#;
   Thai_Character_Kho_Khai                 : constant Unicode_Char := 16#0E02#;
   Thai_Character_Kho_Khuat                : constant Unicode_Char := 16#0E03#;
   Thai_Character_Kho_Khwai                : constant Unicode_Char := 16#0E04#;
   Thai_Character_Kho_Khon                 : constant Unicode_Char := 16#0E05#;
   Thai_Character_Kho_Rakhang              : constant Unicode_Char := 16#0E06#;
   Thai_Character_Ngo_Ngu                  : constant Unicode_Char := 16#0E07#;
   Thai_Character_Cho_Chan                 : constant Unicode_Char := 16#0E08#;
   Thai_Character_Cho_Ching                : constant Unicode_Char := 16#0E09#;
   Thai_Character_Cho_Chang                : constant Unicode_Char := 16#0E0A#;
   Thai_Character_So_So                    : constant Unicode_Char := 16#0E0B#;
   Thai_Character_Cho_Choe                 : constant Unicode_Char := 16#0E0C#;
   Thai_Character_Yo_Ying                  : constant Unicode_Char := 16#0E0D#;
   Thai_Character_Do_Chada                 : constant Unicode_Char := 16#0E0E#;
   Thai_Character_To_Patak                 : constant Unicode_Char := 16#0E0F#;
   Thai_Character_Tho_Than                 : constant Unicode_Char := 16#0E10#;
   Thai_Character_Tho_Nangmontho           : constant Unicode_Char := 16#0E11#;
   Thai_Character_Tho_Phuthao              : constant Unicode_Char := 16#0E12#;
   Thai_Character_No_Nen                   : constant Unicode_Char := 16#0E13#;
   Thai_Character_Do_Dek                   : constant Unicode_Char := 16#0E14#;
   Thai_Character_To_Tao                   : constant Unicode_Char := 16#0E15#;
   Thai_Character_Tho_Thung                : constant Unicode_Char := 16#0E16#;
   Thai_Character_Tho_Thahan               : constant Unicode_Char := 16#0E17#;
   Thai_Character_Tho_Thong                : constant Unicode_Char := 16#0E18#;
   Thai_Character_No_Nu                    : constant Unicode_Char := 16#0E19#;
   Thai_Character_Bo_Baimai                : constant Unicode_Char := 16#0E1A#;
   Thai_Character_Po_Pla                   : constant Unicode_Char := 16#0E1B#;
   Thai_Character_Pho_Phung                : constant Unicode_Char := 16#0E1C#;
   Thai_Character_Fo_Fa                    : constant Unicode_Char := 16#0E1D#;
   Thai_Character_Pho_Phan                 : constant Unicode_Char := 16#0E1E#;
   Thai_Character_Fo_Fan                   : constant Unicode_Char := 16#0E1F#;
   Thai_Character_Pho_Samphao              : constant Unicode_Char := 16#0E20#;
   Thai_Character_Mo_Ma                    : constant Unicode_Char := 16#0E21#;
   Thai_Character_Yo_Yak                   : constant Unicode_Char := 16#0E22#;
   Thai_Character_Ro_Rua                   : constant Unicode_Char := 16#0E23#;
   Thai_Character_Ru                       : constant Unicode_Char := 16#0E24#;
   Thai_Character_Lo_Ling                  : constant Unicode_Char := 16#0E25#;
   Thai_Character_Lu                       : constant Unicode_Char := 16#0E26#;
   Thai_Character_Wo_Waen                  : constant Unicode_Char := 16#0E27#;
   Thai_Character_So_Sala                  : constant Unicode_Char := 16#0E28#;
   Thai_Character_So_Rusi                  : constant Unicode_Char := 16#0E29#;
   Thai_Character_So_Sua                   : constant Unicode_Char := 16#0E2A#;
   Thai_Character_Ho_Hip                   : constant Unicode_Char := 16#0E2B#;
   Thai_Character_Lo_Chula                 : constant Unicode_Char := 16#0E2C#;
   Thai_Character_O_Ang                    : constant Unicode_Char := 16#0E2D#;
   Thai_Character_Ho_Nokhuk                : constant Unicode_Char := 16#0E2E#;
   Thai_Character_Paiyannoi                : constant Unicode_Char := 16#0E2F#;
   Thai_Character_Sara_A                   : constant Unicode_Char := 16#0E30#;
   Thai_Character_Mai_Han_Akat             : constant Unicode_Char := 16#0E31#;
   Thai_Character_Sara_Aa                  : constant Unicode_Char := 16#0E32#;
   Thai_Character_Sara_Am                  : constant Unicode_Char := 16#0E33#;
   Thai_Character_Sara_I                   : constant Unicode_Char := 16#0E34#;
   Thai_Character_Sara_Ii                  : constant Unicode_Char := 16#0E35#;
   Thai_Character_Sara_Ue                  : constant Unicode_Char := 16#0E36#;
   Thai_Character_Sara_Uee                 : constant Unicode_Char := 16#0E37#;
   Thai_Character_Sara_U                   : constant Unicode_Char := 16#0E38#;
   Thai_Character_Sara_Uu                  : constant Unicode_Char := 16#0E39#;
   Thai_Character_Phinthu                  : constant Unicode_Char := 16#0E3A#;
   Thai_Currency_Symbol_Baht               : constant Unicode_Char := 16#0E3F#;
   Thai_Character_Sara_E                   : constant Unicode_Char := 16#0E40#;
   Thai_Character_Sara_Ae                  : constant Unicode_Char := 16#0E41#;
   Thai_Character_Sara_O                   : constant Unicode_Char := 16#0E42#;
   Thai_Character_Sara_Ai_Maimuan          : constant Unicode_Char := 16#0E43#;
   Thai_Character_Sara_Ai_Maimalai         : constant Unicode_Char := 16#0E44#;
   Thai_Character_Lakkhangyao              : constant Unicode_Char := 16#0E45#;
   Thai_Character_Maiyamok                 : constant Unicode_Char := 16#0E46#;
   Thai_Character_Maitaikhu                : constant Unicode_Char := 16#0E47#;
   Thai_Character_Mai_Ek                   : constant Unicode_Char := 16#0E48#;
   Thai_Character_Mai_Tho                  : constant Unicode_Char := 16#0E49#;
   Thai_Character_Mai_Tri                  : constant Unicode_Char := 16#0E4A#;
   Thai_Character_Mai_Chattawa             : constant Unicode_Char := 16#0E4B#;
   Thai_Character_Thanthakhat              : constant Unicode_Char := 16#0E4C#;
   Thai_Character_Nikhahit                 : constant Unicode_Char := 16#0E4D#;
   Thai_Character_Yamakkan                 : constant Unicode_Char := 16#0E4E#;
   Thai_Character_Fongman                  : constant Unicode_Char := 16#0E4F#;
   Thai_Digit_Zero                         : constant Unicode_Char := 16#0E50#;
   Thai_Digit_One                          : constant Unicode_Char := 16#0E51#;
   Thai_Digit_Two                          : constant Unicode_Char := 16#0E52#;
   Thai_Digit_Three                        : constant Unicode_Char := 16#0E53#;
   Thai_Digit_Four                         : constant Unicode_Char := 16#0E54#;
   Thai_Digit_Five                         : constant Unicode_Char := 16#0E55#;
   Thai_Digit_Six                          : constant Unicode_Char := 16#0E56#;
   Thai_Digit_Seven                        : constant Unicode_Char := 16#0E57#;
   Thai_Digit_Eight                        : constant Unicode_Char := 16#0E58#;
   Thai_Digit_Nine                         : constant Unicode_Char := 16#0E59#;
   Thai_Character_Angkhankhu               : constant Unicode_Char := 16#0E5A#;
   Thai_Character_Khomut                   : constant Unicode_Char := 16#0E5B#;
end Unicode.Names.Thai;
