--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Old_Permic is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Old_Permic_Letter_An                    :
      constant Unicode_Char := 16#10350#;
   Old_Permic_Letter_Bur                   :
      constant Unicode_Char := 16#10351#;
   Old_Permic_Letter_Gai                   :
      constant Unicode_Char := 16#10352#;
   Old_Permic_Letter_Doi                   :
      constant Unicode_Char := 16#10353#;
   Old_Permic_Letter_E                     :
      constant Unicode_Char := 16#10354#;
   Old_Permic_Letter_Zhoi                  :
      constant Unicode_Char := 16#10355#;
   Old_Permic_Letter_Dzhoi                 :
      constant Unicode_Char := 16#10356#;
   Old_Permic_Letter_Zata                  :
      constant Unicode_Char := 16#10357#;
   Old_Permic_Letter_Dzita                 :
      constant Unicode_Char := 16#10358#;
   Old_Permic_Letter_I                     :
      constant Unicode_Char := 16#10359#;
   Old_Permic_Letter_Koke                  :
      constant Unicode_Char := 16#1035A#;
   Old_Permic_Letter_Lei                   :
      constant Unicode_Char := 16#1035B#;
   Old_Permic_Letter_Menoe                 :
      constant Unicode_Char := 16#1035C#;
   Old_Permic_Letter_Nenoe                 :
      constant Unicode_Char := 16#1035D#;
   Old_Permic_Letter_Vooi                  :
      constant Unicode_Char := 16#1035E#;
   Old_Permic_Letter_Peei                  :
      constant Unicode_Char := 16#1035F#;
   Old_Permic_Letter_Rei                   :
      constant Unicode_Char := 16#10360#;
   Old_Permic_Letter_Sii                   :
      constant Unicode_Char := 16#10361#;
   Old_Permic_Letter_Tai                   :
      constant Unicode_Char := 16#10362#;
   Old_Permic_Letter_U                     :
      constant Unicode_Char := 16#10363#;
   Old_Permic_Letter_Chery                 :
      constant Unicode_Char := 16#10364#;
   Old_Permic_Letter_Shooi                 :
      constant Unicode_Char := 16#10365#;
   Old_Permic_Letter_Shchooi               :
      constant Unicode_Char := 16#10366#;
   Old_Permic_Letter_Yry                   :
      constant Unicode_Char := 16#10367#;
   Old_Permic_Letter_Yeru                  :
      constant Unicode_Char := 16#10368#;
   Old_Permic_Letter_O                     :
      constant Unicode_Char := 16#10369#;
   Old_Permic_Letter_Oo                    :
      constant Unicode_Char := 16#1036A#;
   Old_Permic_Letter_Ef                    :
      constant Unicode_Char := 16#1036B#;
   Old_Permic_Letter_Ha                    :
      constant Unicode_Char := 16#1036C#;
   Old_Permic_Letter_Tsiu                  :
      constant Unicode_Char := 16#1036D#;
   Old_Permic_Letter_Ver                   :
      constant Unicode_Char := 16#1036E#;
   Old_Permic_Letter_Yer                   :
      constant Unicode_Char := 16#1036F#;
   Old_Permic_Letter_Yeri                  :
      constant Unicode_Char := 16#10370#;
   Old_Permic_Letter_Yat                   :
      constant Unicode_Char := 16#10371#;
   Old_Permic_Letter_Ie                    :
      constant Unicode_Char := 16#10372#;
   Old_Permic_Letter_Yu                    :
      constant Unicode_Char := 16#10373#;
   Old_Permic_Letter_Ya                    :
      constant Unicode_Char := 16#10374#;
   Old_Permic_Letter_Ia                    :
      constant Unicode_Char := 16#10375#;
   Combining_Old_Permic_Letter_An          :
      constant Unicode_Char := 16#10376#;
   Combining_Old_Permic_Letter_Doi         :
      constant Unicode_Char := 16#10377#;
   Combining_Old_Permic_Letter_Zata        :
      constant Unicode_Char := 16#10378#;
   Combining_Old_Permic_Letter_Nenoe       :
      constant Unicode_Char := 16#10379#;
   Combining_Old_Permic_Letter_Sii         :
      constant Unicode_Char := 16#1037A#;
end Unicode.Names.Old_Permic;
