--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Misc_Symbols_And_Arrows is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   North_East_White_Arrow                  : constant Unicode_Char := 16#2B00#;
   North_West_White_Arrow                  : constant Unicode_Char := 16#2B01#;
   South_East_White_Arrow                  : constant Unicode_Char := 16#2B02#;
   South_West_White_Arrow                  : constant Unicode_Char := 16#2B03#;
   Left_Right_White_Arrow                  : constant Unicode_Char := 16#2B04#;
   Leftwards_Black_Arrow                   : constant Unicode_Char := 16#2B05#;
   Upwards_Black_Arrow                     : constant Unicode_Char := 16#2B06#;
   Downwards_Black_Arrow                   : constant Unicode_Char := 16#2B07#;
   North_East_Black_Arrow                  : constant Unicode_Char := 16#2B08#;
   North_West_Black_Arrow                  : constant Unicode_Char := 16#2B09#;
   South_East_Black_Arrow                  : constant Unicode_Char := 16#2B0A#;
   South_West_Black_Arrow                  : constant Unicode_Char := 16#2B0B#;
   Left_Right_Black_Arrow                  : constant Unicode_Char := 16#2B0C#;
   Up_Down_Black_Arrow                     : constant Unicode_Char := 16#2B0D#;
   Rightwards_Arrow_With_Tip_Downwards     : constant Unicode_Char := 16#2B0E#;
   Rightwards_Arrow_With_Tip_Upwards       : constant Unicode_Char := 16#2B0F#;
   Leftwards_Arrow_With_Tip_Downwards      : constant Unicode_Char := 16#2B10#;
   Leftwards_Arrow_With_Tip_Upwards        : constant Unicode_Char := 16#2B11#;
   Square_With_Top_Half_Black              : constant Unicode_Char := 16#2B12#;
   Square_With_Bottom_Half_Black           : constant Unicode_Char := 16#2B13#;
   Square_With_Upper_Right_Diagonal_Half_Black :
      constant Unicode_Char := 16#2B14#;
   Square_With_Lower_Left_Diagonal_Half_Black :
      constant Unicode_Char := 16#2B15#;
   Diamond_With_Left_Half_Black            : constant Unicode_Char := 16#2B16#;
   Diamond_With_Right_Half_Black           : constant Unicode_Char := 16#2B17#;
   Diamond_With_Top_Half_Black             : constant Unicode_Char := 16#2B18#;
   Diamond_With_Bottom_Half_Black          : constant Unicode_Char := 16#2B19#;
   Dotted_Square                           : constant Unicode_Char := 16#2B1A#;
   Black_Large_Square                      : constant Unicode_Char := 16#2B1B#;
   White_Large_Square                      : constant Unicode_Char := 16#2B1C#;
   Black_Very_Small_Square                 : constant Unicode_Char := 16#2B1D#;
   White_Very_Small_Square                 : constant Unicode_Char := 16#2B1E#;
   Black_Pentagon                          : constant Unicode_Char := 16#2B1F#;
   White_Pentagon                          : constant Unicode_Char := 16#2B20#;
   White_Hexagon                           : constant Unicode_Char := 16#2B21#;
   Black_Hexagon                           : constant Unicode_Char := 16#2B22#;
   Horizontal_Black_Hexagon                : constant Unicode_Char := 16#2B23#;
   Black_Large_Circle                      : constant Unicode_Char := 16#2B24#;
   Black_Medium_Diamond                    : constant Unicode_Char := 16#2B25#;
   White_Medium_Diamond                    : constant Unicode_Char := 16#2B26#;
   Black_Medium_Lozenge                    : constant Unicode_Char := 16#2B27#;
   White_Medium_Lozenge                    : constant Unicode_Char := 16#2B28#;
   Black_Small_Diamond                     : constant Unicode_Char := 16#2B29#;
   Black_Small_Lozenge                     : constant Unicode_Char := 16#2B2A#;
   White_Small_Lozenge                     : constant Unicode_Char := 16#2B2B#;
   Black_Horizontal_Ellipse                : constant Unicode_Char := 16#2B2C#;
   White_Horizontal_Ellipse                : constant Unicode_Char := 16#2B2D#;
   Black_Vertical_Ellipse                  : constant Unicode_Char := 16#2B2E#;
   White_Vertical_Ellipse                  : constant Unicode_Char := 16#2B2F#;
   Left_Arrow_With_Small_Circle            : constant Unicode_Char := 16#2B30#;
   Three_Leftwards_Arrows                  : constant Unicode_Char := 16#2B31#;
   Left_Arrow_With_Circled_Plus            : constant Unicode_Char := 16#2B32#;
   Long_Leftwards_Squiggle_Arrow           : constant Unicode_Char := 16#2B33#;
   Leftwards_Two_Headed_Arrow_With_Vertical_Stroke :
      constant Unicode_Char := 16#2B34#;
   Leftwards_Two_Headed_Arrow_With_Double_Vertical_Stroke :
      constant Unicode_Char := 16#2B35#;
   Leftwards_Two_Headed_Arrow_From_Bar     : constant Unicode_Char := 16#2B36#;
   Leftwards_Two_Headed_Triple_Dash_Arrow  : constant Unicode_Char := 16#2B37#;
   Leftwards_Arrow_With_Dotted_Stem        : constant Unicode_Char := 16#2B38#;
   Leftwards_Arrow_With_Tail_With_Vertical_Stroke :
      constant Unicode_Char := 16#2B39#;
   Leftwards_Arrow_With_Tail_With_Double_Vertical_Stroke :
      constant Unicode_Char := 16#2B3A#;
   Leftwards_Two_Headed_Arrow_With_Tail    : constant Unicode_Char := 16#2B3B#;
   Leftwards_Two_Headed_Arrow_With_Tail_With_Vertical_Stroke :
      constant Unicode_Char := 16#2B3C#;
   Leftwards_Two_Headed_Arrow_With_Tail_With_Double_Vertical_Stroke :
      constant Unicode_Char := 16#2B3D#;
   Leftwards_Arrow_Through_X               : constant Unicode_Char := 16#2B3E#;
   Wave_Arrow_Pointing_Directly_Left       : constant Unicode_Char := 16#2B3F#;
   Equals_Sign_Above_Leftwards_Arrow       : constant Unicode_Char := 16#2B40#;
   Reverse_Tilde_Operator_Above_Leftwards_Arrow :
      constant Unicode_Char := 16#2B41#;
   Leftwards_Arrow_Above_Reverse_Almost_Equal_To :
      constant Unicode_Char := 16#2B42#;
   Rightwards_Arrow_Through_Greater_Than   : constant Unicode_Char := 16#2B43#;
   Rightwards_Arrow_Through_Superset       : constant Unicode_Char := 16#2B44#;
   Leftwards_Quadruple_Arrow               : constant Unicode_Char := 16#2B45#;
   Rightwards_Quadruple_Arrow              : constant Unicode_Char := 16#2B46#;
   Reverse_Tilde_Operator_Above_Rightwards_Arrow :
      constant Unicode_Char := 16#2B47#;
   Rightwards_Arrow_Above_Reverse_Almost_Equal_To :
      constant Unicode_Char := 16#2B48#;
   Tilde_Operator_Above_Leftwards_Arrow    : constant Unicode_Char := 16#2B49#;
   Leftwards_Arrow_Above_Almost_Equal_To   : constant Unicode_Char := 16#2B4A#;
   Leftwards_Arrow_Above_Reverse_Tilde_Operator :
      constant Unicode_Char := 16#2B4B#;
   Rightwards_Arrow_Above_Reverse_Tilde_Operator :
      constant Unicode_Char := 16#2B4C#;
   Downwards_Triangle_Headed_Zigzag_Arrow  : constant Unicode_Char := 16#2B4D#;
   Short_Slanted_North_Arrow               : constant Unicode_Char := 16#2B4E#;
   Short_Backslanted_South_Arrow           : constant Unicode_Char := 16#2B4F#;
   White_Medium_Star                       : constant Unicode_Char := 16#2B50#;
   Black_Small_Star                        : constant Unicode_Char := 16#2B51#;
   White_Small_Star                        : constant Unicode_Char := 16#2B52#;
   Black_Right_Pointing_Pentagon           : constant Unicode_Char := 16#2B53#;
   White_Right_Pointing_Pentagon           : constant Unicode_Char := 16#2B54#;
   Heavy_Large_Circle                      : constant Unicode_Char := 16#2B55#;
   Heavy_Oval_With_Oval_Inside             : constant Unicode_Char := 16#2B56#;
   Heavy_Circle_With_Circle_Inside         : constant Unicode_Char := 16#2B57#;
   Heavy_Circle                            : constant Unicode_Char := 16#2B58#;
   Heavy_Circled_Saltire                   : constant Unicode_Char := 16#2B59#;
   Slanted_North_Arrow_With_Hooked_Head    : constant Unicode_Char := 16#2B5A#;
   Backslanted_South_Arrow_With_Hooked_Tail :
      constant Unicode_Char := 16#2B5B#;
   Slanted_North_Arrow_With_Horizontal_Tail :
      constant Unicode_Char := 16#2B5C#;
   Backslanted_South_Arrow_With_Horizontal_Tail :
      constant Unicode_Char := 16#2B5D#;
   Bent_Arrow_Pointing_Downwards_Then_North_East :
      constant Unicode_Char := 16#2B5E#;
   Short_Bent_Arrow_Pointing_Downwards_Then_North_East :
      constant Unicode_Char := 16#2B5F#;
   Leftwards_Triangle_Headed_Arrow         : constant Unicode_Char := 16#2B60#;
   Upwards_Triangle_Headed_Arrow           : constant Unicode_Char := 16#2B61#;
   Rightwards_Triangle_Headed_Arrow        : constant Unicode_Char := 16#2B62#;
   Downwards_Triangle_Headed_Arrow         : constant Unicode_Char := 16#2B63#;
   Left_Right_Triangle_Headed_Arrow        : constant Unicode_Char := 16#2B64#;
   Up_Down_Triangle_Headed_Arrow           : constant Unicode_Char := 16#2B65#;
   North_West_Triangle_Headed_Arrow        : constant Unicode_Char := 16#2B66#;
   North_East_Triangle_Headed_Arrow        : constant Unicode_Char := 16#2B67#;
   South_East_Triangle_Headed_Arrow        : constant Unicode_Char := 16#2B68#;
   South_West_Triangle_Headed_Arrow        : constant Unicode_Char := 16#2B69#;
   Leftwards_Triangle_Headed_Dashed_Arrow  : constant Unicode_Char := 16#2B6A#;
   Upwards_Triangle_Headed_Dashed_Arrow    : constant Unicode_Char := 16#2B6B#;
   Rightwards_Triangle_Headed_Dashed_Arrow : constant Unicode_Char := 16#2B6C#;
   Downwards_Triangle_Headed_Dashed_Arrow  : constant Unicode_Char := 16#2B6D#;
   Clockwise_Triangle_Headed_Open_Circle_Arrow :
      constant Unicode_Char := 16#2B6E#;
   Anticlockwise_Triangle_Headed_Open_Circle_Arrow :
      constant Unicode_Char := 16#2B6F#;
   Leftwards_Triangle_Headed_Arrow_To_Bar  : constant Unicode_Char := 16#2B70#;
   Upwards_Triangle_Headed_Arrow_To_Bar    : constant Unicode_Char := 16#2B71#;
   Rightwards_Triangle_Headed_Arrow_To_Bar : constant Unicode_Char := 16#2B72#;
   Downwards_Triangle_Headed_Arrow_To_Bar  : constant Unicode_Char := 16#2B73#;
   North_West_Triangle_Headed_Arrow_To_Bar : constant Unicode_Char := 16#2B76#;
   North_East_Triangle_Headed_Arrow_To_Bar : constant Unicode_Char := 16#2B77#;
   South_East_Triangle_Headed_Arrow_To_Bar : constant Unicode_Char := 16#2B78#;
   South_West_Triangle_Headed_Arrow_To_Bar : constant Unicode_Char := 16#2B79#;
   Leftwards_Triangle_Headed_Arrow_With_Double_Horizontal_Stroke :
      constant Unicode_Char := 16#2B7A#;
   Leftwards_Triangle_Headed_Arrow_With_Double_Vertical_Stroke :
      Unicode_Char renames Leftwards_Triangle_Headed_Arrow_With_Double_Horizontal_Stroke;
   Upwards_Triangle_Headed_Arrow_With_Double_Horizontal_Stroke :
      constant Unicode_Char := 16#2B7B#;
   Rightwards_Triangle_Headed_Arrow_With_Double_Horizontal_Stroke :
      constant Unicode_Char := 16#2B7C#;
   Rightwards_Triangle_Headed_Arrow_With_Double_Vertical_Stroke :
      Unicode_Char renames Rightwards_Triangle_Headed_Arrow_With_Double_Horizontal_Stroke;
   Downwards_Triangle_Headed_Arrow_With_Double_Horizontal_Stroke :
      constant Unicode_Char := 16#2B7D#;
   Horizontal_Tab_Key                      : constant Unicode_Char := 16#2B7E#;
   Vertical_Tab_Key                        : constant Unicode_Char := 16#2B7F#;
   Leftwards_Triangle_Headed_Arrow_Over_Rightwards_Triangle_Headed_Arrow :
      constant Unicode_Char := 16#2B80#;
   Upwards_Triangle_Headed_Arrow_Leftwards_Of_Downwards_Triangle_Headed_Arrow :
      constant Unicode_Char := 16#2B81#;
   Rightwards_Triangle_Headed_Arrow_Over_Leftwards_Triangle_Headed_Arrow :
      constant Unicode_Char := 16#2B82#;
   Downwards_Triangle_Headed_Arrow_Leftwards_Of_Upwards_Triangle_Headed_Arrow :
      constant Unicode_Char := 16#2B83#;
   Leftwards_Triangle_Headed_Paired_Arrows : constant Unicode_Char := 16#2B84#;
   Upwards_Triangle_Headed_Paired_Arrows   : constant Unicode_Char := 16#2B85#;
   Rightwards_Triangle_Headed_Paired_Arrows :
      constant Unicode_Char := 16#2B86#;
   Downwards_Triangle_Headed_Paired_Arrows : constant Unicode_Char := 16#2B87#;
   Leftwards_Black_Circled_White_Arrow     : constant Unicode_Char := 16#2B88#;
   Upwards_Black_Circled_White_Arrow       : constant Unicode_Char := 16#2B89#;
   Rightwards_Black_Circled_White_Arrow    : constant Unicode_Char := 16#2B8A#;
   Downwards_Black_Circled_White_Arrow     : constant Unicode_Char := 16#2B8B#;
   Anticlockwise_Triangle_Headed_Right_U_Shaped_Arrow :
      constant Unicode_Char := 16#2B8C#;
   Anticlockwise_Triangle_Headed_Bottom_U_Shaped_Arrow :
      constant Unicode_Char := 16#2B8D#;
   Anticlockwise_Triangle_Headed_Left_U_Shaped_Arrow :
      constant Unicode_Char := 16#2B8E#;
   Anticlockwise_Triangle_Headed_Top_U_Shaped_Arrow :
      constant Unicode_Char := 16#2B8F#;
   Return_Left                             : constant Unicode_Char := 16#2B90#;
   Return_Right                            : constant Unicode_Char := 16#2B91#;
   Newline_Left                            : constant Unicode_Char := 16#2B92#;
   Newline_Right                           : constant Unicode_Char := 16#2B93#;
   Four_Corner_Arrows_Circling_Anticlockwise :
      constant Unicode_Char := 16#2B94#;
   Rightwards_Black_Arrow                  : constant Unicode_Char := 16#2B95#;
   Three_D_Top_Lighted_Leftwards_Equilateral_Arrowhead :
      constant Unicode_Char := 16#2B98#;
   Three_D_Right_Lighted_Upwards_Equilateral_Arrowhead :
      constant Unicode_Char := 16#2B99#;
   Three_D_Top_Lighted_Rightwards_Equilateral_Arrowhead :
      constant Unicode_Char := 16#2B9A#;
   Three_D_Left_Lighted_Downwards_Equilateral_Arrowhead :
      constant Unicode_Char := 16#2B9B#;
   Black_Leftwards_Equilateral_Arrowhead   : constant Unicode_Char := 16#2B9C#;
   Black_Upwards_Equilateral_Arrowhead     : constant Unicode_Char := 16#2B9D#;
   Black_Rightwards_Equilateral_Arrowhead  : constant Unicode_Char := 16#2B9E#;
   Black_Downwards_Equilateral_Arrowhead   : constant Unicode_Char := 16#2B9F#;
   Downwards_Triangle_Headed_Arrow_With_Long_Tip_Leftwards :
      constant Unicode_Char := 16#2BA0#;
   Downwards_Triangle_Headed_Arrow_With_Long_Tip_Rightwards :
      constant Unicode_Char := 16#2BA1#;
   Upwards_Triangle_Headed_Arrow_With_Long_Tip_Leftwards :
      constant Unicode_Char := 16#2BA2#;
   Upwards_Triangle_Headed_Arrow_With_Long_Tip_Rightwards :
      constant Unicode_Char := 16#2BA3#;
   Leftwards_Triangle_Headed_Arrow_With_Long_Tip_Upwards :
      constant Unicode_Char := 16#2BA4#;
   Rightwards_Triangle_Headed_Arrow_With_Long_Tip_Upwards :
      constant Unicode_Char := 16#2BA5#;
   Leftwards_Triangle_Headed_Arrow_With_Long_Tip_Downwards :
      constant Unicode_Char := 16#2BA6#;
   Rightwards_Triangle_Headed_Arrow_With_Long_Tip_Downwards :
      constant Unicode_Char := 16#2BA7#;
   Black_Curved_Downwards_And_Leftwards_Arrow :
      constant Unicode_Char := 16#2BA8#;
   Black_Curved_Downwards_And_Rightwards_Arrow :
      constant Unicode_Char := 16#2BA9#;
   Black_Curved_Upwards_And_Leftwards_Arrow :
      constant Unicode_Char := 16#2BAA#;
   Black_Curved_Upwards_And_Rightwards_Arrow :
      constant Unicode_Char := 16#2BAB#;
   Black_Curved_Leftwards_And_Upwards_Arrow :
      constant Unicode_Char := 16#2BAC#;
   Black_Curved_Rightwards_And_Upwards_Arrow :
      constant Unicode_Char := 16#2BAD#;
   Black_Curved_Leftwards_And_Downwards_Arrow :
      constant Unicode_Char := 16#2BAE#;
   Black_Curved_Rightwards_And_Downwards_Arrow :
      constant Unicode_Char := 16#2BAF#;
   Ribbon_Arrow_Down_Left                  : constant Unicode_Char := 16#2BB0#;
   Ribbon_Arrow_Down_Right                 : constant Unicode_Char := 16#2BB1#;
   Ribbon_Arrow_Up_Left                    : constant Unicode_Char := 16#2BB2#;
   Ribbon_Arrow_Up_Right                   : constant Unicode_Char := 16#2BB3#;
   Ribbon_Arrow_Left_Up                    : constant Unicode_Char := 16#2BB4#;
   Ribbon_Arrow_Right_Up                   : constant Unicode_Char := 16#2BB5#;
   Ribbon_Arrow_Left_Down                  : constant Unicode_Char := 16#2BB6#;
   Ribbon_Arrow_Right_Down                 : constant Unicode_Char := 16#2BB7#;
   Upwards_White_Arrow_From_Bar_With_Horizontal_Bar :
      constant Unicode_Char := 16#2BB8#;
   Up_Arrowhead_In_A_Rectangle_Box         : constant Unicode_Char := 16#2BB9#;
   Ballot_Box_With_Light_X                 : constant Unicode_Char := 16#2BBD#;
   Circled_X                               : constant Unicode_Char := 16#2BBE#;
   Circled_Bold_X                          : constant Unicode_Char := 16#2BBF#;
   Black_Square_Centred                    : constant Unicode_Char := 16#2BC0#;
   Black_Diamond_Centred                   : constant Unicode_Char := 16#2BC1#;
   Turned_Black_Pentagon                   : constant Unicode_Char := 16#2BC2#;
   Horizontal_Black_Octagon                : constant Unicode_Char := 16#2BC3#;
   Black_Octagon                           : constant Unicode_Char := 16#2BC4#;
   Black_Medium_Up_Pointing_Triangle_Centred :
      constant Unicode_Char := 16#2BC5#;
   Black_Medium_Down_Pointing_Triangle_Centred :
      constant Unicode_Char := 16#2BC6#;
   Black_Medium_Left_Pointing_Triangle_Centred :
      constant Unicode_Char := 16#2BC7#;
   Black_Medium_Right_Pointing_Triangle_Centred :
      constant Unicode_Char := 16#2BC8#;
   Top_Half_Black_Circle                   : constant Unicode_Char := 16#2BCA#;
   Bottom_Half_Black_Circle                : constant Unicode_Char := 16#2BCB#;
   Light_Four_Pointed_Black_Cusp           : constant Unicode_Char := 16#2BCC#;
   Rotated_Light_Four_Pointed_Black_Cusp   : constant Unicode_Char := 16#2BCD#;
   White_Four_Pointed_Cusp                 : constant Unicode_Char := 16#2BCE#;
   Rotated_White_Four_Pointed_Cusp         : constant Unicode_Char := 16#2BCF#;
   Square_Position_Indicator               : constant Unicode_Char := 16#2BD0#;
   Uncertainty_Sign                        : constant Unicode_Char := 16#2BD1#;
   Leftwards_Two_Headed_Arrow_With_Triangle_Arrowheads :
      constant Unicode_Char := 16#2BEC#;
   Upwards_Two_Headed_Arrow_With_Triangle_Arrowheads :
      constant Unicode_Char := 16#2BED#;
   Rightwards_Two_Headed_Arrow_With_Triangle_Arrowheads :
      constant Unicode_Char := 16#2BEE#;
   Downwards_Two_Headed_Arrow_With_Triangle_Arrowheads :
      constant Unicode_Char := 16#2BEF#;
end Unicode.Names.Misc_Symbols_And_Arrows;
