--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Ancient_Greek_Music is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Greek_Vocal_Notation_Symbol_1           :
      constant Unicode_Char := 16#1D200#;
   Greek_Vocal_Notation_Symbol_2           :
      constant Unicode_Char := 16#1D201#;
   Greek_Vocal_Notation_Symbol_3           :
      constant Unicode_Char := 16#1D202#;
   Greek_Vocal_Notation_Symbol_4           :
      constant Unicode_Char := 16#1D203#;
   Greek_Vocal_Notation_Symbol_5           :
      constant Unicode_Char := 16#1D204#;
   Greek_Vocal_Notation_Symbol_6           :
      constant Unicode_Char := 16#1D205#;
   Greek_Vocal_Notation_Symbol_7           :
      constant Unicode_Char := 16#1D206#;
   Greek_Vocal_Notation_Symbol_8           :
      constant Unicode_Char := 16#1D207#;
   Greek_Vocal_Notation_Symbol_9           :
      constant Unicode_Char := 16#1D208#;
   Greek_Vocal_Notation_Symbol_10          :
      constant Unicode_Char := 16#1D209#;
   Greek_Vocal_Notation_Symbol_11          :
      constant Unicode_Char := 16#1D20A#;
   Greek_Vocal_Notation_Symbol_12          :
      constant Unicode_Char := 16#1D20B#;
   Greek_Vocal_Notation_Symbol_13          :
      constant Unicode_Char := 16#1D20C#;
   Greek_Vocal_Notation_Symbol_14          :
      constant Unicode_Char := 16#1D20D#;
   Greek_Vocal_Notation_Symbol_15          :
      constant Unicode_Char := 16#1D20E#;
   Greek_Vocal_Notation_Symbol_16          :
      constant Unicode_Char := 16#1D20F#;
   Greek_Vocal_Notation_Symbol_17          :
      constant Unicode_Char := 16#1D210#;
   Greek_Vocal_Notation_Symbol_18          :
      constant Unicode_Char := 16#1D211#;
   Greek_Vocal_Notation_Symbol_19          :
      constant Unicode_Char := 16#1D212#;
   Greek_Vocal_Notation_Symbol_20          :
      constant Unicode_Char := 16#1D213#;
   Greek_Vocal_Notation_Symbol_21          :
      constant Unicode_Char := 16#1D214#;
   Greek_Vocal_Notation_Symbol_22          :
      constant Unicode_Char := 16#1D215#;
   Greek_Vocal_Notation_Symbol_23          :
      constant Unicode_Char := 16#1D216#;
   Greek_Vocal_Notation_Symbol_24          :
      constant Unicode_Char := 16#1D217#;
   Greek_Vocal_Notation_Symbol_50          :
      constant Unicode_Char := 16#1D218#;
   Greek_Vocal_Notation_Symbol_51          :
      constant Unicode_Char := 16#1D219#;
   Greek_Vocal_Notation_Symbol_52          :
      constant Unicode_Char := 16#1D21A#;
   Greek_Vocal_Notation_Symbol_53          :
      constant Unicode_Char := 16#1D21B#;
   Greek_Vocal_Notation_Symbol_54          :
      constant Unicode_Char := 16#1D21C#;
   Greek_Instrumental_Notation_Symbol_1    :
      constant Unicode_Char := 16#1D21D#;
   Greek_Instrumental_Notation_Symbol_2    :
      constant Unicode_Char := 16#1D21E#;
   Greek_Instrumental_Notation_Symbol_4    :
      constant Unicode_Char := 16#1D21F#;
   Greek_Instrumental_Notation_Symbol_5    :
      constant Unicode_Char := 16#1D220#;
   Greek_Instrumental_Notation_Symbol_7    :
      constant Unicode_Char := 16#1D221#;
   Greek_Instrumental_Notation_Symbol_8    :
      constant Unicode_Char := 16#1D222#;
   Greek_Instrumental_Notation_Symbol_11   :
      constant Unicode_Char := 16#1D223#;
   Greek_Instrumental_Notation_Symbol_12   :
      constant Unicode_Char := 16#1D224#;
   Greek_Instrumental_Notation_Symbol_13   :
      constant Unicode_Char := 16#1D225#;
   Greek_Instrumental_Notation_Symbol_14   :
      constant Unicode_Char := 16#1D226#;
   Greek_Instrumental_Notation_Symbol_17   :
      constant Unicode_Char := 16#1D227#;
   Greek_Instrumental_Notation_Symbol_18   :
      constant Unicode_Char := 16#1D228#;
   Greek_Instrumental_Notation_Symbol_19   :
      constant Unicode_Char := 16#1D229#;
   Greek_Instrumental_Notation_Symbol_23   :
      constant Unicode_Char := 16#1D22A#;
   Greek_Instrumental_Notation_Symbol_24   :
      constant Unicode_Char := 16#1D22B#;
   Greek_Instrumental_Notation_Symbol_25   :
      constant Unicode_Char := 16#1D22C#;
   Greek_Instrumental_Notation_Symbol_26   :
      constant Unicode_Char := 16#1D22D#;
   Greek_Instrumental_Notation_Symbol_27   :
      constant Unicode_Char := 16#1D22E#;
   Greek_Instrumental_Notation_Symbol_29   :
      constant Unicode_Char := 16#1D22F#;
   Greek_Instrumental_Notation_Symbol_30   :
      constant Unicode_Char := 16#1D230#;
   Greek_Instrumental_Notation_Symbol_32   :
      constant Unicode_Char := 16#1D231#;
   Greek_Instrumental_Notation_Symbol_36   :
      constant Unicode_Char := 16#1D232#;
   Greek_Instrumental_Notation_Symbol_37   :
      constant Unicode_Char := 16#1D233#;
   Greek_Instrumental_Notation_Symbol_38   :
      constant Unicode_Char := 16#1D234#;
   Greek_Instrumental_Notation_Symbol_39   :
      constant Unicode_Char := 16#1D235#;
   Greek_Instrumental_Notation_Symbol_40   :
      constant Unicode_Char := 16#1D236#;
   Greek_Instrumental_Notation_Symbol_42   :
      constant Unicode_Char := 16#1D237#;
   Greek_Instrumental_Notation_Symbol_43   :
      constant Unicode_Char := 16#1D238#;
   Greek_Instrumental_Notation_Symbol_45   :
      constant Unicode_Char := 16#1D239#;
   Greek_Instrumental_Notation_Symbol_47   :
      constant Unicode_Char := 16#1D23A#;
   Greek_Instrumental_Notation_Symbol_48   :
      constant Unicode_Char := 16#1D23B#;
   Greek_Instrumental_Notation_Symbol_49   :
      constant Unicode_Char := 16#1D23C#;
   Greek_Instrumental_Notation_Symbol_50   :
      constant Unicode_Char := 16#1D23D#;
   Greek_Instrumental_Notation_Symbol_51   :
      constant Unicode_Char := 16#1D23E#;
   Greek_Instrumental_Notation_Symbol_52   :
      constant Unicode_Char := 16#1D23F#;
   Greek_Instrumental_Notation_Symbol_53   :
      constant Unicode_Char := 16#1D240#;
   Greek_Instrumental_Notation_Symbol_54   :
      constant Unicode_Char := 16#1D241#;
   Combining_Greek_Musical_Triseme         :
      constant Unicode_Char := 16#1D242#;
   Combining_Greek_Musical_Tetraseme       :
      constant Unicode_Char := 16#1D243#;
   Combining_Greek_Musical_Pentaseme       :
      constant Unicode_Char := 16#1D244#;
   Greek_Musical_Leimma                    :
      constant Unicode_Char := 16#1D245#;
end Unicode.Names.Ancient_Greek_Music;
