--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Hebrew is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Hebrew_Accent_Etnahta                   : constant Unicode_Char := 16#0591#;
   Hebrew_Accent_Segol                     : constant Unicode_Char := 16#0592#;
   Hebrew_Accent_Shalshelet                : constant Unicode_Char := 16#0593#;
   Hebrew_Accent_Zaqef_Qatan               : constant Unicode_Char := 16#0594#;
   Hebrew_Accent_Zaqef_Gadol               : constant Unicode_Char := 16#0595#;
   Hebrew_Accent_Tipeha                    : constant Unicode_Char := 16#0596#;
   Hebrew_Accent_Revia                     : constant Unicode_Char := 16#0597#;
   Hebrew_Accent_Zarqa                     : constant Unicode_Char := 16#0598#;
   Hebrew_Accent_Pashta                    : constant Unicode_Char := 16#0599#;
   Hebrew_Accent_Yetiv                     : constant Unicode_Char := 16#059A#;
   Hebrew_Accent_Tevir                     : constant Unicode_Char := 16#059B#;
   Hebrew_Accent_Geresh                    : constant Unicode_Char := 16#059C#;
   Hebrew_Accent_Geresh_Muqdam             : constant Unicode_Char := 16#059D#;
   Hebrew_Accent_Gershayim                 : constant Unicode_Char := 16#059E#;
   Hebrew_Accent_Qarney_Para               : constant Unicode_Char := 16#059F#;
   Hebrew_Accent_Telisha_Gedola            : constant Unicode_Char := 16#05A0#;
   Hebrew_Accent_Pazer                     : constant Unicode_Char := 16#05A1#;
   Hebrew_Accent_Atnah_Hafukh              : constant Unicode_Char := 16#05A2#;
   Hebrew_Accent_Munah                     : constant Unicode_Char := 16#05A3#;
   Hebrew_Accent_Mahapakh                  : constant Unicode_Char := 16#05A4#;
   Hebrew_Accent_Merkha                    : constant Unicode_Char := 16#05A5#;
   Hebrew_Accent_Merkha_Kefula             : constant Unicode_Char := 16#05A6#;
   Hebrew_Accent_Darga                     : constant Unicode_Char := 16#05A7#;
   Hebrew_Accent_Qadma                     : constant Unicode_Char := 16#05A8#;
   Hebrew_Accent_Telisha_Qetana            : constant Unicode_Char := 16#05A9#;
   Hebrew_Accent_Yerah_Ben_Yomo            : constant Unicode_Char := 16#05AA#;
   Hebrew_Accent_Ole                       : constant Unicode_Char := 16#05AB#;
   Hebrew_Accent_Iluy                      : constant Unicode_Char := 16#05AC#;
   Hebrew_Accent_Dehi                      : constant Unicode_Char := 16#05AD#;
   Hebrew_Accent_Zinor                     : constant Unicode_Char := 16#05AE#;
   Hebrew_Mark_Masora_Circle               : constant Unicode_Char := 16#05AF#;
   Hebrew_Point_Sheva                      : constant Unicode_Char := 16#05B0#;
   Hebrew_Point_Hataf_Segol                : constant Unicode_Char := 16#05B1#;
   Hebrew_Point_Hataf_Patah                : constant Unicode_Char := 16#05B2#;
   Hebrew_Point_Hataf_Qamats               : constant Unicode_Char := 16#05B3#;
   Hebrew_Point_Hiriq                      : constant Unicode_Char := 16#05B4#;
   Hebrew_Point_Tsere                      : constant Unicode_Char := 16#05B5#;
   Hebrew_Point_Segol                      : constant Unicode_Char := 16#05B6#;
   Hebrew_Point_Patah                      : constant Unicode_Char := 16#05B7#;
   Hebrew_Point_Qamats                     : constant Unicode_Char := 16#05B8#;
   Hebrew_Point_Holam                      : constant Unicode_Char := 16#05B9#;
   Hebrew_Point_Holam_Haser_For_Vav        : constant Unicode_Char := 16#05BA#;
   Hebrew_Point_Qubuts                     : constant Unicode_Char := 16#05BB#;
   Hebrew_Point_Dagesh_Or_Mapiq            : constant Unicode_Char := 16#05BC#;
   Hebrew_Point_Meteg                      : constant Unicode_Char := 16#05BD#;
   Hebrew_Punctuation_Maqaf                : constant Unicode_Char := 16#05BE#;
   Hebrew_Point_Rafe                       : constant Unicode_Char := 16#05BF#;
   Hebrew_Punctuation_Paseq                : constant Unicode_Char := 16#05C0#;
   Hebrew_Point_Shin_Dot                   : constant Unicode_Char := 16#05C1#;
   Hebrew_Point_Sin_Dot                    : constant Unicode_Char := 16#05C2#;
   Hebrew_Punctuation_Sof_Pasuq            : constant Unicode_Char := 16#05C3#;
   Hebrew_Mark_Upper_Dot                   : constant Unicode_Char := 16#05C4#;
   Hebrew_Mark_Lower_Dot                   : constant Unicode_Char := 16#05C5#;
   Hebrew_Punctuation_Nun_Hafukha          : constant Unicode_Char := 16#05C6#;
   Hebrew_Point_Qamats_Qatan               : constant Unicode_Char := 16#05C7#;
   Hebrew_Letter_Alef                      : constant Unicode_Char := 16#05D0#;
   Hebrew_Letter_Bet                       : constant Unicode_Char := 16#05D1#;
   Hebrew_Letter_Gimel                     : constant Unicode_Char := 16#05D2#;
   Hebrew_Letter_Dalet                     : constant Unicode_Char := 16#05D3#;
   Hebrew_Letter_He                        : constant Unicode_Char := 16#05D4#;
   Hebrew_Letter_Vav                       : constant Unicode_Char := 16#05D5#;
   Hebrew_Letter_Zayin                     : constant Unicode_Char := 16#05D6#;
   Hebrew_Letter_Het                       : constant Unicode_Char := 16#05D7#;
   Hebrew_Letter_Tet                       : constant Unicode_Char := 16#05D8#;
   Hebrew_Letter_Yod                       : constant Unicode_Char := 16#05D9#;
   Hebrew_Letter_Final_Kaf                 : constant Unicode_Char := 16#05DA#;
   Hebrew_Letter_Kaf                       : constant Unicode_Char := 16#05DB#;
   Hebrew_Letter_Lamed                     : constant Unicode_Char := 16#05DC#;
   Hebrew_Letter_Final_Mem                 : constant Unicode_Char := 16#05DD#;
   Hebrew_Letter_Mem                       : constant Unicode_Char := 16#05DE#;
   Hebrew_Letter_Final_Nun                 : constant Unicode_Char := 16#05DF#;
   Hebrew_Letter_Nun                       : constant Unicode_Char := 16#05E0#;
   Hebrew_Letter_Samekh                    : constant Unicode_Char := 16#05E1#;
   Hebrew_Letter_Ayin                      : constant Unicode_Char := 16#05E2#;
   Hebrew_Letter_Final_Pe                  : constant Unicode_Char := 16#05E3#;
   Hebrew_Letter_Pe                        : constant Unicode_Char := 16#05E4#;
   Hebrew_Letter_Final_Tsadi               : constant Unicode_Char := 16#05E5#;
   Hebrew_Letter_Tsadi                     : constant Unicode_Char := 16#05E6#;
   Hebrew_Letter_Qof                       : constant Unicode_Char := 16#05E7#;
   Hebrew_Letter_Resh                      : constant Unicode_Char := 16#05E8#;
   Hebrew_Letter_Shin                      : constant Unicode_Char := 16#05E9#;
   Hebrew_Letter_Tav                       : constant Unicode_Char := 16#05EA#;
   Hebrew_Ligature_Yiddish_Double_Vav      : constant Unicode_Char := 16#05F0#;
   Hebrew_Ligature_Yiddish_Vav_Yod         : constant Unicode_Char := 16#05F1#;
   Hebrew_Ligature_Yiddish_Double_Yod      : constant Unicode_Char := 16#05F2#;
   Hebrew_Punctuation_Geresh               : constant Unicode_Char := 16#05F3#;
   Hebrew_Punctuation_Gershayim            : constant Unicode_Char := 16#05F4#;
end Unicode.Names.Hebrew;
