--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cyrillic_Extended_B is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cyrillic_Capital_Letter_Zemlya          : constant Unicode_Char := 16#A640#;
   Cyrillic_Small_Letter_Zemlya            : constant Unicode_Char := 16#A641#;
   Cyrillic_Capital_Letter_Dzelo           : constant Unicode_Char := 16#A642#;
   Cyrillic_Small_Letter_Dzelo             : constant Unicode_Char := 16#A643#;
   Cyrillic_Capital_Letter_Reversed_Dze    : constant Unicode_Char := 16#A644#;
   Cyrillic_Small_Letter_Reversed_Dze      : constant Unicode_Char := 16#A645#;
   Cyrillic_Capital_Letter_Iota            : constant Unicode_Char := 16#A646#;
   Cyrillic_Small_Letter_Iota              : constant Unicode_Char := 16#A647#;
   Cyrillic_Capital_Letter_Djerv           : constant Unicode_Char := 16#A648#;
   Cyrillic_Small_Letter_Djerv             : constant Unicode_Char := 16#A649#;
   Cyrillic_Capital_Letter_Monograph_Uk    : constant Unicode_Char := 16#A64A#;
   Cyrillic_Small_Letter_Monograph_Uk      : constant Unicode_Char := 16#A64B#;
   Cyrillic_Capital_Letter_Broad_Omega     : constant Unicode_Char := 16#A64C#;
   Cyrillic_Small_Letter_Broad_Omega       : constant Unicode_Char := 16#A64D#;
   Cyrillic_Capital_Letter_Neutral_Yer     : constant Unicode_Char := 16#A64E#;
   Cyrillic_Small_Letter_Neutral_Yer       : constant Unicode_Char := 16#A64F#;
   Cyrillic_Capital_Letter_Yeru_With_Back_Yer :
      constant Unicode_Char := 16#A650#;
   Cyrillic_Small_Letter_Yeru_With_Back_Yer :
      constant Unicode_Char := 16#A651#;
   Cyrillic_Capital_Letter_Iotified_Yat    : constant Unicode_Char := 16#A652#;
   Cyrillic_Small_Letter_Iotified_Yat      : constant Unicode_Char := 16#A653#;
   Cyrillic_Capital_Letter_Reversed_Yu     : constant Unicode_Char := 16#A654#;
   Cyrillic_Small_Letter_Reversed_Yu       : constant Unicode_Char := 16#A655#;
   Cyrillic_Capital_Letter_Iotified_A      : constant Unicode_Char := 16#A656#;
   Cyrillic_Small_Letter_Iotified_A        : constant Unicode_Char := 16#A657#;
   Cyrillic_Capital_Letter_Closed_Little_Yus :
      constant Unicode_Char := 16#A658#;
   Cyrillic_Small_Letter_Closed_Little_Yus : constant Unicode_Char := 16#A659#;
   Cyrillic_Capital_Letter_Blended_Yus     : constant Unicode_Char := 16#A65A#;
   Cyrillic_Small_Letter_Blended_Yus       : constant Unicode_Char := 16#A65B#;
   Cyrillic_Capital_Letter_Iotified_Closed_Little_Yus :
      constant Unicode_Char := 16#A65C#;
   Cyrillic_Small_Letter_Iotified_Closed_Little_Yus :
      constant Unicode_Char := 16#A65D#;
   Cyrillic_Capital_Letter_Yn              : constant Unicode_Char := 16#A65E#;
   Cyrillic_Small_Letter_Yn                : constant Unicode_Char := 16#A65F#;
   Cyrillic_Capital_Letter_Reversed_Tse    : constant Unicode_Char := 16#A660#;
   Cyrillic_Small_Letter_Reversed_Tse      : constant Unicode_Char := 16#A661#;
   Cyrillic_Capital_Letter_Soft_De         : constant Unicode_Char := 16#A662#;
   Cyrillic_Small_Letter_Soft_De           : constant Unicode_Char := 16#A663#;
   Cyrillic_Capital_Letter_Soft_El         : constant Unicode_Char := 16#A664#;
   Cyrillic_Small_Letter_Soft_El           : constant Unicode_Char := 16#A665#;
   Cyrillic_Capital_Letter_Soft_Em         : constant Unicode_Char := 16#A666#;
   Cyrillic_Small_Letter_Soft_Em           : constant Unicode_Char := 16#A667#;
   Cyrillic_Capital_Letter_Monocular_O     : constant Unicode_Char := 16#A668#;
   Cyrillic_Small_Letter_Monocular_O       : constant Unicode_Char := 16#A669#;
   Cyrillic_Capital_Letter_Binocular_O     : constant Unicode_Char := 16#A66A#;
   Cyrillic_Small_Letter_Binocular_O       : constant Unicode_Char := 16#A66B#;
   Cyrillic_Capital_Letter_Double_Monocular_O :
      constant Unicode_Char := 16#A66C#;
   Cyrillic_Small_Letter_Double_Monocular_O :
      constant Unicode_Char := 16#A66D#;
   Cyrillic_Letter_Multiocular_O           : constant Unicode_Char := 16#A66E#;
   Combining_Cyrillic_Vzmet                : constant Unicode_Char := 16#A66F#;
   Combining_Cyrillic_Ten_Millions_Sign    : constant Unicode_Char := 16#A670#;
   Combining_Cyrillic_Hundred_Millions_Sign :
      constant Unicode_Char := 16#A671#;
   Combining_Cyrillic_Thousand_Millions_Sign :
      constant Unicode_Char := 16#A672#;
   Slavonic_Asterisk                       : constant Unicode_Char := 16#A673#;
   Combining_Cyrillic_Letter_Ukrainian_Ie  : constant Unicode_Char := 16#A674#;
   Combining_Cyrillic_Letter_I             : constant Unicode_Char := 16#A675#;
   Combining_Cyrillic_Letter_Yi            : constant Unicode_Char := 16#A676#;
   Combining_Cyrillic_Letter_U             : constant Unicode_Char := 16#A677#;
   Combining_Cyrillic_Letter_Hard_Sign     : constant Unicode_Char := 16#A678#;
   Combining_Cyrillic_Letter_Yeru          : constant Unicode_Char := 16#A679#;
   Combining_Cyrillic_Letter_Soft_Sign     : constant Unicode_Char := 16#A67A#;
   Combining_Cyrillic_Letter_Omega         : constant Unicode_Char := 16#A67B#;
   Combining_Cyrillic_Kavyka               : constant Unicode_Char := 16#A67C#;
   Combining_Cyrillic_Payerok              : constant Unicode_Char := 16#A67D#;
   Cyrillic_Kavyka                         : constant Unicode_Char := 16#A67E#;
   Cyrillic_Payerok                        : constant Unicode_Char := 16#A67F#;
   Cyrillic_Capital_Letter_Dwe             : constant Unicode_Char := 16#A680#;
   Cyrillic_Small_Letter_Dwe               : constant Unicode_Char := 16#A681#;
   Cyrillic_Capital_Letter_Dzwe            : constant Unicode_Char := 16#A682#;
   Cyrillic_Small_Letter_Dzwe              : constant Unicode_Char := 16#A683#;
   Cyrillic_Capital_Letter_Zhwe            : constant Unicode_Char := 16#A684#;
   Cyrillic_Small_Letter_Zhwe              : constant Unicode_Char := 16#A685#;
   Cyrillic_Capital_Letter_Cche            : constant Unicode_Char := 16#A686#;
   Cyrillic_Small_Letter_Cche              : constant Unicode_Char := 16#A687#;
   Cyrillic_Capital_Letter_Dzze            : constant Unicode_Char := 16#A688#;
   Cyrillic_Small_Letter_Dzze              : constant Unicode_Char := 16#A689#;
   Cyrillic_Capital_Letter_Te_With_Middle_Hook :
      constant Unicode_Char := 16#A68A#;
   Cyrillic_Small_Letter_Te_With_Middle_Hook :
      constant Unicode_Char := 16#A68B#;
   Cyrillic_Capital_Letter_Twe             : constant Unicode_Char := 16#A68C#;
   Cyrillic_Small_Letter_Twe               : constant Unicode_Char := 16#A68D#;
   Cyrillic_Capital_Letter_Tswe            : constant Unicode_Char := 16#A68E#;
   Cyrillic_Small_Letter_Tswe              : constant Unicode_Char := 16#A68F#;
   Cyrillic_Capital_Letter_Tsse            : constant Unicode_Char := 16#A690#;
   Cyrillic_Small_Letter_Tsse              : constant Unicode_Char := 16#A691#;
   Cyrillic_Capital_Letter_Tche            : constant Unicode_Char := 16#A692#;
   Cyrillic_Small_Letter_Tche              : constant Unicode_Char := 16#A693#;
   Cyrillic_Capital_Letter_Hwe             : constant Unicode_Char := 16#A694#;
   Cyrillic_Small_Letter_Hwe               : constant Unicode_Char := 16#A695#;
   Cyrillic_Capital_Letter_Shwe            : constant Unicode_Char := 16#A696#;
   Cyrillic_Small_Letter_Shwe              : constant Unicode_Char := 16#A697#;
   Cyrillic_Capital_Letter_Double_O        : constant Unicode_Char := 16#A698#;
   Cyrillic_Small_Letter_Double_O          : constant Unicode_Char := 16#A699#;
   Cyrillic_Capital_Letter_Crossed_O       : constant Unicode_Char := 16#A69A#;
   Cyrillic_Small_Letter_Crossed_O         : constant Unicode_Char := 16#A69B#;
   Modifier_Letter_Cyrillic_Hard_Sign      : constant Unicode_Char := 16#A69C#;
   Modifier_Letter_Cyrillic_Soft_Sign      : constant Unicode_Char := 16#A69D#;
   Combining_Cyrillic_Letter_Ef            : constant Unicode_Char := 16#A69E#;
   Combining_Cyrillic_Letter_Iotified_E    : constant Unicode_Char := 16#A69F#;
end Unicode.Names.Cyrillic_Extended_B;
