--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Bamum_Supplement is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Bamum_Letter_Phase_A_Ngkue_Mfon         :
      constant Unicode_Char := 16#16800#;
   Bamum_Letter_Phase_A_Gbiee_Fon          :
      constant Unicode_Char := 16#16801#;
   Bamum_Letter_Phase_A_Pon_Mfon_Pipaemgbiee :
      constant Unicode_Char := 16#16802#;
   Bamum_Letter_Phase_A_Pon_Mfon_Pipaemba  :
      constant Unicode_Char := 16#16803#;
   Bamum_Letter_Phase_A_Naa_Mfon           :
      constant Unicode_Char := 16#16804#;
   Bamum_Letter_Phase_A_Shuenshuet         :
      constant Unicode_Char := 16#16805#;
   Bamum_Letter_Phase_A_Tita_Mfon          :
      constant Unicode_Char := 16#16806#;
   Bamum_Letter_Phase_A_Nza_Mfon           :
      constant Unicode_Char := 16#16807#;
   Bamum_Letter_Phase_A_Shinda_Pa_Nji      :
      constant Unicode_Char := 16#16808#;
   Bamum_Letter_Phase_A_Pon_Pa_Nji_Pipaemgbiee :
      constant Unicode_Char := 16#16809#;
   Bamum_Letter_Phase_A_Pon_Pa_Nji_Pipaemba :
      constant Unicode_Char := 16#1680A#;
   Bamum_Letter_Phase_A_Maembgbiee         :
      constant Unicode_Char := 16#1680B#;
   Bamum_Letter_Phase_A_Tu_Maemba          :
      constant Unicode_Char := 16#1680C#;
   Bamum_Letter_Phase_A_Ngangu             :
      constant Unicode_Char := 16#1680D#;
   Bamum_Letter_Phase_A_Maemveux           :
      constant Unicode_Char := 16#1680E#;
   Bamum_Letter_Phase_A_Mansuae            :
      constant Unicode_Char := 16#1680F#;
   Bamum_Letter_Phase_A_Mveuaengam         :
      constant Unicode_Char := 16#16810#;
   Bamum_Letter_Phase_A_Seunyam            :
      constant Unicode_Char := 16#16811#;
   Bamum_Letter_Phase_A_Ntoqpen            :
      constant Unicode_Char := 16#16812#;
   Bamum_Letter_Phase_A_Keukeutnda         :
      constant Unicode_Char := 16#16813#;
   Bamum_Letter_Phase_A_Nkindi             :
      constant Unicode_Char := 16#16814#;
   Bamum_Letter_Phase_A_Suu                :
      constant Unicode_Char := 16#16815#;
   Bamum_Letter_Phase_A_Ngkuenzeum         :
      constant Unicode_Char := 16#16816#;
   Bamum_Letter_Phase_A_Lapaq              :
      constant Unicode_Char := 16#16817#;
   Bamum_Letter_Phase_A_Let_Kut            :
      constant Unicode_Char := 16#16818#;
   Bamum_Letter_Phase_A_Ntap_Mfaa          :
      constant Unicode_Char := 16#16819#;
   Bamum_Letter_Phase_A_Maekeup            :
      constant Unicode_Char := 16#1681A#;
   Bamum_Letter_Phase_A_Pashae             :
      constant Unicode_Char := 16#1681B#;
   Bamum_Letter_Phase_A_Gheuaerae          :
      constant Unicode_Char := 16#1681C#;
   Bamum_Letter_Phase_A_Pamshae            :
      constant Unicode_Char := 16#1681D#;
   Bamum_Letter_Phase_A_Mon_Nggeuaet       :
      constant Unicode_Char := 16#1681E#;
   Bamum_Letter_Phase_A_Nzun_Meut          :
      constant Unicode_Char := 16#1681F#;
   Bamum_Letter_Phase_A_U_Yuq_Nae          :
      constant Unicode_Char := 16#16820#;
   Bamum_Letter_Phase_A_Gheuaegheuae       :
      constant Unicode_Char := 16#16821#;
   Bamum_Letter_Phase_A_Ntap_Ntaa          :
      constant Unicode_Char := 16#16822#;
   Bamum_Letter_Phase_A_Sisa               :
      constant Unicode_Char := 16#16823#;
   Bamum_Letter_Phase_A_Mgbasa             :
      constant Unicode_Char := 16#16824#;
   Bamum_Letter_Phase_A_Meunjomndeuq       :
      constant Unicode_Char := 16#16825#;
   Bamum_Letter_Phase_A_Moompuq            :
      constant Unicode_Char := 16#16826#;
   Bamum_Letter_Phase_A_Kafa               :
      constant Unicode_Char := 16#16827#;
   Bamum_Letter_Phase_A_Pa_Leeraewa        :
      constant Unicode_Char := 16#16828#;
   Bamum_Letter_Phase_A_Nda_Leeraewa       :
      constant Unicode_Char := 16#16829#;
   Bamum_Letter_Phase_A_Pet                :
      constant Unicode_Char := 16#1682A#;
   Bamum_Letter_Phase_A_Maemkpen           :
      constant Unicode_Char := 16#1682B#;
   Bamum_Letter_Phase_A_Nika               :
      constant Unicode_Char := 16#1682C#;
   Bamum_Letter_Phase_A_Pup                :
      constant Unicode_Char := 16#1682D#;
   Bamum_Letter_Phase_A_Tuaep              :
      constant Unicode_Char := 16#1682E#;
   Bamum_Letter_Phase_A_Luaep              :
      constant Unicode_Char := 16#1682F#;
   Bamum_Letter_Phase_A_Sonjam             :
      constant Unicode_Char := 16#16830#;
   Bamum_Letter_Phase_A_Teuteuwen          :
      constant Unicode_Char := 16#16831#;
   Bamum_Letter_Phase_A_Maenyi             :
      constant Unicode_Char := 16#16832#;
   Bamum_Letter_Phase_A_Ket                :
      constant Unicode_Char := 16#16833#;
   Bamum_Letter_Phase_A_Ndaanggeuaet       :
      constant Unicode_Char := 16#16834#;
   Bamum_Letter_Phase_A_Kuoq               :
      constant Unicode_Char := 16#16835#;
   Bamum_Letter_Phase_A_Moomeut            :
      constant Unicode_Char := 16#16836#;
   Bamum_Letter_Phase_A_Shum               :
      constant Unicode_Char := 16#16837#;
   Bamum_Letter_Phase_A_Lommae             :
      constant Unicode_Char := 16#16838#;
   Bamum_Letter_Phase_A_Firi               :
      constant Unicode_Char := 16#16839#;
   Bamum_Letter_Phase_A_Rom                :
      constant Unicode_Char := 16#1683A#;
   Bamum_Letter_Phase_A_Kpoq               :
      constant Unicode_Char := 16#1683B#;
   Bamum_Letter_Phase_A_Soq                :
      constant Unicode_Char := 16#1683C#;
   Bamum_Letter_Phase_A_Map_Pieet          :
      constant Unicode_Char := 16#1683D#;
   Bamum_Letter_Phase_A_Shirae             :
      constant Unicode_Char := 16#1683E#;
   Bamum_Letter_Phase_A_Ntap               :
      constant Unicode_Char := 16#1683F#;
   Bamum_Letter_Phase_A_Shoq_Nshut_Yum     :
      constant Unicode_Char := 16#16840#;
   Bamum_Letter_Phase_A_Nyit_Mongkeuaeq    :
      constant Unicode_Char := 16#16841#;
   Bamum_Letter_Phase_A_Paarae             :
      constant Unicode_Char := 16#16842#;
   Bamum_Letter_Phase_A_Nkaarae            :
      constant Unicode_Char := 16#16843#;
   Bamum_Letter_Phase_A_Unknown            :
      constant Unicode_Char := 16#16844#;
   Bamum_Letter_Phase_A_Nggen              :
      constant Unicode_Char := 16#16845#;
   Bamum_Letter_Phase_A_Maesi              :
      constant Unicode_Char := 16#16846#;
   Bamum_Letter_Phase_A_Njam               :
      constant Unicode_Char := 16#16847#;
   Bamum_Letter_Phase_A_Mbanyi             :
      constant Unicode_Char := 16#16848#;
   Bamum_Letter_Phase_A_Nyet               :
      constant Unicode_Char := 16#16849#;
   Bamum_Letter_Phase_A_Teuaen             :
      constant Unicode_Char := 16#1684A#;
   Bamum_Letter_Phase_A_Sot                :
      constant Unicode_Char := 16#1684B#;
   Bamum_Letter_Phase_A_Paam               :
      constant Unicode_Char := 16#1684C#;
   Bamum_Letter_Phase_A_Nshiee             :
      constant Unicode_Char := 16#1684D#;
   Bamum_Letter_Phase_A_Maem               :
      constant Unicode_Char := 16#1684E#;
   Bamum_Letter_Phase_A_Nyi                :
      constant Unicode_Char := 16#1684F#;
   Bamum_Letter_Phase_A_Kaq                :
      constant Unicode_Char := 16#16850#;
   Bamum_Letter_Phase_A_Nsha               :
      constant Unicode_Char := 16#16851#;
   Bamum_Letter_Phase_A_Vee                :
      constant Unicode_Char := 16#16852#;
   Bamum_Letter_Phase_A_Lu                 :
      constant Unicode_Char := 16#16853#;
   Bamum_Letter_Phase_A_Nen                :
      constant Unicode_Char := 16#16854#;
   Bamum_Letter_Phase_A_Naq                :
      constant Unicode_Char := 16#16855#;
   Bamum_Letter_Phase_A_Mbaq               :
      constant Unicode_Char := 16#16856#;
   Bamum_Letter_Phase_B_Nshuet             :
      constant Unicode_Char := 16#16857#;
   Bamum_Letter_Phase_B_Tu_Maemgbiee       :
      constant Unicode_Char := 16#16858#;
   Bamum_Letter_Phase_B_Siee               :
      constant Unicode_Char := 16#16859#;
   Bamum_Letter_Phase_B_Set_Tu             :
      constant Unicode_Char := 16#1685A#;
   Bamum_Letter_Phase_B_Lom_Nteum          :
      constant Unicode_Char := 16#1685B#;
   Bamum_Letter_Phase_B_Mba_Maelee         :
      constant Unicode_Char := 16#1685C#;
   Bamum_Letter_Phase_B_Kieem              :
      constant Unicode_Char := 16#1685D#;
   Bamum_Letter_Phase_B_Yeurae             :
      constant Unicode_Char := 16#1685E#;
   Bamum_Letter_Phase_B_Mbaarae            :
      constant Unicode_Char := 16#1685F#;
   Bamum_Letter_Phase_B_Kam                :
      constant Unicode_Char := 16#16860#;
   Bamum_Letter_Phase_B_Peeshi             :
      constant Unicode_Char := 16#16861#;
   Bamum_Letter_Phase_B_Yafu_Leeraewa      :
      constant Unicode_Char := 16#16862#;
   Bamum_Letter_Phase_B_Lam_Nshut_Nyam     :
      constant Unicode_Char := 16#16863#;
   Bamum_Letter_Phase_B_Ntiee_Sheuoq       :
      constant Unicode_Char := 16#16864#;
   Bamum_Letter_Phase_B_Ndu_Njaa           :
      constant Unicode_Char := 16#16865#;
   Bamum_Letter_Phase_B_Gheugheuaem        :
      constant Unicode_Char := 16#16866#;
   Bamum_Letter_Phase_B_Pit                :
      constant Unicode_Char := 16#16867#;
   Bamum_Letter_Phase_B_Tu_Nsiee           :
      constant Unicode_Char := 16#16868#;
   Bamum_Letter_Phase_B_Shet_Njaq          :
      constant Unicode_Char := 16#16869#;
   Bamum_Letter_Phase_B_Sheuaeqtu          :
      constant Unicode_Char := 16#1686A#;
   Bamum_Letter_Phase_B_Mfon_Teuaeq        :
      constant Unicode_Char := 16#1686B#;
   Bamum_Letter_Phase_B_Mbit_Mbaaket       :
      constant Unicode_Char := 16#1686C#;
   Bamum_Letter_Phase_B_Nyi_Nteum          :
      constant Unicode_Char := 16#1686D#;
   Bamum_Letter_Phase_B_Keupuq             :
      constant Unicode_Char := 16#1686E#;
   Bamum_Letter_Phase_B_Gheughen           :
      constant Unicode_Char := 16#1686F#;
   Bamum_Letter_Phase_B_Keuyeux            :
      constant Unicode_Char := 16#16870#;
   Bamum_Letter_Phase_B_Laanae             :
      constant Unicode_Char := 16#16871#;
   Bamum_Letter_Phase_B_Parum              :
      constant Unicode_Char := 16#16872#;
   Bamum_Letter_Phase_B_Veum               :
      constant Unicode_Char := 16#16873#;
   Bamum_Letter_Phase_B_Ngkindi_Mvop       :
      constant Unicode_Char := 16#16874#;
   Bamum_Letter_Phase_B_Nggeu_Mbu          :
      constant Unicode_Char := 16#16875#;
   Bamum_Letter_Phase_B_Wuaet              :
      constant Unicode_Char := 16#16876#;
   Bamum_Letter_Phase_B_Sakeuae            :
      constant Unicode_Char := 16#16877#;
   Bamum_Letter_Phase_B_Taam               :
      constant Unicode_Char := 16#16878#;
   Bamum_Letter_Phase_B_Meuq               :
      constant Unicode_Char := 16#16879#;
   Bamum_Letter_Phase_B_Ngguoq             :
      constant Unicode_Char := 16#1687A#;
   Bamum_Letter_Phase_B_Ngguoq_Large       :
      constant Unicode_Char := 16#1687B#;
   Bamum_Letter_Phase_B_Mfiyaq             :
      constant Unicode_Char := 16#1687C#;
   Bamum_Letter_Phase_B_Sue                :
      constant Unicode_Char := 16#1687D#;
   Bamum_Letter_Phase_B_Mbeuri             :
      constant Unicode_Char := 16#1687E#;
   Bamum_Letter_Phase_B_Montieen           :
      constant Unicode_Char := 16#1687F#;
   Bamum_Letter_Phase_B_Nyaemae            :
      constant Unicode_Char := 16#16880#;
   Bamum_Letter_Phase_B_Pungaam            :
      constant Unicode_Char := 16#16881#;
   Bamum_Letter_Phase_B_Meut_Nggeet        :
      constant Unicode_Char := 16#16882#;
   Bamum_Letter_Phase_B_Feux               :
      constant Unicode_Char := 16#16883#;
   Bamum_Letter_Phase_B_Mbuoq              :
      constant Unicode_Char := 16#16884#;
   Bamum_Letter_Phase_B_Fee                :
      constant Unicode_Char := 16#16885#;
   Bamum_Letter_Phase_B_Keuaem             :
      constant Unicode_Char := 16#16886#;
   Bamum_Letter_Phase_B_Ma_Njeuaena        :
      constant Unicode_Char := 16#16887#;
   Bamum_Letter_Phase_B_Ma_Njuqa           :
      constant Unicode_Char := 16#16888#;
   Bamum_Letter_Phase_B_Let                :
      constant Unicode_Char := 16#16889#;
   Bamum_Letter_Phase_B_Nggaam             :
      constant Unicode_Char := 16#1688A#;
   Bamum_Letter_Phase_B_Nsen               :
      constant Unicode_Char := 16#1688B#;
   Bamum_Letter_Phase_B_Ma                 :
      constant Unicode_Char := 16#1688C#;
   Bamum_Letter_Phase_B_Kiq                :
      constant Unicode_Char := 16#1688D#;
   Bamum_Letter_Phase_B_Ngom               :
      constant Unicode_Char := 16#1688E#;
   Bamum_Letter_Phase_C_Ngkue_Maemba       :
      constant Unicode_Char := 16#1688F#;
   Bamum_Letter_Phase_C_Nza                :
      constant Unicode_Char := 16#16890#;
   Bamum_Letter_Phase_C_Yum                :
      constant Unicode_Char := 16#16891#;
   Bamum_Letter_Phase_C_Wangkuoq           :
      constant Unicode_Char := 16#16892#;
   Bamum_Letter_Phase_C_Nggen              :
      constant Unicode_Char := 16#16893#;
   Bamum_Letter_Phase_C_Ndeuaeree          :
      constant Unicode_Char := 16#16894#;
   Bamum_Letter_Phase_C_Ngkaq              :
      constant Unicode_Char := 16#16895#;
   Bamum_Letter_Phase_C_Gharae             :
      constant Unicode_Char := 16#16896#;
   Bamum_Letter_Phase_C_Mbeekeet           :
      constant Unicode_Char := 16#16897#;
   Bamum_Letter_Phase_C_Gbayi              :
      constant Unicode_Char := 16#16898#;
   Bamum_Letter_Phase_C_Nyir_Mkparaq_Meun  :
      constant Unicode_Char := 16#16899#;
   Bamum_Letter_Phase_C_Ntu_Mbit           :
      constant Unicode_Char := 16#1689A#;
   Bamum_Letter_Phase_C_Mbeum              :
      constant Unicode_Char := 16#1689B#;
   Bamum_Letter_Phase_C_Pirieen            :
      constant Unicode_Char := 16#1689C#;
   Bamum_Letter_Phase_C_Ndombu             :
      constant Unicode_Char := 16#1689D#;
   Bamum_Letter_Phase_C_Mbaa_Cabbage_Tree  :
      constant Unicode_Char := 16#1689E#;
   Bamum_Letter_Phase_C_Keusheuaep         :
      constant Unicode_Char := 16#1689F#;
   Bamum_Letter_Phase_C_Ghap               :
      constant Unicode_Char := 16#168A0#;
   Bamum_Letter_Phase_C_Keukaq             :
      constant Unicode_Char := 16#168A1#;
   Bamum_Letter_Phase_C_Yu_Muomae          :
      constant Unicode_Char := 16#168A2#;
   Bamum_Letter_Phase_C_Nzeum              :
      constant Unicode_Char := 16#168A3#;
   Bamum_Letter_Phase_C_Mbue               :
      constant Unicode_Char := 16#168A4#;
   Bamum_Letter_Phase_C_Nseuaen            :
      constant Unicode_Char := 16#168A5#;
   Bamum_Letter_Phase_C_Mbit               :
      constant Unicode_Char := 16#168A6#;
   Bamum_Letter_Phase_C_Yeuq               :
      constant Unicode_Char := 16#168A7#;
   Bamum_Letter_Phase_C_Kparaq             :
      constant Unicode_Char := 16#168A8#;
   Bamum_Letter_Phase_C_Kaa                :
      constant Unicode_Char := 16#168A9#;
   Bamum_Letter_Phase_C_Seux               :
      constant Unicode_Char := 16#168AA#;
   Bamum_Letter_Phase_C_Ndida              :
      constant Unicode_Char := 16#168AB#;
   Bamum_Letter_Phase_C_Taashae            :
      constant Unicode_Char := 16#168AC#;
   Bamum_Letter_Phase_C_Njueq              :
      constant Unicode_Char := 16#168AD#;
   Bamum_Letter_Phase_C_Tita_Yue           :
      constant Unicode_Char := 16#168AE#;
   Bamum_Letter_Phase_C_Suaet              :
      constant Unicode_Char := 16#168AF#;
   Bamum_Letter_Phase_C_Ngguaen_Nyam       :
      constant Unicode_Char := 16#168B0#;
   Bamum_Letter_Phase_C_Veux               :
      constant Unicode_Char := 16#168B1#;
   Bamum_Letter_Phase_C_Nansanaq           :
      constant Unicode_Char := 16#168B2#;
   Bamum_Letter_Phase_C_Ma_Keuaeri         :
      constant Unicode_Char := 16#168B3#;
   Bamum_Letter_Phase_C_Ntaa               :
      constant Unicode_Char := 16#168B4#;
   Bamum_Letter_Phase_C_Ngguon             :
      constant Unicode_Char := 16#168B5#;
   Bamum_Letter_Phase_C_Lap                :
      constant Unicode_Char := 16#168B6#;
   Bamum_Letter_Phase_C_Mbirieen           :
      constant Unicode_Char := 16#168B7#;
   Bamum_Letter_Phase_C_Mgbasaq            :
      constant Unicode_Char := 16#168B8#;
   Bamum_Letter_Phase_C_Nteungba           :
      constant Unicode_Char := 16#168B9#;
   Bamum_Letter_Phase_C_Teuteux            :
      constant Unicode_Char := 16#168BA#;
   Bamum_Letter_Phase_C_Nggum              :
      constant Unicode_Char := 16#168BB#;
   Bamum_Letter_Phase_C_Fue                :
      constant Unicode_Char := 16#168BC#;
   Bamum_Letter_Phase_C_Ndeut              :
      constant Unicode_Char := 16#168BD#;
   Bamum_Letter_Phase_C_Nsa                :
      constant Unicode_Char := 16#168BE#;
   Bamum_Letter_Phase_C_Nshaq              :
      constant Unicode_Char := 16#168BF#;
   Bamum_Letter_Phase_C_Bung               :
      constant Unicode_Char := 16#168C0#;
   Bamum_Letter_Phase_C_Veuaepen           :
      constant Unicode_Char := 16#168C1#;
   Bamum_Letter_Phase_C_Mberae             :
      constant Unicode_Char := 16#168C2#;
   Bamum_Letter_Phase_C_Ru                 :
      constant Unicode_Char := 16#168C3#;
   Bamum_Letter_Phase_C_Njaem              :
      constant Unicode_Char := 16#168C4#;
   Bamum_Letter_Phase_C_Lam                :
      constant Unicode_Char := 16#168C5#;
   Bamum_Letter_Phase_C_Tituaep            :
      constant Unicode_Char := 16#168C6#;
   Bamum_Letter_Phase_C_Nsuot_Ngom         :
      constant Unicode_Char := 16#168C7#;
   Bamum_Letter_Phase_C_Njeeee             :
      constant Unicode_Char := 16#168C8#;
   Bamum_Letter_Phase_C_Ket                :
      constant Unicode_Char := 16#168C9#;
   Bamum_Letter_Phase_C_Nggu               :
      constant Unicode_Char := 16#168CA#;
   Bamum_Letter_Phase_C_Maesi              :
      constant Unicode_Char := 16#168CB#;
   Bamum_Letter_Phase_C_Mbuaem             :
      constant Unicode_Char := 16#168CC#;
   Bamum_Letter_Phase_C_Lu                 :
      constant Unicode_Char := 16#168CD#;
   Bamum_Letter_Phase_C_Kut                :
      constant Unicode_Char := 16#168CE#;
   Bamum_Letter_Phase_C_Njam               :
      constant Unicode_Char := 16#168CF#;
   Bamum_Letter_Phase_C_Ngom               :
      constant Unicode_Char := 16#168D0#;
   Bamum_Letter_Phase_C_Wup                :
      constant Unicode_Char := 16#168D1#;
   Bamum_Letter_Phase_C_Nggueet            :
      constant Unicode_Char := 16#168D2#;
   Bamum_Letter_Phase_C_Nsom               :
      constant Unicode_Char := 16#168D3#;
   Bamum_Letter_Phase_C_Nten               :
      constant Unicode_Char := 16#168D4#;
   Bamum_Letter_Phase_C_Kuop_Nkaarae       :
      constant Unicode_Char := 16#168D5#;
   Bamum_Letter_Phase_C_Nsun               :
      constant Unicode_Char := 16#168D6#;
   Bamum_Letter_Phase_C_Ndam               :
      constant Unicode_Char := 16#168D7#;
   Bamum_Letter_Phase_C_Ma_Nsiee           :
      constant Unicode_Char := 16#168D8#;
   Bamum_Letter_Phase_C_Yaa                :
      constant Unicode_Char := 16#168D9#;
   Bamum_Letter_Phase_C_Ndap               :
      constant Unicode_Char := 16#168DA#;
   Bamum_Letter_Phase_C_Shueq              :
      constant Unicode_Char := 16#168DB#;
   Bamum_Letter_Phase_C_Setfon             :
      constant Unicode_Char := 16#168DC#;
   Bamum_Letter_Phase_C_Mbi                :
      constant Unicode_Char := 16#168DD#;
   Bamum_Letter_Phase_C_Maemba             :
      constant Unicode_Char := 16#168DE#;
   Bamum_Letter_Phase_C_Mbanyi             :
      constant Unicode_Char := 16#168DF#;
   Bamum_Letter_Phase_C_Keuseux            :
      constant Unicode_Char := 16#168E0#;
   Bamum_Letter_Phase_C_Mbeux              :
      constant Unicode_Char := 16#168E1#;
   Bamum_Letter_Phase_C_Keum               :
      constant Unicode_Char := 16#168E2#;
   Bamum_Letter_Phase_C_Mbaa_Picket        :
      constant Unicode_Char := 16#168E3#;
   Bamum_Letter_Phase_C_Yuwoq              :
      constant Unicode_Char := 16#168E4#;
   Bamum_Letter_Phase_C_Njeux              :
      constant Unicode_Char := 16#168E5#;
   Bamum_Letter_Phase_C_Miee               :
      constant Unicode_Char := 16#168E6#;
   Bamum_Letter_Phase_C_Muae               :
      constant Unicode_Char := 16#168E7#;
   Bamum_Letter_Phase_C_Shiq               :
      constant Unicode_Char := 16#168E8#;
   Bamum_Letter_Phase_C_Ken_Law            :
      constant Unicode_Char := 16#168E9#;
   Bamum_Letter_Phase_C_Ken_Fatigue        :
      constant Unicode_Char := 16#168EA#;
   Bamum_Letter_Phase_C_Ngaq               :
      constant Unicode_Char := 16#168EB#;
   Bamum_Letter_Phase_C_Naq                :
      constant Unicode_Char := 16#168EC#;
   Bamum_Letter_Phase_C_Liq                :
      constant Unicode_Char := 16#168ED#;
   Bamum_Letter_Phase_C_Pin                :
      constant Unicode_Char := 16#168EE#;
   Bamum_Letter_Phase_C_Pen                :
      constant Unicode_Char := 16#168EF#;
   Bamum_Letter_Phase_C_Tet                :
      constant Unicode_Char := 16#168F0#;
   Bamum_Letter_Phase_D_Mbuo               :
      constant Unicode_Char := 16#168F1#;
   Bamum_Letter_Phase_D_Wap                :
      constant Unicode_Char := 16#168F2#;
   Bamum_Letter_Phase_D_Nji                :
      constant Unicode_Char := 16#168F3#;
   Bamum_Letter_Phase_D_Mfon               :
      constant Unicode_Char := 16#168F4#;
   Bamum_Letter_Phase_D_Njiee              :
      constant Unicode_Char := 16#168F5#;
   Bamum_Letter_Phase_D_Liee               :
      constant Unicode_Char := 16#168F6#;
   Bamum_Letter_Phase_D_Njeut              :
      constant Unicode_Char := 16#168F7#;
   Bamum_Letter_Phase_D_Nshee              :
      constant Unicode_Char := 16#168F8#;
   Bamum_Letter_Phase_D_Nggaamae           :
      constant Unicode_Char := 16#168F9#;
   Bamum_Letter_Phase_D_Nyam               :
      constant Unicode_Char := 16#168FA#;
   Bamum_Letter_Phase_D_Wuaen              :
      constant Unicode_Char := 16#168FB#;
   Bamum_Letter_Phase_D_Ngkun              :
      constant Unicode_Char := 16#168FC#;
   Bamum_Letter_Phase_D_Shee               :
      constant Unicode_Char := 16#168FD#;
   Bamum_Letter_Phase_D_Ngkap              :
      constant Unicode_Char := 16#168FE#;
   Bamum_Letter_Phase_D_Keuaetmeun         :
      constant Unicode_Char := 16#168FF#;
   Bamum_Letter_Phase_D_Teut               :
      constant Unicode_Char := 16#16900#;
   Bamum_Letter_Phase_D_Sheuae             :
      constant Unicode_Char := 16#16901#;
   Bamum_Letter_Phase_D_Njap               :
      constant Unicode_Char := 16#16902#;
   Bamum_Letter_Phase_D_Sue                :
      constant Unicode_Char := 16#16903#;
   Bamum_Letter_Phase_D_Ket                :
      constant Unicode_Char := 16#16904#;
   Bamum_Letter_Phase_D_Yaemmae            :
      constant Unicode_Char := 16#16905#;
   Bamum_Letter_Phase_D_Kuom               :
      constant Unicode_Char := 16#16906#;
   Bamum_Letter_Phase_D_Sap                :
      constant Unicode_Char := 16#16907#;
   Bamum_Letter_Phase_D_Mfeut              :
      constant Unicode_Char := 16#16908#;
   Bamum_Letter_Phase_D_Ndeux              :
      constant Unicode_Char := 16#16909#;
   Bamum_Letter_Phase_D_Maleeri            :
      constant Unicode_Char := 16#1690A#;
   Bamum_Letter_Phase_D_Meut               :
      constant Unicode_Char := 16#1690B#;
   Bamum_Letter_Phase_D_Seuaeq             :
      constant Unicode_Char := 16#1690C#;
   Bamum_Letter_Phase_D_Yen                :
      constant Unicode_Char := 16#1690D#;
   Bamum_Letter_Phase_D_Njeuaem            :
      constant Unicode_Char := 16#1690E#;
   Bamum_Letter_Phase_D_Keuot_Mbuae        :
      constant Unicode_Char := 16#1690F#;
   Bamum_Letter_Phase_D_Ngkeuri            :
      constant Unicode_Char := 16#16910#;
   Bamum_Letter_Phase_D_Tu                 :
      constant Unicode_Char := 16#16911#;
   Bamum_Letter_Phase_D_Ghaa               :
      constant Unicode_Char := 16#16912#;
   Bamum_Letter_Phase_D_Ngkyee             :
      constant Unicode_Char := 16#16913#;
   Bamum_Letter_Phase_D_Feufeuaet          :
      constant Unicode_Char := 16#16914#;
   Bamum_Letter_Phase_D_Ndee               :
      constant Unicode_Char := 16#16915#;
   Bamum_Letter_Phase_D_Mgbofum            :
      constant Unicode_Char := 16#16916#;
   Bamum_Letter_Phase_D_Leuaep             :
      constant Unicode_Char := 16#16917#;
   Bamum_Letter_Phase_D_Ndon               :
      constant Unicode_Char := 16#16918#;
   Bamum_Letter_Phase_D_Moni               :
      constant Unicode_Char := 16#16919#;
   Bamum_Letter_Phase_D_Mgbeun             :
      constant Unicode_Char := 16#1691A#;
   Bamum_Letter_Phase_D_Puut               :
      constant Unicode_Char := 16#1691B#;
   Bamum_Letter_Phase_D_Mgbiee             :
      constant Unicode_Char := 16#1691C#;
   Bamum_Letter_Phase_D_Mfo                :
      constant Unicode_Char := 16#1691D#;
   Bamum_Letter_Phase_D_Lum                :
      constant Unicode_Char := 16#1691E#;
   Bamum_Letter_Phase_D_Nsieep             :
      constant Unicode_Char := 16#1691F#;
   Bamum_Letter_Phase_D_Mbaa               :
      constant Unicode_Char := 16#16920#;
   Bamum_Letter_Phase_D_Kwaet              :
      constant Unicode_Char := 16#16921#;
   Bamum_Letter_Phase_D_Nyet               :
      constant Unicode_Char := 16#16922#;
   Bamum_Letter_Phase_D_Teuaen             :
      constant Unicode_Char := 16#16923#;
   Bamum_Letter_Phase_D_Sot                :
      constant Unicode_Char := 16#16924#;
   Bamum_Letter_Phase_D_Yuwoq              :
      constant Unicode_Char := 16#16925#;
   Bamum_Letter_Phase_D_Keum               :
      constant Unicode_Char := 16#16926#;
   Bamum_Letter_Phase_D_Raem               :
      constant Unicode_Char := 16#16927#;
   Bamum_Letter_Phase_D_Teeee              :
      constant Unicode_Char := 16#16928#;
   Bamum_Letter_Phase_D_Ngkeuaeq           :
      constant Unicode_Char := 16#16929#;
   Bamum_Letter_Phase_D_Mfeuae             :
      constant Unicode_Char := 16#1692A#;
   Bamum_Letter_Phase_D_Nsieet             :
      constant Unicode_Char := 16#1692B#;
   Bamum_Letter_Phase_D_Keup               :
      constant Unicode_Char := 16#1692C#;
   Bamum_Letter_Phase_D_Pip                :
      constant Unicode_Char := 16#1692D#;
   Bamum_Letter_Phase_D_Peutae             :
      constant Unicode_Char := 16#1692E#;
   Bamum_Letter_Phase_D_Nyue               :
      constant Unicode_Char := 16#1692F#;
   Bamum_Letter_Phase_D_Let                :
      constant Unicode_Char := 16#16930#;
   Bamum_Letter_Phase_D_Nggaam             :
      constant Unicode_Char := 16#16931#;
   Bamum_Letter_Phase_D_Mfiee              :
      constant Unicode_Char := 16#16932#;
   Bamum_Letter_Phase_D_Nggwaen            :
      constant Unicode_Char := 16#16933#;
   Bamum_Letter_Phase_D_Yuom               :
      constant Unicode_Char := 16#16934#;
   Bamum_Letter_Phase_D_Pap                :
      constant Unicode_Char := 16#16935#;
   Bamum_Letter_Phase_D_Yuop               :
      constant Unicode_Char := 16#16936#;
   Bamum_Letter_Phase_D_Ndam               :
      constant Unicode_Char := 16#16937#;
   Bamum_Letter_Phase_D_Nteum              :
      constant Unicode_Char := 16#16938#;
   Bamum_Letter_Phase_D_Suae               :
      constant Unicode_Char := 16#16939#;
   Bamum_Letter_Phase_D_Kun                :
      constant Unicode_Char := 16#1693A#;
   Bamum_Letter_Phase_D_Nggeux             :
      constant Unicode_Char := 16#1693B#;
   Bamum_Letter_Phase_D_Ngkiee             :
      constant Unicode_Char := 16#1693C#;
   Bamum_Letter_Phase_D_Tuot               :
      constant Unicode_Char := 16#1693D#;
   Bamum_Letter_Phase_D_Meun               :
      constant Unicode_Char := 16#1693E#;
   Bamum_Letter_Phase_D_Kuq                :
      constant Unicode_Char := 16#1693F#;
   Bamum_Letter_Phase_D_Nsum               :
      constant Unicode_Char := 16#16940#;
   Bamum_Letter_Phase_D_Teun               :
      constant Unicode_Char := 16#16941#;
   Bamum_Letter_Phase_D_Maenjet            :
      constant Unicode_Char := 16#16942#;
   Bamum_Letter_Phase_D_Nggap              :
      constant Unicode_Char := 16#16943#;
   Bamum_Letter_Phase_D_Leum               :
      constant Unicode_Char := 16#16944#;
   Bamum_Letter_Phase_D_Ngguom             :
      constant Unicode_Char := 16#16945#;
   Bamum_Letter_Phase_D_Nshut              :
      constant Unicode_Char := 16#16946#;
   Bamum_Letter_Phase_D_Njueq              :
      constant Unicode_Char := 16#16947#;
   Bamum_Letter_Phase_D_Gheuae             :
      constant Unicode_Char := 16#16948#;
   Bamum_Letter_Phase_D_Ku                 :
      constant Unicode_Char := 16#16949#;
   Bamum_Letter_Phase_D_Ren_Old            :
      constant Unicode_Char := 16#1694A#;
   Bamum_Letter_Phase_D_Tae                :
      constant Unicode_Char := 16#1694B#;
   Bamum_Letter_Phase_D_Toq                :
      constant Unicode_Char := 16#1694C#;
   Bamum_Letter_Phase_D_Nyi                :
      constant Unicode_Char := 16#1694D#;
   Bamum_Letter_Phase_D_Rii                :
      constant Unicode_Char := 16#1694E#;
   Bamum_Letter_Phase_D_Leeee              :
      constant Unicode_Char := 16#1694F#;
   Bamum_Letter_Phase_D_Meeee              :
      constant Unicode_Char := 16#16950#;
   Bamum_Letter_Phase_D_M                  :
      constant Unicode_Char := 16#16951#;
   Bamum_Letter_Phase_D_Suu                :
      constant Unicode_Char := 16#16952#;
   Bamum_Letter_Phase_D_Mu                 :
      constant Unicode_Char := 16#16953#;
   Bamum_Letter_Phase_D_Shii               :
      constant Unicode_Char := 16#16954#;
   Bamum_Letter_Phase_D_Sheux              :
      constant Unicode_Char := 16#16955#;
   Bamum_Letter_Phase_D_Kyee               :
      constant Unicode_Char := 16#16956#;
   Bamum_Letter_Phase_D_Nu                 :
      constant Unicode_Char := 16#16957#;
   Bamum_Letter_Phase_D_Shu                :
      constant Unicode_Char := 16#16958#;
   Bamum_Letter_Phase_D_Ntee               :
      constant Unicode_Char := 16#16959#;
   Bamum_Letter_Phase_D_Pee                :
      constant Unicode_Char := 16#1695A#;
   Bamum_Letter_Phase_D_Ni                 :
      constant Unicode_Char := 16#1695B#;
   Bamum_Letter_Phase_D_Shoq               :
      constant Unicode_Char := 16#1695C#;
   Bamum_Letter_Phase_D_Puq                :
      constant Unicode_Char := 16#1695D#;
   Bamum_Letter_Phase_D_Mvop               :
      constant Unicode_Char := 16#1695E#;
   Bamum_Letter_Phase_D_Loq                :
      constant Unicode_Char := 16#1695F#;
   Bamum_Letter_Phase_D_Ren_Much           :
      constant Unicode_Char := 16#16960#;
   Bamum_Letter_Phase_D_Ti                 :
      constant Unicode_Char := 16#16961#;
   Bamum_Letter_Phase_D_Ntuu               :
      constant Unicode_Char := 16#16962#;
   Bamum_Letter_Phase_D_Mbaa_Seven         :
      constant Unicode_Char := 16#16963#;
   Bamum_Letter_Phase_D_Saq                :
      constant Unicode_Char := 16#16964#;
   Bamum_Letter_Phase_D_Faa                :
      constant Unicode_Char := 16#16965#;
   Bamum_Letter_Phase_E_Ndap               :
      constant Unicode_Char := 16#16966#;
   Bamum_Letter_Phase_E_Toon               :
      constant Unicode_Char := 16#16967#;
   Bamum_Letter_Phase_E_Mbeum              :
      constant Unicode_Char := 16#16968#;
   Bamum_Letter_Phase_E_Lap                :
      constant Unicode_Char := 16#16969#;
   Bamum_Letter_Phase_E_Vom                :
      constant Unicode_Char := 16#1696A#;
   Bamum_Letter_Phase_E_Loon               :
      constant Unicode_Char := 16#1696B#;
   Bamum_Letter_Phase_E_Paa                :
      constant Unicode_Char := 16#1696C#;
   Bamum_Letter_Phase_E_Som                :
      constant Unicode_Char := 16#1696D#;
   Bamum_Letter_Phase_E_Raq                :
      constant Unicode_Char := 16#1696E#;
   Bamum_Letter_Phase_E_Nshuop             :
      constant Unicode_Char := 16#1696F#;
   Bamum_Letter_Phase_E_Ndun               :
      constant Unicode_Char := 16#16970#;
   Bamum_Letter_Phase_E_Puae               :
      constant Unicode_Char := 16#16971#;
   Bamum_Letter_Phase_E_Tam                :
      constant Unicode_Char := 16#16972#;
   Bamum_Letter_Phase_E_Ngka               :
      constant Unicode_Char := 16#16973#;
   Bamum_Letter_Phase_E_Kpeux              :
      constant Unicode_Char := 16#16974#;
   Bamum_Letter_Phase_E_Wuo                :
      constant Unicode_Char := 16#16975#;
   Bamum_Letter_Phase_E_See                :
      constant Unicode_Char := 16#16976#;
   Bamum_Letter_Phase_E_Nggeuaet           :
      constant Unicode_Char := 16#16977#;
   Bamum_Letter_Phase_E_Paam               :
      constant Unicode_Char := 16#16978#;
   Bamum_Letter_Phase_E_Too                :
      constant Unicode_Char := 16#16979#;
   Bamum_Letter_Phase_E_Kuop               :
      constant Unicode_Char := 16#1697A#;
   Bamum_Letter_Phase_E_Lom                :
      constant Unicode_Char := 16#1697B#;
   Bamum_Letter_Phase_E_Nshiee             :
      constant Unicode_Char := 16#1697C#;
   Bamum_Letter_Phase_E_Ngop               :
      constant Unicode_Char := 16#1697D#;
   Bamum_Letter_Phase_E_Maem               :
      constant Unicode_Char := 16#1697E#;
   Bamum_Letter_Phase_E_Ngkeux             :
      constant Unicode_Char := 16#1697F#;
   Bamum_Letter_Phase_E_Ngoq               :
      constant Unicode_Char := 16#16980#;
   Bamum_Letter_Phase_E_Nshue              :
      constant Unicode_Char := 16#16981#;
   Bamum_Letter_Phase_E_Rimgba             :
      constant Unicode_Char := 16#16982#;
   Bamum_Letter_Phase_E_Njeux              :
      constant Unicode_Char := 16#16983#;
   Bamum_Letter_Phase_E_Peem               :
      constant Unicode_Char := 16#16984#;
   Bamum_Letter_Phase_E_Saa                :
      constant Unicode_Char := 16#16985#;
   Bamum_Letter_Phase_E_Nggurae            :
      constant Unicode_Char := 16#16986#;
   Bamum_Letter_Phase_E_Mgba               :
      constant Unicode_Char := 16#16987#;
   Bamum_Letter_Phase_E_Gheux              :
      constant Unicode_Char := 16#16988#;
   Bamum_Letter_Phase_E_Ngkeuaem           :
      constant Unicode_Char := 16#16989#;
   Bamum_Letter_Phase_E_Njaemli            :
      constant Unicode_Char := 16#1698A#;
   Bamum_Letter_Phase_E_Map                :
      constant Unicode_Char := 16#1698B#;
   Bamum_Letter_Phase_E_Loot               :
      constant Unicode_Char := 16#1698C#;
   Bamum_Letter_Phase_E_Nggeeee            :
      constant Unicode_Char := 16#1698D#;
   Bamum_Letter_Phase_E_Ndiq               :
      constant Unicode_Char := 16#1698E#;
   Bamum_Letter_Phase_E_Taen_Nteum         :
      constant Unicode_Char := 16#1698F#;
   Bamum_Letter_Phase_E_Set                :
      constant Unicode_Char := 16#16990#;
   Bamum_Letter_Phase_E_Pum                :
      constant Unicode_Char := 16#16991#;
   Bamum_Letter_Phase_E_Ndaa_Softness      :
      constant Unicode_Char := 16#16992#;
   Bamum_Letter_Phase_E_Ngguaeshae_Nyam    :
      constant Unicode_Char := 16#16993#;
   Bamum_Letter_Phase_E_Yiee               :
      constant Unicode_Char := 16#16994#;
   Bamum_Letter_Phase_E_Gheun              :
      constant Unicode_Char := 16#16995#;
   Bamum_Letter_Phase_E_Tuae               :
      constant Unicode_Char := 16#16996#;
   Bamum_Letter_Phase_E_Yeuae              :
      constant Unicode_Char := 16#16997#;
   Bamum_Letter_Phase_E_Po                 :
      constant Unicode_Char := 16#16998#;
   Bamum_Letter_Phase_E_Tumae              :
      constant Unicode_Char := 16#16999#;
   Bamum_Letter_Phase_E_Keuae              :
      constant Unicode_Char := 16#1699A#;
   Bamum_Letter_Phase_E_Suaen              :
      constant Unicode_Char := 16#1699B#;
   Bamum_Letter_Phase_E_Teuaeq             :
      constant Unicode_Char := 16#1699C#;
   Bamum_Letter_Phase_E_Veuae              :
      constant Unicode_Char := 16#1699D#;
   Bamum_Letter_Phase_E_Weux               :
      constant Unicode_Char := 16#1699E#;
   Bamum_Letter_Phase_E_Laam               :
      constant Unicode_Char := 16#1699F#;
   Bamum_Letter_Phase_E_Pu                 :
      constant Unicode_Char := 16#169A0#;
   Bamum_Letter_Phase_E_Taaq               :
      constant Unicode_Char := 16#169A1#;
   Bamum_Letter_Phase_E_Ghaamae            :
      constant Unicode_Char := 16#169A2#;
   Bamum_Letter_Phase_E_Ngeureut           :
      constant Unicode_Char := 16#169A3#;
   Bamum_Letter_Phase_E_Sheuaeq            :
      constant Unicode_Char := 16#169A4#;
   Bamum_Letter_Phase_E_Mgben              :
      constant Unicode_Char := 16#169A5#;
   Bamum_Letter_Phase_E_Mbee               :
      constant Unicode_Char := 16#169A6#;
   Bamum_Letter_Phase_E_Nzaq               :
      constant Unicode_Char := 16#169A7#;
   Bamum_Letter_Phase_E_Nkom               :
      constant Unicode_Char := 16#169A8#;
   Bamum_Letter_Phase_E_Gbet               :
      constant Unicode_Char := 16#169A9#;
   Bamum_Letter_Phase_E_Tum                :
      constant Unicode_Char := 16#169AA#;
   Bamum_Letter_Phase_E_Kuet               :
      constant Unicode_Char := 16#169AB#;
   Bamum_Letter_Phase_E_Yap                :
      constant Unicode_Char := 16#169AC#;
   Bamum_Letter_Phase_E_Nyi_Cleaver        :
      constant Unicode_Char := 16#169AD#;
   Bamum_Letter_Phase_E_Yit                :
      constant Unicode_Char := 16#169AE#;
   Bamum_Letter_Phase_E_Mfeuq              :
      constant Unicode_Char := 16#169AF#;
   Bamum_Letter_Phase_E_Ndiaq              :
      constant Unicode_Char := 16#169B0#;
   Bamum_Letter_Phase_E_Pieeq              :
      constant Unicode_Char := 16#169B1#;
   Bamum_Letter_Phase_E_Yueq               :
      constant Unicode_Char := 16#169B2#;
   Bamum_Letter_Phase_E_Leuaem             :
      constant Unicode_Char := 16#169B3#;
   Bamum_Letter_Phase_E_Fue                :
      constant Unicode_Char := 16#169B4#;
   Bamum_Letter_Phase_E_Gbeux              :
      constant Unicode_Char := 16#169B5#;
   Bamum_Letter_Phase_E_Ngkup              :
      constant Unicode_Char := 16#169B6#;
   Bamum_Letter_Phase_E_Ket                :
      constant Unicode_Char := 16#169B7#;
   Bamum_Letter_Phase_E_Mae                :
      constant Unicode_Char := 16#169B8#;
   Bamum_Letter_Phase_E_Ngkaami            :
      constant Unicode_Char := 16#169B9#;
   Bamum_Letter_Phase_E_Ghet               :
      constant Unicode_Char := 16#169BA#;
   Bamum_Letter_Phase_E_Fa                 :
      constant Unicode_Char := 16#169BB#;
   Bamum_Letter_Phase_E_Ntum               :
      constant Unicode_Char := 16#169BC#;
   Bamum_Letter_Phase_E_Peut               :
      constant Unicode_Char := 16#169BD#;
   Bamum_Letter_Phase_E_Yeum               :
      constant Unicode_Char := 16#169BE#;
   Bamum_Letter_Phase_E_Nggeuae            :
      constant Unicode_Char := 16#169BF#;
   Bamum_Letter_Phase_E_Nyi_Between        :
      constant Unicode_Char := 16#169C0#;
   Bamum_Letter_Phase_E_Nzuq               :
      constant Unicode_Char := 16#169C1#;
   Bamum_Letter_Phase_E_Poon               :
      constant Unicode_Char := 16#169C2#;
   Bamum_Letter_Phase_E_Miee               :
      constant Unicode_Char := 16#169C3#;
   Bamum_Letter_Phase_E_Fuet               :
      constant Unicode_Char := 16#169C4#;
   Bamum_Letter_Phase_E_Nae                :
      constant Unicode_Char := 16#169C5#;
   Bamum_Letter_Phase_E_Muae               :
      constant Unicode_Char := 16#169C6#;
   Bamum_Letter_Phase_E_Gheuae             :
      constant Unicode_Char := 16#169C7#;
   Bamum_Letter_Phase_E_Fu_I               :
      constant Unicode_Char := 16#169C8#;
   Bamum_Letter_Phase_E_Mvi                :
      constant Unicode_Char := 16#169C9#;
   Bamum_Letter_Phase_E_Puaq               :
      constant Unicode_Char := 16#169CA#;
   Bamum_Letter_Phase_E_Ngkum              :
      constant Unicode_Char := 16#169CB#;
   Bamum_Letter_Phase_E_Kut                :
      constant Unicode_Char := 16#169CC#;
   Bamum_Letter_Phase_E_Piet               :
      constant Unicode_Char := 16#169CD#;
   Bamum_Letter_Phase_E_Ntap               :
      constant Unicode_Char := 16#169CE#;
   Bamum_Letter_Phase_E_Yeuaet             :
      constant Unicode_Char := 16#169CF#;
   Bamum_Letter_Phase_E_Nggup              :
      constant Unicode_Char := 16#169D0#;
   Bamum_Letter_Phase_E_Pa_People          :
      constant Unicode_Char := 16#169D1#;
   Bamum_Letter_Phase_E_Fu_Call            :
      constant Unicode_Char := 16#169D2#;
   Bamum_Letter_Phase_E_Fom                :
      constant Unicode_Char := 16#169D3#;
   Bamum_Letter_Phase_E_Njee               :
      constant Unicode_Char := 16#169D4#;
   Bamum_Letter_Phase_E_A                  :
      constant Unicode_Char := 16#169D5#;
   Bamum_Letter_Phase_E_Toq                :
      constant Unicode_Char := 16#169D6#;
   Bamum_Letter_Phase_E_O                  :
      constant Unicode_Char := 16#169D7#;
   Bamum_Letter_Phase_E_I                  :
      constant Unicode_Char := 16#169D8#;
   Bamum_Letter_Phase_E_Laq                :
      constant Unicode_Char := 16#169D9#;
   Bamum_Letter_Phase_E_Pa_Plural          :
      constant Unicode_Char := 16#169DA#;
   Bamum_Letter_Phase_E_Taa                :
      constant Unicode_Char := 16#169DB#;
   Bamum_Letter_Phase_E_Taq                :
      constant Unicode_Char := 16#169DC#;
   Bamum_Letter_Phase_E_Ndaa_My_House      :
      constant Unicode_Char := 16#169DD#;
   Bamum_Letter_Phase_E_Shiq               :
      constant Unicode_Char := 16#169DE#;
   Bamum_Letter_Phase_E_Yeux               :
      constant Unicode_Char := 16#169DF#;
   Bamum_Letter_Phase_E_Nguae              :
      constant Unicode_Char := 16#169E0#;
   Bamum_Letter_Phase_E_Yuaen              :
      constant Unicode_Char := 16#169E1#;
   Bamum_Letter_Phase_E_Yoq_Swimming       :
      constant Unicode_Char := 16#169E2#;
   Bamum_Letter_Phase_E_Yoq_Cover          :
      constant Unicode_Char := 16#169E3#;
   Bamum_Letter_Phase_E_Yuq                :
      constant Unicode_Char := 16#169E4#;
   Bamum_Letter_Phase_E_Yun                :
      constant Unicode_Char := 16#169E5#;
   Bamum_Letter_Phase_E_Keux               :
      constant Unicode_Char := 16#169E6#;
   Bamum_Letter_Phase_E_Peux               :
      constant Unicode_Char := 16#169E7#;
   Bamum_Letter_Phase_E_Njee_Epoch         :
      constant Unicode_Char := 16#169E8#;
   Bamum_Letter_Phase_E_Pue                :
      constant Unicode_Char := 16#169E9#;
   Bamum_Letter_Phase_E_Wue                :
      constant Unicode_Char := 16#169EA#;
   Bamum_Letter_Phase_E_Fee                :
      constant Unicode_Char := 16#169EB#;
   Bamum_Letter_Phase_E_Vee                :
      constant Unicode_Char := 16#169EC#;
   Bamum_Letter_Phase_E_Lu                 :
      constant Unicode_Char := 16#169ED#;
   Bamum_Letter_Phase_E_Mi                 :
      constant Unicode_Char := 16#169EE#;
   Bamum_Letter_Phase_E_Reux               :
      constant Unicode_Char := 16#169EF#;
   Bamum_Letter_Phase_E_Rae                :
      constant Unicode_Char := 16#169F0#;
   Bamum_Letter_Phase_E_Nguaet             :
      constant Unicode_Char := 16#169F1#;
   Bamum_Letter_Phase_E_Nga                :
      constant Unicode_Char := 16#169F2#;
   Bamum_Letter_Phase_E_Sho                :
      constant Unicode_Char := 16#169F3#;
   Bamum_Letter_Phase_E_Shoq               :
      constant Unicode_Char := 16#169F4#;
   Bamum_Letter_Phase_E_Fu_Remedy          :
      constant Unicode_Char := 16#169F5#;
   Bamum_Letter_Phase_E_Na                 :
      constant Unicode_Char := 16#169F6#;
   Bamum_Letter_Phase_E_Pi                 :
      constant Unicode_Char := 16#169F7#;
   Bamum_Letter_Phase_E_Loq                :
      constant Unicode_Char := 16#169F8#;
   Bamum_Letter_Phase_E_Ko                 :
      constant Unicode_Char := 16#169F9#;
   Bamum_Letter_Phase_E_Men                :
      constant Unicode_Char := 16#169FA#;
   Bamum_Letter_Phase_E_Ma                 :
      constant Unicode_Char := 16#169FB#;
   Bamum_Letter_Phase_E_Maq                :
      constant Unicode_Char := 16#169FC#;
   Bamum_Letter_Phase_E_Teu                :
      constant Unicode_Char := 16#169FD#;
   Bamum_Letter_Phase_E_Ki                 :
      constant Unicode_Char := 16#169FE#;
   Bamum_Letter_Phase_E_Mon                :
      constant Unicode_Char := 16#169FF#;
   Bamum_Letter_Phase_E_Ten                :
      constant Unicode_Char := 16#16A00#;
   Bamum_Letter_Phase_E_Faq                :
      constant Unicode_Char := 16#16A01#;
   Bamum_Letter_Phase_E_Ghom               :
      constant Unicode_Char := 16#16A02#;
   Bamum_Letter_Phase_F_Ka                 :
      constant Unicode_Char := 16#16A03#;
   Bamum_Letter_Phase_F_U                  :
      constant Unicode_Char := 16#16A04#;
   Bamum_Letter_Phase_F_Ku                 :
      constant Unicode_Char := 16#16A05#;
   Bamum_Letter_Phase_F_Ee                 :
      constant Unicode_Char := 16#16A06#;
   Bamum_Letter_Phase_F_Ree                :
      constant Unicode_Char := 16#16A07#;
   Bamum_Letter_Phase_F_Tae                :
      constant Unicode_Char := 16#16A08#;
   Bamum_Letter_Phase_F_Nyi                :
      constant Unicode_Char := 16#16A09#;
   Bamum_Letter_Phase_F_La                 :
      constant Unicode_Char := 16#16A0A#;
   Bamum_Letter_Phase_F_Rii                :
      constant Unicode_Char := 16#16A0B#;
   Bamum_Letter_Phase_F_Riee               :
      constant Unicode_Char := 16#16A0C#;
   Bamum_Letter_Phase_F_Meeee              :
      constant Unicode_Char := 16#16A0D#;
   Bamum_Letter_Phase_F_Taa                :
      constant Unicode_Char := 16#16A0E#;
   Bamum_Letter_Phase_F_Ndaa               :
      constant Unicode_Char := 16#16A0F#;
   Bamum_Letter_Phase_F_Njaem              :
      constant Unicode_Char := 16#16A10#;
   Bamum_Letter_Phase_F_M                  :
      constant Unicode_Char := 16#16A11#;
   Bamum_Letter_Phase_F_Suu                :
      constant Unicode_Char := 16#16A12#;
   Bamum_Letter_Phase_F_Shii               :
      constant Unicode_Char := 16#16A13#;
   Bamum_Letter_Phase_F_Si                 :
      constant Unicode_Char := 16#16A14#;
   Bamum_Letter_Phase_F_Seux               :
      constant Unicode_Char := 16#16A15#;
   Bamum_Letter_Phase_F_Kyee               :
      constant Unicode_Char := 16#16A16#;
   Bamum_Letter_Phase_F_Ket                :
      constant Unicode_Char := 16#16A17#;
   Bamum_Letter_Phase_F_Nuae               :
      constant Unicode_Char := 16#16A18#;
   Bamum_Letter_Phase_F_Nu                 :
      constant Unicode_Char := 16#16A19#;
   Bamum_Letter_Phase_F_Njuae              :
      constant Unicode_Char := 16#16A1A#;
   Bamum_Letter_Phase_F_Yoq                :
      constant Unicode_Char := 16#16A1B#;
   Bamum_Letter_Phase_F_Shu                :
      constant Unicode_Char := 16#16A1C#;
   Bamum_Letter_Phase_F_Ya                 :
      constant Unicode_Char := 16#16A1D#;
   Bamum_Letter_Phase_F_Nsha               :
      constant Unicode_Char := 16#16A1E#;
   Bamum_Letter_Phase_F_Peux               :
      constant Unicode_Char := 16#16A1F#;
   Bamum_Letter_Phase_F_Ntee               :
      constant Unicode_Char := 16#16A20#;
   Bamum_Letter_Phase_F_Wue                :
      constant Unicode_Char := 16#16A21#;
   Bamum_Letter_Phase_F_Pee                :
      constant Unicode_Char := 16#16A22#;
   Bamum_Letter_Phase_F_Ru                 :
      constant Unicode_Char := 16#16A23#;
   Bamum_Letter_Phase_F_Ni                 :
      constant Unicode_Char := 16#16A24#;
   Bamum_Letter_Phase_F_Reux               :
      constant Unicode_Char := 16#16A25#;
   Bamum_Letter_Phase_F_Ken                :
      constant Unicode_Char := 16#16A26#;
   Bamum_Letter_Phase_F_Ngkwaen            :
      constant Unicode_Char := 16#16A27#;
   Bamum_Letter_Phase_F_Ngga               :
      constant Unicode_Char := 16#16A28#;
   Bamum_Letter_Phase_F_Sho                :
      constant Unicode_Char := 16#16A29#;
   Bamum_Letter_Phase_F_Puae               :
      constant Unicode_Char := 16#16A2A#;
   Bamum_Letter_Phase_F_Fom                :
      constant Unicode_Char := 16#16A2B#;
   Bamum_Letter_Phase_F_Wa                 :
      constant Unicode_Char := 16#16A2C#;
   Bamum_Letter_Phase_F_Li                 :
      constant Unicode_Char := 16#16A2D#;
   Bamum_Letter_Phase_F_Loq                :
      constant Unicode_Char := 16#16A2E#;
   Bamum_Letter_Phase_F_Ko                 :
      constant Unicode_Char := 16#16A2F#;
   Bamum_Letter_Phase_F_Mben               :
      constant Unicode_Char := 16#16A30#;
   Bamum_Letter_Phase_F_Ren                :
      constant Unicode_Char := 16#16A31#;
   Bamum_Letter_Phase_F_Ma                 :
      constant Unicode_Char := 16#16A32#;
   Bamum_Letter_Phase_F_Mo                 :
      constant Unicode_Char := 16#16A33#;
   Bamum_Letter_Phase_F_Mbaa               :
      constant Unicode_Char := 16#16A34#;
   Bamum_Letter_Phase_F_Tet                :
      constant Unicode_Char := 16#16A35#;
   Bamum_Letter_Phase_F_Kpa                :
      constant Unicode_Char := 16#16A36#;
   Bamum_Letter_Phase_F_Samba              :
      constant Unicode_Char := 16#16A37#;
   Bamum_Letter_Phase_F_Vueq               :
      constant Unicode_Char := 16#16A38#;
end Unicode.Names.Bamum_Supplement;
