--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cyrillic_Supplement is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cyrillic_Capital_Letter_Komi_De         : constant Unicode_Char := 16#0500#;
   Cyrillic_Small_Letter_Komi_De           : constant Unicode_Char := 16#0501#;
   Cyrillic_Capital_Letter_Komi_Dje        : constant Unicode_Char := 16#0502#;
   Cyrillic_Small_Letter_Komi_Dje          : constant Unicode_Char := 16#0503#;
   Cyrillic_Capital_Letter_Komi_Zje        : constant Unicode_Char := 16#0504#;
   Cyrillic_Small_Letter_Komi_Zje          : constant Unicode_Char := 16#0505#;
   Cyrillic_Capital_Letter_Komi_Dzje       : constant Unicode_Char := 16#0506#;
   Cyrillic_Small_Letter_Komi_Dzje         : constant Unicode_Char := 16#0507#;
   Cyrillic_Capital_Letter_Komi_Lje        : constant Unicode_Char := 16#0508#;
   Cyrillic_Small_Letter_Komi_Lje          : constant Unicode_Char := 16#0509#;
   Cyrillic_Capital_Letter_Komi_Nje        : constant Unicode_Char := 16#050A#;
   Cyrillic_Small_Letter_Komi_Nje          : constant Unicode_Char := 16#050B#;
   Cyrillic_Capital_Letter_Komi_Sje        : constant Unicode_Char := 16#050C#;
   Cyrillic_Small_Letter_Komi_Sje          : constant Unicode_Char := 16#050D#;
   Cyrillic_Capital_Letter_Komi_Tje        : constant Unicode_Char := 16#050E#;
   Cyrillic_Small_Letter_Komi_Tje          : constant Unicode_Char := 16#050F#;
   Cyrillic_Capital_Letter_Reversed_Ze     : constant Unicode_Char := 16#0510#;
   Cyrillic_Small_Letter_Reversed_Ze       : constant Unicode_Char := 16#0511#;
   Cyrillic_Capital_Letter_El_With_Hook    : constant Unicode_Char := 16#0512#;
   Cyrillic_Small_Letter_El_With_Hook      : constant Unicode_Char := 16#0513#;
   Cyrillic_Capital_Letter_Lha             : constant Unicode_Char := 16#0514#;
   Cyrillic_Small_Letter_Lha               : constant Unicode_Char := 16#0515#;
   Cyrillic_Capital_Letter_Rha             : constant Unicode_Char := 16#0516#;
   Cyrillic_Small_Letter_Rha               : constant Unicode_Char := 16#0517#;
   Cyrillic_Capital_Letter_Yae             : constant Unicode_Char := 16#0518#;
   Cyrillic_Small_Letter_Yae               : constant Unicode_Char := 16#0519#;
   Cyrillic_Capital_Letter_Qa              : constant Unicode_Char := 16#051A#;
   Cyrillic_Small_Letter_Qa                : constant Unicode_Char := 16#051B#;
   Cyrillic_Capital_Letter_We              : constant Unicode_Char := 16#051C#;
   Cyrillic_Small_Letter_We                : constant Unicode_Char := 16#051D#;
   Cyrillic_Capital_Letter_Aleut_Ka        : constant Unicode_Char := 16#051E#;
   Cyrillic_Small_Letter_Aleut_Ka          : constant Unicode_Char := 16#051F#;
   Cyrillic_Capital_Letter_El_With_Middle_Hook :
      constant Unicode_Char := 16#0520#;
   Cyrillic_Small_Letter_El_With_Middle_Hook :
      constant Unicode_Char := 16#0521#;
   Cyrillic_Capital_Letter_En_With_Middle_Hook :
      constant Unicode_Char := 16#0522#;
   Cyrillic_Small_Letter_En_With_Middle_Hook :
      constant Unicode_Char := 16#0523#;
   Cyrillic_Capital_Letter_Pe_With_Descender :
      constant Unicode_Char := 16#0524#;
   Cyrillic_Small_Letter_Pe_With_Descender : constant Unicode_Char := 16#0525#;
   Cyrillic_Capital_Letter_Shha_With_Descender :
      constant Unicode_Char := 16#0526#;
   Cyrillic_Small_Letter_Shha_With_Descender :
      constant Unicode_Char := 16#0527#;
   Cyrillic_Capital_Letter_En_With_Left_Hook :
      constant Unicode_Char := 16#0528#;
   Cyrillic_Small_Letter_En_With_Left_Hook : constant Unicode_Char := 16#0529#;
   Cyrillic_Capital_Letter_Dzzhe           : constant Unicode_Char := 16#052A#;
   Cyrillic_Small_Letter_Dzzhe             : constant Unicode_Char := 16#052B#;
   Cyrillic_Capital_Letter_Dche            : constant Unicode_Char := 16#052C#;
   Cyrillic_Small_Letter_Dche              : constant Unicode_Char := 16#052D#;
   Cyrillic_Capital_Letter_El_With_Descender :
      constant Unicode_Char := 16#052E#;
   Cyrillic_Small_Letter_El_With_Descender : constant Unicode_Char := 16#052F#;
end Unicode.Names.Cyrillic_Supplement;
