--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Hangul_Jamo is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Hangul_Choseong_Kiyeok                  : constant Unicode_Char := 16#1100#;
   Hangul_Choseong_Ssangkiyeok             : constant Unicode_Char := 16#1101#;
   Hangul_Choseong_Nieun                   : constant Unicode_Char := 16#1102#;
   Hangul_Choseong_Tikeut                  : constant Unicode_Char := 16#1103#;
   Hangul_Choseong_Ssangtikeut             : constant Unicode_Char := 16#1104#;
   Hangul_Choseong_Rieul                   : constant Unicode_Char := 16#1105#;
   Hangul_Choseong_Mieum                   : constant Unicode_Char := 16#1106#;
   Hangul_Choseong_Pieup                   : constant Unicode_Char := 16#1107#;
   Hangul_Choseong_Ssangpieup              : constant Unicode_Char := 16#1108#;
   Hangul_Choseong_Sios                    : constant Unicode_Char := 16#1109#;
   Hangul_Choseong_Ssangsios               : constant Unicode_Char := 16#110A#;
   Hangul_Choseong_Ieung                   : constant Unicode_Char := 16#110B#;
   Hangul_Choseong_Cieuc                   : constant Unicode_Char := 16#110C#;
   Hangul_Choseong_Ssangcieuc              : constant Unicode_Char := 16#110D#;
   Hangul_Choseong_Chieuch                 : constant Unicode_Char := 16#110E#;
   Hangul_Choseong_Khieukh                 : constant Unicode_Char := 16#110F#;
   Hangul_Choseong_Thieuth                 : constant Unicode_Char := 16#1110#;
   Hangul_Choseong_Phieuph                 : constant Unicode_Char := 16#1111#;
   Hangul_Choseong_Hieuh                   : constant Unicode_Char := 16#1112#;
   Hangul_Choseong_Nieun_Kiyeok            : constant Unicode_Char := 16#1113#;
   Hangul_Choseong_Ssangnieun              : constant Unicode_Char := 16#1114#;
   Hangul_Choseong_Nieun_Tikeut            : constant Unicode_Char := 16#1115#;
   Hangul_Choseong_Nieun_Pieup             : constant Unicode_Char := 16#1116#;
   Hangul_Choseong_Tikeut_Kiyeok           : constant Unicode_Char := 16#1117#;
   Hangul_Choseong_Rieul_Nieun             : constant Unicode_Char := 16#1118#;
   Hangul_Choseong_Ssangrieul              : constant Unicode_Char := 16#1119#;
   Hangul_Choseong_Rieul_Hieuh             : constant Unicode_Char := 16#111A#;
   Hangul_Choseong_Kapyeounrieul           : constant Unicode_Char := 16#111B#;
   Hangul_Choseong_Mieum_Pieup             : constant Unicode_Char := 16#111C#;
   Hangul_Choseong_Kapyeounmieum           : constant Unicode_Char := 16#111D#;
   Hangul_Choseong_Pieup_Kiyeok            : constant Unicode_Char := 16#111E#;
   Hangul_Choseong_Pieup_Nieun             : constant Unicode_Char := 16#111F#;
   Hangul_Choseong_Pieup_Tikeut            : constant Unicode_Char := 16#1120#;
   Hangul_Choseong_Pieup_Sios              : constant Unicode_Char := 16#1121#;
   Hangul_Choseong_Pieup_Sios_Kiyeok       : constant Unicode_Char := 16#1122#;
   Hangul_Choseong_Pieup_Sios_Tikeut       : constant Unicode_Char := 16#1123#;
   Hangul_Choseong_Pieup_Sios_Pieup        : constant Unicode_Char := 16#1124#;
   Hangul_Choseong_Pieup_Ssangsios         : constant Unicode_Char := 16#1125#;
   Hangul_Choseong_Pieup_Sios_Cieuc        : constant Unicode_Char := 16#1126#;
   Hangul_Choseong_Pieup_Cieuc             : constant Unicode_Char := 16#1127#;
   Hangul_Choseong_Pieup_Chieuch           : constant Unicode_Char := 16#1128#;
   Hangul_Choseong_Pieup_Thieuth           : constant Unicode_Char := 16#1129#;
   Hangul_Choseong_Pieup_Phieuph           : constant Unicode_Char := 16#112A#;
   Hangul_Choseong_Kapyeounpieup           : constant Unicode_Char := 16#112B#;
   Hangul_Choseong_Kapyeounssangpieup      : constant Unicode_Char := 16#112C#;
   Hangul_Choseong_Sios_Kiyeok             : constant Unicode_Char := 16#112D#;
   Hangul_Choseong_Sios_Nieun              : constant Unicode_Char := 16#112E#;
   Hangul_Choseong_Sios_Tikeut             : constant Unicode_Char := 16#112F#;
   Hangul_Choseong_Sios_Rieul              : constant Unicode_Char := 16#1130#;
   Hangul_Choseong_Sios_Mieum              : constant Unicode_Char := 16#1131#;
   Hangul_Choseong_Sios_Pieup              : constant Unicode_Char := 16#1132#;
   Hangul_Choseong_Sios_Pieup_Kiyeok       : constant Unicode_Char := 16#1133#;
   Hangul_Choseong_Sios_Ssangsios          : constant Unicode_Char := 16#1134#;
   Hangul_Choseong_Sios_Ieung              : constant Unicode_Char := 16#1135#;
   Hangul_Choseong_Sios_Cieuc              : constant Unicode_Char := 16#1136#;
   Hangul_Choseong_Sios_Chieuch            : constant Unicode_Char := 16#1137#;
   Hangul_Choseong_Sios_Khieukh            : constant Unicode_Char := 16#1138#;
   Hangul_Choseong_Sios_Thieuth            : constant Unicode_Char := 16#1139#;
   Hangul_Choseong_Sios_Phieuph            : constant Unicode_Char := 16#113A#;
   Hangul_Choseong_Sios_Hieuh              : constant Unicode_Char := 16#113B#;
   Hangul_Choseong_Chitueumsios            : constant Unicode_Char := 16#113C#;
   Hangul_Choseong_Chitueumssangsios       : constant Unicode_Char := 16#113D#;
   Hangul_Choseong_Ceongchieumsios         : constant Unicode_Char := 16#113E#;
   Hangul_Choseong_Ceongchieumssangsios    : constant Unicode_Char := 16#113F#;
   Hangul_Choseong_Pansios                 : constant Unicode_Char := 16#1140#;
   Hangul_Choseong_Ieung_Kiyeok            : constant Unicode_Char := 16#1141#;
   Hangul_Choseong_Ieung_Tikeut            : constant Unicode_Char := 16#1142#;
   Hangul_Choseong_Ieung_Mieum             : constant Unicode_Char := 16#1143#;
   Hangul_Choseong_Ieung_Pieup             : constant Unicode_Char := 16#1144#;
   Hangul_Choseong_Ieung_Sios              : constant Unicode_Char := 16#1145#;
   Hangul_Choseong_Ieung_Pansios           : constant Unicode_Char := 16#1146#;
   Hangul_Choseong_Ssangieung              : constant Unicode_Char := 16#1147#;
   Hangul_Choseong_Ieung_Cieuc             : constant Unicode_Char := 16#1148#;
   Hangul_Choseong_Ieung_Chieuch           : constant Unicode_Char := 16#1149#;
   Hangul_Choseong_Ieung_Thieuth           : constant Unicode_Char := 16#114A#;
   Hangul_Choseong_Ieung_Phieuph           : constant Unicode_Char := 16#114B#;
   Hangul_Choseong_Yesieung                : constant Unicode_Char := 16#114C#;
   Hangul_Choseong_Cieuc_Ieung             : constant Unicode_Char := 16#114D#;
   Hangul_Choseong_Chitueumcieuc           : constant Unicode_Char := 16#114E#;
   Hangul_Choseong_Chitueumssangcieuc      : constant Unicode_Char := 16#114F#;
   Hangul_Choseong_Ceongchieumcieuc        : constant Unicode_Char := 16#1150#;
   Hangul_Choseong_Ceongchieumssangcieuc   : constant Unicode_Char := 16#1151#;
   Hangul_Choseong_Chieuch_Khieukh         : constant Unicode_Char := 16#1152#;
   Hangul_Choseong_Chieuch_Hieuh           : constant Unicode_Char := 16#1153#;
   Hangul_Choseong_Chitueumchieuch         : constant Unicode_Char := 16#1154#;
   Hangul_Choseong_Ceongchieumchieuch      : constant Unicode_Char := 16#1155#;
   Hangul_Choseong_Phieuph_Pieup           : constant Unicode_Char := 16#1156#;
   Hangul_Choseong_Kapyeounphieuph         : constant Unicode_Char := 16#1157#;
   Hangul_Choseong_Ssanghieuh              : constant Unicode_Char := 16#1158#;
   Hangul_Choseong_Yeorinhieuh             : constant Unicode_Char := 16#1159#;
   Hangul_Choseong_Kiyeok_Tikeut           : constant Unicode_Char := 16#115A#;
   Hangul_Choseong_Nieun_Sios              : constant Unicode_Char := 16#115B#;
   Hangul_Choseong_Nieun_Cieuc             : constant Unicode_Char := 16#115C#;
   Hangul_Choseong_Nieun_Hieuh             : constant Unicode_Char := 16#115D#;
   Hangul_Choseong_Tikeut_Rieul            : constant Unicode_Char := 16#115E#;
   Hangul_Choseong_Filler                  : constant Unicode_Char := 16#115F#;
   Hangul_Jungseong_Filler                 : constant Unicode_Char := 16#1160#;
   Hangul_Jungseong_A                      : constant Unicode_Char := 16#1161#;
   Hangul_Jungseong_Ae                     : constant Unicode_Char := 16#1162#;
   Hangul_Jungseong_Ya                     : constant Unicode_Char := 16#1163#;
   Hangul_Jungseong_Yae                    : constant Unicode_Char := 16#1164#;
   Hangul_Jungseong_Eo                     : constant Unicode_Char := 16#1165#;
   Hangul_Jungseong_E                      : constant Unicode_Char := 16#1166#;
   Hangul_Jungseong_Yeo                    : constant Unicode_Char := 16#1167#;
   Hangul_Jungseong_Ye                     : constant Unicode_Char := 16#1168#;
   Hangul_Jungseong_O                      : constant Unicode_Char := 16#1169#;
   Hangul_Jungseong_Wa                     : constant Unicode_Char := 16#116A#;
   Hangul_Jungseong_Wae                    : constant Unicode_Char := 16#116B#;
   Hangul_Jungseong_Oe                     : constant Unicode_Char := 16#116C#;
   Hangul_Jungseong_Yo                     : constant Unicode_Char := 16#116D#;
   Hangul_Jungseong_U                      : constant Unicode_Char := 16#116E#;
   Hangul_Jungseong_Weo                    : constant Unicode_Char := 16#116F#;
   Hangul_Jungseong_We                     : constant Unicode_Char := 16#1170#;
   Hangul_Jungseong_Wi                     : constant Unicode_Char := 16#1171#;
   Hangul_Jungseong_Yu                     : constant Unicode_Char := 16#1172#;
   Hangul_Jungseong_Eu                     : constant Unicode_Char := 16#1173#;
   Hangul_Jungseong_Yi                     : constant Unicode_Char := 16#1174#;
   Hangul_Jungseong_I                      : constant Unicode_Char := 16#1175#;
   Hangul_Jungseong_A_O                    : constant Unicode_Char := 16#1176#;
   Hangul_Jungseong_A_U                    : constant Unicode_Char := 16#1177#;
   Hangul_Jungseong_Ya_O                   : constant Unicode_Char := 16#1178#;
   Hangul_Jungseong_Ya_Yo                  : constant Unicode_Char := 16#1179#;
   Hangul_Jungseong_Eo_O                   : constant Unicode_Char := 16#117A#;
   Hangul_Jungseong_Eo_U                   : constant Unicode_Char := 16#117B#;
   Hangul_Jungseong_Eo_Eu                  : constant Unicode_Char := 16#117C#;
   Hangul_Jungseong_Yeo_O                  : constant Unicode_Char := 16#117D#;
   Hangul_Jungseong_Yeo_U                  : constant Unicode_Char := 16#117E#;
   Hangul_Jungseong_O_Eo                   : constant Unicode_Char := 16#117F#;
   Hangul_Jungseong_O_E                    : constant Unicode_Char := 16#1180#;
   Hangul_Jungseong_O_Ye                   : constant Unicode_Char := 16#1181#;
   Hangul_Jungseong_O_O                    : constant Unicode_Char := 16#1182#;
   Hangul_Jungseong_O_U                    : constant Unicode_Char := 16#1183#;
   Hangul_Jungseong_Yo_Ya                  : constant Unicode_Char := 16#1184#;
   Hangul_Jungseong_Yo_Yae                 : constant Unicode_Char := 16#1185#;
   Hangul_Jungseong_Yo_Yeo                 : constant Unicode_Char := 16#1186#;
   Hangul_Jungseong_Yo_O                   : constant Unicode_Char := 16#1187#;
   Hangul_Jungseong_Yo_I                   : constant Unicode_Char := 16#1188#;
   Hangul_Jungseong_U_A                    : constant Unicode_Char := 16#1189#;
   Hangul_Jungseong_U_Ae                   : constant Unicode_Char := 16#118A#;
   Hangul_Jungseong_U_Eo_Eu                : constant Unicode_Char := 16#118B#;
   Hangul_Jungseong_U_Ye                   : constant Unicode_Char := 16#118C#;
   Hangul_Jungseong_U_U                    : constant Unicode_Char := 16#118D#;
   Hangul_Jungseong_Yu_A                   : constant Unicode_Char := 16#118E#;
   Hangul_Jungseong_Yu_Eo                  : constant Unicode_Char := 16#118F#;
   Hangul_Jungseong_Yu_E                   : constant Unicode_Char := 16#1190#;
   Hangul_Jungseong_Yu_Yeo                 : constant Unicode_Char := 16#1191#;
   Hangul_Jungseong_Yu_Ye                  : constant Unicode_Char := 16#1192#;
   Hangul_Jungseong_Yu_U                   : constant Unicode_Char := 16#1193#;
   Hangul_Jungseong_Yu_I                   : constant Unicode_Char := 16#1194#;
   Hangul_Jungseong_Eu_U                   : constant Unicode_Char := 16#1195#;
   Hangul_Jungseong_Eu_Eu                  : constant Unicode_Char := 16#1196#;
   Hangul_Jungseong_Yi_U                   : constant Unicode_Char := 16#1197#;
   Hangul_Jungseong_I_A                    : constant Unicode_Char := 16#1198#;
   Hangul_Jungseong_I_Ya                   : constant Unicode_Char := 16#1199#;
   Hangul_Jungseong_I_O                    : constant Unicode_Char := 16#119A#;
   Hangul_Jungseong_I_U                    : constant Unicode_Char := 16#119B#;
   Hangul_Jungseong_I_Eu                   : constant Unicode_Char := 16#119C#;
   Hangul_Jungseong_I_Araea                : constant Unicode_Char := 16#119D#;
   Hangul_Jungseong_Araea                  : constant Unicode_Char := 16#119E#;
   Hangul_Jungseong_Araea_Eo               : constant Unicode_Char := 16#119F#;
   Hangul_Jungseong_Araea_U                : constant Unicode_Char := 16#11A0#;
   Hangul_Jungseong_Araea_I                : constant Unicode_Char := 16#11A1#;
   Hangul_Jungseong_Ssangaraea             : constant Unicode_Char := 16#11A2#;
   Hangul_Jungseong_A_Eu                   : constant Unicode_Char := 16#11A3#;
   Hangul_Jungseong_Ya_U                   : constant Unicode_Char := 16#11A4#;
   Hangul_Jungseong_Yeo_Ya                 : constant Unicode_Char := 16#11A5#;
   Hangul_Jungseong_O_Ya                   : constant Unicode_Char := 16#11A6#;
   Hangul_Jungseong_O_Yae                  : constant Unicode_Char := 16#11A7#;
   Hangul_Jongseong_Kiyeok                 : constant Unicode_Char := 16#11A8#;
   Hangul_Jongseong_Ssangkiyeok            : constant Unicode_Char := 16#11A9#;
   Hangul_Jongseong_Kiyeok_Sios            : constant Unicode_Char := 16#11AA#;
   Hangul_Jongseong_Nieun                  : constant Unicode_Char := 16#11AB#;
   Hangul_Jongseong_Nieun_Cieuc            : constant Unicode_Char := 16#11AC#;
   Hangul_Jongseong_Nieun_Hieuh            : constant Unicode_Char := 16#11AD#;
   Hangul_Jongseong_Tikeut                 : constant Unicode_Char := 16#11AE#;
   Hangul_Jongseong_Rieul                  : constant Unicode_Char := 16#11AF#;
   Hangul_Jongseong_Rieul_Kiyeok           : constant Unicode_Char := 16#11B0#;
   Hangul_Jongseong_Rieul_Mieum            : constant Unicode_Char := 16#11B1#;
   Hangul_Jongseong_Rieul_Pieup            : constant Unicode_Char := 16#11B2#;
   Hangul_Jongseong_Rieul_Sios             : constant Unicode_Char := 16#11B3#;
   Hangul_Jongseong_Rieul_Thieuth          : constant Unicode_Char := 16#11B4#;
   Hangul_Jongseong_Rieul_Phieuph          : constant Unicode_Char := 16#11B5#;
   Hangul_Jongseong_Rieul_Hieuh            : constant Unicode_Char := 16#11B6#;
   Hangul_Jongseong_Mieum                  : constant Unicode_Char := 16#11B7#;
   Hangul_Jongseong_Pieup                  : constant Unicode_Char := 16#11B8#;
   Hangul_Jongseong_Pieup_Sios             : constant Unicode_Char := 16#11B9#;
   Hangul_Jongseong_Sios                   : constant Unicode_Char := 16#11BA#;
   Hangul_Jongseong_Ssangsios              : constant Unicode_Char := 16#11BB#;
   Hangul_Jongseong_Ieung                  : constant Unicode_Char := 16#11BC#;
   Hangul_Jongseong_Cieuc                  : constant Unicode_Char := 16#11BD#;
   Hangul_Jongseong_Chieuch                : constant Unicode_Char := 16#11BE#;
   Hangul_Jongseong_Khieukh                : constant Unicode_Char := 16#11BF#;
   Hangul_Jongseong_Thieuth                : constant Unicode_Char := 16#11C0#;
   Hangul_Jongseong_Phieuph                : constant Unicode_Char := 16#11C1#;
   Hangul_Jongseong_Hieuh                  : constant Unicode_Char := 16#11C2#;
   Hangul_Jongseong_Kiyeok_Rieul           : constant Unicode_Char := 16#11C3#;
   Hangul_Jongseong_Kiyeok_Sios_Kiyeok     : constant Unicode_Char := 16#11C4#;
   Hangul_Jongseong_Nieun_Kiyeok           : constant Unicode_Char := 16#11C5#;
   Hangul_Jongseong_Nieun_Tikeut           : constant Unicode_Char := 16#11C6#;
   Hangul_Jongseong_Nieun_Sios             : constant Unicode_Char := 16#11C7#;
   Hangul_Jongseong_Nieun_Pansios          : constant Unicode_Char := 16#11C8#;
   Hangul_Jongseong_Nieun_Thieuth          : constant Unicode_Char := 16#11C9#;
   Hangul_Jongseong_Tikeut_Kiyeok          : constant Unicode_Char := 16#11CA#;
   Hangul_Jongseong_Tikeut_Rieul           : constant Unicode_Char := 16#11CB#;
   Hangul_Jongseong_Rieul_Kiyeok_Sios      : constant Unicode_Char := 16#11CC#;
   Hangul_Jongseong_Rieul_Nieun            : constant Unicode_Char := 16#11CD#;
   Hangul_Jongseong_Rieul_Tikeut           : constant Unicode_Char := 16#11CE#;
   Hangul_Jongseong_Rieul_Tikeut_Hieuh     : constant Unicode_Char := 16#11CF#;
   Hangul_Jongseong_Ssangrieul             : constant Unicode_Char := 16#11D0#;
   Hangul_Jongseong_Rieul_Mieum_Kiyeok     : constant Unicode_Char := 16#11D1#;
   Hangul_Jongseong_Rieul_Mieum_Sios       : constant Unicode_Char := 16#11D2#;
   Hangul_Jongseong_Rieul_Pieup_Sios       : constant Unicode_Char := 16#11D3#;
   Hangul_Jongseong_Rieul_Pieup_Hieuh      : constant Unicode_Char := 16#11D4#;
   Hangul_Jongseong_Rieul_Kapyeounpieup    : constant Unicode_Char := 16#11D5#;
   Hangul_Jongseong_Rieul_Ssangsios        : constant Unicode_Char := 16#11D6#;
   Hangul_Jongseong_Rieul_Pansios          : constant Unicode_Char := 16#11D7#;
   Hangul_Jongseong_Rieul_Khieukh          : constant Unicode_Char := 16#11D8#;
   Hangul_Jongseong_Rieul_Yeorinhieuh      : constant Unicode_Char := 16#11D9#;
   Hangul_Jongseong_Mieum_Kiyeok           : constant Unicode_Char := 16#11DA#;
   Hangul_Jongseong_Mieum_Rieul            : constant Unicode_Char := 16#11DB#;
   Hangul_Jongseong_Mieum_Pieup            : constant Unicode_Char := 16#11DC#;
   Hangul_Jongseong_Mieum_Sios             : constant Unicode_Char := 16#11DD#;
   Hangul_Jongseong_Mieum_Ssangsios        : constant Unicode_Char := 16#11DE#;
   Hangul_Jongseong_Mieum_Pansios          : constant Unicode_Char := 16#11DF#;
   Hangul_Jongseong_Mieum_Chieuch          : constant Unicode_Char := 16#11E0#;
   Hangul_Jongseong_Mieum_Hieuh            : constant Unicode_Char := 16#11E1#;
   Hangul_Jongseong_Kapyeounmieum          : constant Unicode_Char := 16#11E2#;
   Hangul_Jongseong_Pieup_Rieul            : constant Unicode_Char := 16#11E3#;
   Hangul_Jongseong_Pieup_Phieuph          : constant Unicode_Char := 16#11E4#;
   Hangul_Jongseong_Pieup_Hieuh            : constant Unicode_Char := 16#11E5#;
   Hangul_Jongseong_Kapyeounpieup          : constant Unicode_Char := 16#11E6#;
   Hangul_Jongseong_Sios_Kiyeok            : constant Unicode_Char := 16#11E7#;
   Hangul_Jongseong_Sios_Tikeut            : constant Unicode_Char := 16#11E8#;
   Hangul_Jongseong_Sios_Rieul             : constant Unicode_Char := 16#11E9#;
   Hangul_Jongseong_Sios_Pieup             : constant Unicode_Char := 16#11EA#;
   Hangul_Jongseong_Pansios                : constant Unicode_Char := 16#11EB#;
   Hangul_Jongseong_Ieung_Kiyeok           : constant Unicode_Char := 16#11EC#;
   Hangul_Jongseong_Ieung_Ssangkiyeok      : constant Unicode_Char := 16#11ED#;
   Hangul_Jongseong_Ssangieung             : constant Unicode_Char := 16#11EE#;
   Hangul_Jongseong_Ieung_Khieukh          : constant Unicode_Char := 16#11EF#;
   Hangul_Jongseong_Yesieung               : constant Unicode_Char := 16#11F0#;
   Hangul_Jongseong_Yesieung_Sios          : constant Unicode_Char := 16#11F1#;
   Hangul_Jongseong_Yesieung_Pansios       : constant Unicode_Char := 16#11F2#;
   Hangul_Jongseong_Phieuph_Pieup          : constant Unicode_Char := 16#11F3#;
   Hangul_Jongseong_Kapyeounphieuph        : constant Unicode_Char := 16#11F4#;
   Hangul_Jongseong_Hieuh_Nieun            : constant Unicode_Char := 16#11F5#;
   Hangul_Jongseong_Hieuh_Rieul            : constant Unicode_Char := 16#11F6#;
   Hangul_Jongseong_Hieuh_Mieum            : constant Unicode_Char := 16#11F7#;
   Hangul_Jongseong_Hieuh_Pieup            : constant Unicode_Char := 16#11F8#;
   Hangul_Jongseong_Yeorinhieuh            : constant Unicode_Char := 16#11F9#;
   Hangul_Jongseong_Kiyeok_Nieun           : constant Unicode_Char := 16#11FA#;
   Hangul_Jongseong_Kiyeok_Pieup           : constant Unicode_Char := 16#11FB#;
   Hangul_Jongseong_Kiyeok_Chieuch         : constant Unicode_Char := 16#11FC#;
   Hangul_Jongseong_Kiyeok_Khieukh         : constant Unicode_Char := 16#11FD#;
   Hangul_Jongseong_Kiyeok_Hieuh           : constant Unicode_Char := 16#11FE#;
   Hangul_Jongseong_Ssangnieun             : constant Unicode_Char := 16#11FF#;
end Unicode.Names.Hangul_Jamo;
