--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Ethiopic_Supplement is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Ethiopic_Syllable_Sebatbeit_Mwa         : constant Unicode_Char := 16#1380#;
   Ethiopic_Syllable_Mwi                   : constant Unicode_Char := 16#1381#;
   Ethiopic_Syllable_Mwee                  : constant Unicode_Char := 16#1382#;
   Ethiopic_Syllable_Mwe                   : constant Unicode_Char := 16#1383#;
   Ethiopic_Syllable_Sebatbeit_Bwa         : constant Unicode_Char := 16#1384#;
   Ethiopic_Syllable_Bwi                   : constant Unicode_Char := 16#1385#;
   Ethiopic_Syllable_Bwee                  : constant Unicode_Char := 16#1386#;
   Ethiopic_Syllable_Bwe                   : constant Unicode_Char := 16#1387#;
   Ethiopic_Syllable_Sebatbeit_Fwa         : constant Unicode_Char := 16#1388#;
   Ethiopic_Syllable_Fwi                   : constant Unicode_Char := 16#1389#;
   Ethiopic_Syllable_Fwee                  : constant Unicode_Char := 16#138A#;
   Ethiopic_Syllable_Fwe                   : constant Unicode_Char := 16#138B#;
   Ethiopic_Syllable_Sebatbeit_Pwa         : constant Unicode_Char := 16#138C#;
   Ethiopic_Syllable_Pwi                   : constant Unicode_Char := 16#138D#;
   Ethiopic_Syllable_Pwee                  : constant Unicode_Char := 16#138E#;
   Ethiopic_Syllable_Pwe                   : constant Unicode_Char := 16#138F#;
   Ethiopic_Tonal_Mark_Yizet               : constant Unicode_Char := 16#1390#;
   Ethiopic_Tonal_Mark_Deret               : constant Unicode_Char := 16#1391#;
   Ethiopic_Tonal_Mark_Rikrik              : constant Unicode_Char := 16#1392#;
   Ethiopic_Tonal_Mark_Short_Rikrik        : constant Unicode_Char := 16#1393#;
   Ethiopic_Tonal_Mark_Difat               : constant Unicode_Char := 16#1394#;
   Ethiopic_Tonal_Mark_Kenat               : constant Unicode_Char := 16#1395#;
   Ethiopic_Tonal_Mark_Chiret              : constant Unicode_Char := 16#1396#;
   Ethiopic_Tonal_Mark_Hidet               : constant Unicode_Char := 16#1397#;
   Ethiopic_Tonal_Mark_Deret_Hidet         : constant Unicode_Char := 16#1398#;
   Ethiopic_Tonal_Mark_Kurt                : constant Unicode_Char := 16#1399#;
end Unicode.Names.Ethiopic_Supplement;
