--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Playing_Cards is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Playing_Card_Back                       :
      constant Unicode_Char := 16#1F0A0#;
   Playing_Card_Ace_Of_Spades              :
      constant Unicode_Char := 16#1F0A1#;
   Playing_Card_Two_Of_Spades              :
      constant Unicode_Char := 16#1F0A2#;
   Playing_Card_Three_Of_Spades            :
      constant Unicode_Char := 16#1F0A3#;
   Playing_Card_Four_Of_Spades             :
      constant Unicode_Char := 16#1F0A4#;
   Playing_Card_Five_Of_Spades             :
      constant Unicode_Char := 16#1F0A5#;
   Playing_Card_Six_Of_Spades              :
      constant Unicode_Char := 16#1F0A6#;
   Playing_Card_Seven_Of_Spades            :
      constant Unicode_Char := 16#1F0A7#;
   Playing_Card_Eight_Of_Spades            :
      constant Unicode_Char := 16#1F0A8#;
   Playing_Card_Nine_Of_Spades             :
      constant Unicode_Char := 16#1F0A9#;
   Playing_Card_Ten_Of_Spades              :
      constant Unicode_Char := 16#1F0AA#;
   Playing_Card_Jack_Of_Spades             :
      constant Unicode_Char := 16#1F0AB#;
   Playing_Card_Knight_Of_Spades           :
      constant Unicode_Char := 16#1F0AC#;
   Playing_Card_Queen_Of_Spades            :
      constant Unicode_Char := 16#1F0AD#;
   Playing_Card_King_Of_Spades             :
      constant Unicode_Char := 16#1F0AE#;
   Playing_Card_Ace_Of_Hearts              :
      constant Unicode_Char := 16#1F0B1#;
   Playing_Card_Two_Of_Hearts              :
      constant Unicode_Char := 16#1F0B2#;
   Playing_Card_Three_Of_Hearts            :
      constant Unicode_Char := 16#1F0B3#;
   Playing_Card_Four_Of_Hearts             :
      constant Unicode_Char := 16#1F0B4#;
   Playing_Card_Five_Of_Hearts             :
      constant Unicode_Char := 16#1F0B5#;
   Playing_Card_Six_Of_Hearts              :
      constant Unicode_Char := 16#1F0B6#;
   Playing_Card_Seven_Of_Hearts            :
      constant Unicode_Char := 16#1F0B7#;
   Playing_Card_Eight_Of_Hearts            :
      constant Unicode_Char := 16#1F0B8#;
   Playing_Card_Nine_Of_Hearts             :
      constant Unicode_Char := 16#1F0B9#;
   Playing_Card_Ten_Of_Hearts              :
      constant Unicode_Char := 16#1F0BA#;
   Playing_Card_Jack_Of_Hearts             :
      constant Unicode_Char := 16#1F0BB#;
   Playing_Card_Knight_Of_Hearts           :
      constant Unicode_Char := 16#1F0BC#;
   Playing_Card_Queen_Of_Hearts            :
      constant Unicode_Char := 16#1F0BD#;
   Playing_Card_King_Of_Hearts             :
      constant Unicode_Char := 16#1F0BE#;
   Playing_Card_Red_Joker                  :
      constant Unicode_Char := 16#1F0BF#;
   Playing_Card_Ace_Of_Diamonds            :
      constant Unicode_Char := 16#1F0C1#;
   Playing_Card_Two_Of_Diamonds            :
      constant Unicode_Char := 16#1F0C2#;
   Playing_Card_Three_Of_Diamonds          :
      constant Unicode_Char := 16#1F0C3#;
   Playing_Card_Four_Of_Diamonds           :
      constant Unicode_Char := 16#1F0C4#;
   Playing_Card_Five_Of_Diamonds           :
      constant Unicode_Char := 16#1F0C5#;
   Playing_Card_Six_Of_Diamonds            :
      constant Unicode_Char := 16#1F0C6#;
   Playing_Card_Seven_Of_Diamonds          :
      constant Unicode_Char := 16#1F0C7#;
   Playing_Card_Eight_Of_Diamonds          :
      constant Unicode_Char := 16#1F0C8#;
   Playing_Card_Nine_Of_Diamonds           :
      constant Unicode_Char := 16#1F0C9#;
   Playing_Card_Ten_Of_Diamonds            :
      constant Unicode_Char := 16#1F0CA#;
   Playing_Card_Jack_Of_Diamonds           :
      constant Unicode_Char := 16#1F0CB#;
   Playing_Card_Knight_Of_Diamonds         :
      constant Unicode_Char := 16#1F0CC#;
   Playing_Card_Queen_Of_Diamonds          :
      constant Unicode_Char := 16#1F0CD#;
   Playing_Card_King_Of_Diamonds           :
      constant Unicode_Char := 16#1F0CE#;
   Playing_Card_Black_Joker                :
      constant Unicode_Char := 16#1F0CF#;
   Playing_Card_Ace_Of_Clubs               :
      constant Unicode_Char := 16#1F0D1#;
   Playing_Card_Two_Of_Clubs               :
      constant Unicode_Char := 16#1F0D2#;
   Playing_Card_Three_Of_Clubs             :
      constant Unicode_Char := 16#1F0D3#;
   Playing_Card_Four_Of_Clubs              :
      constant Unicode_Char := 16#1F0D4#;
   Playing_Card_Five_Of_Clubs              :
      constant Unicode_Char := 16#1F0D5#;
   Playing_Card_Six_Of_Clubs               :
      constant Unicode_Char := 16#1F0D6#;
   Playing_Card_Seven_Of_Clubs             :
      constant Unicode_Char := 16#1F0D7#;
   Playing_Card_Eight_Of_Clubs             :
      constant Unicode_Char := 16#1F0D8#;
   Playing_Card_Nine_Of_Clubs              :
      constant Unicode_Char := 16#1F0D9#;
   Playing_Card_Ten_Of_Clubs               :
      constant Unicode_Char := 16#1F0DA#;
   Playing_Card_Jack_Of_Clubs              :
      constant Unicode_Char := 16#1F0DB#;
   Playing_Card_Knight_Of_Clubs            :
      constant Unicode_Char := 16#1F0DC#;
   Playing_Card_Queen_Of_Clubs             :
      constant Unicode_Char := 16#1F0DD#;
   Playing_Card_King_Of_Clubs              :
      constant Unicode_Char := 16#1F0DE#;
   Playing_Card_White_Joker                :
      constant Unicode_Char := 16#1F0DF#;
   Playing_Card_Fool                       :
      constant Unicode_Char := 16#1F0E0#;
   Playing_Card_Trump_1                    :
      constant Unicode_Char := 16#1F0E1#;
   Playing_Card_Trump_2                    :
      constant Unicode_Char := 16#1F0E2#;
   Playing_Card_Trump_3                    :
      constant Unicode_Char := 16#1F0E3#;
   Playing_Card_Trump_4                    :
      constant Unicode_Char := 16#1F0E4#;
   Playing_Card_Trump_5                    :
      constant Unicode_Char := 16#1F0E5#;
   Playing_Card_Trump_6                    :
      constant Unicode_Char := 16#1F0E6#;
   Playing_Card_Trump_7                    :
      constant Unicode_Char := 16#1F0E7#;
   Playing_Card_Trump_8                    :
      constant Unicode_Char := 16#1F0E8#;
   Playing_Card_Trump_9                    :
      constant Unicode_Char := 16#1F0E9#;
   Playing_Card_Trump_10                   :
      constant Unicode_Char := 16#1F0EA#;
   Playing_Card_Trump_11                   :
      constant Unicode_Char := 16#1F0EB#;
   Playing_Card_Trump_12                   :
      constant Unicode_Char := 16#1F0EC#;
   Playing_Card_Trump_13                   :
      constant Unicode_Char := 16#1F0ED#;
   Playing_Card_Trump_14                   :
      constant Unicode_Char := 16#1F0EE#;
   Playing_Card_Trump_15                   :
      constant Unicode_Char := 16#1F0EF#;
   Playing_Card_Trump_16                   :
      constant Unicode_Char := 16#1F0F0#;
   Playing_Card_Trump_17                   :
      constant Unicode_Char := 16#1F0F1#;
   Playing_Card_Trump_18                   :
      constant Unicode_Char := 16#1F0F2#;
   Playing_Card_Trump_19                   :
      constant Unicode_Char := 16#1F0F3#;
   Playing_Card_Trump_20                   :
      constant Unicode_Char := 16#1F0F4#;
   Playing_Card_Trump_21                   :
      constant Unicode_Char := 16#1F0F5#;
end Unicode.Names.Playing_Cards;
