--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cherokee_Supplement is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cherokee_Small_Letter_A                 : constant Unicode_Char := 16#AB70#;
   Cherokee_Small_Letter_E                 : constant Unicode_Char := 16#AB71#;
   Cherokee_Small_Letter_I                 : constant Unicode_Char := 16#AB72#;
   Cherokee_Small_Letter_O                 : constant Unicode_Char := 16#AB73#;
   Cherokee_Small_Letter_U                 : constant Unicode_Char := 16#AB74#;
   Cherokee_Small_Letter_V                 : constant Unicode_Char := 16#AB75#;
   Cherokee_Small_Letter_Ga                : constant Unicode_Char := 16#AB76#;
   Cherokee_Small_Letter_Ka                : constant Unicode_Char := 16#AB77#;
   Cherokee_Small_Letter_Ge                : constant Unicode_Char := 16#AB78#;
   Cherokee_Small_Letter_Gi                : constant Unicode_Char := 16#AB79#;
   Cherokee_Small_Letter_Go                : constant Unicode_Char := 16#AB7A#;
   Cherokee_Small_Letter_Gu                : constant Unicode_Char := 16#AB7B#;
   Cherokee_Small_Letter_Gv                : constant Unicode_Char := 16#AB7C#;
   Cherokee_Small_Letter_Ha                : constant Unicode_Char := 16#AB7D#;
   Cherokee_Small_Letter_He                : constant Unicode_Char := 16#AB7E#;
   Cherokee_Small_Letter_Hi                : constant Unicode_Char := 16#AB7F#;
   Cherokee_Small_Letter_Ho                : constant Unicode_Char := 16#AB80#;
   Cherokee_Small_Letter_Hu                : constant Unicode_Char := 16#AB81#;
   Cherokee_Small_Letter_Hv                : constant Unicode_Char := 16#AB82#;
   Cherokee_Small_Letter_La                : constant Unicode_Char := 16#AB83#;
   Cherokee_Small_Letter_Le                : constant Unicode_Char := 16#AB84#;
   Cherokee_Small_Letter_Li                : constant Unicode_Char := 16#AB85#;
   Cherokee_Small_Letter_Lo                : constant Unicode_Char := 16#AB86#;
   Cherokee_Small_Letter_Lu                : constant Unicode_Char := 16#AB87#;
   Cherokee_Small_Letter_Lv                : constant Unicode_Char := 16#AB88#;
   Cherokee_Small_Letter_Ma                : constant Unicode_Char := 16#AB89#;
   Cherokee_Small_Letter_Me                : constant Unicode_Char := 16#AB8A#;
   Cherokee_Small_Letter_Mi                : constant Unicode_Char := 16#AB8B#;
   Cherokee_Small_Letter_Mo                : constant Unicode_Char := 16#AB8C#;
   Cherokee_Small_Letter_Mu                : constant Unicode_Char := 16#AB8D#;
   Cherokee_Small_Letter_Na                : constant Unicode_Char := 16#AB8E#;
   Cherokee_Small_Letter_Hna               : constant Unicode_Char := 16#AB8F#;
   Cherokee_Small_Letter_Nah               : constant Unicode_Char := 16#AB90#;
   Cherokee_Small_Letter_Ne                : constant Unicode_Char := 16#AB91#;
   Cherokee_Small_Letter_Ni                : constant Unicode_Char := 16#AB92#;
   Cherokee_Small_Letter_No                : constant Unicode_Char := 16#AB93#;
   Cherokee_Small_Letter_Nu                : constant Unicode_Char := 16#AB94#;
   Cherokee_Small_Letter_Nv                : constant Unicode_Char := 16#AB95#;
   Cherokee_Small_Letter_Qua               : constant Unicode_Char := 16#AB96#;
   Cherokee_Small_Letter_Que               : constant Unicode_Char := 16#AB97#;
   Cherokee_Small_Letter_Qui               : constant Unicode_Char := 16#AB98#;
   Cherokee_Small_Letter_Quo               : constant Unicode_Char := 16#AB99#;
   Cherokee_Small_Letter_Quu               : constant Unicode_Char := 16#AB9A#;
   Cherokee_Small_Letter_Quv               : constant Unicode_Char := 16#AB9B#;
   Cherokee_Small_Letter_Sa                : constant Unicode_Char := 16#AB9C#;
   Cherokee_Small_Letter_S                 : constant Unicode_Char := 16#AB9D#;
   Cherokee_Small_Letter_Se                : constant Unicode_Char := 16#AB9E#;
   Cherokee_Small_Letter_Si                : constant Unicode_Char := 16#AB9F#;
   Cherokee_Small_Letter_So                : constant Unicode_Char := 16#ABA0#;
   Cherokee_Small_Letter_Su                : constant Unicode_Char := 16#ABA1#;
   Cherokee_Small_Letter_Sv                : constant Unicode_Char := 16#ABA2#;
   Cherokee_Small_Letter_Da                : constant Unicode_Char := 16#ABA3#;
   Cherokee_Small_Letter_Ta                : constant Unicode_Char := 16#ABA4#;
   Cherokee_Small_Letter_De                : constant Unicode_Char := 16#ABA5#;
   Cherokee_Small_Letter_Te                : constant Unicode_Char := 16#ABA6#;
   Cherokee_Small_Letter_Di                : constant Unicode_Char := 16#ABA7#;
   Cherokee_Small_Letter_Ti                : constant Unicode_Char := 16#ABA8#;
   Cherokee_Small_Letter_Do                : constant Unicode_Char := 16#ABA9#;
   Cherokee_Small_Letter_Du                : constant Unicode_Char := 16#ABAA#;
   Cherokee_Small_Letter_Dv                : constant Unicode_Char := 16#ABAB#;
   Cherokee_Small_Letter_Dla               : constant Unicode_Char := 16#ABAC#;
   Cherokee_Small_Letter_Tla               : constant Unicode_Char := 16#ABAD#;
   Cherokee_Small_Letter_Tle               : constant Unicode_Char := 16#ABAE#;
   Cherokee_Small_Letter_Tli               : constant Unicode_Char := 16#ABAF#;
   Cherokee_Small_Letter_Tlo               : constant Unicode_Char := 16#ABB0#;
   Cherokee_Small_Letter_Tlu               : constant Unicode_Char := 16#ABB1#;
   Cherokee_Small_Letter_Tlv               : constant Unicode_Char := 16#ABB2#;
   Cherokee_Small_Letter_Tsa               : constant Unicode_Char := 16#ABB3#;
   Cherokee_Small_Letter_Tse               : constant Unicode_Char := 16#ABB4#;
   Cherokee_Small_Letter_Tsi               : constant Unicode_Char := 16#ABB5#;
   Cherokee_Small_Letter_Tso               : constant Unicode_Char := 16#ABB6#;
   Cherokee_Small_Letter_Tsu               : constant Unicode_Char := 16#ABB7#;
   Cherokee_Small_Letter_Tsv               : constant Unicode_Char := 16#ABB8#;
   Cherokee_Small_Letter_Wa                : constant Unicode_Char := 16#ABB9#;
   Cherokee_Small_Letter_We                : constant Unicode_Char := 16#ABBA#;
   Cherokee_Small_Letter_Wi                : constant Unicode_Char := 16#ABBB#;
   Cherokee_Small_Letter_Wo                : constant Unicode_Char := 16#ABBC#;
   Cherokee_Small_Letter_Wu                : constant Unicode_Char := 16#ABBD#;
   Cherokee_Small_Letter_Wv                : constant Unicode_Char := 16#ABBE#;
   Cherokee_Small_Letter_Ya                : constant Unicode_Char := 16#ABBF#;
end Unicode.Names.Cherokee_Supplement;
