--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Nko is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Nko_Digit_Zero                          : constant Unicode_Char := 16#07C0#;
   Nko_Digit_One                           : constant Unicode_Char := 16#07C1#;
   Nko_Digit_Two                           : constant Unicode_Char := 16#07C2#;
   Nko_Digit_Three                         : constant Unicode_Char := 16#07C3#;
   Nko_Digit_Four                          : constant Unicode_Char := 16#07C4#;
   Nko_Digit_Five                          : constant Unicode_Char := 16#07C5#;
   Nko_Digit_Six                           : constant Unicode_Char := 16#07C6#;
   Nko_Digit_Seven                         : constant Unicode_Char := 16#07C7#;
   Nko_Digit_Eight                         : constant Unicode_Char := 16#07C8#;
   Nko_Digit_Nine                          : constant Unicode_Char := 16#07C9#;
   Nko_Letter_A                            : constant Unicode_Char := 16#07CA#;
   Nko_Letter_Ee                           : constant Unicode_Char := 16#07CB#;
   Nko_Letter_I                            : constant Unicode_Char := 16#07CC#;
   Nko_Letter_E                            : constant Unicode_Char := 16#07CD#;
   Nko_Letter_U                            : constant Unicode_Char := 16#07CE#;
   Nko_Letter_Oo                           : constant Unicode_Char := 16#07CF#;
   Nko_Letter_O                            : constant Unicode_Char := 16#07D0#;
   Nko_Letter_Dagbasinna                   : constant Unicode_Char := 16#07D1#;
   Nko_Letter_N                            : constant Unicode_Char := 16#07D2#;
   Nko_Letter_Ba                           : constant Unicode_Char := 16#07D3#;
   Nko_Letter_Pa                           : constant Unicode_Char := 16#07D4#;
   Nko_Letter_Ta                           : constant Unicode_Char := 16#07D5#;
   Nko_Letter_Ja                           : constant Unicode_Char := 16#07D6#;
   Nko_Letter_Cha                          : constant Unicode_Char := 16#07D7#;
   Nko_Letter_Da                           : constant Unicode_Char := 16#07D8#;
   Nko_Letter_Ra                           : constant Unicode_Char := 16#07D9#;
   Nko_Letter_Rra                          : constant Unicode_Char := 16#07DA#;
   Nko_Letter_Sa                           : constant Unicode_Char := 16#07DB#;
   Nko_Letter_Gba                          : constant Unicode_Char := 16#07DC#;
   Nko_Letter_Fa                           : constant Unicode_Char := 16#07DD#;
   Nko_Letter_Ka                           : constant Unicode_Char := 16#07DE#;
   Nko_Letter_La                           : constant Unicode_Char := 16#07DF#;
   Nko_Letter_Na_Woloso                    : constant Unicode_Char := 16#07E0#;
   Nko_Letter_Ma                           : constant Unicode_Char := 16#07E1#;
   Nko_Letter_Nya                          : constant Unicode_Char := 16#07E2#;
   Nko_Letter_Na                           : constant Unicode_Char := 16#07E3#;
   Nko_Letter_Ha                           : constant Unicode_Char := 16#07E4#;
   Nko_Letter_Wa                           : constant Unicode_Char := 16#07E5#;
   Nko_Letter_Ya                           : constant Unicode_Char := 16#07E6#;
   Nko_Letter_Nya_Woloso                   : constant Unicode_Char := 16#07E7#;
   Nko_Letter_Jona_Ja                      : constant Unicode_Char := 16#07E8#;
   Nko_Letter_Jona_Cha                     : constant Unicode_Char := 16#07E9#;
   Nko_Letter_Jona_Ra                      : constant Unicode_Char := 16#07EA#;
   Nko_Combining_Short_High_Tone           : constant Unicode_Char := 16#07EB#;
   Nko_Combining_Short_Low_Tone            : constant Unicode_Char := 16#07EC#;
   Nko_Combining_Short_Rising_Tone         : constant Unicode_Char := 16#07ED#;
   Nko_Combining_Long_Descending_Tone      : constant Unicode_Char := 16#07EE#;
   Nko_Combining_Long_High_Tone            : constant Unicode_Char := 16#07EF#;
   Nko_Combining_Long_Low_Tone             : constant Unicode_Char := 16#07F0#;
   Nko_Combining_Long_Rising_Tone          : constant Unicode_Char := 16#07F1#;
   Nko_Combining_Nasalization_Mark         : constant Unicode_Char := 16#07F2#;
   Nko_Combining_Double_Dot_Above          : constant Unicode_Char := 16#07F3#;
   Nko_High_Tone_Apostrophe                : constant Unicode_Char := 16#07F4#;
   Nko_Low_Tone_Apostrophe                 : constant Unicode_Char := 16#07F5#;
   Nko_Symbol_Oo_Dennen                    : constant Unicode_Char := 16#07F6#;
   Nko_Symbol_Gbakurunen                   : constant Unicode_Char := 16#07F7#;
   Nko_Comma                               : constant Unicode_Char := 16#07F8#;
   Nko_Exclamation_Mark                    : constant Unicode_Char := 16#07F9#;
   Nko_Lajanyalan                          : constant Unicode_Char := 16#07FA#;
end Unicode.Names.Nko;
