--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Early_Dynastic_Cuneiform is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cuneiform_Sign_Ab_Times_Nun_Tenu        :
      constant Unicode_Char := 16#12480#;
   Cuneiform_Sign_Ab_Times_Shu2            :
      constant Unicode_Char := 16#12481#;
   Cuneiform_Sign_Ad_Times_Esh2            :
      constant Unicode_Char := 16#12482#;
   Cuneiform_Sign_Bad_Times_Dish_Tenu      :
      constant Unicode_Char := 16#12483#;
   Cuneiform_Sign_Bahar2_Times_Ab2         :
      constant Unicode_Char := 16#12484#;
   Cuneiform_Sign_Bahar2_Times_Ni          :
      constant Unicode_Char := 16#12485#;
   Cuneiform_Sign_Bahar2_Times_Za          :
      constant Unicode_Char := 16#12486#;
   Cuneiform_Sign_Bu_Over_Bu_Times_Na2     :
      constant Unicode_Char := 16#12487#;
   Cuneiform_Sign_Da_Times_Tak4            :
      constant Unicode_Char := 16#12488#;
   Cuneiform_Sign_Dag_Times_Kur            :
      constant Unicode_Char := 16#12489#;
   Cuneiform_Sign_Dim_Times_Igi            :
      constant Unicode_Char := 16#1248A#;
   Cuneiform_Sign_Dim_Times_U_U_U          :
      constant Unicode_Char := 16#1248B#;
   Cuneiform_Sign_Dim2_Times_Ud            :
      constant Unicode_Char := 16#1248C#;
   Cuneiform_Sign_Dug_Times_Anshe          :
      constant Unicode_Char := 16#1248D#;
   Cuneiform_Sign_Dug_Times_Ash            :
      constant Unicode_Char := 16#1248E#;
   Cuneiform_Sign_Dug_Times_Ash_At_Left    :
      constant Unicode_Char := 16#1248F#;
   Cuneiform_Sign_Dug_Times_Din            :
      constant Unicode_Char := 16#12490#;
   Cuneiform_Sign_Dug_Times_Dun            :
      constant Unicode_Char := 16#12491#;
   Cuneiform_Sign_Dug_Times_Erin2          :
      constant Unicode_Char := 16#12492#;
   Cuneiform_Sign_Dug_Times_Ga             :
      constant Unicode_Char := 16#12493#;
   Cuneiform_Sign_Dug_Times_Gi             :
      constant Unicode_Char := 16#12494#;
   Cuneiform_Sign_Dug_Times_Gir2_Gunu      :
      constant Unicode_Char := 16#12495#;
   Cuneiform_Sign_Dug_Times_Gish           :
      constant Unicode_Char := 16#12496#;
   Cuneiform_Sign_Dug_Times_Ha             :
      constant Unicode_Char := 16#12497#;
   Cuneiform_Sign_Dug_Times_Hi             :
      constant Unicode_Char := 16#12498#;
   Cuneiform_Sign_Dug_Times_Igi_Gunu       :
      constant Unicode_Char := 16#12499#;
   Cuneiform_Sign_Dug_Times_Kaskal         :
      constant Unicode_Char := 16#1249A#;
   Cuneiform_Sign_Dug_Times_Kur            :
      constant Unicode_Char := 16#1249B#;
   Cuneiform_Sign_Dug_Times_Kushu2         :
      constant Unicode_Char := 16#1249C#;
   Cuneiform_Sign_Dug_Times_Kushu2_Plus_Kaskal :
      constant Unicode_Char := 16#1249D#;
   Cuneiform_Sign_Dug_Times_Lak_020        :
      constant Unicode_Char := 16#1249E#;
   Cuneiform_Sign_Dug_Times_Lam            :
      constant Unicode_Char := 16#1249F#;
   Cuneiform_Sign_Dug_Times_Lam_Times_Kur  :
      constant Unicode_Char := 16#124A0#;
   Cuneiform_Sign_Dug_Times_Luh_Plus_Gish  :
      constant Unicode_Char := 16#124A1#;
   Cuneiform_Sign_Dug_Times_Mash           :
      constant Unicode_Char := 16#124A2#;
   Cuneiform_Sign_Dug_Times_Mes            :
      constant Unicode_Char := 16#124A3#;
   Cuneiform_Sign_Dug_Times_Mi             :
      constant Unicode_Char := 16#124A4#;
   Cuneiform_Sign_Dug_Times_Ni             :
      constant Unicode_Char := 16#124A5#;
   Cuneiform_Sign_Dug_Times_Pi             :
      constant Unicode_Char := 16#124A6#;
   Cuneiform_Sign_Dug_Times_She            :
      constant Unicode_Char := 16#124A7#;
   Cuneiform_Sign_Dug_Times_Si_Gunu        :
      constant Unicode_Char := 16#124A8#;
   Cuneiform_Sign_E2_Times_Kur             :
      constant Unicode_Char := 16#124A9#;
   Cuneiform_Sign_E2_Times_Pap             :
      constant Unicode_Char := 16#124AA#;
   Cuneiform_Sign_Erin2_X                  :
      constant Unicode_Char := 16#124AB#;
   Cuneiform_Sign_Esh2_Crossing_Esh2       :
      constant Unicode_Char := 16#124AC#;
   Cuneiform_Sign_Ezen_Sheshig_Times_Ash   :
      constant Unicode_Char := 16#124AD#;
   Cuneiform_Sign_Ezen_Sheshig_Times_Hi    :
      constant Unicode_Char := 16#124AE#;
   Cuneiform_Sign_Ezen_Sheshig_Times_Igi_Gunu :
      constant Unicode_Char := 16#124AF#;
   Cuneiform_Sign_Ezen_Sheshig_Times_La    :
      constant Unicode_Char := 16#124B0#;
   Cuneiform_Sign_Ezen_Sheshig_Times_Lal   :
      constant Unicode_Char := 16#124B1#;
   Cuneiform_Sign_Ezen_Sheshig_Times_Me    :
      constant Unicode_Char := 16#124B2#;
   Cuneiform_Sign_Ezen_Sheshig_Times_Mes   :
      constant Unicode_Char := 16#124B3#;
   Cuneiform_Sign_Ezen_Sheshig_Times_Su    :
      constant Unicode_Char := 16#124B4#;
   Cuneiform_Sign_Ezen_Times_Su            :
      constant Unicode_Char := 16#124B5#;
   Cuneiform_Sign_Ga2_Times_Bahar2         :
      constant Unicode_Char := 16#124B6#;
   Cuneiform_Sign_Ga2_Times_Dim_Gunu       :
      constant Unicode_Char := 16#124B7#;
   Cuneiform_Sign_Ga2_Times_Dug_Times_Igi_Gunu :
      constant Unicode_Char := 16#124B8#;
   Cuneiform_Sign_Ga2_Times_Dug_Times_Kaskal :
      constant Unicode_Char := 16#124B9#;
   Cuneiform_Sign_Ga2_Times_Eren           :
      constant Unicode_Char := 16#124BA#;
   Cuneiform_Sign_Ga2_Times_Ga             :
      constant Unicode_Char := 16#124BB#;
   Cuneiform_Sign_Ga2_Times_Gar_Plus_Di    :
      constant Unicode_Char := 16#124BC#;
   Cuneiform_Sign_Ga2_Times_Gar_Plus_Ne    :
      constant Unicode_Char := 16#124BD#;
   Cuneiform_Sign_Ga2_Times_Ha_Plus_A      :
      constant Unicode_Char := 16#124BE#;
   Cuneiform_Sign_Ga2_Times_Kushu2_Plus_Kaskal :
      constant Unicode_Char := 16#124BF#;
   Cuneiform_Sign_Ga2_Times_Lam            :
      constant Unicode_Char := 16#124C0#;
   Cuneiform_Sign_Ga2_Times_Lam_Times_Kur  :
      constant Unicode_Char := 16#124C1#;
   Cuneiform_Sign_Ga2_Times_Luh            :
      constant Unicode_Char := 16#124C2#;
   Cuneiform_Sign_Ga2_Times_Mush           :
      constant Unicode_Char := 16#124C3#;
   Cuneiform_Sign_Ga2_Times_Ne             :
      constant Unicode_Char := 16#124C4#;
   Cuneiform_Sign_Ga2_Times_Ne_Plus_E2     :
      constant Unicode_Char := 16#124C5#;
   Cuneiform_Sign_Ga2_Times_Ne_Plus_Gi     :
      constant Unicode_Char := 16#124C6#;
   Cuneiform_Sign_Ga2_Times_Shim           :
      constant Unicode_Char := 16#124C7#;
   Cuneiform_Sign_Ga2_Times_Ziz2           :
      constant Unicode_Char := 16#124C8#;
   Cuneiform_Sign_Gaba_Rotated_Ninety_Degrees :
      constant Unicode_Char := 16#124C9#;
   Cuneiform_Sign_Geshtin_Times_U          :
      constant Unicode_Char := 16#124CA#;
   Cuneiform_Sign_Gish_Times_Gish_Crossing_Gish :
      constant Unicode_Char := 16#124CB#;
   Cuneiform_Sign_Gu2_Times_Igi_Gunu       :
      constant Unicode_Char := 16#124CC#;
   Cuneiform_Sign_Gud_Plus_Gish_Times_Tak4 :
      constant Unicode_Char := 16#124CD#;
   Cuneiform_Sign_Ha_Tenu_Gunu             :
      constant Unicode_Char := 16#124CE#;
   Cuneiform_Sign_Hi_Times_Ash_Over_Hi_Times_Ash :
      constant Unicode_Char := 16#124CF#;
   Cuneiform_Sign_Ka_Times_Bu              :
      constant Unicode_Char := 16#124D0#;
   Cuneiform_Sign_Ka_Times_Ka              :
      constant Unicode_Char := 16#124D1#;
   Cuneiform_Sign_Ka_Times_U_U_U           :
      constant Unicode_Char := 16#124D2#;
   Cuneiform_Sign_Ka_Times_Ur              :
      constant Unicode_Char := 16#124D3#;
   Cuneiform_Sign_Lagab_Times_Zu_Over_Zu   :
      constant Unicode_Char := 16#124D4#;
   Cuneiform_Sign_Lak_003                  :
      constant Unicode_Char := 16#124D5#;
   Cuneiform_Sign_Lak_021                  :
      constant Unicode_Char := 16#124D6#;
   Cuneiform_Sign_Lak_025                  :
      constant Unicode_Char := 16#124D7#;
   Cuneiform_Sign_Lak_030                  :
      constant Unicode_Char := 16#124D8#;
   Cuneiform_Sign_Lak_050                  :
      constant Unicode_Char := 16#124D9#;
   Cuneiform_Sign_Lak_051                  :
      constant Unicode_Char := 16#124DA#;
   Cuneiform_Sign_Lak_062                  :
      constant Unicode_Char := 16#124DB#;
   Cuneiform_Sign_Lak_079_Over_Lak_079_Gunu :
      constant Unicode_Char := 16#124DC#;
   Cuneiform_Sign_Lak_080                  :
      constant Unicode_Char := 16#124DD#;
   Cuneiform_Sign_Lak_081_Over_Lak_081     :
      constant Unicode_Char := 16#124DE#;
   Cuneiform_Sign_Lak_092                  :
      constant Unicode_Char := 16#124DF#;
   Cuneiform_Sign_Lak_130                  :
      constant Unicode_Char := 16#124E0#;
   Cuneiform_Sign_Lak_142                  :
      constant Unicode_Char := 16#124E1#;
   Cuneiform_Sign_Lak_210                  :
      constant Unicode_Char := 16#124E2#;
   Cuneiform_Sign_Lak_219                  :
      constant Unicode_Char := 16#124E3#;
   Cuneiform_Sign_Lak_220                  :
      constant Unicode_Char := 16#124E4#;
   Cuneiform_Sign_Lak_225                  :
      constant Unicode_Char := 16#124E5#;
   Cuneiform_Sign_Lak_228                  :
      constant Unicode_Char := 16#124E6#;
   Cuneiform_Sign_Lak_238                  :
      constant Unicode_Char := 16#124E7#;
   Cuneiform_Sign_Lak_265                  :
      constant Unicode_Char := 16#124E8#;
   Cuneiform_Sign_Lak_266                  :
      constant Unicode_Char := 16#124E9#;
   Cuneiform_Sign_Lak_343                  :
      constant Unicode_Char := 16#124EA#;
   Cuneiform_Sign_Lak_347                  :
      constant Unicode_Char := 16#124EB#;
   Cuneiform_Sign_Lak_348                  :
      constant Unicode_Char := 16#124EC#;
   Cuneiform_Sign_Lak_383                  :
      constant Unicode_Char := 16#124ED#;
   Cuneiform_Sign_Lak_384                  :
      constant Unicode_Char := 16#124EE#;
   Cuneiform_Sign_Lak_390                  :
      constant Unicode_Char := 16#124EF#;
   Cuneiform_Sign_Lak_441                  :
      constant Unicode_Char := 16#124F0#;
   Cuneiform_Sign_Lak_449                  :
      constant Unicode_Char := 16#124F1#;
   Cuneiform_Sign_Lak_449_Times_Gu         :
      constant Unicode_Char := 16#124F2#;
   Cuneiform_Sign_Lak_449_Times_Igi        :
      constant Unicode_Char := 16#124F3#;
   Cuneiform_Sign_Lak_449_Times_Pap_Plus_Lu3 :
      constant Unicode_Char := 16#124F4#;
   Cuneiform_Sign_Lak_449_Times_Pap_Plus_Pap_Plus_Lu3 :
      constant Unicode_Char := 16#124F5#;
   Cuneiform_Sign_Lak_449_Times_U2_Plus_Ba :
      constant Unicode_Char := 16#124F6#;
   Cuneiform_Sign_Lak_450                  :
      constant Unicode_Char := 16#124F7#;
   Cuneiform_Sign_Lak_457                  :
      constant Unicode_Char := 16#124F8#;
   Cuneiform_Sign_Lak_470                  :
      constant Unicode_Char := 16#124F9#;
   Cuneiform_Sign_Lak_483                  :
      constant Unicode_Char := 16#124FA#;
   Cuneiform_Sign_Lak_490                  :
      constant Unicode_Char := 16#124FB#;
   Cuneiform_Sign_Lak_492                  :
      constant Unicode_Char := 16#124FC#;
   Cuneiform_Sign_Lak_493                  :
      constant Unicode_Char := 16#124FD#;
   Cuneiform_Sign_Lak_495                  :
      constant Unicode_Char := 16#124FE#;
   Cuneiform_Sign_Lak_550                  :
      constant Unicode_Char := 16#124FF#;
   Cuneiform_Sign_Lak_608                  :
      constant Unicode_Char := 16#12500#;
   Cuneiform_Sign_Lak_617                  :
      constant Unicode_Char := 16#12501#;
   Cuneiform_Sign_Lak_617_Times_Ash        :
      constant Unicode_Char := 16#12502#;
   Cuneiform_Sign_Lak_617_Times_Bad        :
      constant Unicode_Char := 16#12503#;
   Cuneiform_Sign_Lak_617_Times_Dun3_Gunu_Gunu :
      constant Unicode_Char := 16#12504#;
   Cuneiform_Sign_Lak_617_Times_Ku3        :
      constant Unicode_Char := 16#12505#;
   Cuneiform_Sign_Lak_617_Times_La         :
      constant Unicode_Char := 16#12506#;
   Cuneiform_Sign_Lak_617_Times_Tar        :
      constant Unicode_Char := 16#12507#;
   Cuneiform_Sign_Lak_617_Times_Te         :
      constant Unicode_Char := 16#12508#;
   Cuneiform_Sign_Lak_617_Times_U2         :
      constant Unicode_Char := 16#12509#;
   Cuneiform_Sign_Lak_617_Times_Ud         :
      constant Unicode_Char := 16#1250A#;
   Cuneiform_Sign_Lak_617_Times_Uruda      :
      constant Unicode_Char := 16#1250B#;
   Cuneiform_Sign_Lak_636                  :
      constant Unicode_Char := 16#1250C#;
   Cuneiform_Sign_Lak_648                  :
      constant Unicode_Char := 16#1250D#;
   Cuneiform_Sign_Lak_648_Times_Dub        :
      constant Unicode_Char := 16#1250E#;
   Cuneiform_Sign_Lak_648_Times_Ga         :
      constant Unicode_Char := 16#1250F#;
   Cuneiform_Sign_Lak_648_Times_Igi        :
      constant Unicode_Char := 16#12510#;
   Cuneiform_Sign_Lak_648_Times_Igi_Gunu   :
      constant Unicode_Char := 16#12511#;
   Cuneiform_Sign_Lak_648_Times_Ni         :
      constant Unicode_Char := 16#12512#;
   Cuneiform_Sign_Lak_648_Times_Pap_Plus_Pap_Plus_Lu3 :
      constant Unicode_Char := 16#12513#;
   Cuneiform_Sign_Lak_648_Times_Shesh_Plus_Ki :
      constant Unicode_Char := 16#12514#;
   Cuneiform_Sign_Lak_648_Times_Ud         :
      constant Unicode_Char := 16#12515#;
   Cuneiform_Sign_Lak_648_Times_Uruda      :
      constant Unicode_Char := 16#12516#;
   Cuneiform_Sign_Lak_724                  :
      constant Unicode_Char := 16#12517#;
   Cuneiform_Sign_Lak_749                  :
      constant Unicode_Char := 16#12518#;
   Cuneiform_Sign_Lu2_Gunu_Times_Ash       :
      constant Unicode_Char := 16#12519#;
   Cuneiform_Sign_Lu2_Times_Dish           :
      constant Unicode_Char := 16#1251A#;
   Cuneiform_Sign_Lu2_Times_Hal            :
      constant Unicode_Char := 16#1251B#;
   Cuneiform_Sign_Lu2_Times_Pap            :
      constant Unicode_Char := 16#1251C#;
   Cuneiform_Sign_Lu2_Times_Pap_Plus_Pap_Plus_Lu3 :
      constant Unicode_Char := 16#1251D#;
   Cuneiform_Sign_Lu2_Times_Tak4           :
      constant Unicode_Char := 16#1251E#;
   Cuneiform_Sign_Mi_Plus_Za7              :
      constant Unicode_Char := 16#1251F#;
   Cuneiform_Sign_Mush_Over_Mush_Times_Ga  :
      constant Unicode_Char := 16#12520#;
   Cuneiform_Sign_Mush_Over_Mush_Times_Kak :
      constant Unicode_Char := 16#12521#;
   Cuneiform_Sign_Ninda2_Times_Dim_Gunu    :
      constant Unicode_Char := 16#12522#;
   Cuneiform_Sign_Ninda2_Times_Gish        :
      constant Unicode_Char := 16#12523#;
   Cuneiform_Sign_Ninda2_Times_Gul         :
      constant Unicode_Char := 16#12524#;
   Cuneiform_Sign_Ninda2_Times_Hi          :
      constant Unicode_Char := 16#12525#;
   Cuneiform_Sign_Ninda2_Times_Kesh2       :
      constant Unicode_Char := 16#12526#;
   Cuneiform_Sign_Ninda2_Times_Lak_050     :
      constant Unicode_Char := 16#12527#;
   Cuneiform_Sign_Ninda2_Times_Mash        :
      constant Unicode_Char := 16#12528#;
   Cuneiform_Sign_Ninda2_Times_Pap_Plus_Pap :
      constant Unicode_Char := 16#12529#;
   Cuneiform_Sign_Ninda2_Times_U           :
      constant Unicode_Char := 16#1252A#;
   Cuneiform_Sign_Ninda2_Times_U_Plus_U    :
      constant Unicode_Char := 16#1252B#;
   Cuneiform_Sign_Ninda2_Times_Uruda       :
      constant Unicode_Char := 16#1252C#;
   Cuneiform_Sign_Sag_Gunu_Times_Ha        :
      constant Unicode_Char := 16#1252D#;
   Cuneiform_Sign_Sag_Times_En             :
      constant Unicode_Char := 16#1252E#;
   Cuneiform_Sign_Sag_Times_She_At_Left    :
      constant Unicode_Char := 16#1252F#;
   Cuneiform_Sign_Sag_Times_Tak4           :
      constant Unicode_Char := 16#12530#;
   Cuneiform_Sign_Sha6_Tenu                :
      constant Unicode_Char := 16#12531#;
   Cuneiform_Sign_She_Over_She             :
      constant Unicode_Char := 16#12532#;
   Cuneiform_Sign_She_Plus_Hub2            :
      constant Unicode_Char := 16#12533#;
   Cuneiform_Sign_She_Plus_Nam2            :
      constant Unicode_Char := 16#12534#;
   Cuneiform_Sign_She_Plus_Sar             :
      constant Unicode_Char := 16#12535#;
   Cuneiform_Sign_Shu2_Plus_Dug_Times_Ni   :
      constant Unicode_Char := 16#12536#;
   Cuneiform_Sign_Shu2_Plus_E2_Times_An    :
      constant Unicode_Char := 16#12537#;
   Cuneiform_Sign_Si_Times_Tak4            :
      constant Unicode_Char := 16#12538#;
   Cuneiform_Sign_Tak4_Plus_Sag            :
      constant Unicode_Char := 16#12539#;
   Cuneiform_Sign_Tum_Times_Gan2_Tenu      :
      constant Unicode_Char := 16#1253A#;
   Cuneiform_Sign_Tum_Times_Three_Dish     :
      constant Unicode_Char := 16#1253B#;
   Cuneiform_Sign_Ur2_Inverted             :
      constant Unicode_Char := 16#1253C#;
   Cuneiform_Sign_Ur2_Times_Ud             :
      constant Unicode_Char := 16#1253D#;
   Cuneiform_Sign_Uru_Times_Dara3          :
      constant Unicode_Char := 16#1253E#;
   Cuneiform_Sign_Uru_Times_Lak_668        :
      constant Unicode_Char := 16#1253F#;
   Cuneiform_Sign_Uru_Times_Lu3            :
      constant Unicode_Char := 16#12540#;
   Cuneiform_Sign_Za7                      :
      constant Unicode_Char := 16#12541#;
   Cuneiform_Sign_Zu_Over_Zu_Plus_Sar      :
      constant Unicode_Char := 16#12542#;
   Cuneiform_Sign_Zu5_Times_Three_Dish_Tenu :
      constant Unicode_Char := 16#12543#;
end Unicode.Names.Early_Dynastic_Cuneiform;
