--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Sutton_Signwriting is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Signwriting_Hand_Fist_Index             :
      constant Unicode_Char := 16#1D800#;
   Signwriting_Hand_Circle_Index           :
      constant Unicode_Char := 16#1D801#;
   Signwriting_Hand_Cup_Index              :
      constant Unicode_Char := 16#1D802#;
   Signwriting_Hand_Oval_Index             :
      constant Unicode_Char := 16#1D803#;
   Signwriting_Hand_Hinge_Index            :
      constant Unicode_Char := 16#1D804#;
   Signwriting_Hand_Angle_Index            :
      constant Unicode_Char := 16#1D805#;
   Signwriting_Hand_Fist_Index_Bent        :
      constant Unicode_Char := 16#1D806#;
   Signwriting_Hand_Circle_Index_Bent      :
      constant Unicode_Char := 16#1D807#;
   Signwriting_Hand_Fist_Thumb_Under_Index_Bent :
      constant Unicode_Char := 16#1D808#;
   Signwriting_Hand_Fist_Index_Raised_Knuckle :
      constant Unicode_Char := 16#1D809#;
   Signwriting_Hand_Fist_Index_Cupped      :
      constant Unicode_Char := 16#1D80A#;
   Signwriting_Hand_Fist_Index_Hinged      :
      constant Unicode_Char := 16#1D80B#;
   Signwriting_Hand_Fist_Index_Hinged_Low  :
      constant Unicode_Char := 16#1D80C#;
   Signwriting_Hand_Circle_Index_Hinge     :
      constant Unicode_Char := 16#1D80D#;
   Signwriting_Hand_Fist_Index_Middle      :
      constant Unicode_Char := 16#1D80E#;
   Signwriting_Hand_Circle_Index_Middle    :
      constant Unicode_Char := 16#1D80F#;
   Signwriting_Hand_Fist_Index_Middle_Bent :
      constant Unicode_Char := 16#1D810#;
   Signwriting_Hand_Fist_Index_Middle_Raised_Knuckles :
      constant Unicode_Char := 16#1D811#;
   Signwriting_Hand_Fist_Index_Middle_Hinged :
      constant Unicode_Char := 16#1D812#;
   Signwriting_Hand_Fist_Index_Up_Middle_Hinged :
      constant Unicode_Char := 16#1D813#;
   Signwriting_Hand_Fist_Index_Hinged_Middle_Up :
      constant Unicode_Char := 16#1D814#;
   Signwriting_Hand_Fist_Index_Middle_Conjoined :
      constant Unicode_Char := 16#1D815#;
   Signwriting_Hand_Fist_Index_Middle_Conjoined_Index_Bent :
      constant Unicode_Char := 16#1D816#;
   Signwriting_Hand_Fist_Index_Middle_Conjoined_Middle_Bent :
      constant Unicode_Char := 16#1D817#;
   Signwriting_Hand_Fist_Index_Middle_Conjoined_Cupped :
      constant Unicode_Char := 16#1D818#;
   Signwriting_Hand_Fist_Index_Middle_Conjoined_Hinged :
      constant Unicode_Char := 16#1D819#;
   Signwriting_Hand_Fist_Index_Middle_Crossed :
      constant Unicode_Char := 16#1D81A#;
   Signwriting_Hand_Circle_Index_Middle_Crossed :
      constant Unicode_Char := 16#1D81B#;
   Signwriting_Hand_Fist_Middle_Bent_Over_Index :
      constant Unicode_Char := 16#1D81C#;
   Signwriting_Hand_Fist_Index_Bent_Over_Middle :
      constant Unicode_Char := 16#1D81D#;
   Signwriting_Hand_Fist_Index_Middle_Thumb :
      constant Unicode_Char := 16#1D81E#;
   Signwriting_Hand_Circle_Index_Middle_Thumb :
      constant Unicode_Char := 16#1D81F#;
   Signwriting_Hand_Fist_Index_Middle_Straight_Thumb_Bent :
      constant Unicode_Char := 16#1D820#;
   Signwriting_Hand_Fist_Index_Middle_Bent_Thumb_Straight :
      constant Unicode_Char := 16#1D821#;
   Signwriting_Hand_Fist_Index_Middle_Thumb_Bent :
      constant Unicode_Char := 16#1D822#;
   Signwriting_Hand_Fist_Index_Middle_Hinged_Spread_Thumb_Side :
      constant Unicode_Char := 16#1D823#;
   Signwriting_Hand_Fist_Index_Up_Middle_Hinged_Thumb_Side :
      constant Unicode_Char := 16#1D824#;
   Signwriting_Hand_Fist_Index_Up_Middle_Hinged_Thumb_Conjoined :
      constant Unicode_Char := 16#1D825#;
   Signwriting_Hand_Fist_Index_Hinged_Middle_Up_Thumb_Side :
      constant Unicode_Char := 16#1D826#;
   Signwriting_Hand_Fist_Index_Middle_Up_Spread_Thumb_Forward :
      constant Unicode_Char := 16#1D827#;
   Signwriting_Hand_Fist_Index_Middle_Thumb_Cupped :
      constant Unicode_Char := 16#1D828#;
   Signwriting_Hand_Fist_Index_Middle_Thumb_Circled :
      constant Unicode_Char := 16#1D829#;
   Signwriting_Hand_Fist_Index_Middle_Thumb_Hooked :
      constant Unicode_Char := 16#1D82A#;
   Signwriting_Hand_Fist_Index_Middle_Thumb_Hinged :
      constant Unicode_Char := 16#1D82B#;
   Signwriting_Hand_Fist_Thumb_Between_Index_Middle_Straight :
      constant Unicode_Char := 16#1D82C#;
   Signwriting_Hand_Fist_Index_Middle_Conjoined_Thumb_Side :
      constant Unicode_Char := 16#1D82D#;
   Signwriting_Hand_Fist_Index_Middle_Conjoined_Thumb_Side_Conjoined :
      constant Unicode_Char := 16#1D82E#;
   Signwriting_Hand_Fist_Index_Middle_Conjoined_Thumb_Side_Bent :
      constant Unicode_Char := 16#1D82F#;
   Signwriting_Hand_Fist_Middle_Thumb_Hooked_Index_Up :
      constant Unicode_Char := 16#1D830#;
   Signwriting_Hand_Fist_Index_Thumb_Hooked_Middle_Up :
      constant Unicode_Char := 16#1D831#;
   Signwriting_Hand_Fist_Index_Middle_Conjoined_Hinged_Thumb_Side :
      constant Unicode_Char := 16#1D832#;
   Signwriting_Hand_Fist_Index_Middle_Crossed_Thumb_Side :
      constant Unicode_Char := 16#1D833#;
   Signwriting_Hand_Fist_Index_Middle_Conjoined_Thumb_Forward :
      constant Unicode_Char := 16#1D834#;
   Signwriting_Hand_Fist_Index_Middle_Conjoined_Cupped_Thumb_Forward :
      constant Unicode_Char := 16#1D835#;
   Signwriting_Hand_Fist_Middle_Thumb_Cupped_Index_Up :
      constant Unicode_Char := 16#1D836#;
   Signwriting_Hand_Fist_Index_Thumb_Cupped_Middle_Up :
      constant Unicode_Char := 16#1D837#;
   Signwriting_Hand_Fist_Middle_Thumb_Circled_Index_Up :
      constant Unicode_Char := 16#1D838#;
   Signwriting_Hand_Fist_Middle_Thumb_Circled_Index_Hinged :
      constant Unicode_Char := 16#1D839#;
   Signwriting_Hand_Fist_Index_Thumb_Angled_Out_Middle_Up :
      constant Unicode_Char := 16#1D83A#;
   Signwriting_Hand_Fist_Index_Thumb_Angled_In_Middle_Up :
      constant Unicode_Char := 16#1D83B#;
   Signwriting_Hand_Fist_Index_Thumb_Circled_Middle_Up :
      constant Unicode_Char := 16#1D83C#;
   Signwriting_Hand_Fist_Index_Middle_Thumb_Conjoined_Hinged :
      constant Unicode_Char := 16#1D83D#;
   Signwriting_Hand_Fist_Index_Middle_Thumb_Angled_Out :
      constant Unicode_Char := 16#1D83E#;
   Signwriting_Hand_Fist_Index_Middle_Thumb_Angled :
      constant Unicode_Char := 16#1D83F#;
   Signwriting_Hand_Fist_Middle_Thumb_Angled_Out_Index_Up :
      constant Unicode_Char := 16#1D840#;
   Signwriting_Hand_Fist_Middle_Thumb_Angled_Out_Index_Crossed :
      constant Unicode_Char := 16#1D841#;
   Signwriting_Hand_Fist_Middle_Thumb_Angled_Index_Up :
      constant Unicode_Char := 16#1D842#;
   Signwriting_Hand_Fist_Index_Thumb_Hooked_Middle_Hinged :
      constant Unicode_Char := 16#1D843#;
   Signwriting_Hand_Flat_Four_Fingers      :
      constant Unicode_Char := 16#1D844#;
   Signwriting_Hand_Flat_Four_Fingers_Bent :
      constant Unicode_Char := 16#1D845#;
   Signwriting_Hand_Flat_Four_Fingers_Hinged :
      constant Unicode_Char := 16#1D846#;
   Signwriting_Hand_Flat_Four_Fingers_Conjoined :
      constant Unicode_Char := 16#1D847#;
   Signwriting_Hand_Flat_Four_Fingers_Conjoined_Split :
      constant Unicode_Char := 16#1D848#;
   Signwriting_Hand_Claw_Four_Fingers_Conjoined :
      constant Unicode_Char := 16#1D849#;
   Signwriting_Hand_Fist_Four_Fingers_Conjoined_Bent :
      constant Unicode_Char := 16#1D84A#;
   Signwriting_Hand_Hinge_Four_Fingers_Conjoined :
      constant Unicode_Char := 16#1D84B#;
   Signwriting_Hand_Flat_Five_Fingers_Spread :
      constant Unicode_Char := 16#1D84C#;
   Signwriting_Hand_Flat_Heel_Five_Fingers_Spread :
      constant Unicode_Char := 16#1D84D#;
   Signwriting_Hand_Flat_Five_Fingers_Spread_Four_Bent :
      constant Unicode_Char := 16#1D84E#;
   Signwriting_Hand_Flat_Heel_Five_Fingers_Spread_Four_Bent :
      constant Unicode_Char := 16#1D84F#;
   Signwriting_Hand_Flat_Five_Fingers_Spread_Bent :
      constant Unicode_Char := 16#1D850#;
   Signwriting_Hand_Flat_Heel_Five_Fingers_Spread_Bent :
      constant Unicode_Char := 16#1D851#;
   Signwriting_Hand_Flat_Five_Fingers_Spread_Thumb_Forward :
      constant Unicode_Char := 16#1D852#;
   Signwriting_Hand_Cup_Five_Fingers_Spread :
      constant Unicode_Char := 16#1D853#;
   Signwriting_Hand_Cup_Five_Fingers_Spread_Open :
      constant Unicode_Char := 16#1D854#;
   Signwriting_Hand_Hinge_Five_Fingers_Spread_Open :
      constant Unicode_Char := 16#1D855#;
   Signwriting_Hand_Oval_Five_Fingers_Spread :
      constant Unicode_Char := 16#1D856#;
   Signwriting_Hand_Flat_Five_Fingers_Spread_Hinged :
      constant Unicode_Char := 16#1D857#;
   Signwriting_Hand_Flat_Five_Fingers_Spread_Hinged_Thumb_Side :
      constant Unicode_Char := 16#1D858#;
   Signwriting_Hand_Flat_Five_Fingers_Spread_Hinged_No_Thumb :
      constant Unicode_Char := 16#1D859#;
   Signwriting_Hand_Flat                   :
      constant Unicode_Char := 16#1D85A#;
   Signwriting_Hand_Flat_Between_Palm_Facings :
      constant Unicode_Char := 16#1D85B#;
   Signwriting_Hand_Flat_Heel              :
      constant Unicode_Char := 16#1D85C#;
   Signwriting_Hand_Flat_Thumb_Side        :
      constant Unicode_Char := 16#1D85D#;
   Signwriting_Hand_Flat_Heel_Thumb_Side   :
      constant Unicode_Char := 16#1D85E#;
   Signwriting_Hand_Flat_Thumb_Bent        :
      constant Unicode_Char := 16#1D85F#;
   Signwriting_Hand_Flat_Thumb_Forward     :
      constant Unicode_Char := 16#1D860#;
   Signwriting_Hand_Flat_Split_Index_Thumb_Side :
      constant Unicode_Char := 16#1D861#;
   Signwriting_Hand_Flat_Split_Centre      :
      constant Unicode_Char := 16#1D862#;
   Signwriting_Hand_Flat_Split_Centre_Thumb_Side :
      constant Unicode_Char := 16#1D863#;
   Signwriting_Hand_Flat_Split_Centre_Thumb_Side_Bent :
      constant Unicode_Char := 16#1D864#;
   Signwriting_Hand_Flat_Split_Little      :
      constant Unicode_Char := 16#1D865#;
   Signwriting_Hand_Claw                   :
      constant Unicode_Char := 16#1D866#;
   Signwriting_Hand_Claw_Thumb_Side        :
      constant Unicode_Char := 16#1D867#;
   Signwriting_Hand_Claw_No_Thumb          :
      constant Unicode_Char := 16#1D868#;
   Signwriting_Hand_Claw_Thumb_Forward     :
      constant Unicode_Char := 16#1D869#;
   Signwriting_Hand_Hook_Curlicue          :
      constant Unicode_Char := 16#1D86A#;
   Signwriting_Hand_Hook                   :
      constant Unicode_Char := 16#1D86B#;
   Signwriting_Hand_Cup_Open               :
      constant Unicode_Char := 16#1D86C#;
   Signwriting_Hand_Cup                    :
      constant Unicode_Char := 16#1D86D#;
   Signwriting_Hand_Cup_Open_Thumb_Side    :
      constant Unicode_Char := 16#1D86E#;
   Signwriting_Hand_Cup_Thumb_Side         :
      constant Unicode_Char := 16#1D86F#;
   Signwriting_Hand_Cup_Open_No_Thumb      :
      constant Unicode_Char := 16#1D870#;
   Signwriting_Hand_Cup_No_Thumb           :
      constant Unicode_Char := 16#1D871#;
   Signwriting_Hand_Cup_Open_Thumb_Forward :
      constant Unicode_Char := 16#1D872#;
   Signwriting_Hand_Cup_Thumb_Forward      :
      constant Unicode_Char := 16#1D873#;
   Signwriting_Hand_Curlicue_Open          :
      constant Unicode_Char := 16#1D874#;
   Signwriting_Hand_Curlicue               :
      constant Unicode_Char := 16#1D875#;
   Signwriting_Hand_Circle                 :
      constant Unicode_Char := 16#1D876#;
   Signwriting_Hand_Oval                   :
      constant Unicode_Char := 16#1D877#;
   Signwriting_Hand_Oval_Thumb_Side        :
      constant Unicode_Char := 16#1D878#;
   Signwriting_Hand_Oval_No_Thumb          :
      constant Unicode_Char := 16#1D879#;
   Signwriting_Hand_Oval_Thumb_Forward     :
      constant Unicode_Char := 16#1D87A#;
   Signwriting_Hand_Hinge_Open             :
      constant Unicode_Char := 16#1D87B#;
   Signwriting_Hand_Hinge_Open_Thumb_Forward :
      constant Unicode_Char := 16#1D87C#;
   Signwriting_Hand_Hinge                  :
      constant Unicode_Char := 16#1D87D#;
   Signwriting_Hand_Hinge_Small            :
      constant Unicode_Char := 16#1D87E#;
   Signwriting_Hand_Hinge_Open_Thumb_Side  :
      constant Unicode_Char := 16#1D87F#;
   Signwriting_Hand_Hinge_Thumb_Side       :
      constant Unicode_Char := 16#1D880#;
   Signwriting_Hand_Hinge_Open_No_Thumb    :
      constant Unicode_Char := 16#1D881#;
   Signwriting_Hand_Hinge_No_Thumb         :
      constant Unicode_Char := 16#1D882#;
   Signwriting_Hand_Hinge_Thumb_Side_Touching_Index :
      constant Unicode_Char := 16#1D883#;
   Signwriting_Hand_Hinge_Thumb_Between_Middle_Ring :
      constant Unicode_Char := 16#1D884#;
   Signwriting_Hand_Angle                  :
      constant Unicode_Char := 16#1D885#;
   Signwriting_Hand_Fist_Index_Middle_Ring :
      constant Unicode_Char := 16#1D886#;
   Signwriting_Hand_Circle_Index_Middle_Ring :
      constant Unicode_Char := 16#1D887#;
   Signwriting_Hand_Hinge_Index_Middle_Ring :
      constant Unicode_Char := 16#1D888#;
   Signwriting_Hand_Angle_Index_Middle_Ring :
      constant Unicode_Char := 16#1D889#;
   Signwriting_Hand_Hinge_Little           :
      constant Unicode_Char := 16#1D88A#;
   Signwriting_Hand_Fist_Index_Middle_Ring_Bent :
      constant Unicode_Char := 16#1D88B#;
   Signwriting_Hand_Fist_Index_Middle_Ring_Conjoined :
      constant Unicode_Char := 16#1D88C#;
   Signwriting_Hand_Hinge_Index_Middle_Ring_Conjoined :
      constant Unicode_Char := 16#1D88D#;
   Signwriting_Hand_Fist_Little_Down       :
      constant Unicode_Char := 16#1D88E#;
   Signwriting_Hand_Fist_Little_Down_Ripple_Straight :
      constant Unicode_Char := 16#1D88F#;
   Signwriting_Hand_Fist_Little_Down_Ripple_Curved :
      constant Unicode_Char := 16#1D890#;
   Signwriting_Hand_Fist_Little_Down_Others_Circled :
      constant Unicode_Char := 16#1D891#;
   Signwriting_Hand_Fist_Little_Up         :
      constant Unicode_Char := 16#1D892#;
   Signwriting_Hand_Fist_Thumb_Under_Little_Up :
      constant Unicode_Char := 16#1D893#;
   Signwriting_Hand_Circle_Little_Up       :
      constant Unicode_Char := 16#1D894#;
   Signwriting_Hand_Oval_Little_Up         :
      constant Unicode_Char := 16#1D895#;
   Signwriting_Hand_Angle_Little_Up        :
      constant Unicode_Char := 16#1D896#;
   Signwriting_Hand_Fist_Little_Raised_Knuckle :
      constant Unicode_Char := 16#1D897#;
   Signwriting_Hand_Fist_Little_Bent       :
      constant Unicode_Char := 16#1D898#;
   Signwriting_Hand_Fist_Little_Touches_Thumb :
      constant Unicode_Char := 16#1D899#;
   Signwriting_Hand_Fist_Little_Thumb      :
      constant Unicode_Char := 16#1D89A#;
   Signwriting_Hand_Hinge_Little_Thumb     :
      constant Unicode_Char := 16#1D89B#;
   Signwriting_Hand_Fist_Little_Index_Thumb :
      constant Unicode_Char := 16#1D89C#;
   Signwriting_Hand_Hinge_Little_Index_Thumb :
      constant Unicode_Char := 16#1D89D#;
   Signwriting_Hand_Angle_Little_Index_Thumb_Index_Thumb_Out :
      constant Unicode_Char := 16#1D89E#;
   Signwriting_Hand_Angle_Little_Index_Thumb_Index_Thumb :
      constant Unicode_Char := 16#1D89F#;
   Signwriting_Hand_Fist_Little_Index      :
      constant Unicode_Char := 16#1D8A0#;
   Signwriting_Hand_Circle_Little_Index    :
      constant Unicode_Char := 16#1D8A1#;
   Signwriting_Hand_Hinge_Little_Index     :
      constant Unicode_Char := 16#1D8A2#;
   Signwriting_Hand_Angle_Little_Index     :
      constant Unicode_Char := 16#1D8A3#;
   Signwriting_Hand_Fist_Index_Middle_Little :
      constant Unicode_Char := 16#1D8A4#;
   Signwriting_Hand_Circle_Index_Middle_Little :
      constant Unicode_Char := 16#1D8A5#;
   Signwriting_Hand_Hinge_Index_Middle_Little :
      constant Unicode_Char := 16#1D8A6#;
   Signwriting_Hand_Hinge_Ring             :
      constant Unicode_Char := 16#1D8A7#;
   Signwriting_Hand_Angle_Index_Middle_Little :
      constant Unicode_Char := 16#1D8A8#;
   Signwriting_Hand_Fist_Index_Middle_Cross_Little :
      constant Unicode_Char := 16#1D8A9#;
   Signwriting_Hand_Circle_Index_Middle_Cross_Little :
      constant Unicode_Char := 16#1D8AA#;
   Signwriting_Hand_Fist_Ring_Down         :
      constant Unicode_Char := 16#1D8AB#;
   Signwriting_Hand_Hinge_Ring_Down_Index_Thumb_Hook_Middle :
      constant Unicode_Char := 16#1D8AC#;
   Signwriting_Hand_Angle_Ring_Down_Middle_Thumb_Index_Cross :
      constant Unicode_Char := 16#1D8AD#;
   Signwriting_Hand_Fist_Ring_Up           :
      constant Unicode_Char := 16#1D8AE#;
   Signwriting_Hand_Fist_Ring_Raised_Knuckle :
      constant Unicode_Char := 16#1D8AF#;
   Signwriting_Hand_Fist_Ring_Little       :
      constant Unicode_Char := 16#1D8B0#;
   Signwriting_Hand_Circle_Ring_Little     :
      constant Unicode_Char := 16#1D8B1#;
   Signwriting_Hand_Oval_Ring_Little       :
      constant Unicode_Char := 16#1D8B2#;
   Signwriting_Hand_Angle_Ring_Little      :
      constant Unicode_Char := 16#1D8B3#;
   Signwriting_Hand_Fist_Ring_Middle       :
      constant Unicode_Char := 16#1D8B4#;
   Signwriting_Hand_Fist_Ring_Middle_Conjoined :
      constant Unicode_Char := 16#1D8B5#;
   Signwriting_Hand_Fist_Ring_Middle_Raised_Knuckles :
      constant Unicode_Char := 16#1D8B6#;
   Signwriting_Hand_Fist_Ring_Index        :
      constant Unicode_Char := 16#1D8B7#;
   Signwriting_Hand_Fist_Ring_Thumb        :
      constant Unicode_Char := 16#1D8B8#;
   Signwriting_Hand_Hook_Ring_Thumb        :
      constant Unicode_Char := 16#1D8B9#;
   Signwriting_Hand_Fist_Index_Ring_Little :
      constant Unicode_Char := 16#1D8BA#;
   Signwriting_Hand_Circle_Index_Ring_Little :
      constant Unicode_Char := 16#1D8BB#;
   Signwriting_Hand_Curlicue_Index_Ring_Little_On :
      constant Unicode_Char := 16#1D8BC#;
   Signwriting_Hand_Hook_Index_Ring_Little_Out :
      constant Unicode_Char := 16#1D8BD#;
   Signwriting_Hand_Hook_Index_Ring_Little_In :
      constant Unicode_Char := 16#1D8BE#;
   Signwriting_Hand_Hook_Index_Ring_Little_Under :
      constant Unicode_Char := 16#1D8BF#;
   Signwriting_Hand_Cup_Index_Ring_Little  :
      constant Unicode_Char := 16#1D8C0#;
   Signwriting_Hand_Hinge_Index_Ring_Little :
      constant Unicode_Char := 16#1D8C1#;
   Signwriting_Hand_Angle_Index_Ring_Little_Out :
      constant Unicode_Char := 16#1D8C2#;
   Signwriting_Hand_Angle_Index_Ring_Little :
      constant Unicode_Char := 16#1D8C3#;
   Signwriting_Hand_Fist_Middle_Down       :
      constant Unicode_Char := 16#1D8C4#;
   Signwriting_Hand_Hinge_Middle           :
      constant Unicode_Char := 16#1D8C5#;
   Signwriting_Hand_Fist_Middle_Up         :
      constant Unicode_Char := 16#1D8C6#;
   Signwriting_Hand_Circle_Middle_Up       :
      constant Unicode_Char := 16#1D8C7#;
   Signwriting_Hand_Fist_Middle_Raised_Knuckle :
      constant Unicode_Char := 16#1D8C8#;
   Signwriting_Hand_Fist_Middle_Up_Thumb_Side :
      constant Unicode_Char := 16#1D8C9#;
   Signwriting_Hand_Hook_Middle_Thumb      :
      constant Unicode_Char := 16#1D8CA#;
   Signwriting_Hand_Fist_Middle_Thumb_Little :
      constant Unicode_Char := 16#1D8CB#;
   Signwriting_Hand_Fist_Middle_Little     :
      constant Unicode_Char := 16#1D8CC#;
   Signwriting_Hand_Fist_Middle_Ring_Little :
      constant Unicode_Char := 16#1D8CD#;
   Signwriting_Hand_Circle_Middle_Ring_Little :
      constant Unicode_Char := 16#1D8CE#;
   Signwriting_Hand_Curlicue_Middle_Ring_Little_On :
      constant Unicode_Char := 16#1D8CF#;
   Signwriting_Hand_Cup_Middle_Ring_Little :
      constant Unicode_Char := 16#1D8D0#;
   Signwriting_Hand_Hinge_Middle_Ring_Little :
      constant Unicode_Char := 16#1D8D1#;
   Signwriting_Hand_Angle_Middle_Ring_Little_Out :
      constant Unicode_Char := 16#1D8D2#;
   Signwriting_Hand_Angle_Middle_Ring_Little_In :
      constant Unicode_Char := 16#1D8D3#;
   Signwriting_Hand_Angle_Middle_Ring_Little :
      constant Unicode_Char := 16#1D8D4#;
   Signwriting_Hand_Circle_Middle_Ring_Little_Bent :
      constant Unicode_Char := 16#1D8D5#;
   Signwriting_Hand_Claw_Middle_Ring_Little_Conjoined :
      constant Unicode_Char := 16#1D8D6#;
   Signwriting_Hand_Claw_Middle_Ring_Little_Conjoined_Side :
      constant Unicode_Char := 16#1D8D7#;
   Signwriting_Hand_Hook_Middle_Ring_Little_Conjoined_Out :
      constant Unicode_Char := 16#1D8D8#;
   Signwriting_Hand_Hook_Middle_Ring_Little_Conjoined_In :
      constant Unicode_Char := 16#1D8D9#;
   Signwriting_Hand_Hook_Middle_Ring_Little_Conjoined :
      constant Unicode_Char := 16#1D8DA#;
   Signwriting_Hand_Hinge_Index_Hinged     :
      constant Unicode_Char := 16#1D8DB#;
   Signwriting_Hand_Fist_Index_Thumb_Side  :
      constant Unicode_Char := 16#1D8DC#;
   Signwriting_Hand_Hinge_Index_Thumb_Side :
      constant Unicode_Char := 16#1D8DD#;
   Signwriting_Hand_Fist_Index_Thumb_Side_Thumb_Diagonal :
      constant Unicode_Char := 16#1D8DE#;
   Signwriting_Hand_Fist_Index_Thumb_Side_Thumb_Conjoined :
      constant Unicode_Char := 16#1D8DF#;
   Signwriting_Hand_Fist_Index_Thumb_Side_Thumb_Bent :
      constant Unicode_Char := 16#1D8E0#;
   Signwriting_Hand_Fist_Index_Thumb_Side_Index_Bent :
      constant Unicode_Char := 16#1D8E1#;
   Signwriting_Hand_Fist_Index_Thumb_Side_Both_Bent :
      constant Unicode_Char := 16#1D8E2#;
   Signwriting_Hand_Fist_Index_Thumb_Side_Index_Hinge :
      constant Unicode_Char := 16#1D8E3#;
   Signwriting_Hand_Fist_Index_Thumb_Forward_Index_Straight :
      constant Unicode_Char := 16#1D8E4#;
   Signwriting_Hand_Fist_Index_Thumb_Forward_Index_Bent :
      constant Unicode_Char := 16#1D8E5#;
   Signwriting_Hand_Fist_Index_Thumb_Hook  :
      constant Unicode_Char := 16#1D8E6#;
   Signwriting_Hand_Fist_Index_Thumb_Curlicue :
      constant Unicode_Char := 16#1D8E7#;
   Signwriting_Hand_Fist_Index_Thumb_Curve_Thumb_Inside :
      constant Unicode_Char := 16#1D8E8#;
   Signwriting_Hand_Claw_Index_Thumb_Curve_Thumb_Inside :
      constant Unicode_Char := 16#1D8E9#;
   Signwriting_Hand_Fist_Index_Thumb_Curve_Thumb_Under :
      constant Unicode_Char := 16#1D8EA#;
   Signwriting_Hand_Fist_Index_Thumb_Circle :
      constant Unicode_Char := 16#1D8EB#;
   Signwriting_Hand_Cup_Index_Thumb        :
      constant Unicode_Char := 16#1D8EC#;
   Signwriting_Hand_Cup_Index_Thumb_Open   :
      constant Unicode_Char := 16#1D8ED#;
   Signwriting_Hand_Hinge_Index_Thumb_Open :
      constant Unicode_Char := 16#1D8EE#;
   Signwriting_Hand_Hinge_Index_Thumb_Large :
      constant Unicode_Char := 16#1D8EF#;
   Signwriting_Hand_Hinge_Index_Thumb      :
      constant Unicode_Char := 16#1D8F0#;
   Signwriting_Hand_Hinge_Index_Thumb_Small :
      constant Unicode_Char := 16#1D8F1#;
   Signwriting_Hand_Angle_Index_Thumb_Out  :
      constant Unicode_Char := 16#1D8F2#;
   Signwriting_Hand_Angle_Index_Thumb_In   :
      constant Unicode_Char := 16#1D8F3#;
   Signwriting_Hand_Angle_Index_Thumb      :
      constant Unicode_Char := 16#1D8F4#;
   Signwriting_Hand_Fist_Thumb             :
      constant Unicode_Char := 16#1D8F5#;
   Signwriting_Hand_Fist_Thumb_Heel        :
      constant Unicode_Char := 16#1D8F6#;
   Signwriting_Hand_Fist_Thumb_Side_Diagonal :
      constant Unicode_Char := 16#1D8F7#;
   Signwriting_Hand_Fist_Thumb_Side_Conjoined :
      constant Unicode_Char := 16#1D8F8#;
   Signwriting_Hand_Fist_Thumb_Side_Bent   :
      constant Unicode_Char := 16#1D8F9#;
   Signwriting_Hand_Fist_Thumb_Forward     :
      constant Unicode_Char := 16#1D8FA#;
   Signwriting_Hand_Fist_Thumb_Between_Index_Middle :
      constant Unicode_Char := 16#1D8FB#;
   Signwriting_Hand_Fist_Thumb_Between_Middle_Ring :
      constant Unicode_Char := 16#1D8FC#;
   Signwriting_Hand_Fist_Thumb_Between_Ring_Little :
      constant Unicode_Char := 16#1D8FD#;
   Signwriting_Hand_Fist_Thumb_Under_Two_Fingers :
      constant Unicode_Char := 16#1D8FE#;
   Signwriting_Hand_Fist_Thumb_Over_Two_Fingers :
      constant Unicode_Char := 16#1D8FF#;
   Signwriting_Hand_Fist_Thumb_Under_Three_Fingers :
      constant Unicode_Char := 16#1D900#;
   Signwriting_Hand_Fist_Thumb_Under_Four_Fingers :
      constant Unicode_Char := 16#1D901#;
   Signwriting_Hand_Fist_Thumb_Over_Four_Raised_Knuckles :
      constant Unicode_Char := 16#1D902#;
   Signwriting_Hand_Fist                   :
      constant Unicode_Char := 16#1D903#;
   Signwriting_Hand_Fist_Heel              :
      constant Unicode_Char := 16#1D904#;
   Signwriting_Touch_Single                :
      constant Unicode_Char := 16#1D905#;
   Signwriting_Touch_Multiple              :
      constant Unicode_Char := 16#1D906#;
   Signwriting_Touch_Between               :
      constant Unicode_Char := 16#1D907#;
   Signwriting_Grasp_Single                :
      constant Unicode_Char := 16#1D908#;
   Signwriting_Grasp_Multiple              :
      constant Unicode_Char := 16#1D909#;
   Signwriting_Grasp_Between               :
      constant Unicode_Char := 16#1D90A#;
   Signwriting_Strike_Single               :
      constant Unicode_Char := 16#1D90B#;
   Signwriting_Strike_Multiple             :
      constant Unicode_Char := 16#1D90C#;
   Signwriting_Strike_Between              :
      constant Unicode_Char := 16#1D90D#;
   Signwriting_Brush_Single                :
      constant Unicode_Char := 16#1D90E#;
   Signwriting_Brush_Multiple              :
      constant Unicode_Char := 16#1D90F#;
   Signwriting_Brush_Between               :
      constant Unicode_Char := 16#1D910#;
   Signwriting_Rub_Single                  :
      constant Unicode_Char := 16#1D911#;
   Signwriting_Rub_Multiple                :
      constant Unicode_Char := 16#1D912#;
   Signwriting_Rub_Between                 :
      constant Unicode_Char := 16#1D913#;
   Signwriting_Surface_Symbols             :
      constant Unicode_Char := 16#1D914#;
   Signwriting_Surface_Between             :
      constant Unicode_Char := 16#1D915#;
   Signwriting_Squeeze_Large_Single        :
      constant Unicode_Char := 16#1D916#;
   Signwriting_Squeeze_Small_Single        :
      constant Unicode_Char := 16#1D917#;
   Signwriting_Squeeze_Large_Multiple      :
      constant Unicode_Char := 16#1D918#;
   Signwriting_Squeeze_Small_Multiple      :
      constant Unicode_Char := 16#1D919#;
   Signwriting_Squeeze_Sequential          :
      constant Unicode_Char := 16#1D91A#;
   Signwriting_Flick_Large_Single          :
      constant Unicode_Char := 16#1D91B#;
   Signwriting_Flick_Small_Single          :
      constant Unicode_Char := 16#1D91C#;
   Signwriting_Flick_Large_Multiple        :
      constant Unicode_Char := 16#1D91D#;
   Signwriting_Flick_Small_Multiple        :
      constant Unicode_Char := 16#1D91E#;
   Signwriting_Flick_Sequential            :
      constant Unicode_Char := 16#1D91F#;
   Signwriting_Squeeze_Flick_Alternating   :
      constant Unicode_Char := 16#1D920#;
   Signwriting_Movement_Hinge_Up_Down_Large :
      constant Unicode_Char := 16#1D921#;
   Signwriting_Movement_Hinge_Up_Down_Small :
      constant Unicode_Char := 16#1D922#;
   Signwriting_Movement_Hinge_Up_Sequential :
      constant Unicode_Char := 16#1D923#;
   Signwriting_Movement_Hinge_Down_Sequential :
      constant Unicode_Char := 16#1D924#;
   Signwriting_Movement_Hinge_Up_Down_Alternating_Large :
      constant Unicode_Char := 16#1D925#;
   Signwriting_Movement_Hinge_Up_Down_Alternating_Small :
      constant Unicode_Char := 16#1D926#;
   Signwriting_Movement_Hinge_Side_To_Side_Scissors :
      constant Unicode_Char := 16#1D927#;
   Signwriting_Movement_Wallplane_Finger_Contact :
      constant Unicode_Char := 16#1D928#;
   Signwriting_Movement_Floorplane_Finger_Contact :
      constant Unicode_Char := 16#1D929#;
   Signwriting_Movement_Wallplane_Single_Straight_Small :
      constant Unicode_Char := 16#1D92A#;
   Signwriting_Movement_Wallplane_Single_Straight_Medium :
      constant Unicode_Char := 16#1D92B#;
   Signwriting_Movement_Wallplane_Single_Straight_Large :
      constant Unicode_Char := 16#1D92C#;
   Signwriting_Movement_Wallplane_Single_Straight_Largest :
      constant Unicode_Char := 16#1D92D#;
   Signwriting_Movement_Wallplane_Single_Wrist_Flex :
      constant Unicode_Char := 16#1D92E#;
   Signwriting_Movement_Wallplane_Double_Straight :
      constant Unicode_Char := 16#1D92F#;
   Signwriting_Movement_Wallplane_Double_Wrist_Flex :
      constant Unicode_Char := 16#1D930#;
   Signwriting_Movement_Wallplane_Double_Alternating :
      constant Unicode_Char := 16#1D931#;
   Signwriting_Movement_Wallplane_Double_Alternating_Wrist_Flex :
      constant Unicode_Char := 16#1D932#;
   Signwriting_Movement_Wallplane_Cross    :
      constant Unicode_Char := 16#1D933#;
   Signwriting_Movement_Wallplane_Triple_Straight_Movement :
      constant Unicode_Char := 16#1D934#;
   Signwriting_Movement_Wallplane_Triple_Wrist_Flex :
      constant Unicode_Char := 16#1D935#;
   Signwriting_Movement_Wallplane_Triple_Alternating :
      constant Unicode_Char := 16#1D936#;
   Signwriting_Movement_Wallplane_Triple_Alternating_Wrist_Flex :
      constant Unicode_Char := 16#1D937#;
   Signwriting_Movement_Wallplane_Bend_Small :
      constant Unicode_Char := 16#1D938#;
   Signwriting_Movement_Wallplane_Bend_Medium :
      constant Unicode_Char := 16#1D939#;
   Signwriting_Movement_Wallplane_Bend_Large :
      constant Unicode_Char := 16#1D93A#;
   Signwriting_Movement_Wallplane_Corner_Small :
      constant Unicode_Char := 16#1D93B#;
   Signwriting_Movement_Wallplane_Corner_Medium :
      constant Unicode_Char := 16#1D93C#;
   Signwriting_Movement_Wallplane_Corner_Large :
      constant Unicode_Char := 16#1D93D#;
   Signwriting_Movement_Wallplane_Corner_Rotation :
      constant Unicode_Char := 16#1D93E#;
   Signwriting_Movement_Wallplane_Check_Small :
      constant Unicode_Char := 16#1D93F#;
   Signwriting_Movement_Wallplane_Check_Medium :
      constant Unicode_Char := 16#1D940#;
   Signwriting_Movement_Wallplane_Check_Large :
      constant Unicode_Char := 16#1D941#;
   Signwriting_Movement_Wallplane_Box_Small :
      constant Unicode_Char := 16#1D942#;
   Signwriting_Movement_Wallplane_Box_Medium :
      constant Unicode_Char := 16#1D943#;
   Signwriting_Movement_Wallplane_Box_Large :
      constant Unicode_Char := 16#1D944#;
   Signwriting_Movement_Wallplane_Zigzag_Small :
      constant Unicode_Char := 16#1D945#;
   Signwriting_Movement_Wallplane_Zigzag_Medium :
      constant Unicode_Char := 16#1D946#;
   Signwriting_Movement_Wallplane_Zigzag_Large :
      constant Unicode_Char := 16#1D947#;
   Signwriting_Movement_Wallplane_Peaks_Small :
      constant Unicode_Char := 16#1D948#;
   Signwriting_Movement_Wallplane_Peaks_Medium :
      constant Unicode_Char := 16#1D949#;
   Signwriting_Movement_Wallplane_Peaks_Large :
      constant Unicode_Char := 16#1D94A#;
   Signwriting_Travel_Wallplane_Rotation_Wallplane_Single :
      constant Unicode_Char := 16#1D94B#;
   Signwriting_Travel_Wallplane_Rotation_Wallplane_Double :
      constant Unicode_Char := 16#1D94C#;
   Signwriting_Travel_Wallplane_Rotation_Wallplane_Alternating :
      constant Unicode_Char := 16#1D94D#;
   Signwriting_Travel_Wallplane_Rotation_Floorplane_Single :
      constant Unicode_Char := 16#1D94E#;
   Signwriting_Travel_Wallplane_Rotation_Floorplane_Double :
      constant Unicode_Char := 16#1D94F#;
   Signwriting_Travel_Wallplane_Rotation_Floorplane_Alternating :
      constant Unicode_Char := 16#1D950#;
   Signwriting_Travel_Wallplane_Shaking    :
      constant Unicode_Char := 16#1D951#;
   Signwriting_Travel_Wallplane_Arm_Spiral_Single :
      constant Unicode_Char := 16#1D952#;
   Signwriting_Travel_Wallplane_Arm_Spiral_Double :
      constant Unicode_Char := 16#1D953#;
   Signwriting_Travel_Wallplane_Arm_Spiral_Triple :
      constant Unicode_Char := 16#1D954#;
   Signwriting_Movement_Diagonal_Away_Small :
      constant Unicode_Char := 16#1D955#;
   Signwriting_Movement_Diagonal_Away_Medium :
      constant Unicode_Char := 16#1D956#;
   Signwriting_Movement_Diagonal_Away_Large :
      constant Unicode_Char := 16#1D957#;
   Signwriting_Movement_Diagonal_Away_Largest :
      constant Unicode_Char := 16#1D958#;
   Signwriting_Movement_Diagonal_Towards_Small :
      constant Unicode_Char := 16#1D959#;
   Signwriting_Movement_Diagonal_Towards_Medium :
      constant Unicode_Char := 16#1D95A#;
   Signwriting_Movement_Diagonal_Towards_Large :
      constant Unicode_Char := 16#1D95B#;
   Signwriting_Movement_Diagonal_Towards_Largest :
      constant Unicode_Char := 16#1D95C#;
   Signwriting_Movement_Diagonal_Between_Away_Small :
      constant Unicode_Char := 16#1D95D#;
   Signwriting_Movement_Diagonal_Between_Away_Medium :
      constant Unicode_Char := 16#1D95E#;
   Signwriting_Movement_Diagonal_Between_Away_Large :
      constant Unicode_Char := 16#1D95F#;
   Signwriting_Movement_Diagonal_Between_Away_Largest :
      constant Unicode_Char := 16#1D960#;
   Signwriting_Movement_Diagonal_Between_Towards_Small :
      constant Unicode_Char := 16#1D961#;
   Signwriting_Movement_Diagonal_Between_Towards_Medium :
      constant Unicode_Char := 16#1D962#;
   Signwriting_Movement_Diagonal_Between_Towards_Large :
      constant Unicode_Char := 16#1D963#;
   Signwriting_Movement_Diagonal_Between_Towards_Largest :
      constant Unicode_Char := 16#1D964#;
   Signwriting_Movement_Floorplane_Single_Straight_Small :
      constant Unicode_Char := 16#1D965#;
   Signwriting_Movement_Floorplane_Single_Straight_Medium :
      constant Unicode_Char := 16#1D966#;
   Signwriting_Movement_Floorplane_Single_Straight_Large :
      constant Unicode_Char := 16#1D967#;
   Signwriting_Movement_Floorplane_Single_Straight_Largest :
      constant Unicode_Char := 16#1D968#;
   Signwriting_Movement_Floorplane_Single_Wrist_Flex :
      constant Unicode_Char := 16#1D969#;
   Signwriting_Movement_Floorplane_Double_Straight :
      constant Unicode_Char := 16#1D96A#;
   Signwriting_Movement_Floorplane_Double_Wrist_Flex :
      constant Unicode_Char := 16#1D96B#;
   Signwriting_Movement_Floorplane_Double_Alternating :
      constant Unicode_Char := 16#1D96C#;
   Signwriting_Movement_Floorplane_Double_Alternating_Wrist_Flex :
      constant Unicode_Char := 16#1D96D#;
   Signwriting_Movement_Floorplane_Cross   :
      constant Unicode_Char := 16#1D96E#;
   Signwriting_Movement_Floorplane_Triple_Straight_Movement :
      constant Unicode_Char := 16#1D96F#;
   Signwriting_Movement_Floorplane_Triple_Wrist_Flex :
      constant Unicode_Char := 16#1D970#;
   Signwriting_Movement_Floorplane_Triple_Alternating_Movement :
      constant Unicode_Char := 16#1D971#;
   Signwriting_Movement_Floorplane_Triple_Alternating_Wrist_Flex :
      constant Unicode_Char := 16#1D972#;
   Signwriting_Movement_Floorplane_Bend    :
      constant Unicode_Char := 16#1D973#;
   Signwriting_Movement_Floorplane_Corner_Small :
      constant Unicode_Char := 16#1D974#;
   Signwriting_Movement_Floorplane_Corner_Medium :
      constant Unicode_Char := 16#1D975#;
   Signwriting_Movement_Floorplane_Corner_Large :
      constant Unicode_Char := 16#1D976#;
   Signwriting_Movement_Floorplane_Check   :
      constant Unicode_Char := 16#1D977#;
   Signwriting_Movement_Floorplane_Box_Small :
      constant Unicode_Char := 16#1D978#;
   Signwriting_Movement_Floorplane_Box_Medium :
      constant Unicode_Char := 16#1D979#;
   Signwriting_Movement_Floorplane_Box_Large :
      constant Unicode_Char := 16#1D97A#;
   Signwriting_Movement_Floorplane_Zigzag_Small :
      constant Unicode_Char := 16#1D97B#;
   Signwriting_Movement_Floorplane_Zigzag_Medium :
      constant Unicode_Char := 16#1D97C#;
   Signwriting_Movement_Floorplane_Zigzag_Large :
      constant Unicode_Char := 16#1D97D#;
   Signwriting_Movement_Floorplane_Peaks_Small :
      constant Unicode_Char := 16#1D97E#;
   Signwriting_Movement_Floorplane_Peaks_Medium :
      constant Unicode_Char := 16#1D97F#;
   Signwriting_Movement_Floorplane_Peaks_Large :
      constant Unicode_Char := 16#1D980#;
   Signwriting_Travel_Floorplane_Rotation_Floorplane_Single :
      constant Unicode_Char := 16#1D981#;
   Signwriting_Travel_Floorplane_Rotation_Floorplane_Double :
      constant Unicode_Char := 16#1D982#;
   Signwriting_Travel_Floorplane_Rotation_Floorplane_Alternating :
      constant Unicode_Char := 16#1D983#;
   Signwriting_Travel_Floorplane_Rotation_Wallplane_Single :
      constant Unicode_Char := 16#1D984#;
   Signwriting_Travel_Floorplane_Rotation_Wallplane_Double :
      constant Unicode_Char := 16#1D985#;
   Signwriting_Travel_Floorplane_Rotation_Wallplane_Alternating :
      constant Unicode_Char := 16#1D986#;
   Signwriting_Travel_Floorplane_Shaking   :
      constant Unicode_Char := 16#1D987#;
   Signwriting_Movement_Wallplane_Curve_Quarter_Small :
      constant Unicode_Char := 16#1D988#;
   Signwriting_Movement_Wallplane_Curve_Quarter_Medium :
      constant Unicode_Char := 16#1D989#;
   Signwriting_Movement_Wallplane_Curve_Quarter_Large :
      constant Unicode_Char := 16#1D98A#;
   Signwriting_Movement_Wallplane_Curve_Quarter_Largest :
      constant Unicode_Char := 16#1D98B#;
   Signwriting_Movement_Wallplane_Curve_Half_Circle_Small :
      constant Unicode_Char := 16#1D98C#;
   Signwriting_Movement_Wallplane_Curve_Half_Circle_Medium :
      constant Unicode_Char := 16#1D98D#;
   Signwriting_Movement_Wallplane_Curve_Half_Circle_Large :
      constant Unicode_Char := 16#1D98E#;
   Signwriting_Movement_Wallplane_Curve_Half_Circle_Largest :
      constant Unicode_Char := 16#1D98F#;
   Signwriting_Movement_Wallplane_Curve_Three_Quarter_Circle_Small :
      constant Unicode_Char := 16#1D990#;
   Signwriting_Movement_Wallplane_Curve_Three_Quarter_Circle_Medium :
      constant Unicode_Char := 16#1D991#;
   Signwriting_Movement_Wallplane_Hump_Small :
      constant Unicode_Char := 16#1D992#;
   Signwriting_Movement_Wallplane_Hump_Medium :
      constant Unicode_Char := 16#1D993#;
   Signwriting_Movement_Wallplane_Hump_Large :
      constant Unicode_Char := 16#1D994#;
   Signwriting_Movement_Wallplane_Loop_Small :
      constant Unicode_Char := 16#1D995#;
   Signwriting_Movement_Wallplane_Loop_Medium :
      constant Unicode_Char := 16#1D996#;
   Signwriting_Movement_Wallplane_Loop_Large :
      constant Unicode_Char := 16#1D997#;
   Signwriting_Movement_Wallplane_Loop_Small_Double :
      constant Unicode_Char := 16#1D998#;
   Signwriting_Movement_Wallplane_Wave_Curve_Double_Small :
      constant Unicode_Char := 16#1D999#;
   Signwriting_Movement_Wallplane_Wave_Curve_Double_Medium :
      constant Unicode_Char := 16#1D99A#;
   Signwriting_Movement_Wallplane_Wave_Curve_Double_Large :
      constant Unicode_Char := 16#1D99B#;
   Signwriting_Movement_Wallplane_Wave_Curve_Triple_Small :
      constant Unicode_Char := 16#1D99C#;
   Signwriting_Movement_Wallplane_Wave_Curve_Triple_Medium :
      constant Unicode_Char := 16#1D99D#;
   Signwriting_Movement_Wallplane_Wave_Curve_Triple_Large :
      constant Unicode_Char := 16#1D99E#;
   Signwriting_Movement_Wallplane_Curve_Then_Straight :
      constant Unicode_Char := 16#1D99F#;
   Signwriting_Movement_Wallplane_Curved_Cross_Small :
      constant Unicode_Char := 16#1D9A0#;
   Signwriting_Movement_Wallplane_Curved_Cross_Medium :
      constant Unicode_Char := 16#1D9A1#;
   Signwriting_Rotation_Wallplane_Single   :
      constant Unicode_Char := 16#1D9A2#;
   Signwriting_Rotation_Wallplane_Double   :
      constant Unicode_Char := 16#1D9A3#;
   Signwriting_Rotation_Wallplane_Alternate :
      constant Unicode_Char := 16#1D9A4#;
   Signwriting_Movement_Wallplane_Shaking  :
      constant Unicode_Char := 16#1D9A5#;
   Signwriting_Movement_Wallplane_Curve_Hitting_Front_Wall :
      constant Unicode_Char := 16#1D9A6#;
   Signwriting_Movement_Wallplane_Hump_Hitting_Front_Wall :
      constant Unicode_Char := 16#1D9A7#;
   Signwriting_Movement_Wallplane_Loop_Hitting_Front_Wall :
      constant Unicode_Char := 16#1D9A8#;
   Signwriting_Movement_Wallplane_Wave_Hitting_Front_Wall :
      constant Unicode_Char := 16#1D9A9#;
   Signwriting_Rotation_Wallplane_Single_Hitting_Front_Wall :
      constant Unicode_Char := 16#1D9AA#;
   Signwriting_Rotation_Wallplane_Double_Hitting_Front_Wall :
      constant Unicode_Char := 16#1D9AB#;
   Signwriting_Rotation_Wallplane_Alternating_Hitting_Front_Wall :
      constant Unicode_Char := 16#1D9AC#;
   Signwriting_Movement_Wallplane_Curve_Hitting_Chest :
      constant Unicode_Char := 16#1D9AD#;
   Signwriting_Movement_Wallplane_Hump_Hitting_Chest :
      constant Unicode_Char := 16#1D9AE#;
   Signwriting_Movement_Wallplane_Loop_Hitting_Chest :
      constant Unicode_Char := 16#1D9AF#;
   Signwriting_Movement_Wallplane_Wave_Hitting_Chest :
      constant Unicode_Char := 16#1D9B0#;
   Signwriting_Rotation_Wallplane_Single_Hitting_Chest :
      constant Unicode_Char := 16#1D9B1#;
   Signwriting_Rotation_Wallplane_Double_Hitting_Chest :
      constant Unicode_Char := 16#1D9B2#;
   Signwriting_Rotation_Wallplane_Alternating_Hitting_Chest :
      constant Unicode_Char := 16#1D9B3#;
   Signwriting_Movement_Wallplane_Wave_Diagonal_Path_Small :
      constant Unicode_Char := 16#1D9B4#;
   Signwriting_Movement_Wallplane_Wave_Diagonal_Path_Medium :
      constant Unicode_Char := 16#1D9B5#;
   Signwriting_Movement_Wallplane_Wave_Diagonal_Path_Large :
      constant Unicode_Char := 16#1D9B6#;
   Signwriting_Movement_Floorplane_Curve_Hitting_Ceiling_Small :
      constant Unicode_Char := 16#1D9B7#;
   Signwriting_Movement_Floorplane_Curve_Hitting_Ceiling_Large :
      constant Unicode_Char := 16#1D9B8#;
   Signwriting_Movement_Floorplane_Hump_Hitting_Ceiling_Small_Double :
      constant Unicode_Char := 16#1D9B9#;
   Signwriting_Movement_Floorplane_Hump_Hitting_Ceiling_Large_Double :
      constant Unicode_Char := 16#1D9BA#;
   Signwriting_Movement_Floorplane_Hump_Hitting_Ceiling_Small_Triple :
      constant Unicode_Char := 16#1D9BB#;
   Signwriting_Movement_Floorplane_Hump_Hitting_Ceiling_Large_Triple :
      constant Unicode_Char := 16#1D9BC#;
   Signwriting_Movement_Floorplane_Loop_Hitting_Ceiling_Small_Single :
      constant Unicode_Char := 16#1D9BD#;
   Signwriting_Movement_Floorplane_Loop_Hitting_Ceiling_Large_Single :
      constant Unicode_Char := 16#1D9BE#;
   Signwriting_Movement_Floorplane_Loop_Hitting_Ceiling_Small_Double :
      constant Unicode_Char := 16#1D9BF#;
   Signwriting_Movement_Floorplane_Loop_Hitting_Ceiling_Large_Double :
      constant Unicode_Char := 16#1D9C0#;
   Signwriting_Movement_Floorplane_Wave_Hitting_Ceiling_Small :
      constant Unicode_Char := 16#1D9C1#;
   Signwriting_Movement_Floorplane_Wave_Hitting_Ceiling_Large :
      constant Unicode_Char := 16#1D9C2#;
   Signwriting_Rotation_Floorplane_Single_Hitting_Ceiling :
      constant Unicode_Char := 16#1D9C3#;
   Signwriting_Rotation_Floorplane_Double_Hitting_Ceiling :
      constant Unicode_Char := 16#1D9C4#;
   Signwriting_Rotation_Floorplane_Alternating_Hitting_Ceiling :
      constant Unicode_Char := 16#1D9C5#;
   Signwriting_Movement_Floorplane_Curve_Hitting_Floor_Small :
      constant Unicode_Char := 16#1D9C6#;
   Signwriting_Movement_Floorplane_Curve_Hitting_Floor_Large :
      constant Unicode_Char := 16#1D9C7#;
   Signwriting_Movement_Floorplane_Hump_Hitting_Floor_Small_Double :
      constant Unicode_Char := 16#1D9C8#;
   Signwriting_Movement_Floorplane_Hump_Hitting_Floor_Large_Double :
      constant Unicode_Char := 16#1D9C9#;
   Signwriting_Movement_Floorplane_Hump_Hitting_Floor_Triple_Small_Triple :
      constant Unicode_Char := 16#1D9CA#;
   Signwriting_Movement_Floorplane_Hump_Hitting_Floor_Triple_Large_Triple :
      constant Unicode_Char := 16#1D9CB#;
   Signwriting_Movement_Floorplane_Loop_Hitting_Floor_Small_Single :
      constant Unicode_Char := 16#1D9CC#;
   Signwriting_Movement_Floorplane_Loop_Hitting_Floor_Large_Single :
      constant Unicode_Char := 16#1D9CD#;
   Signwriting_Movement_Floorplane_Loop_Hitting_Floor_Small_Double :
      constant Unicode_Char := 16#1D9CE#;
   Signwriting_Movement_Floorplane_Loop_Hitting_Floor_Large_Double :
      constant Unicode_Char := 16#1D9CF#;
   Signwriting_Movement_Floorplane_Wave_Hitting_Floor_Small :
      constant Unicode_Char := 16#1D9D0#;
   Signwriting_Movement_Floorplane_Wave_Hitting_Floor_Large :
      constant Unicode_Char := 16#1D9D1#;
   Signwriting_Rotation_Floorplane_Single_Hitting_Floor :
      constant Unicode_Char := 16#1D9D2#;
   Signwriting_Rotation_Floorplane_Double_Hitting_Floor :
      constant Unicode_Char := 16#1D9D3#;
   Signwriting_Rotation_Floorplane_Alternating_Hitting_Floor :
      constant Unicode_Char := 16#1D9D4#;
   Signwriting_Movement_Floorplane_Curve_Small :
      constant Unicode_Char := 16#1D9D5#;
   Signwriting_Movement_Floorplane_Curve_Medium :
      constant Unicode_Char := 16#1D9D6#;
   Signwriting_Movement_Floorplane_Curve_Large :
      constant Unicode_Char := 16#1D9D7#;
   Signwriting_Movement_Floorplane_Curve_Largest :
      constant Unicode_Char := 16#1D9D8#;
   Signwriting_Movement_Floorplane_Curve_Combined :
      constant Unicode_Char := 16#1D9D9#;
   Signwriting_Movement_Floorplane_Hump_Small :
      constant Unicode_Char := 16#1D9DA#;
   Signwriting_Movement_Floorplane_Loop_Small :
      constant Unicode_Char := 16#1D9DB#;
   Signwriting_Movement_Floorplane_Wave_Snake :
      constant Unicode_Char := 16#1D9DC#;
   Signwriting_Movement_Floorplane_Wave_Small :
      constant Unicode_Char := 16#1D9DD#;
   Signwriting_Movement_Floorplane_Wave_Large :
      constant Unicode_Char := 16#1D9DE#;
   Signwriting_Rotation_Floorplane_Single  :
      constant Unicode_Char := 16#1D9DF#;
   Signwriting_Rotation_Floorplane_Double  :
      constant Unicode_Char := 16#1D9E0#;
   Signwriting_Rotation_Floorplane_Alternating :
      constant Unicode_Char := 16#1D9E1#;
   Signwriting_Movement_Floorplane_Shaking_Parallel :
      constant Unicode_Char := 16#1D9E2#;
   Signwriting_Movement_Wallplane_Arm_Circle_Small_Single :
      constant Unicode_Char := 16#1D9E3#;
   Signwriting_Movement_Wallplane_Arm_Circle_Medium_Single :
      constant Unicode_Char := 16#1D9E4#;
   Signwriting_Movement_Wallplane_Arm_Circle_Small_Double :
      constant Unicode_Char := 16#1D9E5#;
   Signwriting_Movement_Wallplane_Arm_Circle_Medium_Double :
      constant Unicode_Char := 16#1D9E6#;
   Signwriting_Movement_Floorplane_Arm_Circle_Hitting_Wall_Small_Single :
      constant Unicode_Char := 16#1D9E7#;
   Signwriting_Movement_Floorplane_Arm_Circle_Hitting_Wall_Medium_Single :
      constant Unicode_Char := 16#1D9E8#;
   Signwriting_Movement_Floorplane_Arm_Circle_Hitting_Wall_Large_Single :
      constant Unicode_Char := 16#1D9E9#;
   Signwriting_Movement_Floorplane_Arm_Circle_Hitting_Wall_Small_Double :
      constant Unicode_Char := 16#1D9EA#;
   Signwriting_Movement_Floorplane_Arm_Circle_Hitting_Wall_Medium_Double :
      constant Unicode_Char := 16#1D9EB#;
   Signwriting_Movement_Floorplane_Arm_Circle_Hitting_Wall_Large_Double :
      constant Unicode_Char := 16#1D9EC#;
   Signwriting_Movement_Wallplane_Wrist_Circle_Front_Single :
      constant Unicode_Char := 16#1D9ED#;
   Signwriting_Movement_Wallplane_Wrist_Circle_Front_Double :
      constant Unicode_Char := 16#1D9EE#;
   Signwriting_Movement_Floorplane_Wrist_Circle_Hitting_Wall_Single :
      constant Unicode_Char := 16#1D9EF#;
   Signwriting_Movement_Floorplane_Wrist_Circle_Hitting_Wall_Double :
      constant Unicode_Char := 16#1D9F0#;
   Signwriting_Movement_Wallplane_Finger_Circles_Single :
      constant Unicode_Char := 16#1D9F1#;
   Signwriting_Movement_Wallplane_Finger_Circles_Double :
      constant Unicode_Char := 16#1D9F2#;
   Signwriting_Movement_Floorplane_Finger_Circles_Hitting_Wall_Single :
      constant Unicode_Char := 16#1D9F3#;
   Signwriting_Movement_Floorplane_Finger_Circles_Hitting_Wall_Double :
      constant Unicode_Char := 16#1D9F4#;
   Signwriting_Dynamic_Arrowhead_Small     :
      constant Unicode_Char := 16#1D9F5#;
   Signwriting_Dynamic_Arrowhead_Large     :
      constant Unicode_Char := 16#1D9F6#;
   Signwriting_Dynamic_Fast                :
      constant Unicode_Char := 16#1D9F7#;
   Signwriting_Dynamic_Slow                :
      constant Unicode_Char := 16#1D9F8#;
   Signwriting_Dynamic_Tense               :
      constant Unicode_Char := 16#1D9F9#;
   Signwriting_Dynamic_Relaxed             :
      constant Unicode_Char := 16#1D9FA#;
   Signwriting_Dynamic_Simultaneous        :
      constant Unicode_Char := 16#1D9FB#;
   Signwriting_Dynamic_Simultaneous_Alternating :
      constant Unicode_Char := 16#1D9FC#;
   Signwriting_Dynamic_Every_Other_Time    :
      constant Unicode_Char := 16#1D9FD#;
   Signwriting_Dynamic_Gradual             :
      constant Unicode_Char := 16#1D9FE#;
   Signwriting_Head                        :
      constant Unicode_Char := 16#1D9FF#;
   Signwriting_Head_Rim                    :
      constant Unicode_Char := 16#1DA00#;
   Signwriting_Head_Movement_Wallplane_Straight :
      constant Unicode_Char := 16#1DA01#;
   Signwriting_Head_Movement_Wallplane_Tilt :
      constant Unicode_Char := 16#1DA02#;
   Signwriting_Head_Movement_Floorplane_Straight :
      constant Unicode_Char := 16#1DA03#;
   Signwriting_Head_Movement_Wallplane_Curve :
      constant Unicode_Char := 16#1DA04#;
   Signwriting_Head_Movement_Floorplane_Curve :
      constant Unicode_Char := 16#1DA05#;
   Signwriting_Head_Movement_Circle        :
      constant Unicode_Char := 16#1DA06#;
   Signwriting_Face_Direction_Position_Nose_Forward_Tilting :
      constant Unicode_Char := 16#1DA07#;
   Signwriting_Face_Direction_Position_Nose_Up_Or_Down :
      constant Unicode_Char := 16#1DA08#;
   Signwriting_Face_Direction_Position_Nose_Up_Or_Down_Tilting :
      constant Unicode_Char := 16#1DA09#;
   Signwriting_Eyebrows_Straight_Up        :
      constant Unicode_Char := 16#1DA0A#;
   Signwriting_Eyebrows_Straight_Neutral   :
      constant Unicode_Char := 16#1DA0B#;
   Signwriting_Eyebrows_Straight_Down      :
      constant Unicode_Char := 16#1DA0C#;
   Signwriting_Dreamy_Eyebrows_Neutral_Down :
      constant Unicode_Char := 16#1DA0D#;
   Signwriting_Dreamy_Eyebrows_Down_Neutral :
      constant Unicode_Char := 16#1DA0E#;
   Signwriting_Dreamy_Eyebrows_Up_Neutral  :
      constant Unicode_Char := 16#1DA0F#;
   Signwriting_Dreamy_Eyebrows_Neutral_Up  :
      constant Unicode_Char := 16#1DA10#;
   Signwriting_Forehead_Neutral            :
      constant Unicode_Char := 16#1DA11#;
   Signwriting_Forehead_Contact            :
      constant Unicode_Char := 16#1DA12#;
   Signwriting_Forehead_Wrinkled           :
      constant Unicode_Char := 16#1DA13#;
   Signwriting_Eyes_Open                   :
      constant Unicode_Char := 16#1DA14#;
   Signwriting_Eyes_Squeezed               :
      constant Unicode_Char := 16#1DA15#;
   Signwriting_Eyes_Closed                 :
      constant Unicode_Char := 16#1DA16#;
   Signwriting_Eye_Blink_Single            :
      constant Unicode_Char := 16#1DA17#;
   Signwriting_Eye_Blink_Multiple          :
      constant Unicode_Char := 16#1DA18#;
   Signwriting_Eyes_Half_Open              :
      constant Unicode_Char := 16#1DA19#;
   Signwriting_Eyes_Wide_Open              :
      constant Unicode_Char := 16#1DA1A#;
   Signwriting_Eyes_Half_Closed            :
      constant Unicode_Char := 16#1DA1B#;
   Signwriting_Eyes_Widening_Movement      :
      constant Unicode_Char := 16#1DA1C#;
   Signwriting_Eye_Wink                    :
      constant Unicode_Char := 16#1DA1D#;
   Signwriting_Eyelashes_Up                :
      constant Unicode_Char := 16#1DA1E#;
   Signwriting_Eyelashes_Down              :
      constant Unicode_Char := 16#1DA1F#;
   Signwriting_Eyelashes_Fluttering        :
      constant Unicode_Char := 16#1DA20#;
   Signwriting_Eyegaze_Wallplane_Straight  :
      constant Unicode_Char := 16#1DA21#;
   Signwriting_Eyegaze_Wallplane_Straight_Double :
      constant Unicode_Char := 16#1DA22#;
   Signwriting_Eyegaze_Wallplane_Straight_Alternating :
      constant Unicode_Char := 16#1DA23#;
   Signwriting_Eyegaze_Floorplane_Straight :
      constant Unicode_Char := 16#1DA24#;
   Signwriting_Eyegaze_Floorplane_Straight_Double :
      constant Unicode_Char := 16#1DA25#;
   Signwriting_Eyegaze_Floorplane_Straight_Alternating :
      constant Unicode_Char := 16#1DA26#;
   Signwriting_Eyegaze_Wallplane_Curved    :
      constant Unicode_Char := 16#1DA27#;
   Signwriting_Eyegaze_Floorplane_Curved   :
      constant Unicode_Char := 16#1DA28#;
   Signwriting_Eyegaze_Wallplane_Circling  :
      constant Unicode_Char := 16#1DA29#;
   Signwriting_Cheeks_Puffed               :
      constant Unicode_Char := 16#1DA2A#;
   Signwriting_Cheeks_Neutral              :
      constant Unicode_Char := 16#1DA2B#;
   Signwriting_Cheeks_Sucked               :
      constant Unicode_Char := 16#1DA2C#;
   Signwriting_Tense_Cheeks_High           :
      constant Unicode_Char := 16#1DA2D#;
   Signwriting_Tense_Cheeks_Middle         :
      constant Unicode_Char := 16#1DA2E#;
   Signwriting_Tense_Cheeks_Low            :
      constant Unicode_Char := 16#1DA2F#;
   Signwriting_Ears                        :
      constant Unicode_Char := 16#1DA30#;
   Signwriting_Nose_Neutral                :
      constant Unicode_Char := 16#1DA31#;
   Signwriting_Nose_Contact                :
      constant Unicode_Char := 16#1DA32#;
   Signwriting_Nose_Wrinkles               :
      constant Unicode_Char := 16#1DA33#;
   Signwriting_Nose_Wiggles                :
      constant Unicode_Char := 16#1DA34#;
   Signwriting_Air_Blowing_Out             :
      constant Unicode_Char := 16#1DA35#;
   Signwriting_Air_Sucking_In              :
      constant Unicode_Char := 16#1DA36#;
   Signwriting_Air_Blow_Small_Rotations    :
      constant Unicode_Char := 16#1DA37#;
   Signwriting_Air_Suck_Small_Rotations    :
      constant Unicode_Char := 16#1DA38#;
   Signwriting_Breath_Inhale               :
      constant Unicode_Char := 16#1DA39#;
   Signwriting_Breath_Exhale               :
      constant Unicode_Char := 16#1DA3A#;
   Signwriting_Mouth_Closed_Neutral        :
      constant Unicode_Char := 16#1DA3B#;
   Signwriting_Mouth_Closed_Forward        :
      constant Unicode_Char := 16#1DA3C#;
   Signwriting_Mouth_Closed_Contact        :
      constant Unicode_Char := 16#1DA3D#;
   Signwriting_Mouth_Smile                 :
      constant Unicode_Char := 16#1DA3E#;
   Signwriting_Mouth_Smile_Wrinkled        :
      constant Unicode_Char := 16#1DA3F#;
   Signwriting_Mouth_Smile_Open            :
      constant Unicode_Char := 16#1DA40#;
   Signwriting_Mouth_Frown                 :
      constant Unicode_Char := 16#1DA41#;
   Signwriting_Mouth_Frown_Wrinkled        :
      constant Unicode_Char := 16#1DA42#;
   Signwriting_Mouth_Frown_Open            :
      constant Unicode_Char := 16#1DA43#;
   Signwriting_Mouth_Open_Circle           :
      constant Unicode_Char := 16#1DA44#;
   Signwriting_Mouth_Open_Forward          :
      constant Unicode_Char := 16#1DA45#;
   Signwriting_Mouth_Open_Wrinkled         :
      constant Unicode_Char := 16#1DA46#;
   Signwriting_Mouth_Open_Oval             :
      constant Unicode_Char := 16#1DA47#;
   Signwriting_Mouth_Open_Oval_Wrinkled    :
      constant Unicode_Char := 16#1DA48#;
   Signwriting_Mouth_Open_Oval_Yawn        :
      constant Unicode_Char := 16#1DA49#;
   Signwriting_Mouth_Open_Rectangle        :
      constant Unicode_Char := 16#1DA4A#;
   Signwriting_Mouth_Open_Rectangle_Wrinkled :
      constant Unicode_Char := 16#1DA4B#;
   Signwriting_Mouth_Open_Rectangle_Yawn   :
      constant Unicode_Char := 16#1DA4C#;
   Signwriting_Mouth_Kiss                  :
      constant Unicode_Char := 16#1DA4D#;
   Signwriting_Mouth_Kiss_Forward          :
      constant Unicode_Char := 16#1DA4E#;
   Signwriting_Mouth_Kiss_Wrinkled         :
      constant Unicode_Char := 16#1DA4F#;
   Signwriting_Mouth_Tense                 :
      constant Unicode_Char := 16#1DA50#;
   Signwriting_Mouth_Tense_Forward         :
      constant Unicode_Char := 16#1DA51#;
   Signwriting_Mouth_Tense_Sucked          :
      constant Unicode_Char := 16#1DA52#;
   Signwriting_Lips_Pressed_Together       :
      constant Unicode_Char := 16#1DA53#;
   Signwriting_Lip_Lower_Over_Upper        :
      constant Unicode_Char := 16#1DA54#;
   Signwriting_Lip_Upper_Over_Lower        :
      constant Unicode_Char := 16#1DA55#;
   Signwriting_Mouth_Corners               :
      constant Unicode_Char := 16#1DA56#;
   Signwriting_Mouth_Wrinkles_Single       :
      constant Unicode_Char := 16#1DA57#;
   Signwriting_Mouth_Wrinkles_Double       :
      constant Unicode_Char := 16#1DA58#;
   Signwriting_Tongue_Sticking_Out_Far     :
      constant Unicode_Char := 16#1DA59#;
   Signwriting_Tongue_Licking_Lips         :
      constant Unicode_Char := 16#1DA5A#;
   Signwriting_Tongue_Tip_Between_Lips     :
      constant Unicode_Char := 16#1DA5B#;
   Signwriting_Tongue_Tip_Touching_Inside_Mouth :
      constant Unicode_Char := 16#1DA5C#;
   Signwriting_Tongue_Inside_Mouth_Relaxed :
      constant Unicode_Char := 16#1DA5D#;
   Signwriting_Tongue_Moves_Against_Cheek  :
      constant Unicode_Char := 16#1DA5E#;
   Signwriting_Tongue_Centre_Sticking_Out  :
      constant Unicode_Char := 16#1DA5F#;
   Signwriting_Tongue_Centre_Inside_Mouth  :
      constant Unicode_Char := 16#1DA60#;
   Signwriting_Teeth                       :
      constant Unicode_Char := 16#1DA61#;
   Signwriting_Teeth_Movement              :
      constant Unicode_Char := 16#1DA62#;
   Signwriting_Teeth_On_Tongue             :
      constant Unicode_Char := 16#1DA63#;
   Signwriting_Teeth_On_Tongue_Movement    :
      constant Unicode_Char := 16#1DA64#;
   Signwriting_Teeth_On_Lips               :
      constant Unicode_Char := 16#1DA65#;
   Signwriting_Teeth_On_Lips_Movement      :
      constant Unicode_Char := 16#1DA66#;
   Signwriting_Teeth_Bite_Lips             :
      constant Unicode_Char := 16#1DA67#;
   Signwriting_Movement_Wallplane_Jaw      :
      constant Unicode_Char := 16#1DA68#;
   Signwriting_Movement_Floorplane_Jaw     :
      constant Unicode_Char := 16#1DA69#;
   Signwriting_Neck                        :
      constant Unicode_Char := 16#1DA6A#;
   Signwriting_Hair                        :
      constant Unicode_Char := 16#1DA6B#;
   Signwriting_Excitement                  :
      constant Unicode_Char := 16#1DA6C#;
   Signwriting_Shoulder_Hip_Spine          :
      constant Unicode_Char := 16#1DA6D#;
   Signwriting_Shoulder_Hip_Positions      :
      constant Unicode_Char := 16#1DA6E#;
   Signwriting_Wallplane_Shoulder_Hip_Move :
      constant Unicode_Char := 16#1DA6F#;
   Signwriting_Floorplane_Shoulder_Hip_Move :
      constant Unicode_Char := 16#1DA70#;
   Signwriting_Shoulder_Tilting_From_Waist :
      constant Unicode_Char := 16#1DA71#;
   Signwriting_Torso_Wallplane_Straight_Stretch :
      constant Unicode_Char := 16#1DA72#;
   Signwriting_Torso_Wallplane_Curved_Bend :
      constant Unicode_Char := 16#1DA73#;
   Signwriting_Torso_Floorplane_Twisting   :
      constant Unicode_Char := 16#1DA74#;
   Signwriting_Upper_Body_Tilting_From_Hip_Joints :
      constant Unicode_Char := 16#1DA75#;
   Signwriting_Limb_Combination            :
      constant Unicode_Char := 16#1DA76#;
   Signwriting_Limb_Length_1               :
      constant Unicode_Char := 16#1DA77#;
   Signwriting_Limb_Length_2               :
      constant Unicode_Char := 16#1DA78#;
   Signwriting_Limb_Length_3               :
      constant Unicode_Char := 16#1DA79#;
   Signwriting_Limb_Length_4               :
      constant Unicode_Char := 16#1DA7A#;
   Signwriting_Limb_Length_5               :
      constant Unicode_Char := 16#1DA7B#;
   Signwriting_Limb_Length_6               :
      constant Unicode_Char := 16#1DA7C#;
   Signwriting_Limb_Length_7               :
      constant Unicode_Char := 16#1DA7D#;
   Signwriting_Finger                      :
      constant Unicode_Char := 16#1DA7E#;
   Signwriting_Location_Wallplane_Space    :
      constant Unicode_Char := 16#1DA7F#;
   Signwriting_Location_Floorplane_Space   :
      constant Unicode_Char := 16#1DA80#;
   Signwriting_Location_Height             :
      constant Unicode_Char := 16#1DA81#;
   Signwriting_Location_Width              :
      constant Unicode_Char := 16#1DA82#;
   Signwriting_Location_Depth              :
      constant Unicode_Char := 16#1DA83#;
   Signwriting_Location_Head_Neck          :
      constant Unicode_Char := 16#1DA84#;
   Signwriting_Location_Torso              :
      constant Unicode_Char := 16#1DA85#;
   Signwriting_Location_Limbs_Digits       :
      constant Unicode_Char := 16#1DA86#;
   Signwriting_Comma                       :
      constant Unicode_Char := 16#1DA87#;
   Signwriting_Full_Stop                   :
      constant Unicode_Char := 16#1DA88#;
   Signwriting_Semicolon                   :
      constant Unicode_Char := 16#1DA89#;
   Signwriting_Colon                       :
      constant Unicode_Char := 16#1DA8A#;
   Signwriting_Parenthesis                 :
      constant Unicode_Char := 16#1DA8B#;
   Signwriting_Fill_Modifier_2             :
      constant Unicode_Char := 16#1DA9B#;
   Signwriting_Fill_Modifier_3             :
      constant Unicode_Char := 16#1DA9C#;
   Signwriting_Fill_Modifier_4             :
      constant Unicode_Char := 16#1DA9D#;
   Signwriting_Fill_Modifier_5             :
      constant Unicode_Char := 16#1DA9E#;
   Signwriting_Fill_Modifier_6             :
      constant Unicode_Char := 16#1DA9F#;
   Signwriting_Rotation_Modifier_2         :
      constant Unicode_Char := 16#1DAA1#;
   Signwriting_Rotation_Modifier_3         :
      constant Unicode_Char := 16#1DAA2#;
   Signwriting_Rotation_Modifier_4         :
      constant Unicode_Char := 16#1DAA3#;
   Signwriting_Rotation_Modifier_5         :
      constant Unicode_Char := 16#1DAA4#;
   Signwriting_Rotation_Modifier_6         :
      constant Unicode_Char := 16#1DAA5#;
   Signwriting_Rotation_Modifier_7         :
      constant Unicode_Char := 16#1DAA6#;
   Signwriting_Rotation_Modifier_8         :
      constant Unicode_Char := 16#1DAA7#;
   Signwriting_Rotation_Modifier_9         :
      constant Unicode_Char := 16#1DAA8#;
   Signwriting_Rotation_Modifier_10        :
      constant Unicode_Char := 16#1DAA9#;
   Signwriting_Rotation_Modifier_11        :
      constant Unicode_Char := 16#1DAAA#;
   Signwriting_Rotation_Modifier_12        :
      constant Unicode_Char := 16#1DAAB#;
   Signwriting_Rotation_Modifier_13        :
      constant Unicode_Char := 16#1DAAC#;
   Signwriting_Rotation_Modifier_14        :
      constant Unicode_Char := 16#1DAAD#;
   Signwriting_Rotation_Modifier_15        :
      constant Unicode_Char := 16#1DAAE#;
   Signwriting_Rotation_Modifier_16        :
      constant Unicode_Char := 16#1DAAF#;
end Unicode.Names.Sutton_Signwriting;
