--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Kaithi is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Kaithi_Sign_Candrabindu                 :
      constant Unicode_Char := 16#11080#;
   Kaithi_Sign_Anusvara                    :
      constant Unicode_Char := 16#11081#;
   Kaithi_Sign_Visarga                     :
      constant Unicode_Char := 16#11082#;
   Kaithi_Letter_A                         :
      constant Unicode_Char := 16#11083#;
   Kaithi_Letter_Aa                        :
      constant Unicode_Char := 16#11084#;
   Kaithi_Letter_I                         :
      constant Unicode_Char := 16#11085#;
   Kaithi_Letter_Ii                        :
      constant Unicode_Char := 16#11086#;
   Kaithi_Letter_U                         :
      constant Unicode_Char := 16#11087#;
   Kaithi_Letter_Uu                        :
      constant Unicode_Char := 16#11088#;
   Kaithi_Letter_E                         :
      constant Unicode_Char := 16#11089#;
   Kaithi_Letter_Ai                        :
      constant Unicode_Char := 16#1108A#;
   Kaithi_Letter_O                         :
      constant Unicode_Char := 16#1108B#;
   Kaithi_Letter_Au                        :
      constant Unicode_Char := 16#1108C#;
   Kaithi_Letter_Ka                        :
      constant Unicode_Char := 16#1108D#;
   Kaithi_Letter_Kha                       :
      constant Unicode_Char := 16#1108E#;
   Kaithi_Letter_Ga                        :
      constant Unicode_Char := 16#1108F#;
   Kaithi_Letter_Gha                       :
      constant Unicode_Char := 16#11090#;
   Kaithi_Letter_Nga                       :
      constant Unicode_Char := 16#11091#;
   Kaithi_Letter_Ca                        :
      constant Unicode_Char := 16#11092#;
   Kaithi_Letter_Cha                       :
      constant Unicode_Char := 16#11093#;
   Kaithi_Letter_Ja                        :
      constant Unicode_Char := 16#11094#;
   Kaithi_Letter_Jha                       :
      constant Unicode_Char := 16#11095#;
   Kaithi_Letter_Nya                       :
      constant Unicode_Char := 16#11096#;
   Kaithi_Letter_Tta                       :
      constant Unicode_Char := 16#11097#;
   Kaithi_Letter_Ttha                      :
      constant Unicode_Char := 16#11098#;
   Kaithi_Letter_Dda                       :
      constant Unicode_Char := 16#11099#;
   Kaithi_Letter_Dddha                     :
      constant Unicode_Char := 16#1109A#;
   Kaithi_Letter_Ddha                      :
      constant Unicode_Char := 16#1109B#;
   Kaithi_Letter_Rha                       :
      constant Unicode_Char := 16#1109C#;
   Kaithi_Letter_Nna                       :
      constant Unicode_Char := 16#1109D#;
   Kaithi_Letter_Ta                        :
      constant Unicode_Char := 16#1109E#;
   Kaithi_Letter_Tha                       :
      constant Unicode_Char := 16#1109F#;
   Kaithi_Letter_Da                        :
      constant Unicode_Char := 16#110A0#;
   Kaithi_Letter_Dha                       :
      constant Unicode_Char := 16#110A1#;
   Kaithi_Letter_Na                        :
      constant Unicode_Char := 16#110A2#;
   Kaithi_Letter_Pa                        :
      constant Unicode_Char := 16#110A3#;
   Kaithi_Letter_Pha                       :
      constant Unicode_Char := 16#110A4#;
   Kaithi_Letter_Ba                        :
      constant Unicode_Char := 16#110A5#;
   Kaithi_Letter_Bha                       :
      constant Unicode_Char := 16#110A6#;
   Kaithi_Letter_Ma                        :
      constant Unicode_Char := 16#110A7#;
   Kaithi_Letter_Ya                        :
      constant Unicode_Char := 16#110A8#;
   Kaithi_Letter_Ra                        :
      constant Unicode_Char := 16#110A9#;
   Kaithi_Letter_La                        :
      constant Unicode_Char := 16#110AA#;
   Kaithi_Letter_Va                        :
      constant Unicode_Char := 16#110AB#;
   Kaithi_Letter_Sha                       :
      constant Unicode_Char := 16#110AC#;
   Kaithi_Letter_Ssa                       :
      constant Unicode_Char := 16#110AD#;
   Kaithi_Letter_Sa                        :
      constant Unicode_Char := 16#110AE#;
   Kaithi_Letter_Ha                        :
      constant Unicode_Char := 16#110AF#;
   Kaithi_Vowel_Sign_Aa                    :
      constant Unicode_Char := 16#110B0#;
   Kaithi_Vowel_Sign_I                     :
      constant Unicode_Char := 16#110B1#;
   Kaithi_Vowel_Sign_Ii                    :
      constant Unicode_Char := 16#110B2#;
   Kaithi_Vowel_Sign_U                     :
      constant Unicode_Char := 16#110B3#;
   Kaithi_Vowel_Sign_Uu                    :
      constant Unicode_Char := 16#110B4#;
   Kaithi_Vowel_Sign_E                     :
      constant Unicode_Char := 16#110B5#;
   Kaithi_Vowel_Sign_Ai                    :
      constant Unicode_Char := 16#110B6#;
   Kaithi_Vowel_Sign_O                     :
      constant Unicode_Char := 16#110B7#;
   Kaithi_Vowel_Sign_Au                    :
      constant Unicode_Char := 16#110B8#;
   Kaithi_Sign_Virama                      :
      constant Unicode_Char := 16#110B9#;
   Kaithi_Sign_Nukta                       :
      constant Unicode_Char := 16#110BA#;
   Kaithi_Abbreviation_Sign                :
      constant Unicode_Char := 16#110BB#;
   Kaithi_Enumeration_Sign                 :
      constant Unicode_Char := 16#110BC#;
   Kaithi_Number_Sign                      :
      constant Unicode_Char := 16#110BD#;
   Kaithi_Section_Mark                     :
      constant Unicode_Char := 16#110BE#;
   Kaithi_Double_Section_Mark              :
      constant Unicode_Char := 16#110BF#;
   Kaithi_Danda                            :
      constant Unicode_Char := 16#110C0#;
   Kaithi_Double_Danda                     :
      constant Unicode_Char := 16#110C1#;
end Unicode.Names.Kaithi;
