--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Duployan is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Duployan_Letter_H                       :
      constant Unicode_Char := 16#1BC00#;
   Duployan_Letter_X                       :
      constant Unicode_Char := 16#1BC01#;
   Duployan_Letter_P                       :
      constant Unicode_Char := 16#1BC02#;
   Duployan_Letter_T                       :
      constant Unicode_Char := 16#1BC03#;
   Duployan_Letter_F                       :
      constant Unicode_Char := 16#1BC04#;
   Duployan_Letter_K                       :
      constant Unicode_Char := 16#1BC05#;
   Duployan_Letter_L                       :
      constant Unicode_Char := 16#1BC06#;
   Duployan_Letter_B                       :
      constant Unicode_Char := 16#1BC07#;
   Duployan_Letter_D                       :
      constant Unicode_Char := 16#1BC08#;
   Duployan_Letter_V                       :
      constant Unicode_Char := 16#1BC09#;
   Duployan_Letter_G                       :
      constant Unicode_Char := 16#1BC0A#;
   Duployan_Letter_R                       :
      constant Unicode_Char := 16#1BC0B#;
   Duployan_Letter_P_N                     :
      constant Unicode_Char := 16#1BC0C#;
   Duployan_Letter_D_S                     :
      constant Unicode_Char := 16#1BC0D#;
   Duployan_Letter_F_N                     :
      constant Unicode_Char := 16#1BC0E#;
   Duployan_Letter_K_M                     :
      constant Unicode_Char := 16#1BC0F#;
   Duployan_Letter_R_S                     :
      constant Unicode_Char := 16#1BC10#;
   Duployan_Letter_Th                      :
      constant Unicode_Char := 16#1BC11#;
   Duployan_Letter_Sloan_Dh                :
      constant Unicode_Char := 16#1BC12#;
   Duployan_Letter_Dh                      :
      constant Unicode_Char := 16#1BC13#;
   Duployan_Letter_Kk                      :
      constant Unicode_Char := 16#1BC14#;
   Duployan_Letter_Sloan_J                 :
      constant Unicode_Char := 16#1BC15#;
   Duployan_Letter_Hl                      :
      constant Unicode_Char := 16#1BC16#;
   Duployan_Letter_Lh                      :
      constant Unicode_Char := 16#1BC17#;
   Duployan_Letter_Rh                      :
      constant Unicode_Char := 16#1BC18#;
   Duployan_Letter_M                       :
      constant Unicode_Char := 16#1BC19#;
   Duployan_Letter_N                       :
      constant Unicode_Char := 16#1BC1A#;
   Duployan_Letter_J                       :
      constant Unicode_Char := 16#1BC1B#;
   Duployan_Letter_S                       :
      constant Unicode_Char := 16#1BC1C#;
   Duployan_Letter_M_N                     :
      constant Unicode_Char := 16#1BC1D#;
   Duployan_Letter_N_M                     :
      constant Unicode_Char := 16#1BC1E#;
   Duployan_Letter_J_M                     :
      constant Unicode_Char := 16#1BC1F#;
   Duployan_Letter_S_J                     :
      constant Unicode_Char := 16#1BC20#;
   Duployan_Letter_M_With_Dot              :
      constant Unicode_Char := 16#1BC21#;
   Duployan_Letter_N_With_Dot              :
      constant Unicode_Char := 16#1BC22#;
   Duployan_Letter_J_With_Dot              :
      constant Unicode_Char := 16#1BC23#;
   Duployan_Letter_J_With_Dots_Inside_And_Above :
      constant Unicode_Char := 16#1BC24#;
   Duployan_Letter_S_With_Dot              :
      constant Unicode_Char := 16#1BC25#;
   Duployan_Letter_S_With_Dot_Below        :
      constant Unicode_Char := 16#1BC26#;
   Duployan_Letter_M_S                     :
      constant Unicode_Char := 16#1BC27#;
   Duployan_Letter_N_S                     :
      constant Unicode_Char := 16#1BC28#;
   Duployan_Letter_J_S                     :
      constant Unicode_Char := 16#1BC29#;
   Duployan_Letter_S_S                     :
      constant Unicode_Char := 16#1BC2A#;
   Duployan_Letter_M_N_S                   :
      constant Unicode_Char := 16#1BC2B#;
   Duployan_Letter_N_M_S                   :
      constant Unicode_Char := 16#1BC2C#;
   Duployan_Letter_J_M_S                   :
      constant Unicode_Char := 16#1BC2D#;
   Duployan_Letter_S_J_S                   :
      constant Unicode_Char := 16#1BC2E#;
   Duployan_Letter_J_S_With_Dot            :
      constant Unicode_Char := 16#1BC2F#;
   Duployan_Letter_J_N                     :
      constant Unicode_Char := 16#1BC30#;
   Duployan_Letter_J_N_S                   :
      constant Unicode_Char := 16#1BC31#;
   Duployan_Letter_S_T                     :
      constant Unicode_Char := 16#1BC32#;
   Duployan_Letter_S_T_R                   :
      constant Unicode_Char := 16#1BC33#;
   Duployan_Letter_S_P                     :
      constant Unicode_Char := 16#1BC34#;
   Duployan_Letter_S_P_R                   :
      constant Unicode_Char := 16#1BC35#;
   Duployan_Letter_T_S                     :
      constant Unicode_Char := 16#1BC36#;
   Duployan_Letter_T_R_S                   :
      constant Unicode_Char := 16#1BC37#;
   Duployan_Letter_W                       :
      constant Unicode_Char := 16#1BC38#;
   Duployan_Letter_Wh                      :
      constant Unicode_Char := 16#1BC39#;
   Duployan_Letter_W_R                     :
      constant Unicode_Char := 16#1BC3A#;
   Duployan_Letter_S_N                     :
      constant Unicode_Char := 16#1BC3B#;
   Duployan_Letter_S_M                     :
      constant Unicode_Char := 16#1BC3C#;
   Duployan_Letter_K_R_S                   :
      constant Unicode_Char := 16#1BC3D#;
   Duployan_Letter_G_R_S                   :
      constant Unicode_Char := 16#1BC3E#;
   Duployan_Letter_S_K                     :
      constant Unicode_Char := 16#1BC3F#;
   Duployan_Letter_S_K_R                   :
      constant Unicode_Char := 16#1BC40#;
   Duployan_Letter_A                       :
      constant Unicode_Char := 16#1BC41#;
   Duployan_Letter_Sloan_Ow                :
      constant Unicode_Char := 16#1BC42#;
   Duployan_Letter_Oa                      :
      constant Unicode_Char := 16#1BC43#;
   Duployan_Letter_O                       :
      constant Unicode_Char := 16#1BC44#;
   Duployan_Letter_Aou                     :
      constant Unicode_Char := 16#1BC45#;
   Duployan_Letter_I                       :
      constant Unicode_Char := 16#1BC46#;
   Duployan_Letter_E                       :
      constant Unicode_Char := 16#1BC47#;
   Duployan_Letter_Ie                      :
      constant Unicode_Char := 16#1BC48#;
   Duployan_Letter_Short_I                 :
      constant Unicode_Char := 16#1BC49#;
   Duployan_Letter_Ui                      :
      constant Unicode_Char := 16#1BC4A#;
   Duployan_Letter_Ee                      :
      constant Unicode_Char := 16#1BC4B#;
   Duployan_Letter_Sloan_Eh                :
      constant Unicode_Char := 16#1BC4C#;
   Duployan_Letter_Romanian_I              :
      constant Unicode_Char := 16#1BC4D#;
   Duployan_Letter_Sloan_Ee                :
      constant Unicode_Char := 16#1BC4E#;
   Duployan_Letter_Long_I                  :
      constant Unicode_Char := 16#1BC4F#;
   Duployan_Letter_Ye                      :
      constant Unicode_Char := 16#1BC50#;
   Duployan_Letter_U                       :
      constant Unicode_Char := 16#1BC51#;
   Duployan_Letter_Eu                      :
      constant Unicode_Char := 16#1BC52#;
   Duployan_Letter_Xw                      :
      constant Unicode_Char := 16#1BC53#;
   Duployan_Letter_U_N                     :
      constant Unicode_Char := 16#1BC54#;
   Duployan_Letter_Long_U                  :
      constant Unicode_Char := 16#1BC55#;
   Duployan_Letter_Romanian_U              :
      constant Unicode_Char := 16#1BC56#;
   Duployan_Letter_Uh                      :
      constant Unicode_Char := 16#1BC57#;
   Duployan_Letter_Sloan_U                 :
      constant Unicode_Char := 16#1BC58#;
   Duployan_Letter_Ooh                     :
      constant Unicode_Char := 16#1BC59#;
   Duployan_Letter_Ow                      :
      constant Unicode_Char := 16#1BC5A#;
   Duployan_Letter_Ou                      :
      constant Unicode_Char := 16#1BC5B#;
   Duployan_Letter_Wa                      :
      constant Unicode_Char := 16#1BC5C#;
   Duployan_Letter_Wo                      :
      constant Unicode_Char := 16#1BC5D#;
   Duployan_Letter_Wi                      :
      constant Unicode_Char := 16#1BC5E#;
   Duployan_Letter_Wei                     :
      constant Unicode_Char := 16#1BC5F#;
   Duployan_Letter_Wow                     :
      constant Unicode_Char := 16#1BC60#;
   Duployan_Letter_Nasal_U                 :
      constant Unicode_Char := 16#1BC61#;
   Duployan_Letter_Nasal_O                 :
      constant Unicode_Char := 16#1BC62#;
   Duployan_Letter_Nasal_I                 :
      constant Unicode_Char := 16#1BC63#;
   Duployan_Letter_Nasal_A                 :
      constant Unicode_Char := 16#1BC64#;
   Duployan_Letter_Pernin_An               :
      constant Unicode_Char := 16#1BC65#;
   Duployan_Letter_Pernin_Am               :
      constant Unicode_Char := 16#1BC66#;
   Duployan_Letter_Sloan_En                :
      constant Unicode_Char := 16#1BC67#;
   Duployan_Letter_Sloan_An                :
      constant Unicode_Char := 16#1BC68#;
   Duployan_Letter_Sloan_On                :
      constant Unicode_Char := 16#1BC69#;
   Duployan_Letter_Vocalic_M               :
      constant Unicode_Char := 16#1BC6A#;
   Duployan_Affix_Left_Horizontal_Secant   :
      constant Unicode_Char := 16#1BC70#;
   Duployan_Affix_Mid_Horizontal_Secant    :
      constant Unicode_Char := 16#1BC71#;
   Duployan_Affix_Right_Horizontal_Secant  :
      constant Unicode_Char := 16#1BC72#;
   Duployan_Affix_Low_Vertical_Secant      :
      constant Unicode_Char := 16#1BC73#;
   Duployan_Affix_Mid_Vertical_Secant      :
      constant Unicode_Char := 16#1BC74#;
   Duployan_Affix_High_Vertical_Secant     :
      constant Unicode_Char := 16#1BC75#;
   Duployan_Affix_Attached_Secant          :
      constant Unicode_Char := 16#1BC76#;
   Duployan_Affix_Attached_Left_To_Right_Secant :
      constant Unicode_Char := 16#1BC77#;
   Duployan_Affix_Attached_Tangent         :
      constant Unicode_Char := 16#1BC78#;
   Duployan_Affix_Attached_Tail            :
      constant Unicode_Char := 16#1BC79#;
   Duployan_Affix_Attached_E_Hook          :
      constant Unicode_Char := 16#1BC7A#;
   Duployan_Affix_Attached_I_Hook          :
      constant Unicode_Char := 16#1BC7B#;
   Duployan_Affix_Attached_Tangent_Hook    :
      constant Unicode_Char := 16#1BC7C#;
   Duployan_Affix_High_Acute               :
      constant Unicode_Char := 16#1BC80#;
   Duployan_Affix_High_Tight_Acute         :
      constant Unicode_Char := 16#1BC81#;
   Duployan_Affix_High_Grave               :
      constant Unicode_Char := 16#1BC82#;
   Duployan_Affix_High_Long_Grave          :
      constant Unicode_Char := 16#1BC83#;
   Duployan_Affix_High_Dot                 :
      constant Unicode_Char := 16#1BC84#;
   Duployan_Affix_High_Circle              :
      constant Unicode_Char := 16#1BC85#;
   Duployan_Affix_High_Line                :
      constant Unicode_Char := 16#1BC86#;
   Duployan_Affix_High_Wave                :
      constant Unicode_Char := 16#1BC87#;
   Duployan_Affix_High_Vertical            :
      constant Unicode_Char := 16#1BC88#;
   Duployan_Affix_Low_Acute                :
      constant Unicode_Char := 16#1BC90#;
   Duployan_Affix_Low_Tight_Acute          :
      constant Unicode_Char := 16#1BC91#;
   Duployan_Affix_Low_Grave                :
      constant Unicode_Char := 16#1BC92#;
   Duployan_Affix_Low_Long_Grave           :
      constant Unicode_Char := 16#1BC93#;
   Duployan_Affix_Low_Dot                  :
      constant Unicode_Char := 16#1BC94#;
   Duployan_Affix_Low_Circle               :
      constant Unicode_Char := 16#1BC95#;
   Duployan_Affix_Low_Line                 :
      constant Unicode_Char := 16#1BC96#;
   Duployan_Affix_Low_Wave                 :
      constant Unicode_Char := 16#1BC97#;
   Duployan_Affix_Low_Vertical             :
      constant Unicode_Char := 16#1BC98#;
   Duployan_Affix_Low_Arrow                :
      constant Unicode_Char := 16#1BC99#;
   Duployan_Sign_O_With_Cross              :
      constant Unicode_Char := 16#1BC9C#;
   Duployan_Thick_Letter_Selector          :
      constant Unicode_Char := 16#1BC9D#;
   Duployan_Double_Mark                    :
      constant Unicode_Char := 16#1BC9E#;
   Duployan_Punctuation_Chinook_Full_Stop  :
      constant Unicode_Char := 16#1BC9F#;
end Unicode.Names.Duployan;
