--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Lepcha is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Lepcha_Letter_Ka                        : constant Unicode_Char := 16#1C00#;
   Lepcha_Letter_Kla                       : constant Unicode_Char := 16#1C01#;
   Lepcha_Letter_Kha                       : constant Unicode_Char := 16#1C02#;
   Lepcha_Letter_Ga                        : constant Unicode_Char := 16#1C03#;
   Lepcha_Letter_Gla                       : constant Unicode_Char := 16#1C04#;
   Lepcha_Letter_Nga                       : constant Unicode_Char := 16#1C05#;
   Lepcha_Letter_Ca                        : constant Unicode_Char := 16#1C06#;
   Lepcha_Letter_Cha                       : constant Unicode_Char := 16#1C07#;
   Lepcha_Letter_Ja                        : constant Unicode_Char := 16#1C08#;
   Lepcha_Letter_Nya                       : constant Unicode_Char := 16#1C09#;
   Lepcha_Letter_Ta                        : constant Unicode_Char := 16#1C0A#;
   Lepcha_Letter_Tha                       : constant Unicode_Char := 16#1C0B#;
   Lepcha_Letter_Da                        : constant Unicode_Char := 16#1C0C#;
   Lepcha_Letter_Na                        : constant Unicode_Char := 16#1C0D#;
   Lepcha_Letter_Pa                        : constant Unicode_Char := 16#1C0E#;
   Lepcha_Letter_Pla                       : constant Unicode_Char := 16#1C0F#;
   Lepcha_Letter_Pha                       : constant Unicode_Char := 16#1C10#;
   Lepcha_Letter_Fa                        : constant Unicode_Char := 16#1C11#;
   Lepcha_Letter_Fla                       : constant Unicode_Char := 16#1C12#;
   Lepcha_Letter_Ba                        : constant Unicode_Char := 16#1C13#;
   Lepcha_Letter_Bla                       : constant Unicode_Char := 16#1C14#;
   Lepcha_Letter_Ma                        : constant Unicode_Char := 16#1C15#;
   Lepcha_Letter_Mla                       : constant Unicode_Char := 16#1C16#;
   Lepcha_Letter_Tsa                       : constant Unicode_Char := 16#1C17#;
   Lepcha_Letter_Tsha                      : constant Unicode_Char := 16#1C18#;
   Lepcha_Letter_Dza                       : constant Unicode_Char := 16#1C19#;
   Lepcha_Letter_Ya                        : constant Unicode_Char := 16#1C1A#;
   Lepcha_Letter_Ra                        : constant Unicode_Char := 16#1C1B#;
   Lepcha_Letter_La                        : constant Unicode_Char := 16#1C1C#;
   Lepcha_Letter_Ha                        : constant Unicode_Char := 16#1C1D#;
   Lepcha_Letter_Hla                       : constant Unicode_Char := 16#1C1E#;
   Lepcha_Letter_Va                        : constant Unicode_Char := 16#1C1F#;
   Lepcha_Letter_Sa                        : constant Unicode_Char := 16#1C20#;
   Lepcha_Letter_Sha                       : constant Unicode_Char := 16#1C21#;
   Lepcha_Letter_Wa                        : constant Unicode_Char := 16#1C22#;
   Lepcha_Letter_A                         : constant Unicode_Char := 16#1C23#;
   Lepcha_Subjoined_Letter_Ya              : constant Unicode_Char := 16#1C24#;
   Lepcha_Subjoined_Letter_Ra              : constant Unicode_Char := 16#1C25#;
   Lepcha_Vowel_Sign_Aa                    : constant Unicode_Char := 16#1C26#;
   Lepcha_Vowel_Sign_I                     : constant Unicode_Char := 16#1C27#;
   Lepcha_Vowel_Sign_O                     : constant Unicode_Char := 16#1C28#;
   Lepcha_Vowel_Sign_Oo                    : constant Unicode_Char := 16#1C29#;
   Lepcha_Vowel_Sign_U                     : constant Unicode_Char := 16#1C2A#;
   Lepcha_Vowel_Sign_Uu                    : constant Unicode_Char := 16#1C2B#;
   Lepcha_Vowel_Sign_E                     : constant Unicode_Char := 16#1C2C#;
   Lepcha_Consonant_Sign_K                 : constant Unicode_Char := 16#1C2D#;
   Lepcha_Consonant_Sign_M                 : constant Unicode_Char := 16#1C2E#;
   Lepcha_Consonant_Sign_L                 : constant Unicode_Char := 16#1C2F#;
   Lepcha_Consonant_Sign_N                 : constant Unicode_Char := 16#1C30#;
   Lepcha_Consonant_Sign_P                 : constant Unicode_Char := 16#1C31#;
   Lepcha_Consonant_Sign_R                 : constant Unicode_Char := 16#1C32#;
   Lepcha_Consonant_Sign_T                 : constant Unicode_Char := 16#1C33#;
   Lepcha_Consonant_Sign_Nyin_Do           : constant Unicode_Char := 16#1C34#;
   Lepcha_Consonant_Sign_Kang              : constant Unicode_Char := 16#1C35#;
   Lepcha_Sign_Ran                         : constant Unicode_Char := 16#1C36#;
   Lepcha_Sign_Nukta                       : constant Unicode_Char := 16#1C37#;
   Lepcha_Punctuation_Ta_Rol               : constant Unicode_Char := 16#1C3B#;
   Lepcha_Punctuation_Nyet_Thyoom_Ta_Rol   : constant Unicode_Char := 16#1C3C#;
   Lepcha_Punctuation_Cer_Wa               : constant Unicode_Char := 16#1C3D#;
   Lepcha_Punctuation_Tshook_Cer_Wa        : constant Unicode_Char := 16#1C3E#;
   Lepcha_Punctuation_Tshook               : constant Unicode_Char := 16#1C3F#;
   Lepcha_Digit_Zero                       : constant Unicode_Char := 16#1C40#;
   Lepcha_Digit_One                        : constant Unicode_Char := 16#1C41#;
   Lepcha_Digit_Two                        : constant Unicode_Char := 16#1C42#;
   Lepcha_Digit_Three                      : constant Unicode_Char := 16#1C43#;
   Lepcha_Digit_Four                       : constant Unicode_Char := 16#1C44#;
   Lepcha_Digit_Five                       : constant Unicode_Char := 16#1C45#;
   Lepcha_Digit_Six                        : constant Unicode_Char := 16#1C46#;
   Lepcha_Digit_Seven                      : constant Unicode_Char := 16#1C47#;
   Lepcha_Digit_Eight                      : constant Unicode_Char := 16#1C48#;
   Lepcha_Digit_Nine                       : constant Unicode_Char := 16#1C49#;
   Lepcha_Letter_Tta                       : constant Unicode_Char := 16#1C4D#;
   Lepcha_Letter_Ttha                      : constant Unicode_Char := 16#1C4E#;
   Lepcha_Letter_Dda                       : constant Unicode_Char := 16#1C4F#;
end Unicode.Names.Lepcha;
