--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Latin_Extended_D is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Modifier_Letter_Stress_And_High_Tone    : constant Unicode_Char := 16#A720#;
   Modifier_Letter_Stress_And_Low_Tone     : constant Unicode_Char := 16#A721#;
   Latin_Capital_Letter_Egyptological_Alef : constant Unicode_Char := 16#A722#;
   Latin_Small_Letter_Egyptological_Alef   : constant Unicode_Char := 16#A723#;
   Latin_Capital_Letter_Egyptological_Ain  : constant Unicode_Char := 16#A724#;
   Latin_Small_Letter_Egyptological_Ain    : constant Unicode_Char := 16#A725#;
   Latin_Capital_Letter_Heng               : constant Unicode_Char := 16#A726#;
   Latin_Small_Letter_Heng                 : constant Unicode_Char := 16#A727#;
   Latin_Capital_Letter_Tz                 : constant Unicode_Char := 16#A728#;
   Latin_Small_Letter_Tz                   : constant Unicode_Char := 16#A729#;
   Latin_Capital_Letter_Tresillo           : constant Unicode_Char := 16#A72A#;
   Latin_Small_Letter_Tresillo             : constant Unicode_Char := 16#A72B#;
   Latin_Capital_Letter_Cuatrillo          : constant Unicode_Char := 16#A72C#;
   Latin_Small_Letter_Cuatrillo            : constant Unicode_Char := 16#A72D#;
   Latin_Capital_Letter_Cuatrillo_With_Comma :
      constant Unicode_Char := 16#A72E#;
   Latin_Small_Letter_Cuatrillo_With_Comma : constant Unicode_Char := 16#A72F#;
   Latin_Letter_Small_Capital_F            : constant Unicode_Char := 16#A730#;
   Latin_Letter_Small_Capital_S            : constant Unicode_Char := 16#A731#;
   Latin_Capital_Letter_Aa                 : constant Unicode_Char := 16#A732#;
   Latin_Small_Letter_Aa                   : constant Unicode_Char := 16#A733#;
   Latin_Capital_Letter_Ao                 : constant Unicode_Char := 16#A734#;
   Latin_Small_Letter_Ao                   : constant Unicode_Char := 16#A735#;
   Latin_Capital_Letter_Au                 : constant Unicode_Char := 16#A736#;
   Latin_Small_Letter_Au                   : constant Unicode_Char := 16#A737#;
   Latin_Capital_Letter_Av                 : constant Unicode_Char := 16#A738#;
   Latin_Small_Letter_Av                   : constant Unicode_Char := 16#A739#;
   Latin_Capital_Letter_Av_With_Horizontal_Bar :
      constant Unicode_Char := 16#A73A#;
   Latin_Small_Letter_Av_With_Horizontal_Bar :
      constant Unicode_Char := 16#A73B#;
   Latin_Capital_Letter_Ay                 : constant Unicode_Char := 16#A73C#;
   Latin_Small_Letter_Ay                   : constant Unicode_Char := 16#A73D#;
   Latin_Capital_Letter_Reversed_C_With_Dot :
      constant Unicode_Char := 16#A73E#;
   Latin_Small_Letter_Reversed_C_With_Dot  : constant Unicode_Char := 16#A73F#;
   Latin_Capital_Letter_K_With_Stroke      : constant Unicode_Char := 16#A740#;
   Latin_Small_Letter_K_With_Stroke        : constant Unicode_Char := 16#A741#;
   Latin_Capital_Letter_K_With_Diagonal_Stroke :
      constant Unicode_Char := 16#A742#;
   Latin_Small_Letter_K_With_Diagonal_Stroke :
      constant Unicode_Char := 16#A743#;
   Latin_Capital_Letter_K_With_Stroke_And_Diagonal_Stroke :
      constant Unicode_Char := 16#A744#;
   Latin_Small_Letter_K_With_Stroke_And_Diagonal_Stroke :
      constant Unicode_Char := 16#A745#;
   Latin_Capital_Letter_Broken_L           : constant Unicode_Char := 16#A746#;
   Latin_Small_Letter_Broken_L             : constant Unicode_Char := 16#A747#;
   Latin_Capital_Letter_L_With_High_Stroke : constant Unicode_Char := 16#A748#;
   Latin_Small_Letter_L_With_High_Stroke   : constant Unicode_Char := 16#A749#;
   Latin_Capital_Letter_O_With_Long_Stroke_Overlay :
      constant Unicode_Char := 16#A74A#;
   Latin_Small_Letter_O_With_Long_Stroke_Overlay :
      constant Unicode_Char := 16#A74B#;
   Latin_Capital_Letter_O_With_Loop        : constant Unicode_Char := 16#A74C#;
   Latin_Small_Letter_O_With_Loop          : constant Unicode_Char := 16#A74D#;
   Latin_Capital_Letter_Oo                 : constant Unicode_Char := 16#A74E#;
   Latin_Small_Letter_Oo                   : constant Unicode_Char := 16#A74F#;
   Latin_Capital_Letter_P_With_Stroke_Through_Descender :
      constant Unicode_Char := 16#A750#;
   Latin_Small_Letter_P_With_Stroke_Through_Descender :
      constant Unicode_Char := 16#A751#;
   Latin_Capital_Letter_P_With_Flourish    : constant Unicode_Char := 16#A752#;
   Latin_Small_Letter_P_With_Flourish      : constant Unicode_Char := 16#A753#;
   Latin_Capital_Letter_P_With_Squirrel_Tail :
      constant Unicode_Char := 16#A754#;
   Latin_Small_Letter_P_With_Squirrel_Tail : constant Unicode_Char := 16#A755#;
   Latin_Capital_Letter_Q_With_Stroke_Through_Descender :
      constant Unicode_Char := 16#A756#;
   Latin_Small_Letter_Q_With_Stroke_Through_Descender :
      constant Unicode_Char := 16#A757#;
   Latin_Capital_Letter_Q_With_Diagonal_Stroke :
      constant Unicode_Char := 16#A758#;
   Latin_Small_Letter_Q_With_Diagonal_Stroke :
      constant Unicode_Char := 16#A759#;
   Latin_Capital_Letter_R_Rotunda          : constant Unicode_Char := 16#A75A#;
   Latin_Small_Letter_R_Rotunda            : constant Unicode_Char := 16#A75B#;
   Latin_Capital_Letter_Rum_Rotunda        : constant Unicode_Char := 16#A75C#;
   Latin_Small_Letter_Rum_Rotunda          : constant Unicode_Char := 16#A75D#;
   Latin_Capital_Letter_V_With_Diagonal_Stroke :
      constant Unicode_Char := 16#A75E#;
   Latin_Small_Letter_V_With_Diagonal_Stroke :
      constant Unicode_Char := 16#A75F#;
   Latin_Capital_Letter_Vy                 : constant Unicode_Char := 16#A760#;
   Latin_Small_Letter_Vy                   : constant Unicode_Char := 16#A761#;
   Latin_Capital_Letter_Visigothic_Z       : constant Unicode_Char := 16#A762#;
   Latin_Small_Letter_Visigothic_Z         : constant Unicode_Char := 16#A763#;
   Latin_Capital_Letter_Thorn_With_Stroke  : constant Unicode_Char := 16#A764#;
   Latin_Small_Letter_Thorn_With_Stroke    : constant Unicode_Char := 16#A765#;
   Latin_Capital_Letter_Thorn_With_Stroke_Through_Descender :
      constant Unicode_Char := 16#A766#;
   Latin_Small_Letter_Thorn_With_Stroke_Through_Descender :
      constant Unicode_Char := 16#A767#;
   Latin_Capital_Letter_Vend               : constant Unicode_Char := 16#A768#;
   Latin_Small_Letter_Vend                 : constant Unicode_Char := 16#A769#;
   Latin_Capital_Letter_Et                 : constant Unicode_Char := 16#A76A#;
   Latin_Small_Letter_Et                   : constant Unicode_Char := 16#A76B#;
   Latin_Capital_Letter_Is                 : constant Unicode_Char := 16#A76C#;
   Latin_Small_Letter_Is                   : constant Unicode_Char := 16#A76D#;
   Latin_Capital_Letter_Con                : constant Unicode_Char := 16#A76E#;
   Latin_Small_Letter_Con                  : constant Unicode_Char := 16#A76F#;
   Modifier_Letter_Us                      : constant Unicode_Char := 16#A770#;
   Latin_Small_Letter_Dum                  : constant Unicode_Char := 16#A771#;
   Latin_Small_Letter_Lum                  : constant Unicode_Char := 16#A772#;
   Latin_Small_Letter_Mum                  : constant Unicode_Char := 16#A773#;
   Latin_Small_Letter_Num                  : constant Unicode_Char := 16#A774#;
   Latin_Small_Letter_Rum                  : constant Unicode_Char := 16#A775#;
   Latin_Letter_Small_Capital_Rum          : constant Unicode_Char := 16#A776#;
   Latin_Small_Letter_Tum                  : constant Unicode_Char := 16#A777#;
   Latin_Small_Letter_Um                   : constant Unicode_Char := 16#A778#;
   Latin_Capital_Letter_Insular_D          : constant Unicode_Char := 16#A779#;
   Latin_Small_Letter_Insular_D            : constant Unicode_Char := 16#A77A#;
   Latin_Capital_Letter_Insular_F          : constant Unicode_Char := 16#A77B#;
   Latin_Small_Letter_Insular_F            : constant Unicode_Char := 16#A77C#;
   Latin_Capital_Letter_Insular_G          : constant Unicode_Char := 16#A77D#;
   Latin_Capital_Letter_Turned_Insular_G   : constant Unicode_Char := 16#A77E#;
   Latin_Small_Letter_Turned_Insular_G     : constant Unicode_Char := 16#A77F#;
   Latin_Capital_Letter_Turned_L           : constant Unicode_Char := 16#A780#;
   Latin_Small_Letter_Turned_L             : constant Unicode_Char := 16#A781#;
   Latin_Capital_Letter_Insular_R          : constant Unicode_Char := 16#A782#;
   Latin_Small_Letter_Insular_R            : constant Unicode_Char := 16#A783#;
   Latin_Capital_Letter_Insular_S          : constant Unicode_Char := 16#A784#;
   Latin_Small_Letter_Insular_S            : constant Unicode_Char := 16#A785#;
   Latin_Capital_Letter_Insular_T          : constant Unicode_Char := 16#A786#;
   Latin_Small_Letter_Insular_T            : constant Unicode_Char := 16#A787#;
   Modifier_Letter_Low_Circumflex_Accent   : constant Unicode_Char := 16#A788#;
   Modifier_Letter_Colon                   : constant Unicode_Char := 16#A789#;
   Modifier_Letter_Short_Equals_Sign       : constant Unicode_Char := 16#A78A#;
   Latin_Capital_Letter_Saltillo           : constant Unicode_Char := 16#A78B#;
   Latin_Small_Letter_Saltillo             : constant Unicode_Char := 16#A78C#;
   Latin_Capital_Letter_Turned_H           : constant Unicode_Char := 16#A78D#;
   Latin_Small_Letter_L_With_Retroflex_Hook_And_Belt :
      constant Unicode_Char := 16#A78E#;
   Latin_Letter_Sinological_Dot            : constant Unicode_Char := 16#A78F#;
   Latin_Capital_Letter_N_With_Descender   : constant Unicode_Char := 16#A790#;
   Latin_Small_Letter_N_With_Descender     : constant Unicode_Char := 16#A791#;
   Latin_Capital_Letter_C_With_Bar         : constant Unicode_Char := 16#A792#;
   Latin_Small_Letter_C_With_Bar           : constant Unicode_Char := 16#A793#;
   Latin_Small_Letter_C_With_Palatal_Hook  : constant Unicode_Char := 16#A794#;
   Latin_Small_Letter_H_With_Palatal_Hook  : constant Unicode_Char := 16#A795#;
   Latin_Capital_Letter_B_With_Flourish    : constant Unicode_Char := 16#A796#;
   Latin_Small_Letter_B_With_Flourish      : constant Unicode_Char := 16#A797#;
   Latin_Capital_Letter_F_With_Stroke      : constant Unicode_Char := 16#A798#;
   Latin_Small_Letter_F_With_Stroke        : constant Unicode_Char := 16#A799#;
   Latin_Capital_Letter_Volapuk_Ae         : constant Unicode_Char := 16#A79A#;
   Latin_Small_Letter_Volapuk_Ae           : constant Unicode_Char := 16#A79B#;
   Latin_Capital_Letter_Volapuk_Oe         : constant Unicode_Char := 16#A79C#;
   Latin_Small_Letter_Volapuk_Oe           : constant Unicode_Char := 16#A79D#;
   Latin_Capital_Letter_Volapuk_Ue         : constant Unicode_Char := 16#A79E#;
   Latin_Small_Letter_Volapuk_Ue           : constant Unicode_Char := 16#A79F#;
   Latin_Capital_Letter_G_With_Oblique_Stroke :
      constant Unicode_Char := 16#A7A0#;
   Latin_Small_Letter_G_With_Oblique_Stroke :
      constant Unicode_Char := 16#A7A1#;
   Latin_Capital_Letter_K_With_Oblique_Stroke :
      constant Unicode_Char := 16#A7A2#;
   Latin_Small_Letter_K_With_Oblique_Stroke :
      constant Unicode_Char := 16#A7A3#;
   Latin_Capital_Letter_N_With_Oblique_Stroke :
      constant Unicode_Char := 16#A7A4#;
   Latin_Small_Letter_N_With_Oblique_Stroke :
      constant Unicode_Char := 16#A7A5#;
   Latin_Capital_Letter_R_With_Oblique_Stroke :
      constant Unicode_Char := 16#A7A6#;
   Latin_Small_Letter_R_With_Oblique_Stroke :
      constant Unicode_Char := 16#A7A7#;
   Latin_Capital_Letter_S_With_Oblique_Stroke :
      constant Unicode_Char := 16#A7A8#;
   Latin_Small_Letter_S_With_Oblique_Stroke :
      constant Unicode_Char := 16#A7A9#;
   Latin_Capital_Letter_H_With_Hook        : constant Unicode_Char := 16#A7AA#;
   Latin_Capital_Letter_Reversed_Open_E    : constant Unicode_Char := 16#A7AB#;
   Latin_Capital_Letter_Script_G           : constant Unicode_Char := 16#A7AC#;
   Latin_Capital_Letter_L_With_Belt        : constant Unicode_Char := 16#A7AD#;
   Latin_Capital_Letter_Turned_K           : constant Unicode_Char := 16#A7B0#;
   Latin_Capital_Letter_Turned_T           : constant Unicode_Char := 16#A7B1#;
   Latin_Capital_Letter_J_With_Crossed_Tail :
      constant Unicode_Char := 16#A7B2#;
   Latin_Capital_Letter_Chi                : constant Unicode_Char := 16#A7B3#;
   Latin_Capital_Letter_Beta               : constant Unicode_Char := 16#A7B4#;
   Latin_Small_Letter_Beta                 : constant Unicode_Char := 16#A7B5#;
   Latin_Capital_Letter_Omega              : constant Unicode_Char := 16#A7B6#;
   Latin_Small_Letter_Omega                : constant Unicode_Char := 16#A7B7#;
   Latin_Epigraphic_Letter_Sideways_I      : constant Unicode_Char := 16#A7F7#;
   Modifier_Letter_Capital_H_With_Stroke   : constant Unicode_Char := 16#A7F8#;
   Modifier_Letter_Small_Ligature_Oe       : constant Unicode_Char := 16#A7F9#;
   Latin_Letter_Small_Capital_Turned_M     : constant Unicode_Char := 16#A7FA#;
   Latin_Epigraphic_Letter_Reversed_F      : constant Unicode_Char := 16#A7FB#;
   Latin_Epigraphic_Letter_Reversed_P      : constant Unicode_Char := 16#A7FC#;
   Latin_Epigraphic_Letter_Inverted_M      : constant Unicode_Char := 16#A7FD#;
   Latin_Epigraphic_Letter_I_Longa         : constant Unicode_Char := 16#A7FE#;
   Latin_Epigraphic_Letter_Archaic_M       : constant Unicode_Char := 16#A7FF#;
end Unicode.Names.Latin_Extended_D;
