--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Greek_And_Coptic is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Greek_Capital_Letter_Heta               : constant Unicode_Char := 16#0370#;
   Greek_Small_Letter_Heta                 : constant Unicode_Char := 16#0371#;
   Greek_Capital_Letter_Archaic_Sampi      : constant Unicode_Char := 16#0372#;
   Greek_Small_Letter_Archaic_Sampi        : constant Unicode_Char := 16#0373#;
   Greek_Numeral_Sign                      : constant Unicode_Char := 16#0374#;
   Greek_Lower_Numeral_Sign                : constant Unicode_Char := 16#0375#;
   Greek_Capital_Letter_Pamphylian_Digamma : constant Unicode_Char := 16#0376#;
   Greek_Small_Letter_Pamphylian_Digamma   : constant Unicode_Char := 16#0377#;
   Greek_Ypogegrammeni                     : constant Unicode_Char := 16#037A#;
   Greek_Small_Reversed_Lunate_Sigma_Symbol :
      constant Unicode_Char := 16#037B#;
   Greek_Small_Dotted_Lunate_Sigma_Symbol  : constant Unicode_Char := 16#037C#;
   Greek_Small_Reversed_Dotted_Lunate_Sigma_Symbol :
      constant Unicode_Char := 16#037D#;
   Greek_Question_Mark                     : constant Unicode_Char := 16#037E#;
   Greek_Capital_Letter_Yot                : constant Unicode_Char := 16#037F#;
   Greek_Tonos                             : constant Unicode_Char := 16#0384#;
   Greek_Dialytika_Tonos                   : constant Unicode_Char := 16#0385#;
   Greek_Capital_Letter_Alpha_With_Tonos   : constant Unicode_Char := 16#0386#;
   Greek_Ano_Teleia                        : constant Unicode_Char := 16#0387#;
   Greek_Capital_Letter_Epsilon_With_Tonos : constant Unicode_Char := 16#0388#;
   Greek_Capital_Letter_Eta_With_Tonos     : constant Unicode_Char := 16#0389#;
   Greek_Capital_Letter_Iota_With_Tonos    : constant Unicode_Char := 16#038A#;
   Greek_Capital_Letter_Omicron_With_Tonos : constant Unicode_Char := 16#038C#;
   Greek_Capital_Letter_Upsilon_With_Tonos : constant Unicode_Char := 16#038E#;
   Greek_Capital_Letter_Omega_With_Tonos   : constant Unicode_Char := 16#038F#;
   Greek_Small_Letter_Iota_With_Dialytika_And_Tonos :
      constant Unicode_Char := 16#0390#;
   Greek_Capital_Letter_Alpha              : constant Unicode_Char := 16#0391#;
   Greek_Capital_Letter_Beta               : constant Unicode_Char := 16#0392#;
   Greek_Capital_Letter_Gamma              : constant Unicode_Char := 16#0393#;
   Greek_Capital_Letter_Delta              : constant Unicode_Char := 16#0394#;
   Greek_Capital_Letter_Epsilon            : constant Unicode_Char := 16#0395#;
   Greek_Capital_Letter_Zeta               : constant Unicode_Char := 16#0396#;
   Greek_Capital_Letter_Eta                : constant Unicode_Char := 16#0397#;
   Greek_Capital_Letter_Theta              : constant Unicode_Char := 16#0398#;
   Greek_Capital_Letter_Iota               : constant Unicode_Char := 16#0399#;
   Greek_Capital_Letter_Kappa              : constant Unicode_Char := 16#039A#;
   Greek_Capital_Letter_Lamda              : constant Unicode_Char := 16#039B#;
   Greek_Capital_Letter_Mu                 : constant Unicode_Char := 16#039C#;
   Greek_Capital_Letter_Nu                 : constant Unicode_Char := 16#039D#;
   Greek_Capital_Letter_Xi                 : constant Unicode_Char := 16#039E#;
   Greek_Capital_Letter_Omicron            : constant Unicode_Char := 16#039F#;
   Greek_Capital_Letter_Pi                 : constant Unicode_Char := 16#03A0#;
   Greek_Capital_Letter_Rho                : constant Unicode_Char := 16#03A1#;
   Greek_Capital_Letter_Sigma              : constant Unicode_Char := 16#03A3#;
   Greek_Capital_Letter_Tau                : constant Unicode_Char := 16#03A4#;
   Greek_Capital_Letter_Upsilon            : constant Unicode_Char := 16#03A5#;
   Greek_Capital_Letter_Phi                : constant Unicode_Char := 16#03A6#;
   Greek_Capital_Letter_Chi                : constant Unicode_Char := 16#03A7#;
   Greek_Capital_Letter_Psi                : constant Unicode_Char := 16#03A8#;
   Greek_Capital_Letter_Omega              : constant Unicode_Char := 16#03A9#;
   Greek_Capital_Letter_Iota_With_Dialytika :
      constant Unicode_Char := 16#03AA#;
   Greek_Capital_Letter_Upsilon_With_Dialytika :
      constant Unicode_Char := 16#03AB#;
   Greek_Small_Letter_Alpha_With_Tonos     : constant Unicode_Char := 16#03AC#;
   Greek_Small_Letter_Epsilon_With_Tonos   : constant Unicode_Char := 16#03AD#;
   Greek_Small_Letter_Eta_With_Tonos       : constant Unicode_Char := 16#03AE#;
   Greek_Small_Letter_Iota_With_Tonos      : constant Unicode_Char := 16#03AF#;
   Greek_Small_Letter_Upsilon_With_Dialytika_And_Tonos :
      constant Unicode_Char := 16#03B0#;
   Greek_Small_Letter_Alpha                : constant Unicode_Char := 16#03B1#;
   Greek_Small_Letter_Beta                 : constant Unicode_Char := 16#03B2#;
   Greek_Small_Letter_Gamma                : constant Unicode_Char := 16#03B3#;
   Greek_Small_Letter_Delta                : constant Unicode_Char := 16#03B4#;
   Greek_Small_Letter_Epsilon              : constant Unicode_Char := 16#03B5#;
   Greek_Small_Letter_Zeta                 : constant Unicode_Char := 16#03B6#;
   Greek_Small_Letter_Eta                  : constant Unicode_Char := 16#03B7#;
   Greek_Small_Letter_Theta                : constant Unicode_Char := 16#03B8#;
   Greek_Small_Letter_Iota                 : constant Unicode_Char := 16#03B9#;
   Greek_Small_Letter_Kappa                : constant Unicode_Char := 16#03BA#;
   Greek_Small_Letter_Lamda                : constant Unicode_Char := 16#03BB#;
   Greek_Small_Letter_Mu                   : constant Unicode_Char := 16#03BC#;
   Greek_Small_Letter_Nu                   : constant Unicode_Char := 16#03BD#;
   Greek_Small_Letter_Xi                   : constant Unicode_Char := 16#03BE#;
   Greek_Small_Letter_Omicron              : constant Unicode_Char := 16#03BF#;
   Greek_Small_Letter_Pi                   : constant Unicode_Char := 16#03C0#;
   Greek_Small_Letter_Rho                  : constant Unicode_Char := 16#03C1#;
   Greek_Small_Letter_Final_Sigma          : constant Unicode_Char := 16#03C2#;
   Greek_Small_Letter_Sigma                : constant Unicode_Char := 16#03C3#;
   Greek_Small_Letter_Tau                  : constant Unicode_Char := 16#03C4#;
   Greek_Small_Letter_Upsilon              : constant Unicode_Char := 16#03C5#;
   Greek_Small_Letter_Phi                  : constant Unicode_Char := 16#03C6#;
   Greek_Small_Letter_Chi                  : constant Unicode_Char := 16#03C7#;
   Greek_Small_Letter_Psi                  : constant Unicode_Char := 16#03C8#;
   Greek_Small_Letter_Omega                : constant Unicode_Char := 16#03C9#;
   Greek_Small_Letter_Iota_With_Dialytika  : constant Unicode_Char := 16#03CA#;
   Greek_Small_Letter_Upsilon_With_Dialytika :
      constant Unicode_Char := 16#03CB#;
   Greek_Small_Letter_Omicron_With_Tonos   : constant Unicode_Char := 16#03CC#;
   Greek_Small_Letter_Upsilon_With_Tonos   : constant Unicode_Char := 16#03CD#;
   Greek_Small_Letter_Omega_With_Tonos     : constant Unicode_Char := 16#03CE#;
   Greek_Capital_Kai_Symbol                : constant Unicode_Char := 16#03CF#;
   Greek_Beta_Symbol                       : constant Unicode_Char := 16#03D0#;
   Greek_Theta_Symbol                      : constant Unicode_Char := 16#03D1#;
   Greek_Upsilon_With_Hook_Symbol          : constant Unicode_Char := 16#03D2#;
   Greek_Upsilon_With_Acute_And_Hook_Symbol :
      constant Unicode_Char := 16#03D3#;
   Greek_Upsilon_With_Diaeresis_And_Hook_Symbol :
      constant Unicode_Char := 16#03D4#;
   Greek_Phi_Symbol                        : constant Unicode_Char := 16#03D5#;
   Greek_Pi_Symbol                         : constant Unicode_Char := 16#03D6#;
   Greek_Kai_Symbol                        : constant Unicode_Char := 16#03D7#;
   Greek_Letter_Archaic_Koppa              : constant Unicode_Char := 16#03D8#;
   Greek_Small_Letter_Archaic_Koppa        : constant Unicode_Char := 16#03D9#;
   Greek_Letter_Stigma                     : constant Unicode_Char := 16#03DA#;
   Greek_Small_Letter_Stigma               : constant Unicode_Char := 16#03DB#;
   Greek_Letter_Digamma                    : constant Unicode_Char := 16#03DC#;
   Greek_Small_Letter_Digamma              : constant Unicode_Char := 16#03DD#;
   Greek_Letter_Koppa                      : constant Unicode_Char := 16#03DE#;
   Greek_Small_Letter_Koppa                : constant Unicode_Char := 16#03DF#;
   Greek_Letter_Sampi                      : constant Unicode_Char := 16#03E0#;
   Greek_Small_Letter_Sampi                : constant Unicode_Char := 16#03E1#;
   Coptic_Capital_Letter_Shei              : constant Unicode_Char := 16#03E2#;
   Coptic_Small_Letter_Shei                : constant Unicode_Char := 16#03E3#;
   Coptic_Capital_Letter_Fei               : constant Unicode_Char := 16#03E4#;
   Coptic_Small_Letter_Fei                 : constant Unicode_Char := 16#03E5#;
   Coptic_Capital_Letter_Khei              : constant Unicode_Char := 16#03E6#;
   Coptic_Small_Letter_Khei                : constant Unicode_Char := 16#03E7#;
   Coptic_Capital_Letter_Hori              : constant Unicode_Char := 16#03E8#;
   Coptic_Small_Letter_Hori                : constant Unicode_Char := 16#03E9#;
   Coptic_Capital_Letter_Gangia            : constant Unicode_Char := 16#03EA#;
   Coptic_Small_Letter_Gangia              : constant Unicode_Char := 16#03EB#;
   Coptic_Capital_Letter_Shima             : constant Unicode_Char := 16#03EC#;
   Coptic_Small_Letter_Shima               : constant Unicode_Char := 16#03ED#;
   Coptic_Capital_Letter_Dei               : constant Unicode_Char := 16#03EE#;
   Coptic_Small_Letter_Dei                 : constant Unicode_Char := 16#03EF#;
   Greek_Kappa_Symbol                      : constant Unicode_Char := 16#03F0#;
   Greek_Rho_Symbol                        : constant Unicode_Char := 16#03F1#;
   Greek_Lunate_Sigma_Symbol               : constant Unicode_Char := 16#03F2#;
   Greek_Letter_Yot                        : constant Unicode_Char := 16#03F3#;
   Greek_Capital_Theta_Symbol              : constant Unicode_Char := 16#03F4#;
   Greek_Lunate_Epsilon_Symbol             : constant Unicode_Char := 16#03F5#;
   Greek_Reversed_Lunate_Epsilon_Symbol    : constant Unicode_Char := 16#03F6#;
   Greek_Capital_Letter_Sho                : constant Unicode_Char := 16#03F7#;
   Greek_Small_Letter_Sho                  : constant Unicode_Char := 16#03F8#;
   Greek_Capital_Lunate_Sigma_Symbol       : constant Unicode_Char := 16#03F9#;
   Greek_Capital_Letter_San                : constant Unicode_Char := 16#03FA#;
   Greek_Small_Letter_San                  : constant Unicode_Char := 16#03FB#;
   Greek_Rho_With_Stroke_Symbol            : constant Unicode_Char := 16#03FC#;
   Greek_Capital_Reversed_Lunate_Sigma_Symbol :
      constant Unicode_Char := 16#03FD#;
   Greek_Capital_Dotted_Lunate_Sigma_Symbol :
      constant Unicode_Char := 16#03FE#;
   Greek_Capital_Reversed_Dotted_Lunate_Sigma_Symbol :
      constant Unicode_Char := 16#03FF#;
end Unicode.Names.Greek_And_Coptic;
