--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Pau_Cin_Hau is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Pau_Cin_Hau_Letter_Pa                   :
      constant Unicode_Char := 16#11AC0#;
   Pau_Cin_Hau_Letter_Ka                   :
      constant Unicode_Char := 16#11AC1#;
   Pau_Cin_Hau_Letter_La                   :
      constant Unicode_Char := 16#11AC2#;
   Pau_Cin_Hau_Letter_Ma                   :
      constant Unicode_Char := 16#11AC3#;
   Pau_Cin_Hau_Letter_Da                   :
      constant Unicode_Char := 16#11AC4#;
   Pau_Cin_Hau_Letter_Za                   :
      constant Unicode_Char := 16#11AC5#;
   Pau_Cin_Hau_Letter_Va                   :
      constant Unicode_Char := 16#11AC6#;
   Pau_Cin_Hau_Letter_Nga                  :
      constant Unicode_Char := 16#11AC7#;
   Pau_Cin_Hau_Letter_Ha                   :
      constant Unicode_Char := 16#11AC8#;
   Pau_Cin_Hau_Letter_Ga                   :
      constant Unicode_Char := 16#11AC9#;
   Pau_Cin_Hau_Letter_Kha                  :
      constant Unicode_Char := 16#11ACA#;
   Pau_Cin_Hau_Letter_Sa                   :
      constant Unicode_Char := 16#11ACB#;
   Pau_Cin_Hau_Letter_Ba                   :
      constant Unicode_Char := 16#11ACC#;
   Pau_Cin_Hau_Letter_Ca                   :
      constant Unicode_Char := 16#11ACD#;
   Pau_Cin_Hau_Letter_Ta                   :
      constant Unicode_Char := 16#11ACE#;
   Pau_Cin_Hau_Letter_Tha                  :
      constant Unicode_Char := 16#11ACF#;
   Pau_Cin_Hau_Letter_Na                   :
      constant Unicode_Char := 16#11AD0#;
   Pau_Cin_Hau_Letter_Pha                  :
      constant Unicode_Char := 16#11AD1#;
   Pau_Cin_Hau_Letter_Ra                   :
      constant Unicode_Char := 16#11AD2#;
   Pau_Cin_Hau_Letter_Fa                   :
      constant Unicode_Char := 16#11AD3#;
   Pau_Cin_Hau_Letter_Cha                  :
      constant Unicode_Char := 16#11AD4#;
   Pau_Cin_Hau_Letter_A                    :
      constant Unicode_Char := 16#11AD5#;
   Pau_Cin_Hau_Letter_E                    :
      constant Unicode_Char := 16#11AD6#;
   Pau_Cin_Hau_Letter_I                    :
      constant Unicode_Char := 16#11AD7#;
   Pau_Cin_Hau_Letter_O                    :
      constant Unicode_Char := 16#11AD8#;
   Pau_Cin_Hau_Letter_U                    :
      constant Unicode_Char := 16#11AD9#;
   Pau_Cin_Hau_Letter_Ua                   :
      constant Unicode_Char := 16#11ADA#;
   Pau_Cin_Hau_Letter_Ia                   :
      constant Unicode_Char := 16#11ADB#;
   Pau_Cin_Hau_Letter_Final_P              :
      constant Unicode_Char := 16#11ADC#;
   Pau_Cin_Hau_Letter_Final_K              :
      constant Unicode_Char := 16#11ADD#;
   Pau_Cin_Hau_Letter_Final_T              :
      constant Unicode_Char := 16#11ADE#;
   Pau_Cin_Hau_Letter_Final_M              :
      constant Unicode_Char := 16#11ADF#;
   Pau_Cin_Hau_Letter_Final_N              :
      constant Unicode_Char := 16#11AE0#;
   Pau_Cin_Hau_Letter_Final_L              :
      constant Unicode_Char := 16#11AE1#;
   Pau_Cin_Hau_Letter_Final_W              :
      constant Unicode_Char := 16#11AE2#;
   Pau_Cin_Hau_Letter_Final_Ng             :
      constant Unicode_Char := 16#11AE3#;
   Pau_Cin_Hau_Letter_Final_Y              :
      constant Unicode_Char := 16#11AE4#;
   Pau_Cin_Hau_Rising_Tone_Long            :
      constant Unicode_Char := 16#11AE5#;
   Pau_Cin_Hau_Rising_Tone                 :
      constant Unicode_Char := 16#11AE6#;
   Pau_Cin_Hau_Sandhi_Glottal_Stop         :
      constant Unicode_Char := 16#11AE7#;
   Pau_Cin_Hau_Rising_Tone_Long_Final      :
      constant Unicode_Char := 16#11AE8#;
   Pau_Cin_Hau_Rising_Tone_Final           :
      constant Unicode_Char := 16#11AE9#;
   Pau_Cin_Hau_Sandhi_Glottal_Stop_Final   :
      constant Unicode_Char := 16#11AEA#;
   Pau_Cin_Hau_Sandhi_Tone_Long            :
      constant Unicode_Char := 16#11AEB#;
   Pau_Cin_Hau_Sandhi_Tone                 :
      constant Unicode_Char := 16#11AEC#;
   Pau_Cin_Hau_Sandhi_Tone_Long_Final      :
      constant Unicode_Char := 16#11AED#;
   Pau_Cin_Hau_Sandhi_Tone_Final           :
      constant Unicode_Char := 16#11AEE#;
   Pau_Cin_Hau_Mid_Level_Tone              :
      constant Unicode_Char := 16#11AEF#;
   Pau_Cin_Hau_Glottal_Stop_Variant        :
      constant Unicode_Char := 16#11AF0#;
   Pau_Cin_Hau_Mid_Level_Tone_Long_Final   :
      constant Unicode_Char := 16#11AF1#;
   Pau_Cin_Hau_Mid_Level_Tone_Final        :
      constant Unicode_Char := 16#11AF2#;
   Pau_Cin_Hau_Low_Falling_Tone_Long       :
      constant Unicode_Char := 16#11AF3#;
   Pau_Cin_Hau_Low_Falling_Tone            :
      constant Unicode_Char := 16#11AF4#;
   Pau_Cin_Hau_Glottal_Stop                :
      constant Unicode_Char := 16#11AF5#;
   Pau_Cin_Hau_Low_Falling_Tone_Long_Final :
      constant Unicode_Char := 16#11AF6#;
   Pau_Cin_Hau_Low_Falling_Tone_Final      :
      constant Unicode_Char := 16#11AF7#;
   Pau_Cin_Hau_Glottal_Stop_Final          :
      constant Unicode_Char := 16#11AF8#;
end Unicode.Names.Pau_Cin_Hau;
