--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Misc_Math_Symbols_B is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Triple_Vertical_Bar_Delimiter           : constant Unicode_Char := 16#2980#;
   Z_Notation_Spot                         : constant Unicode_Char := 16#2981#;
   Z_Notation_Type_Colon                   : constant Unicode_Char := 16#2982#;
   Left_White_Curly_Bracket                : constant Unicode_Char := 16#2983#;
   Right_White_Curly_Bracket               : constant Unicode_Char := 16#2984#;
   Left_White_Parenthesis                  : constant Unicode_Char := 16#2985#;
   Right_White_Parenthesis                 : constant Unicode_Char := 16#2986#;
   Z_Notation_Left_Image_Bracket           : constant Unicode_Char := 16#2987#;
   Z_Notation_Right_Image_Bracket          : constant Unicode_Char := 16#2988#;
   Z_Notation_Left_Binding_Bracket         : constant Unicode_Char := 16#2989#;
   Z_Notation_Right_Binding_Bracket        : constant Unicode_Char := 16#298A#;
   Left_Square_Bracket_With_Underbar       : constant Unicode_Char := 16#298B#;
   Right_Square_Bracket_With_Underbar      : constant Unicode_Char := 16#298C#;
   Left_Square_Bracket_With_Tick_In_Top_Corner :
      constant Unicode_Char := 16#298D#;
   Right_Square_Bracket_With_Tick_In_Bottom_Corner :
      constant Unicode_Char := 16#298E#;
   Left_Square_Bracket_With_Tick_In_Bottom_Corner :
      constant Unicode_Char := 16#298F#;
   Right_Square_Bracket_With_Tick_In_Top_Corner :
      constant Unicode_Char := 16#2990#;
   Left_Angle_Bracket_With_Dot             : constant Unicode_Char := 16#2991#;
   Right_Angle_Bracket_With_Dot            : constant Unicode_Char := 16#2992#;
   Left_Arc_Less_Than_Bracket              : constant Unicode_Char := 16#2993#;
   Right_Arc_Greater_Than_Bracket          : constant Unicode_Char := 16#2994#;
   Double_Left_Arc_Greater_Than_Bracket    : constant Unicode_Char := 16#2995#;
   Double_Right_Arc_Less_Than_Bracket      : constant Unicode_Char := 16#2996#;
   Left_Black_Tortoise_Shell_Bracket       : constant Unicode_Char := 16#2997#;
   Right_Black_Tortoise_Shell_Bracket      : constant Unicode_Char := 16#2998#;
   Dotted_Fence                            : constant Unicode_Char := 16#2999#;
   Vertical_Zigzag_Line                    : constant Unicode_Char := 16#299A#;
   Measured_Angle_Opening_Left             : constant Unicode_Char := 16#299B#;
   Right_Angle_Variant_With_Square         : constant Unicode_Char := 16#299C#;
   Measured_Right_Angle_With_Dot           : constant Unicode_Char := 16#299D#;
   Angle_With_S_Inside                     : constant Unicode_Char := 16#299E#;
   Acute_Angle                             : constant Unicode_Char := 16#299F#;
   Spherical_Angle_Opening_Left            : constant Unicode_Char := 16#29A0#;
   Spherical_Angle_Opening_Up              : constant Unicode_Char := 16#29A1#;
   Turned_Angle                            : constant Unicode_Char := 16#29A2#;
   Reversed_Angle                          : constant Unicode_Char := 16#29A3#;
   Angle_With_Underbar                     : constant Unicode_Char := 16#29A4#;
   Reversed_Angle_With_Underbar            : constant Unicode_Char := 16#29A5#;
   Oblique_Angle_Opening_Up                : constant Unicode_Char := 16#29A6#;
   Oblique_Angle_Opening_Down              : constant Unicode_Char := 16#29A7#;
   Measured_Angle_With_Open_Arm_Ending_In_Arrow_Pointing_Up_And_Right :
      constant Unicode_Char := 16#29A8#;
   Measured_Angle_With_Open_Arm_Ending_In_Arrow_Pointing_Up_And_Left :
      constant Unicode_Char := 16#29A9#;
   Measured_Angle_With_Open_Arm_Ending_In_Arrow_Pointing_Down_And_Right :
      constant Unicode_Char := 16#29AA#;
   Measured_Angle_With_Open_Arm_Ending_In_Arrow_Pointing_Down_And_Left :
      constant Unicode_Char := 16#29AB#;
   Measured_Angle_With_Open_Arm_Ending_In_Arrow_Pointing_Right_And_Up :
      constant Unicode_Char := 16#29AC#;
   Measured_Angle_With_Open_Arm_Ending_In_Arrow_Pointing_Left_And_Up :
      constant Unicode_Char := 16#29AD#;
   Measured_Angle_With_Open_Arm_Ending_In_Arrow_Pointing_Right_And_Down :
      constant Unicode_Char := 16#29AE#;
   Measured_Angle_With_Open_Arm_Ending_In_Arrow_Pointing_Left_And_Down :
      constant Unicode_Char := 16#29AF#;
   Reversed_Empty_Set                      : constant Unicode_Char := 16#29B0#;
   Empty_Set_With_Overbar                  : constant Unicode_Char := 16#29B1#;
   Empty_Set_With_Small_Circle_Above       : constant Unicode_Char := 16#29B2#;
   Empty_Set_With_Right_Arrow_Above        : constant Unicode_Char := 16#29B3#;
   Empty_Set_With_Left_Arrow_Above         : constant Unicode_Char := 16#29B4#;
   Circle_With_Horizontal_Bar              : constant Unicode_Char := 16#29B5#;
   Circled_Vertical_Bar                    : constant Unicode_Char := 16#29B6#;
   Circled_Parallel                        : constant Unicode_Char := 16#29B7#;
   Circled_Reverse_Solidus                 : constant Unicode_Char := 16#29B8#;
   Circled_Perpendicular                   : constant Unicode_Char := 16#29B9#;
   Circle_Divided_By_Horizontal_Bar_And_Top_Half_Divided_By_Vertical_Bar :
      constant Unicode_Char := 16#29BA#;
   Circle_With_Superimposed_X              : constant Unicode_Char := 16#29BB#;
   Circled_Anticlockwise_Rotated_Division_Sign :
      constant Unicode_Char := 16#29BC#;
   Up_Arrow_Through_Circle                 : constant Unicode_Char := 16#29BD#;
   Circled_White_Bullet                    : constant Unicode_Char := 16#29BE#;
   Circled_Bullet                          : constant Unicode_Char := 16#29BF#;
   Circled_Less_Than                       : constant Unicode_Char := 16#29C0#;
   Circled_Greater_Than                    : constant Unicode_Char := 16#29C1#;
   Circle_With_Small_Circle_To_The_Right   : constant Unicode_Char := 16#29C2#;
   Circle_With_Two_Horizontal_Strokes_To_The_Right :
      constant Unicode_Char := 16#29C3#;
   Squared_Rising_Diagonal_Slash           : constant Unicode_Char := 16#29C4#;
   Squared_Falling_Diagonal_Slash          : constant Unicode_Char := 16#29C5#;
   Squared_Asterisk                        : constant Unicode_Char := 16#29C6#;
   Squared_Small_Circle                    : constant Unicode_Char := 16#29C7#;
   Squared_Square                          : constant Unicode_Char := 16#29C8#;
   Two_Joined_Squares                      : constant Unicode_Char := 16#29C9#;
   Triangle_With_Dot_Above                 : constant Unicode_Char := 16#29CA#;
   Triangle_With_Underbar                  : constant Unicode_Char := 16#29CB#;
   S_In_Triangle                           : constant Unicode_Char := 16#29CC#;
   Triangle_With_Serifs_At_Bottom          : constant Unicode_Char := 16#29CD#;
   Right_Triangle_Above_Left_Triangle      : constant Unicode_Char := 16#29CE#;
   Left_Triangle_Beside_Vertical_Bar       : constant Unicode_Char := 16#29CF#;
   Vertical_Bar_Beside_Right_Triangle      : constant Unicode_Char := 16#29D0#;
   Bowtie_With_Left_Half_Black             : constant Unicode_Char := 16#29D1#;
   Bowtie_With_Right_Half_Black            : constant Unicode_Char := 16#29D2#;
   Black_Bowtie                            : constant Unicode_Char := 16#29D3#;
   Times_With_Left_Half_Black              : constant Unicode_Char := 16#29D4#;
   Times_With_Right_Half_Black             : constant Unicode_Char := 16#29D5#;
   White_Hourglass                         : constant Unicode_Char := 16#29D6#;
   Black_Hourglass                         : constant Unicode_Char := 16#29D7#;
   Left_Wiggly_Fence                       : constant Unicode_Char := 16#29D8#;
   Right_Wiggly_Fence                      : constant Unicode_Char := 16#29D9#;
   Left_Double_Wiggly_Fence                : constant Unicode_Char := 16#29DA#;
   Right_Double_Wiggly_Fence               : constant Unicode_Char := 16#29DB#;
   Incomplete_Infinity                     : constant Unicode_Char := 16#29DC#;
   Tie_Over_Infinity                       : constant Unicode_Char := 16#29DD#;
   Infinity_Negated_With_Vertical_Bar      : constant Unicode_Char := 16#29DE#;
   Double_Ended_Multimap                   : constant Unicode_Char := 16#29DF#;
   Square_With_Contoured_Outline           : constant Unicode_Char := 16#29E0#;
   Increases_As                            : constant Unicode_Char := 16#29E1#;
   Shuffle_Product                         : constant Unicode_Char := 16#29E2#;
   Equals_Sign_And_Slanted_Parallel        : constant Unicode_Char := 16#29E3#;
   Equals_Sign_And_Slanted_Parallel_With_Tilde_Above :
      constant Unicode_Char := 16#29E4#;
   Identical_To_And_Slanted_Parallel       : constant Unicode_Char := 16#29E5#;
   Gleich_Stark                            : constant Unicode_Char := 16#29E6#;
   Thermodynamic                           : constant Unicode_Char := 16#29E7#;
   Down_Pointing_Triangle_With_Left_Half_Black :
      constant Unicode_Char := 16#29E8#;
   Down_Pointing_Triangle_With_Right_Half_Black :
      constant Unicode_Char := 16#29E9#;
   Black_Diamond_With_Down_Arrow           : constant Unicode_Char := 16#29EA#;
   Black_Lozenge                           : constant Unicode_Char := 16#29EB#;
   White_Circle_With_Down_Arrow            : constant Unicode_Char := 16#29EC#;
   Black_Circle_With_Down_Arrow            : constant Unicode_Char := 16#29ED#;
   Error_Barred_White_Square               : constant Unicode_Char := 16#29EE#;
   Error_Barred_Black_Square               : constant Unicode_Char := 16#29EF#;
   Error_Barred_White_Diamond              : constant Unicode_Char := 16#29F0#;
   Error_Barred_Black_Diamond              : constant Unicode_Char := 16#29F1#;
   Error_Barred_White_Circle               : constant Unicode_Char := 16#29F2#;
   Error_Barred_Black_Circle               : constant Unicode_Char := 16#29F3#;
   Rule_Delayed                            : constant Unicode_Char := 16#29F4#;
   Reverse_Solidus_Operator                : constant Unicode_Char := 16#29F5#;
   Solidus_With_Overbar                    : constant Unicode_Char := 16#29F6#;
   Reverse_Solidus_With_Horizontal_Stroke  : constant Unicode_Char := 16#29F7#;
   Big_Solidus                             : constant Unicode_Char := 16#29F8#;
   Big_Reverse_Solidus                     : constant Unicode_Char := 16#29F9#;
   Double_Plus                             : constant Unicode_Char := 16#29FA#;
   Triple_Plus                             : constant Unicode_Char := 16#29FB#;
   Left_Pointing_Curved_Angle_Bracket      : constant Unicode_Char := 16#29FC#;
   Right_Pointing_Curved_Angle_Bracket     : constant Unicode_Char := 16#29FD#;
   Tiny                                    : constant Unicode_Char := 16#29FE#;
   Miny                                    : constant Unicode_Char := 16#29FF#;
end Unicode.Names.Misc_Math_Symbols_B;
