--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Old_Turkic is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Old_Turkic_Letter_Orkhon_A              :
      constant Unicode_Char := 16#10C00#;
   Old_Turkic_Letter_Yenisei_A             :
      constant Unicode_Char := 16#10C01#;
   Old_Turkic_Letter_Yenisei_Ae            :
      constant Unicode_Char := 16#10C02#;
   Old_Turkic_Letter_Orkhon_I              :
      constant Unicode_Char := 16#10C03#;
   Old_Turkic_Letter_Yenisei_I             :
      constant Unicode_Char := 16#10C04#;
   Old_Turkic_Letter_Yenisei_E             :
      constant Unicode_Char := 16#10C05#;
   Old_Turkic_Letter_Orkhon_O              :
      constant Unicode_Char := 16#10C06#;
   Old_Turkic_Letter_Orkhon_Oe             :
      constant Unicode_Char := 16#10C07#;
   Old_Turkic_Letter_Yenisei_Oe            :
      constant Unicode_Char := 16#10C08#;
   Old_Turkic_Letter_Orkhon_Ab             :
      constant Unicode_Char := 16#10C09#;
   Old_Turkic_Letter_Yenisei_Ab            :
      constant Unicode_Char := 16#10C0A#;
   Old_Turkic_Letter_Orkhon_Aeb            :
      constant Unicode_Char := 16#10C0B#;
   Old_Turkic_Letter_Yenisei_Aeb           :
      constant Unicode_Char := 16#10C0C#;
   Old_Turkic_Letter_Orkhon_Ag             :
      constant Unicode_Char := 16#10C0D#;
   Old_Turkic_Letter_Yenisei_Ag            :
      constant Unicode_Char := 16#10C0E#;
   Old_Turkic_Letter_Orkhon_Aeg            :
      constant Unicode_Char := 16#10C0F#;
   Old_Turkic_Letter_Yenisei_Aeg           :
      constant Unicode_Char := 16#10C10#;
   Old_Turkic_Letter_Orkhon_Ad             :
      constant Unicode_Char := 16#10C11#;
   Old_Turkic_Letter_Yenisei_Ad            :
      constant Unicode_Char := 16#10C12#;
   Old_Turkic_Letter_Orkhon_Aed            :
      constant Unicode_Char := 16#10C13#;
   Old_Turkic_Letter_Orkhon_Ez             :
      constant Unicode_Char := 16#10C14#;
   Old_Turkic_Letter_Yenisei_Ez            :
      constant Unicode_Char := 16#10C15#;
   Old_Turkic_Letter_Orkhon_Ay             :
      constant Unicode_Char := 16#10C16#;
   Old_Turkic_Letter_Yenisei_Ay            :
      constant Unicode_Char := 16#10C17#;
   Old_Turkic_Letter_Orkhon_Aey            :
      constant Unicode_Char := 16#10C18#;
   Old_Turkic_Letter_Yenisei_Aey           :
      constant Unicode_Char := 16#10C19#;
   Old_Turkic_Letter_Orkhon_Aek            :
      constant Unicode_Char := 16#10C1A#;
   Old_Turkic_Letter_Yenisei_Aek           :
      constant Unicode_Char := 16#10C1B#;
   Old_Turkic_Letter_Orkhon_Oek            :
      constant Unicode_Char := 16#10C1C#;
   Old_Turkic_Letter_Yenisei_Oek           :
      constant Unicode_Char := 16#10C1D#;
   Old_Turkic_Letter_Orkhon_Al             :
      constant Unicode_Char := 16#10C1E#;
   Old_Turkic_Letter_Yenisei_Al            :
      constant Unicode_Char := 16#10C1F#;
   Old_Turkic_Letter_Orkhon_Ael            :
      constant Unicode_Char := 16#10C20#;
   Old_Turkic_Letter_Orkhon_Elt            :
      constant Unicode_Char := 16#10C21#;
   Old_Turkic_Letter_Orkhon_Em             :
      constant Unicode_Char := 16#10C22#;
   Old_Turkic_Letter_Orkhon_An             :
      constant Unicode_Char := 16#10C23#;
   Old_Turkic_Letter_Orkhon_Aen            :
      constant Unicode_Char := 16#10C24#;
   Old_Turkic_Letter_Yenisei_Aen           :
      constant Unicode_Char := 16#10C25#;
   Old_Turkic_Letter_Orkhon_Ent            :
      constant Unicode_Char := 16#10C26#;
   Old_Turkic_Letter_Yenisei_Ent           :
      constant Unicode_Char := 16#10C27#;
   Old_Turkic_Letter_Orkhon_Enc            :
      constant Unicode_Char := 16#10C28#;
   Old_Turkic_Letter_Yenisei_Enc           :
      constant Unicode_Char := 16#10C29#;
   Old_Turkic_Letter_Orkhon_Eny            :
      constant Unicode_Char := 16#10C2A#;
   Old_Turkic_Letter_Yenisei_Eny           :
      constant Unicode_Char := 16#10C2B#;
   Old_Turkic_Letter_Yenisei_Ang           :
      constant Unicode_Char := 16#10C2C#;
   Old_Turkic_Letter_Orkhon_Eng            :
      constant Unicode_Char := 16#10C2D#;
   Old_Turkic_Letter_Yenisei_Aeng          :
      constant Unicode_Char := 16#10C2E#;
   Old_Turkic_Letter_Orkhon_Ep             :
      constant Unicode_Char := 16#10C2F#;
   Old_Turkic_Letter_Orkhon_Op             :
      constant Unicode_Char := 16#10C30#;
   Old_Turkic_Letter_Orkhon_Ic             :
      constant Unicode_Char := 16#10C31#;
   Old_Turkic_Letter_Orkhon_Ec             :
      constant Unicode_Char := 16#10C32#;
   Old_Turkic_Letter_Yenisei_Ec            :
      constant Unicode_Char := 16#10C33#;
   Old_Turkic_Letter_Orkhon_Aq             :
      constant Unicode_Char := 16#10C34#;
   Old_Turkic_Letter_Yenisei_Aq            :
      constant Unicode_Char := 16#10C35#;
   Old_Turkic_Letter_Orkhon_Iq             :
      constant Unicode_Char := 16#10C36#;
   Old_Turkic_Letter_Yenisei_Iq            :
      constant Unicode_Char := 16#10C37#;
   Old_Turkic_Letter_Orkhon_Oq             :
      constant Unicode_Char := 16#10C38#;
   Old_Turkic_Letter_Yenisei_Oq            :
      constant Unicode_Char := 16#10C39#;
   Old_Turkic_Letter_Orkhon_Ar             :
      constant Unicode_Char := 16#10C3A#;
   Old_Turkic_Letter_Yenisei_Ar            :
      constant Unicode_Char := 16#10C3B#;
   Old_Turkic_Letter_Orkhon_Aer            :
      constant Unicode_Char := 16#10C3C#;
   Old_Turkic_Letter_Orkhon_As             :
      constant Unicode_Char := 16#10C3D#;
   Old_Turkic_Letter_Orkhon_Aes            :
      constant Unicode_Char := 16#10C3E#;
   Old_Turkic_Letter_Orkhon_Ash            :
      constant Unicode_Char := 16#10C3F#;
   Old_Turkic_Letter_Yenisei_Ash           :
      constant Unicode_Char := 16#10C40#;
   Old_Turkic_Letter_Orkhon_Esh            :
      constant Unicode_Char := 16#10C41#;
   Old_Turkic_Letter_Yenisei_Esh           :
      constant Unicode_Char := 16#10C42#;
   Old_Turkic_Letter_Orkhon_At             :
      constant Unicode_Char := 16#10C43#;
   Old_Turkic_Letter_Yenisei_At            :
      constant Unicode_Char := 16#10C44#;
   Old_Turkic_Letter_Orkhon_Aet            :
      constant Unicode_Char := 16#10C45#;
   Old_Turkic_Letter_Yenisei_Aet           :
      constant Unicode_Char := 16#10C46#;
   Old_Turkic_Letter_Orkhon_Ot             :
      constant Unicode_Char := 16#10C47#;
   Old_Turkic_Letter_Orkhon_Bash           :
      constant Unicode_Char := 16#10C48#;
end Unicode.Names.Old_Turkic;
