--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cjk_Compat_Ideographs is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cjk_Compatibility_Ideograph_F900        : constant Unicode_Char := 16#F900#;
   Cjk_Compatibility_Ideograph_F901        : constant Unicode_Char := 16#F901#;
   Cjk_Compatibility_Ideograph_F902        : constant Unicode_Char := 16#F902#;
   Cjk_Compatibility_Ideograph_F903        : constant Unicode_Char := 16#F903#;
   Cjk_Compatibility_Ideograph_F904        : constant Unicode_Char := 16#F904#;
   Cjk_Compatibility_Ideograph_F905        : constant Unicode_Char := 16#F905#;
   Cjk_Compatibility_Ideograph_F906        : constant Unicode_Char := 16#F906#;
   Cjk_Compatibility_Ideograph_F907        : constant Unicode_Char := 16#F907#;
   Cjk_Compatibility_Ideograph_F908        : constant Unicode_Char := 16#F908#;
   Cjk_Compatibility_Ideograph_F909        : constant Unicode_Char := 16#F909#;
   Cjk_Compatibility_Ideograph_F90a        : constant Unicode_Char := 16#F90A#;
   Cjk_Compatibility_Ideograph_F90b        : constant Unicode_Char := 16#F90B#;
   Cjk_Compatibility_Ideograph_F90c        : constant Unicode_Char := 16#F90C#;
   Cjk_Compatibility_Ideograph_F90d        : constant Unicode_Char := 16#F90D#;
   Cjk_Compatibility_Ideograph_F90e        : constant Unicode_Char := 16#F90E#;
   Cjk_Compatibility_Ideograph_F90f        : constant Unicode_Char := 16#F90F#;
   Cjk_Compatibility_Ideograph_F910        : constant Unicode_Char := 16#F910#;
   Cjk_Compatibility_Ideograph_F911        : constant Unicode_Char := 16#F911#;
   Cjk_Compatibility_Ideograph_F912        : constant Unicode_Char := 16#F912#;
   Cjk_Compatibility_Ideograph_F913        : constant Unicode_Char := 16#F913#;
   Cjk_Compatibility_Ideograph_F914        : constant Unicode_Char := 16#F914#;
   Cjk_Compatibility_Ideograph_F915        : constant Unicode_Char := 16#F915#;
   Cjk_Compatibility_Ideograph_F916        : constant Unicode_Char := 16#F916#;
   Cjk_Compatibility_Ideograph_F917        : constant Unicode_Char := 16#F917#;
   Cjk_Compatibility_Ideograph_F918        : constant Unicode_Char := 16#F918#;
   Cjk_Compatibility_Ideograph_F919        : constant Unicode_Char := 16#F919#;
   Cjk_Compatibility_Ideograph_F91a        : constant Unicode_Char := 16#F91A#;
   Cjk_Compatibility_Ideograph_F91b        : constant Unicode_Char := 16#F91B#;
   Cjk_Compatibility_Ideograph_F91c        : constant Unicode_Char := 16#F91C#;
   Cjk_Compatibility_Ideograph_F91d        : constant Unicode_Char := 16#F91D#;
   Cjk_Compatibility_Ideograph_F91e        : constant Unicode_Char := 16#F91E#;
   Cjk_Compatibility_Ideograph_F91f        : constant Unicode_Char := 16#F91F#;
   Cjk_Compatibility_Ideograph_F920        : constant Unicode_Char := 16#F920#;
   Cjk_Compatibility_Ideograph_F921        : constant Unicode_Char := 16#F921#;
   Cjk_Compatibility_Ideograph_F922        : constant Unicode_Char := 16#F922#;
   Cjk_Compatibility_Ideograph_F923        : constant Unicode_Char := 16#F923#;
   Cjk_Compatibility_Ideograph_F924        : constant Unicode_Char := 16#F924#;
   Cjk_Compatibility_Ideograph_F925        : constant Unicode_Char := 16#F925#;
   Cjk_Compatibility_Ideograph_F926        : constant Unicode_Char := 16#F926#;
   Cjk_Compatibility_Ideograph_F927        : constant Unicode_Char := 16#F927#;
   Cjk_Compatibility_Ideograph_F928        : constant Unicode_Char := 16#F928#;
   Cjk_Compatibility_Ideograph_F929        : constant Unicode_Char := 16#F929#;
   Cjk_Compatibility_Ideograph_F92a        : constant Unicode_Char := 16#F92A#;
   Cjk_Compatibility_Ideograph_F92b        : constant Unicode_Char := 16#F92B#;
   Cjk_Compatibility_Ideograph_F92c        : constant Unicode_Char := 16#F92C#;
   Cjk_Compatibility_Ideograph_F92d        : constant Unicode_Char := 16#F92D#;
   Cjk_Compatibility_Ideograph_F92e        : constant Unicode_Char := 16#F92E#;
   Cjk_Compatibility_Ideograph_F92f        : constant Unicode_Char := 16#F92F#;
   Cjk_Compatibility_Ideograph_F930        : constant Unicode_Char := 16#F930#;
   Cjk_Compatibility_Ideograph_F931        : constant Unicode_Char := 16#F931#;
   Cjk_Compatibility_Ideograph_F932        : constant Unicode_Char := 16#F932#;
   Cjk_Compatibility_Ideograph_F933        : constant Unicode_Char := 16#F933#;
   Cjk_Compatibility_Ideograph_F934        : constant Unicode_Char := 16#F934#;
   Cjk_Compatibility_Ideograph_F935        : constant Unicode_Char := 16#F935#;
   Cjk_Compatibility_Ideograph_F936        : constant Unicode_Char := 16#F936#;
   Cjk_Compatibility_Ideograph_F937        : constant Unicode_Char := 16#F937#;
   Cjk_Compatibility_Ideograph_F938        : constant Unicode_Char := 16#F938#;
   Cjk_Compatibility_Ideograph_F939        : constant Unicode_Char := 16#F939#;
   Cjk_Compatibility_Ideograph_F93a        : constant Unicode_Char := 16#F93A#;
   Cjk_Compatibility_Ideograph_F93b        : constant Unicode_Char := 16#F93B#;
   Cjk_Compatibility_Ideograph_F93c        : constant Unicode_Char := 16#F93C#;
   Cjk_Compatibility_Ideograph_F93d        : constant Unicode_Char := 16#F93D#;
   Cjk_Compatibility_Ideograph_F93e        : constant Unicode_Char := 16#F93E#;
   Cjk_Compatibility_Ideograph_F93f        : constant Unicode_Char := 16#F93F#;
   Cjk_Compatibility_Ideograph_F940        : constant Unicode_Char := 16#F940#;
   Cjk_Compatibility_Ideograph_F941        : constant Unicode_Char := 16#F941#;
   Cjk_Compatibility_Ideograph_F942        : constant Unicode_Char := 16#F942#;
   Cjk_Compatibility_Ideograph_F943        : constant Unicode_Char := 16#F943#;
   Cjk_Compatibility_Ideograph_F944        : constant Unicode_Char := 16#F944#;
   Cjk_Compatibility_Ideograph_F945        : constant Unicode_Char := 16#F945#;
   Cjk_Compatibility_Ideograph_F946        : constant Unicode_Char := 16#F946#;
   Cjk_Compatibility_Ideograph_F947        : constant Unicode_Char := 16#F947#;
   Cjk_Compatibility_Ideograph_F948        : constant Unicode_Char := 16#F948#;
   Cjk_Compatibility_Ideograph_F949        : constant Unicode_Char := 16#F949#;
   Cjk_Compatibility_Ideograph_F94a        : constant Unicode_Char := 16#F94A#;
   Cjk_Compatibility_Ideograph_F94b        : constant Unicode_Char := 16#F94B#;
   Cjk_Compatibility_Ideograph_F94c        : constant Unicode_Char := 16#F94C#;
   Cjk_Compatibility_Ideograph_F94d        : constant Unicode_Char := 16#F94D#;
   Cjk_Compatibility_Ideograph_F94e        : constant Unicode_Char := 16#F94E#;
   Cjk_Compatibility_Ideograph_F94f        : constant Unicode_Char := 16#F94F#;
   Cjk_Compatibility_Ideograph_F950        : constant Unicode_Char := 16#F950#;
   Cjk_Compatibility_Ideograph_F951        : constant Unicode_Char := 16#F951#;
   Cjk_Compatibility_Ideograph_F952        : constant Unicode_Char := 16#F952#;
   Cjk_Compatibility_Ideograph_F953        : constant Unicode_Char := 16#F953#;
   Cjk_Compatibility_Ideograph_F954        : constant Unicode_Char := 16#F954#;
   Cjk_Compatibility_Ideograph_F955        : constant Unicode_Char := 16#F955#;
   Cjk_Compatibility_Ideograph_F956        : constant Unicode_Char := 16#F956#;
   Cjk_Compatibility_Ideograph_F957        : constant Unicode_Char := 16#F957#;
   Cjk_Compatibility_Ideograph_F958        : constant Unicode_Char := 16#F958#;
   Cjk_Compatibility_Ideograph_F959        : constant Unicode_Char := 16#F959#;
   Cjk_Compatibility_Ideograph_F95a        : constant Unicode_Char := 16#F95A#;
   Cjk_Compatibility_Ideograph_F95b        : constant Unicode_Char := 16#F95B#;
   Cjk_Compatibility_Ideograph_F95c        : constant Unicode_Char := 16#F95C#;
   Cjk_Compatibility_Ideograph_F95d        : constant Unicode_Char := 16#F95D#;
   Cjk_Compatibility_Ideograph_F95e        : constant Unicode_Char := 16#F95E#;
   Cjk_Compatibility_Ideograph_F95f        : constant Unicode_Char := 16#F95F#;
   Cjk_Compatibility_Ideograph_F960        : constant Unicode_Char := 16#F960#;
   Cjk_Compatibility_Ideograph_F961        : constant Unicode_Char := 16#F961#;
   Cjk_Compatibility_Ideograph_F962        : constant Unicode_Char := 16#F962#;
   Cjk_Compatibility_Ideograph_F963        : constant Unicode_Char := 16#F963#;
   Cjk_Compatibility_Ideograph_F964        : constant Unicode_Char := 16#F964#;
   Cjk_Compatibility_Ideograph_F965        : constant Unicode_Char := 16#F965#;
   Cjk_Compatibility_Ideograph_F966        : constant Unicode_Char := 16#F966#;
   Cjk_Compatibility_Ideograph_F967        : constant Unicode_Char := 16#F967#;
   Cjk_Compatibility_Ideograph_F968        : constant Unicode_Char := 16#F968#;
   Cjk_Compatibility_Ideograph_F969        : constant Unicode_Char := 16#F969#;
   Cjk_Compatibility_Ideograph_F96a        : constant Unicode_Char := 16#F96A#;
   Cjk_Compatibility_Ideograph_F96b        : constant Unicode_Char := 16#F96B#;
   Cjk_Compatibility_Ideograph_F96c        : constant Unicode_Char := 16#F96C#;
   Cjk_Compatibility_Ideograph_F96d        : constant Unicode_Char := 16#F96D#;
   Cjk_Compatibility_Ideograph_F96e        : constant Unicode_Char := 16#F96E#;
   Cjk_Compatibility_Ideograph_F96f        : constant Unicode_Char := 16#F96F#;
   Cjk_Compatibility_Ideograph_F970        : constant Unicode_Char := 16#F970#;
   Cjk_Compatibility_Ideograph_F971        : constant Unicode_Char := 16#F971#;
   Cjk_Compatibility_Ideograph_F972        : constant Unicode_Char := 16#F972#;
   Cjk_Compatibility_Ideograph_F973        : constant Unicode_Char := 16#F973#;
   Cjk_Compatibility_Ideograph_F974        : constant Unicode_Char := 16#F974#;
   Cjk_Compatibility_Ideograph_F975        : constant Unicode_Char := 16#F975#;
   Cjk_Compatibility_Ideograph_F976        : constant Unicode_Char := 16#F976#;
   Cjk_Compatibility_Ideograph_F977        : constant Unicode_Char := 16#F977#;
   Cjk_Compatibility_Ideograph_F978        : constant Unicode_Char := 16#F978#;
   Cjk_Compatibility_Ideograph_F979        : constant Unicode_Char := 16#F979#;
   Cjk_Compatibility_Ideograph_F97a        : constant Unicode_Char := 16#F97A#;
   Cjk_Compatibility_Ideograph_F97b        : constant Unicode_Char := 16#F97B#;
   Cjk_Compatibility_Ideograph_F97c        : constant Unicode_Char := 16#F97C#;
   Cjk_Compatibility_Ideograph_F97d        : constant Unicode_Char := 16#F97D#;
   Cjk_Compatibility_Ideograph_F97e        : constant Unicode_Char := 16#F97E#;
   Cjk_Compatibility_Ideograph_F97f        : constant Unicode_Char := 16#F97F#;
   Cjk_Compatibility_Ideograph_F980        : constant Unicode_Char := 16#F980#;
   Cjk_Compatibility_Ideograph_F981        : constant Unicode_Char := 16#F981#;
   Cjk_Compatibility_Ideograph_F982        : constant Unicode_Char := 16#F982#;
   Cjk_Compatibility_Ideograph_F983        : constant Unicode_Char := 16#F983#;
   Cjk_Compatibility_Ideograph_F984        : constant Unicode_Char := 16#F984#;
   Cjk_Compatibility_Ideograph_F985        : constant Unicode_Char := 16#F985#;
   Cjk_Compatibility_Ideograph_F986        : constant Unicode_Char := 16#F986#;
   Cjk_Compatibility_Ideograph_F987        : constant Unicode_Char := 16#F987#;
   Cjk_Compatibility_Ideograph_F988        : constant Unicode_Char := 16#F988#;
   Cjk_Compatibility_Ideograph_F989        : constant Unicode_Char := 16#F989#;
   Cjk_Compatibility_Ideograph_F98a        : constant Unicode_Char := 16#F98A#;
   Cjk_Compatibility_Ideograph_F98b        : constant Unicode_Char := 16#F98B#;
   Cjk_Compatibility_Ideograph_F98c        : constant Unicode_Char := 16#F98C#;
   Cjk_Compatibility_Ideograph_F98d        : constant Unicode_Char := 16#F98D#;
   Cjk_Compatibility_Ideograph_F98e        : constant Unicode_Char := 16#F98E#;
   Cjk_Compatibility_Ideograph_F98f        : constant Unicode_Char := 16#F98F#;
   Cjk_Compatibility_Ideograph_F990        : constant Unicode_Char := 16#F990#;
   Cjk_Compatibility_Ideograph_F991        : constant Unicode_Char := 16#F991#;
   Cjk_Compatibility_Ideograph_F992        : constant Unicode_Char := 16#F992#;
   Cjk_Compatibility_Ideograph_F993        : constant Unicode_Char := 16#F993#;
   Cjk_Compatibility_Ideograph_F994        : constant Unicode_Char := 16#F994#;
   Cjk_Compatibility_Ideograph_F995        : constant Unicode_Char := 16#F995#;
   Cjk_Compatibility_Ideograph_F996        : constant Unicode_Char := 16#F996#;
   Cjk_Compatibility_Ideograph_F997        : constant Unicode_Char := 16#F997#;
   Cjk_Compatibility_Ideograph_F998        : constant Unicode_Char := 16#F998#;
   Cjk_Compatibility_Ideograph_F999        : constant Unicode_Char := 16#F999#;
   Cjk_Compatibility_Ideograph_F99a        : constant Unicode_Char := 16#F99A#;
   Cjk_Compatibility_Ideograph_F99b        : constant Unicode_Char := 16#F99B#;
   Cjk_Compatibility_Ideograph_F99c        : constant Unicode_Char := 16#F99C#;
   Cjk_Compatibility_Ideograph_F99d        : constant Unicode_Char := 16#F99D#;
   Cjk_Compatibility_Ideograph_F99e        : constant Unicode_Char := 16#F99E#;
   Cjk_Compatibility_Ideograph_F99f        : constant Unicode_Char := 16#F99F#;
   Cjk_Compatibility_Ideograph_F9a0        : constant Unicode_Char := 16#F9A0#;
   Cjk_Compatibility_Ideograph_F9a1        : constant Unicode_Char := 16#F9A1#;
   Cjk_Compatibility_Ideograph_F9a2        : constant Unicode_Char := 16#F9A2#;
   Cjk_Compatibility_Ideograph_F9a3        : constant Unicode_Char := 16#F9A3#;
   Cjk_Compatibility_Ideograph_F9a4        : constant Unicode_Char := 16#F9A4#;
   Cjk_Compatibility_Ideograph_F9a5        : constant Unicode_Char := 16#F9A5#;
   Cjk_Compatibility_Ideograph_F9a6        : constant Unicode_Char := 16#F9A6#;
   Cjk_Compatibility_Ideograph_F9a7        : constant Unicode_Char := 16#F9A7#;
   Cjk_Compatibility_Ideograph_F9a8        : constant Unicode_Char := 16#F9A8#;
   Cjk_Compatibility_Ideograph_F9a9        : constant Unicode_Char := 16#F9A9#;
   Cjk_Compatibility_Ideograph_F9aa        : constant Unicode_Char := 16#F9AA#;
   Cjk_Compatibility_Ideograph_F9ab        : constant Unicode_Char := 16#F9AB#;
   Cjk_Compatibility_Ideograph_F9ac        : constant Unicode_Char := 16#F9AC#;
   Cjk_Compatibility_Ideograph_F9ad        : constant Unicode_Char := 16#F9AD#;
   Cjk_Compatibility_Ideograph_F9ae        : constant Unicode_Char := 16#F9AE#;
   Cjk_Compatibility_Ideograph_F9af        : constant Unicode_Char := 16#F9AF#;
   Cjk_Compatibility_Ideograph_F9b0        : constant Unicode_Char := 16#F9B0#;
   Cjk_Compatibility_Ideograph_F9b1        : constant Unicode_Char := 16#F9B1#;
   Cjk_Compatibility_Ideograph_F9b2        : constant Unicode_Char := 16#F9B2#;
   Cjk_Compatibility_Ideograph_F9b3        : constant Unicode_Char := 16#F9B3#;
   Cjk_Compatibility_Ideograph_F9b4        : constant Unicode_Char := 16#F9B4#;
   Cjk_Compatibility_Ideograph_F9b5        : constant Unicode_Char := 16#F9B5#;
   Cjk_Compatibility_Ideograph_F9b6        : constant Unicode_Char := 16#F9B6#;
   Cjk_Compatibility_Ideograph_F9b7        : constant Unicode_Char := 16#F9B7#;
   Cjk_Compatibility_Ideograph_F9b8        : constant Unicode_Char := 16#F9B8#;
   Cjk_Compatibility_Ideograph_F9b9        : constant Unicode_Char := 16#F9B9#;
   Cjk_Compatibility_Ideograph_F9ba        : constant Unicode_Char := 16#F9BA#;
   Cjk_Compatibility_Ideograph_F9bb        : constant Unicode_Char := 16#F9BB#;
   Cjk_Compatibility_Ideograph_F9bc        : constant Unicode_Char := 16#F9BC#;
   Cjk_Compatibility_Ideograph_F9bd        : constant Unicode_Char := 16#F9BD#;
   Cjk_Compatibility_Ideograph_F9be        : constant Unicode_Char := 16#F9BE#;
   Cjk_Compatibility_Ideograph_F9bf        : constant Unicode_Char := 16#F9BF#;
   Cjk_Compatibility_Ideograph_F9c0        : constant Unicode_Char := 16#F9C0#;
   Cjk_Compatibility_Ideograph_F9c1        : constant Unicode_Char := 16#F9C1#;
   Cjk_Compatibility_Ideograph_F9c2        : constant Unicode_Char := 16#F9C2#;
   Cjk_Compatibility_Ideograph_F9c3        : constant Unicode_Char := 16#F9C3#;
   Cjk_Compatibility_Ideograph_F9c4        : constant Unicode_Char := 16#F9C4#;
   Cjk_Compatibility_Ideograph_F9c5        : constant Unicode_Char := 16#F9C5#;
   Cjk_Compatibility_Ideograph_F9c6        : constant Unicode_Char := 16#F9C6#;
   Cjk_Compatibility_Ideograph_F9c7        : constant Unicode_Char := 16#F9C7#;
   Cjk_Compatibility_Ideograph_F9c8        : constant Unicode_Char := 16#F9C8#;
   Cjk_Compatibility_Ideograph_F9c9        : constant Unicode_Char := 16#F9C9#;
   Cjk_Compatibility_Ideograph_F9ca        : constant Unicode_Char := 16#F9CA#;
   Cjk_Compatibility_Ideograph_F9cb        : constant Unicode_Char := 16#F9CB#;
   Cjk_Compatibility_Ideograph_F9cc        : constant Unicode_Char := 16#F9CC#;
   Cjk_Compatibility_Ideograph_F9cd        : constant Unicode_Char := 16#F9CD#;
   Cjk_Compatibility_Ideograph_F9ce        : constant Unicode_Char := 16#F9CE#;
   Cjk_Compatibility_Ideograph_F9cf        : constant Unicode_Char := 16#F9CF#;
   Cjk_Compatibility_Ideograph_F9d0        : constant Unicode_Char := 16#F9D0#;
   Cjk_Compatibility_Ideograph_F9d1        : constant Unicode_Char := 16#F9D1#;
   Cjk_Compatibility_Ideograph_F9d2        : constant Unicode_Char := 16#F9D2#;
   Cjk_Compatibility_Ideograph_F9d3        : constant Unicode_Char := 16#F9D3#;
   Cjk_Compatibility_Ideograph_F9d4        : constant Unicode_Char := 16#F9D4#;
   Cjk_Compatibility_Ideograph_F9d5        : constant Unicode_Char := 16#F9D5#;
   Cjk_Compatibility_Ideograph_F9d6        : constant Unicode_Char := 16#F9D6#;
   Cjk_Compatibility_Ideograph_F9d7        : constant Unicode_Char := 16#F9D7#;
   Cjk_Compatibility_Ideograph_F9d8        : constant Unicode_Char := 16#F9D8#;
   Cjk_Compatibility_Ideograph_F9d9        : constant Unicode_Char := 16#F9D9#;
   Cjk_Compatibility_Ideograph_F9da        : constant Unicode_Char := 16#F9DA#;
   Cjk_Compatibility_Ideograph_F9db        : constant Unicode_Char := 16#F9DB#;
   Cjk_Compatibility_Ideograph_F9dc        : constant Unicode_Char := 16#F9DC#;
   Cjk_Compatibility_Ideograph_F9dd        : constant Unicode_Char := 16#F9DD#;
   Cjk_Compatibility_Ideograph_F9de        : constant Unicode_Char := 16#F9DE#;
   Cjk_Compatibility_Ideograph_F9df        : constant Unicode_Char := 16#F9DF#;
   Cjk_Compatibility_Ideograph_F9e0        : constant Unicode_Char := 16#F9E0#;
   Cjk_Compatibility_Ideograph_F9e1        : constant Unicode_Char := 16#F9E1#;
   Cjk_Compatibility_Ideograph_F9e2        : constant Unicode_Char := 16#F9E2#;
   Cjk_Compatibility_Ideograph_F9e3        : constant Unicode_Char := 16#F9E3#;
   Cjk_Compatibility_Ideograph_F9e4        : constant Unicode_Char := 16#F9E4#;
   Cjk_Compatibility_Ideograph_F9e5        : constant Unicode_Char := 16#F9E5#;
   Cjk_Compatibility_Ideograph_F9e6        : constant Unicode_Char := 16#F9E6#;
   Cjk_Compatibility_Ideograph_F9e7        : constant Unicode_Char := 16#F9E7#;
   Cjk_Compatibility_Ideograph_F9e8        : constant Unicode_Char := 16#F9E8#;
   Cjk_Compatibility_Ideograph_F9e9        : constant Unicode_Char := 16#F9E9#;
   Cjk_Compatibility_Ideograph_F9ea        : constant Unicode_Char := 16#F9EA#;
   Cjk_Compatibility_Ideograph_F9eb        : constant Unicode_Char := 16#F9EB#;
   Cjk_Compatibility_Ideograph_F9ec        : constant Unicode_Char := 16#F9EC#;
   Cjk_Compatibility_Ideograph_F9ed        : constant Unicode_Char := 16#F9ED#;
   Cjk_Compatibility_Ideograph_F9ee        : constant Unicode_Char := 16#F9EE#;
   Cjk_Compatibility_Ideograph_F9ef        : constant Unicode_Char := 16#F9EF#;
   Cjk_Compatibility_Ideograph_F9f0        : constant Unicode_Char := 16#F9F0#;
   Cjk_Compatibility_Ideograph_F9f1        : constant Unicode_Char := 16#F9F1#;
   Cjk_Compatibility_Ideograph_F9f2        : constant Unicode_Char := 16#F9F2#;
   Cjk_Compatibility_Ideograph_F9f3        : constant Unicode_Char := 16#F9F3#;
   Cjk_Compatibility_Ideograph_F9f4        : constant Unicode_Char := 16#F9F4#;
   Cjk_Compatibility_Ideograph_F9f5        : constant Unicode_Char := 16#F9F5#;
   Cjk_Compatibility_Ideograph_F9f6        : constant Unicode_Char := 16#F9F6#;
   Cjk_Compatibility_Ideograph_F9f7        : constant Unicode_Char := 16#F9F7#;
   Cjk_Compatibility_Ideograph_F9f8        : constant Unicode_Char := 16#F9F8#;
   Cjk_Compatibility_Ideograph_F9f9        : constant Unicode_Char := 16#F9F9#;
   Cjk_Compatibility_Ideograph_F9fa        : constant Unicode_Char := 16#F9FA#;
   Cjk_Compatibility_Ideograph_F9fb        : constant Unicode_Char := 16#F9FB#;
   Cjk_Compatibility_Ideograph_F9fc        : constant Unicode_Char := 16#F9FC#;
   Cjk_Compatibility_Ideograph_F9fd        : constant Unicode_Char := 16#F9FD#;
   Cjk_Compatibility_Ideograph_F9fe        : constant Unicode_Char := 16#F9FE#;
   Cjk_Compatibility_Ideograph_F9ff        : constant Unicode_Char := 16#F9FF#;
   Cjk_Compatibility_Ideograph_Fa00        : constant Unicode_Char := 16#FA00#;
   Cjk_Compatibility_Ideograph_Fa01        : constant Unicode_Char := 16#FA01#;
   Cjk_Compatibility_Ideograph_Fa02        : constant Unicode_Char := 16#FA02#;
   Cjk_Compatibility_Ideograph_Fa03        : constant Unicode_Char := 16#FA03#;
   Cjk_Compatibility_Ideograph_Fa04        : constant Unicode_Char := 16#FA04#;
   Cjk_Compatibility_Ideograph_Fa05        : constant Unicode_Char := 16#FA05#;
   Cjk_Compatibility_Ideograph_Fa06        : constant Unicode_Char := 16#FA06#;
   Cjk_Compatibility_Ideograph_Fa07        : constant Unicode_Char := 16#FA07#;
   Cjk_Compatibility_Ideograph_Fa08        : constant Unicode_Char := 16#FA08#;
   Cjk_Compatibility_Ideograph_Fa09        : constant Unicode_Char := 16#FA09#;
   Cjk_Compatibility_Ideograph_Fa0a        : constant Unicode_Char := 16#FA0A#;
   Cjk_Compatibility_Ideograph_Fa0b        : constant Unicode_Char := 16#FA0B#;
   Cjk_Compatibility_Ideograph_Fa0c        : constant Unicode_Char := 16#FA0C#;
   Cjk_Compatibility_Ideograph_Fa0d        : constant Unicode_Char := 16#FA0D#;
   Cjk_Compatibility_Ideograph_Fa0e        : constant Unicode_Char := 16#FA0E#;
   Cjk_Compatibility_Ideograph_Fa0f        : constant Unicode_Char := 16#FA0F#;
   Cjk_Compatibility_Ideograph_Fa10        : constant Unicode_Char := 16#FA10#;
   Cjk_Compatibility_Ideograph_Fa11        : constant Unicode_Char := 16#FA11#;
   Cjk_Compatibility_Ideograph_Fa12        : constant Unicode_Char := 16#FA12#;
   Cjk_Compatibility_Ideograph_Fa13        : constant Unicode_Char := 16#FA13#;
   Cjk_Compatibility_Ideograph_Fa14        : constant Unicode_Char := 16#FA14#;
   Cjk_Compatibility_Ideograph_Fa15        : constant Unicode_Char := 16#FA15#;
   Cjk_Compatibility_Ideograph_Fa16        : constant Unicode_Char := 16#FA16#;
   Cjk_Compatibility_Ideograph_Fa17        : constant Unicode_Char := 16#FA17#;
   Cjk_Compatibility_Ideograph_Fa18        : constant Unicode_Char := 16#FA18#;
   Cjk_Compatibility_Ideograph_Fa19        : constant Unicode_Char := 16#FA19#;
   Cjk_Compatibility_Ideograph_Fa1a        : constant Unicode_Char := 16#FA1A#;
   Cjk_Compatibility_Ideograph_Fa1b        : constant Unicode_Char := 16#FA1B#;
   Cjk_Compatibility_Ideograph_Fa1c        : constant Unicode_Char := 16#FA1C#;
   Cjk_Compatibility_Ideograph_Fa1d        : constant Unicode_Char := 16#FA1D#;
   Cjk_Compatibility_Ideograph_Fa1e        : constant Unicode_Char := 16#FA1E#;
   Cjk_Compatibility_Ideograph_Fa1f        : constant Unicode_Char := 16#FA1F#;
   Cjk_Compatibility_Ideograph_Fa20        : constant Unicode_Char := 16#FA20#;
   Cjk_Compatibility_Ideograph_Fa21        : constant Unicode_Char := 16#FA21#;
   Cjk_Compatibility_Ideograph_Fa22        : constant Unicode_Char := 16#FA22#;
   Cjk_Compatibility_Ideograph_Fa23        : constant Unicode_Char := 16#FA23#;
   Cjk_Compatibility_Ideograph_Fa24        : constant Unicode_Char := 16#FA24#;
   Cjk_Compatibility_Ideograph_Fa25        : constant Unicode_Char := 16#FA25#;
   Cjk_Compatibility_Ideograph_Fa26        : constant Unicode_Char := 16#FA26#;
   Cjk_Compatibility_Ideograph_Fa27        : constant Unicode_Char := 16#FA27#;
   Cjk_Compatibility_Ideograph_Fa28        : constant Unicode_Char := 16#FA28#;
   Cjk_Compatibility_Ideograph_Fa29        : constant Unicode_Char := 16#FA29#;
   Cjk_Compatibility_Ideograph_Fa2a        : constant Unicode_Char := 16#FA2A#;
   Cjk_Compatibility_Ideograph_Fa2b        : constant Unicode_Char := 16#FA2B#;
   Cjk_Compatibility_Ideograph_Fa2c        : constant Unicode_Char := 16#FA2C#;
   Cjk_Compatibility_Ideograph_Fa2d        : constant Unicode_Char := 16#FA2D#;
   Cjk_Compatibility_Ideograph_Fa2e        : constant Unicode_Char := 16#FA2E#;
   Cjk_Compatibility_Ideograph_Fa2f        : constant Unicode_Char := 16#FA2F#;
   Cjk_Compatibility_Ideograph_Fa30        : constant Unicode_Char := 16#FA30#;
   Cjk_Compatibility_Ideograph_Fa31        : constant Unicode_Char := 16#FA31#;
   Cjk_Compatibility_Ideograph_Fa32        : constant Unicode_Char := 16#FA32#;
   Cjk_Compatibility_Ideograph_Fa33        : constant Unicode_Char := 16#FA33#;
   Cjk_Compatibility_Ideograph_Fa34        : constant Unicode_Char := 16#FA34#;
   Cjk_Compatibility_Ideograph_Fa35        : constant Unicode_Char := 16#FA35#;
   Cjk_Compatibility_Ideograph_Fa36        : constant Unicode_Char := 16#FA36#;
   Cjk_Compatibility_Ideograph_Fa37        : constant Unicode_Char := 16#FA37#;
   Cjk_Compatibility_Ideograph_Fa38        : constant Unicode_Char := 16#FA38#;
   Cjk_Compatibility_Ideograph_Fa39        : constant Unicode_Char := 16#FA39#;
   Cjk_Compatibility_Ideograph_Fa3a        : constant Unicode_Char := 16#FA3A#;
   Cjk_Compatibility_Ideograph_Fa3b        : constant Unicode_Char := 16#FA3B#;
   Cjk_Compatibility_Ideograph_Fa3c        : constant Unicode_Char := 16#FA3C#;
   Cjk_Compatibility_Ideograph_Fa3d        : constant Unicode_Char := 16#FA3D#;
   Cjk_Compatibility_Ideograph_Fa3e        : constant Unicode_Char := 16#FA3E#;
   Cjk_Compatibility_Ideograph_Fa3f        : constant Unicode_Char := 16#FA3F#;
   Cjk_Compatibility_Ideograph_Fa40        : constant Unicode_Char := 16#FA40#;
   Cjk_Compatibility_Ideograph_Fa41        : constant Unicode_Char := 16#FA41#;
   Cjk_Compatibility_Ideograph_Fa42        : constant Unicode_Char := 16#FA42#;
   Cjk_Compatibility_Ideograph_Fa43        : constant Unicode_Char := 16#FA43#;
   Cjk_Compatibility_Ideograph_Fa44        : constant Unicode_Char := 16#FA44#;
   Cjk_Compatibility_Ideograph_Fa45        : constant Unicode_Char := 16#FA45#;
   Cjk_Compatibility_Ideograph_Fa46        : constant Unicode_Char := 16#FA46#;
   Cjk_Compatibility_Ideograph_Fa47        : constant Unicode_Char := 16#FA47#;
   Cjk_Compatibility_Ideograph_Fa48        : constant Unicode_Char := 16#FA48#;
   Cjk_Compatibility_Ideograph_Fa49        : constant Unicode_Char := 16#FA49#;
   Cjk_Compatibility_Ideograph_Fa4a        : constant Unicode_Char := 16#FA4A#;
   Cjk_Compatibility_Ideograph_Fa4b        : constant Unicode_Char := 16#FA4B#;
   Cjk_Compatibility_Ideograph_Fa4c        : constant Unicode_Char := 16#FA4C#;
   Cjk_Compatibility_Ideograph_Fa4d        : constant Unicode_Char := 16#FA4D#;
   Cjk_Compatibility_Ideograph_Fa4e        : constant Unicode_Char := 16#FA4E#;
   Cjk_Compatibility_Ideograph_Fa4f        : constant Unicode_Char := 16#FA4F#;
   Cjk_Compatibility_Ideograph_Fa50        : constant Unicode_Char := 16#FA50#;
   Cjk_Compatibility_Ideograph_Fa51        : constant Unicode_Char := 16#FA51#;
   Cjk_Compatibility_Ideograph_Fa52        : constant Unicode_Char := 16#FA52#;
   Cjk_Compatibility_Ideograph_Fa53        : constant Unicode_Char := 16#FA53#;
   Cjk_Compatibility_Ideograph_Fa54        : constant Unicode_Char := 16#FA54#;
   Cjk_Compatibility_Ideograph_Fa55        : constant Unicode_Char := 16#FA55#;
   Cjk_Compatibility_Ideograph_Fa56        : constant Unicode_Char := 16#FA56#;
   Cjk_Compatibility_Ideograph_Fa57        : constant Unicode_Char := 16#FA57#;
   Cjk_Compatibility_Ideograph_Fa58        : constant Unicode_Char := 16#FA58#;
   Cjk_Compatibility_Ideograph_Fa59        : constant Unicode_Char := 16#FA59#;
   Cjk_Compatibility_Ideograph_Fa5a        : constant Unicode_Char := 16#FA5A#;
   Cjk_Compatibility_Ideograph_Fa5b        : constant Unicode_Char := 16#FA5B#;
   Cjk_Compatibility_Ideograph_Fa5c        : constant Unicode_Char := 16#FA5C#;
   Cjk_Compatibility_Ideograph_Fa5d        : constant Unicode_Char := 16#FA5D#;
   Cjk_Compatibility_Ideograph_Fa5e        : constant Unicode_Char := 16#FA5E#;
   Cjk_Compatibility_Ideograph_Fa5f        : constant Unicode_Char := 16#FA5F#;
   Cjk_Compatibility_Ideograph_Fa60        : constant Unicode_Char := 16#FA60#;
   Cjk_Compatibility_Ideograph_Fa61        : constant Unicode_Char := 16#FA61#;
   Cjk_Compatibility_Ideograph_Fa62        : constant Unicode_Char := 16#FA62#;
   Cjk_Compatibility_Ideograph_Fa63        : constant Unicode_Char := 16#FA63#;
   Cjk_Compatibility_Ideograph_Fa64        : constant Unicode_Char := 16#FA64#;
   Cjk_Compatibility_Ideograph_Fa65        : constant Unicode_Char := 16#FA65#;
   Cjk_Compatibility_Ideograph_Fa66        : constant Unicode_Char := 16#FA66#;
   Cjk_Compatibility_Ideograph_Fa67        : constant Unicode_Char := 16#FA67#;
   Cjk_Compatibility_Ideograph_Fa68        : constant Unicode_Char := 16#FA68#;
   Cjk_Compatibility_Ideograph_Fa69        : constant Unicode_Char := 16#FA69#;
   Cjk_Compatibility_Ideograph_Fa6a        : constant Unicode_Char := 16#FA6A#;
   Cjk_Compatibility_Ideograph_Fa6b        : constant Unicode_Char := 16#FA6B#;
   Cjk_Compatibility_Ideograph_Fa6c        : constant Unicode_Char := 16#FA6C#;
   Cjk_Compatibility_Ideograph_Fa6d        : constant Unicode_Char := 16#FA6D#;
   Cjk_Compatibility_Ideograph_Fa70        : constant Unicode_Char := 16#FA70#;
   Cjk_Compatibility_Ideograph_Fa71        : constant Unicode_Char := 16#FA71#;
   Cjk_Compatibility_Ideograph_Fa72        : constant Unicode_Char := 16#FA72#;
   Cjk_Compatibility_Ideograph_Fa73        : constant Unicode_Char := 16#FA73#;
   Cjk_Compatibility_Ideograph_Fa74        : constant Unicode_Char := 16#FA74#;
   Cjk_Compatibility_Ideograph_Fa75        : constant Unicode_Char := 16#FA75#;
   Cjk_Compatibility_Ideograph_Fa76        : constant Unicode_Char := 16#FA76#;
   Cjk_Compatibility_Ideograph_Fa77        : constant Unicode_Char := 16#FA77#;
   Cjk_Compatibility_Ideograph_Fa78        : constant Unicode_Char := 16#FA78#;
   Cjk_Compatibility_Ideograph_Fa79        : constant Unicode_Char := 16#FA79#;
   Cjk_Compatibility_Ideograph_Fa7a        : constant Unicode_Char := 16#FA7A#;
   Cjk_Compatibility_Ideograph_Fa7b        : constant Unicode_Char := 16#FA7B#;
   Cjk_Compatibility_Ideograph_Fa7c        : constant Unicode_Char := 16#FA7C#;
   Cjk_Compatibility_Ideograph_Fa7d        : constant Unicode_Char := 16#FA7D#;
   Cjk_Compatibility_Ideograph_Fa7e        : constant Unicode_Char := 16#FA7E#;
   Cjk_Compatibility_Ideograph_Fa7f        : constant Unicode_Char := 16#FA7F#;
   Cjk_Compatibility_Ideograph_Fa80        : constant Unicode_Char := 16#FA80#;
   Cjk_Compatibility_Ideograph_Fa81        : constant Unicode_Char := 16#FA81#;
   Cjk_Compatibility_Ideograph_Fa82        : constant Unicode_Char := 16#FA82#;
   Cjk_Compatibility_Ideograph_Fa83        : constant Unicode_Char := 16#FA83#;
   Cjk_Compatibility_Ideograph_Fa84        : constant Unicode_Char := 16#FA84#;
   Cjk_Compatibility_Ideograph_Fa85        : constant Unicode_Char := 16#FA85#;
   Cjk_Compatibility_Ideograph_Fa86        : constant Unicode_Char := 16#FA86#;
   Cjk_Compatibility_Ideograph_Fa87        : constant Unicode_Char := 16#FA87#;
   Cjk_Compatibility_Ideograph_Fa88        : constant Unicode_Char := 16#FA88#;
   Cjk_Compatibility_Ideograph_Fa89        : constant Unicode_Char := 16#FA89#;
   Cjk_Compatibility_Ideograph_Fa8a        : constant Unicode_Char := 16#FA8A#;
   Cjk_Compatibility_Ideograph_Fa8b        : constant Unicode_Char := 16#FA8B#;
   Cjk_Compatibility_Ideograph_Fa8c        : constant Unicode_Char := 16#FA8C#;
   Cjk_Compatibility_Ideograph_Fa8d        : constant Unicode_Char := 16#FA8D#;
   Cjk_Compatibility_Ideograph_Fa8e        : constant Unicode_Char := 16#FA8E#;
   Cjk_Compatibility_Ideograph_Fa8f        : constant Unicode_Char := 16#FA8F#;
   Cjk_Compatibility_Ideograph_Fa90        : constant Unicode_Char := 16#FA90#;
   Cjk_Compatibility_Ideograph_Fa91        : constant Unicode_Char := 16#FA91#;
   Cjk_Compatibility_Ideograph_Fa92        : constant Unicode_Char := 16#FA92#;
   Cjk_Compatibility_Ideograph_Fa93        : constant Unicode_Char := 16#FA93#;
   Cjk_Compatibility_Ideograph_Fa94        : constant Unicode_Char := 16#FA94#;
   Cjk_Compatibility_Ideograph_Fa95        : constant Unicode_Char := 16#FA95#;
   Cjk_Compatibility_Ideograph_Fa96        : constant Unicode_Char := 16#FA96#;
   Cjk_Compatibility_Ideograph_Fa97        : constant Unicode_Char := 16#FA97#;
   Cjk_Compatibility_Ideograph_Fa98        : constant Unicode_Char := 16#FA98#;
   Cjk_Compatibility_Ideograph_Fa99        : constant Unicode_Char := 16#FA99#;
   Cjk_Compatibility_Ideograph_Fa9a        : constant Unicode_Char := 16#FA9A#;
   Cjk_Compatibility_Ideograph_Fa9b        : constant Unicode_Char := 16#FA9B#;
   Cjk_Compatibility_Ideograph_Fa9c        : constant Unicode_Char := 16#FA9C#;
   Cjk_Compatibility_Ideograph_Fa9d        : constant Unicode_Char := 16#FA9D#;
   Cjk_Compatibility_Ideograph_Fa9e        : constant Unicode_Char := 16#FA9E#;
   Cjk_Compatibility_Ideograph_Fa9f        : constant Unicode_Char := 16#FA9F#;
   Cjk_Compatibility_Ideograph_Faa0        : constant Unicode_Char := 16#FAA0#;
   Cjk_Compatibility_Ideograph_Faa1        : constant Unicode_Char := 16#FAA1#;
   Cjk_Compatibility_Ideograph_Faa2        : constant Unicode_Char := 16#FAA2#;
   Cjk_Compatibility_Ideograph_Faa3        : constant Unicode_Char := 16#FAA3#;
   Cjk_Compatibility_Ideograph_Faa4        : constant Unicode_Char := 16#FAA4#;
   Cjk_Compatibility_Ideograph_Faa5        : constant Unicode_Char := 16#FAA5#;
   Cjk_Compatibility_Ideograph_Faa6        : constant Unicode_Char := 16#FAA6#;
   Cjk_Compatibility_Ideograph_Faa7        : constant Unicode_Char := 16#FAA7#;
   Cjk_Compatibility_Ideograph_Faa8        : constant Unicode_Char := 16#FAA8#;
   Cjk_Compatibility_Ideograph_Faa9        : constant Unicode_Char := 16#FAA9#;
   Cjk_Compatibility_Ideograph_Faaa        : constant Unicode_Char := 16#FAAA#;
   Cjk_Compatibility_Ideograph_Faab        : constant Unicode_Char := 16#FAAB#;
   Cjk_Compatibility_Ideograph_Faac        : constant Unicode_Char := 16#FAAC#;
   Cjk_Compatibility_Ideograph_Faad        : constant Unicode_Char := 16#FAAD#;
   Cjk_Compatibility_Ideograph_Faae        : constant Unicode_Char := 16#FAAE#;
   Cjk_Compatibility_Ideograph_Faaf        : constant Unicode_Char := 16#FAAF#;
   Cjk_Compatibility_Ideograph_Fab0        : constant Unicode_Char := 16#FAB0#;
   Cjk_Compatibility_Ideograph_Fab1        : constant Unicode_Char := 16#FAB1#;
   Cjk_Compatibility_Ideograph_Fab2        : constant Unicode_Char := 16#FAB2#;
   Cjk_Compatibility_Ideograph_Fab3        : constant Unicode_Char := 16#FAB3#;
   Cjk_Compatibility_Ideograph_Fab4        : constant Unicode_Char := 16#FAB4#;
   Cjk_Compatibility_Ideograph_Fab5        : constant Unicode_Char := 16#FAB5#;
   Cjk_Compatibility_Ideograph_Fab6        : constant Unicode_Char := 16#FAB6#;
   Cjk_Compatibility_Ideograph_Fab7        : constant Unicode_Char := 16#FAB7#;
   Cjk_Compatibility_Ideograph_Fab8        : constant Unicode_Char := 16#FAB8#;
   Cjk_Compatibility_Ideograph_Fab9        : constant Unicode_Char := 16#FAB9#;
   Cjk_Compatibility_Ideograph_Faba        : constant Unicode_Char := 16#FABA#;
   Cjk_Compatibility_Ideograph_Fabb        : constant Unicode_Char := 16#FABB#;
   Cjk_Compatibility_Ideograph_Fabc        : constant Unicode_Char := 16#FABC#;
   Cjk_Compatibility_Ideograph_Fabd        : constant Unicode_Char := 16#FABD#;
   Cjk_Compatibility_Ideograph_Fabe        : constant Unicode_Char := 16#FABE#;
   Cjk_Compatibility_Ideograph_Fabf        : constant Unicode_Char := 16#FABF#;
   Cjk_Compatibility_Ideograph_Fac0        : constant Unicode_Char := 16#FAC0#;
   Cjk_Compatibility_Ideograph_Fac1        : constant Unicode_Char := 16#FAC1#;
   Cjk_Compatibility_Ideograph_Fac2        : constant Unicode_Char := 16#FAC2#;
   Cjk_Compatibility_Ideograph_Fac3        : constant Unicode_Char := 16#FAC3#;
   Cjk_Compatibility_Ideograph_Fac4        : constant Unicode_Char := 16#FAC4#;
   Cjk_Compatibility_Ideograph_Fac5        : constant Unicode_Char := 16#FAC5#;
   Cjk_Compatibility_Ideograph_Fac6        : constant Unicode_Char := 16#FAC6#;
   Cjk_Compatibility_Ideograph_Fac7        : constant Unicode_Char := 16#FAC7#;
   Cjk_Compatibility_Ideograph_Fac8        : constant Unicode_Char := 16#FAC8#;
   Cjk_Compatibility_Ideograph_Fac9        : constant Unicode_Char := 16#FAC9#;
   Cjk_Compatibility_Ideograph_Faca        : constant Unicode_Char := 16#FACA#;
   Cjk_Compatibility_Ideograph_Facb        : constant Unicode_Char := 16#FACB#;
   Cjk_Compatibility_Ideograph_Facc        : constant Unicode_Char := 16#FACC#;
   Cjk_Compatibility_Ideograph_Facd        : constant Unicode_Char := 16#FACD#;
   Cjk_Compatibility_Ideograph_Face        : constant Unicode_Char := 16#FACE#;
   Cjk_Compatibility_Ideograph_Facf        : constant Unicode_Char := 16#FACF#;
   Cjk_Compatibility_Ideograph_Fad0        : constant Unicode_Char := 16#FAD0#;
   Cjk_Compatibility_Ideograph_Fad1        : constant Unicode_Char := 16#FAD1#;
   Cjk_Compatibility_Ideograph_Fad2        : constant Unicode_Char := 16#FAD2#;
   Cjk_Compatibility_Ideograph_Fad3        : constant Unicode_Char := 16#FAD3#;
   Cjk_Compatibility_Ideograph_Fad4        : constant Unicode_Char := 16#FAD4#;
   Cjk_Compatibility_Ideograph_Fad5        : constant Unicode_Char := 16#FAD5#;
   Cjk_Compatibility_Ideograph_Fad6        : constant Unicode_Char := 16#FAD6#;
   Cjk_Compatibility_Ideograph_Fad7        : constant Unicode_Char := 16#FAD7#;
   Cjk_Compatibility_Ideograph_Fad8        : constant Unicode_Char := 16#FAD8#;
   Cjk_Compatibility_Ideograph_Fad9        : constant Unicode_Char := 16#FAD9#;
end Unicode.Names.Cjk_Compat_Ideographs;
