--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Bassa_Vah is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Bassa_Vah_Letter_Enni                   :
      constant Unicode_Char := 16#16AD0#;
   Bassa_Vah_Letter_Ka                     :
      constant Unicode_Char := 16#16AD1#;
   Bassa_Vah_Letter_Se                     :
      constant Unicode_Char := 16#16AD2#;
   Bassa_Vah_Letter_Fa                     :
      constant Unicode_Char := 16#16AD3#;
   Bassa_Vah_Letter_Mbe                    :
      constant Unicode_Char := 16#16AD4#;
   Bassa_Vah_Letter_Yie                    :
      constant Unicode_Char := 16#16AD5#;
   Bassa_Vah_Letter_Gah                    :
      constant Unicode_Char := 16#16AD6#;
   Bassa_Vah_Letter_Dhii                   :
      constant Unicode_Char := 16#16AD7#;
   Bassa_Vah_Letter_Kpah                   :
      constant Unicode_Char := 16#16AD8#;
   Bassa_Vah_Letter_Jo                     :
      constant Unicode_Char := 16#16AD9#;
   Bassa_Vah_Letter_Hwah                   :
      constant Unicode_Char := 16#16ADA#;
   Bassa_Vah_Letter_Wa                     :
      constant Unicode_Char := 16#16ADB#;
   Bassa_Vah_Letter_Zo                     :
      constant Unicode_Char := 16#16ADC#;
   Bassa_Vah_Letter_Gbu                    :
      constant Unicode_Char := 16#16ADD#;
   Bassa_Vah_Letter_Do                     :
      constant Unicode_Char := 16#16ADE#;
   Bassa_Vah_Letter_Ce                     :
      constant Unicode_Char := 16#16ADF#;
   Bassa_Vah_Letter_Uwu                    :
      constant Unicode_Char := 16#16AE0#;
   Bassa_Vah_Letter_To                     :
      constant Unicode_Char := 16#16AE1#;
   Bassa_Vah_Letter_Ba                     :
      constant Unicode_Char := 16#16AE2#;
   Bassa_Vah_Letter_Vu                     :
      constant Unicode_Char := 16#16AE3#;
   Bassa_Vah_Letter_Yein                   :
      constant Unicode_Char := 16#16AE4#;
   Bassa_Vah_Letter_Pa                     :
      constant Unicode_Char := 16#16AE5#;
   Bassa_Vah_Letter_Wadda                  :
      constant Unicode_Char := 16#16AE6#;
   Bassa_Vah_Letter_A                      :
      constant Unicode_Char := 16#16AE7#;
   Bassa_Vah_Letter_O                      :
      constant Unicode_Char := 16#16AE8#;
   Bassa_Vah_Letter_Oo                     :
      constant Unicode_Char := 16#16AE9#;
   Bassa_Vah_Letter_U                      :
      constant Unicode_Char := 16#16AEA#;
   Bassa_Vah_Letter_Ee                     :
      constant Unicode_Char := 16#16AEB#;
   Bassa_Vah_Letter_E                      :
      constant Unicode_Char := 16#16AEC#;
   Bassa_Vah_Letter_I                      :
      constant Unicode_Char := 16#16AED#;
   Bassa_Vah_Combining_High_Tone           :
      constant Unicode_Char := 16#16AF0#;
   Bassa_Vah_Combining_Low_Tone            :
      constant Unicode_Char := 16#16AF1#;
   Bassa_Vah_Combining_Mid_Tone            :
      constant Unicode_Char := 16#16AF2#;
   Bassa_Vah_Combining_Low_Mid_Tone        :
      constant Unicode_Char := 16#16AF3#;
   Bassa_Vah_Combining_High_Low_Tone       :
      constant Unicode_Char := 16#16AF4#;
   Bassa_Vah_Full_Stop                     :
      constant Unicode_Char := 16#16AF5#;
end Unicode.Names.Bassa_Vah;
