--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Javanese is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Javanese_Sign_Panyangga                 : constant Unicode_Char := 16#A980#;
   Javanese_Sign_Cecak                     : constant Unicode_Char := 16#A981#;
   Javanese_Sign_Layar                     : constant Unicode_Char := 16#A982#;
   Javanese_Sign_Wignyan                   : constant Unicode_Char := 16#A983#;
   Javanese_Letter_A                       : constant Unicode_Char := 16#A984#;
   Javanese_Letter_I_Kawi                  : constant Unicode_Char := 16#A985#;
   Javanese_Letter_I                       : constant Unicode_Char := 16#A986#;
   Javanese_Letter_Ii                      : constant Unicode_Char := 16#A987#;
   Javanese_Letter_U                       : constant Unicode_Char := 16#A988#;
   Javanese_Letter_Pa_Cerek                : constant Unicode_Char := 16#A989#;
   Javanese_Letter_Nga_Lelet               : constant Unicode_Char := 16#A98A#;
   Javanese_Letter_Nga_Lelet_Raswadi       : constant Unicode_Char := 16#A98B#;
   Javanese_Letter_E                       : constant Unicode_Char := 16#A98C#;
   Javanese_Letter_Ai                      : constant Unicode_Char := 16#A98D#;
   Javanese_Letter_O                       : constant Unicode_Char := 16#A98E#;
   Javanese_Letter_Ka                      : constant Unicode_Char := 16#A98F#;
   Javanese_Letter_Ka_Sasak                : constant Unicode_Char := 16#A990#;
   Javanese_Letter_Ka_Murda                : constant Unicode_Char := 16#A991#;
   Javanese_Letter_Ga                      : constant Unicode_Char := 16#A992#;
   Javanese_Letter_Ga_Murda                : constant Unicode_Char := 16#A993#;
   Javanese_Letter_Nga                     : constant Unicode_Char := 16#A994#;
   Javanese_Letter_Ca                      : constant Unicode_Char := 16#A995#;
   Javanese_Letter_Ca_Murda                : constant Unicode_Char := 16#A996#;
   Javanese_Letter_Ja                      : constant Unicode_Char := 16#A997#;
   Javanese_Letter_Nya_Murda               : constant Unicode_Char := 16#A998#;
   Javanese_Letter_Ja_Mahaprana            : constant Unicode_Char := 16#A999#;
   Javanese_Letter_Nya                     : constant Unicode_Char := 16#A99A#;
   Javanese_Letter_Tta                     : constant Unicode_Char := 16#A99B#;
   Javanese_Letter_Tta_Mahaprana           : constant Unicode_Char := 16#A99C#;
   Javanese_Letter_Dda                     : constant Unicode_Char := 16#A99D#;
   Javanese_Letter_Dda_Mahaprana           : constant Unicode_Char := 16#A99E#;
   Javanese_Letter_Na_Murda                : constant Unicode_Char := 16#A99F#;
   Javanese_Letter_Ta                      : constant Unicode_Char := 16#A9A0#;
   Javanese_Letter_Ta_Murda                : constant Unicode_Char := 16#A9A1#;
   Javanese_Letter_Da                      : constant Unicode_Char := 16#A9A2#;
   Javanese_Letter_Da_Mahaprana            : constant Unicode_Char := 16#A9A3#;
   Javanese_Letter_Na                      : constant Unicode_Char := 16#A9A4#;
   Javanese_Letter_Pa                      : constant Unicode_Char := 16#A9A5#;
   Javanese_Letter_Pa_Murda                : constant Unicode_Char := 16#A9A6#;
   Javanese_Letter_Ba                      : constant Unicode_Char := 16#A9A7#;
   Javanese_Letter_Ba_Murda                : constant Unicode_Char := 16#A9A8#;
   Javanese_Letter_Ma                      : constant Unicode_Char := 16#A9A9#;
   Javanese_Letter_Ya                      : constant Unicode_Char := 16#A9AA#;
   Javanese_Letter_Ra                      : constant Unicode_Char := 16#A9AB#;
   Javanese_Letter_Ra_Agung                : constant Unicode_Char := 16#A9AC#;
   Javanese_Letter_La                      : constant Unicode_Char := 16#A9AD#;
   Javanese_Letter_Wa                      : constant Unicode_Char := 16#A9AE#;
   Javanese_Letter_Sa_Murda                : constant Unicode_Char := 16#A9AF#;
   Javanese_Letter_Sa_Mahaprana            : constant Unicode_Char := 16#A9B0#;
   Javanese_Letter_Sa                      : constant Unicode_Char := 16#A9B1#;
   Javanese_Letter_Ha                      : constant Unicode_Char := 16#A9B2#;
   Javanese_Sign_Cecak_Telu                : constant Unicode_Char := 16#A9B3#;
   Javanese_Vowel_Sign_Tarung              : constant Unicode_Char := 16#A9B4#;
   Javanese_Vowel_Sign_Tolong              : constant Unicode_Char := 16#A9B5#;
   Javanese_Vowel_Sign_Wulu                : constant Unicode_Char := 16#A9B6#;
   Javanese_Vowel_Sign_Wulu_Melik          : constant Unicode_Char := 16#A9B7#;
   Javanese_Vowel_Sign_Suku                : constant Unicode_Char := 16#A9B8#;
   Javanese_Vowel_Sign_Suku_Mendut         : constant Unicode_Char := 16#A9B9#;
   Javanese_Vowel_Sign_Taling              : constant Unicode_Char := 16#A9BA#;
   Javanese_Vowel_Sign_Dirga_Mure          : constant Unicode_Char := 16#A9BB#;
   Javanese_Vowel_Sign_Pepet               : constant Unicode_Char := 16#A9BC#;
   Javanese_Consonant_Sign_Keret           : constant Unicode_Char := 16#A9BD#;
   Javanese_Consonant_Sign_Pengkal         : constant Unicode_Char := 16#A9BE#;
   Javanese_Consonant_Sign_Cakra           : constant Unicode_Char := 16#A9BF#;
   Javanese_Pangkon                        : constant Unicode_Char := 16#A9C0#;
   Javanese_Left_Rerenggan                 : constant Unicode_Char := 16#A9C1#;
   Javanese_Right_Rerenggan                : constant Unicode_Char := 16#A9C2#;
   Javanese_Pada_Andap                     : constant Unicode_Char := 16#A9C3#;
   Javanese_Pada_Madya                     : constant Unicode_Char := 16#A9C4#;
   Javanese_Pada_Luhur                     : constant Unicode_Char := 16#A9C5#;
   Javanese_Pada_Windu                     : constant Unicode_Char := 16#A9C6#;
   Javanese_Pada_Pangkat                   : constant Unicode_Char := 16#A9C7#;
   Javanese_Pada_Lingsa                    : constant Unicode_Char := 16#A9C8#;
   Javanese_Pada_Lungsi                    : constant Unicode_Char := 16#A9C9#;
   Javanese_Pada_Adeg                      : constant Unicode_Char := 16#A9CA#;
   Javanese_Pada_Adeg_Adeg                 : constant Unicode_Char := 16#A9CB#;
   Javanese_Pada_Piseleh                   : constant Unicode_Char := 16#A9CC#;
   Javanese_Turned_Pada_Piseleh            : constant Unicode_Char := 16#A9CD#;
   Javanese_Pangrangkep                    : constant Unicode_Char := 16#A9CF#;
   Javanese_Digit_Zero                     : constant Unicode_Char := 16#A9D0#;
   Javanese_Digit_One                      : constant Unicode_Char := 16#A9D1#;
   Javanese_Digit_Two                      : constant Unicode_Char := 16#A9D2#;
   Javanese_Digit_Three                    : constant Unicode_Char := 16#A9D3#;
   Javanese_Digit_Four                     : constant Unicode_Char := 16#A9D4#;
   Javanese_Digit_Five                     : constant Unicode_Char := 16#A9D5#;
   Javanese_Digit_Six                      : constant Unicode_Char := 16#A9D6#;
   Javanese_Digit_Seven                    : constant Unicode_Char := 16#A9D7#;
   Javanese_Digit_Eight                    : constant Unicode_Char := 16#A9D8#;
   Javanese_Digit_Nine                     : constant Unicode_Char := 16#A9D9#;
   Javanese_Pada_Tirta_Tumetes             : constant Unicode_Char := 16#A9DE#;
   Javanese_Pada_Isen_Isen                 : constant Unicode_Char := 16#A9DF#;
end Unicode.Names.Javanese;
