--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Shavian is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Shavian_Letter_Peep                     :
      constant Unicode_Char := 16#10450#;
   Shavian_Letter_Tot                      :
      constant Unicode_Char := 16#10451#;
   Shavian_Letter_Kick                     :
      constant Unicode_Char := 16#10452#;
   Shavian_Letter_Fee                      :
      constant Unicode_Char := 16#10453#;
   Shavian_Letter_Thigh                    :
      constant Unicode_Char := 16#10454#;
   Shavian_Letter_So                       :
      constant Unicode_Char := 16#10455#;
   Shavian_Letter_Sure                     :
      constant Unicode_Char := 16#10456#;
   Shavian_Letter_Church                   :
      constant Unicode_Char := 16#10457#;
   Shavian_Letter_Yea                      :
      constant Unicode_Char := 16#10458#;
   Shavian_Letter_Hung                     :
      constant Unicode_Char := 16#10459#;
   Shavian_Letter_Bib                      :
      constant Unicode_Char := 16#1045A#;
   Shavian_Letter_Dead                     :
      constant Unicode_Char := 16#1045B#;
   Shavian_Letter_Gag                      :
      constant Unicode_Char := 16#1045C#;
   Shavian_Letter_Vow                      :
      constant Unicode_Char := 16#1045D#;
   Shavian_Letter_They                     :
      constant Unicode_Char := 16#1045E#;
   Shavian_Letter_Zoo                      :
      constant Unicode_Char := 16#1045F#;
   Shavian_Letter_Measure                  :
      constant Unicode_Char := 16#10460#;
   Shavian_Letter_Judge                    :
      constant Unicode_Char := 16#10461#;
   Shavian_Letter_Woe                      :
      constant Unicode_Char := 16#10462#;
   Shavian_Letter_Ha_Ha                    :
      constant Unicode_Char := 16#10463#;
   Shavian_Letter_Loll                     :
      constant Unicode_Char := 16#10464#;
   Shavian_Letter_Mime                     :
      constant Unicode_Char := 16#10465#;
   Shavian_Letter_If                       :
      constant Unicode_Char := 16#10466#;
   Shavian_Letter_Egg                      :
      constant Unicode_Char := 16#10467#;
   Shavian_Letter_Ash                      :
      constant Unicode_Char := 16#10468#;
   Shavian_Letter_Ado                      :
      constant Unicode_Char := 16#10469#;
   Shavian_Letter_On                       :
      constant Unicode_Char := 16#1046A#;
   Shavian_Letter_Wool                     :
      constant Unicode_Char := 16#1046B#;
   Shavian_Letter_Out                      :
      constant Unicode_Char := 16#1046C#;
   Shavian_Letter_Ah                       :
      constant Unicode_Char := 16#1046D#;
   Shavian_Letter_Roar                     :
      constant Unicode_Char := 16#1046E#;
   Shavian_Letter_Nun                      :
      constant Unicode_Char := 16#1046F#;
   Shavian_Letter_Eat                      :
      constant Unicode_Char := 16#10470#;
   Shavian_Letter_Age                      :
      constant Unicode_Char := 16#10471#;
   Shavian_Letter_Ice                      :
      constant Unicode_Char := 16#10472#;
   Shavian_Letter_Up                       :
      constant Unicode_Char := 16#10473#;
   Shavian_Letter_Oak                      :
      constant Unicode_Char := 16#10474#;
   Shavian_Letter_Ooze                     :
      constant Unicode_Char := 16#10475#;
   Shavian_Letter_Oil                      :
      constant Unicode_Char := 16#10476#;
   Shavian_Letter_Awe                      :
      constant Unicode_Char := 16#10477#;
   Shavian_Letter_Are                      :
      constant Unicode_Char := 16#10478#;
   Shavian_Letter_Or                       :
      constant Unicode_Char := 16#10479#;
   Shavian_Letter_Air                      :
      constant Unicode_Char := 16#1047A#;
   Shavian_Letter_Err                      :
      constant Unicode_Char := 16#1047B#;
   Shavian_Letter_Array                    :
      constant Unicode_Char := 16#1047C#;
   Shavian_Letter_Ear                      :
      constant Unicode_Char := 16#1047D#;
   Shavian_Letter_Ian                      :
      constant Unicode_Char := 16#1047E#;
   Shavian_Letter_Yew                      :
      constant Unicode_Char := 16#1047F#;
end Unicode.Names.Shavian;
