--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Domino_Tiles is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Domino_Tile_Horizontal_Back             :
      constant Unicode_Char := 16#1F030#;
   Domino_Tile_Horizontal_00_00            :
      constant Unicode_Char := 16#1F031#;
   Domino_Tile_Horizontal_00_01            :
      constant Unicode_Char := 16#1F032#;
   Domino_Tile_Horizontal_00_02            :
      constant Unicode_Char := 16#1F033#;
   Domino_Tile_Horizontal_00_03            :
      constant Unicode_Char := 16#1F034#;
   Domino_Tile_Horizontal_00_04            :
      constant Unicode_Char := 16#1F035#;
   Domino_Tile_Horizontal_00_05            :
      constant Unicode_Char := 16#1F036#;
   Domino_Tile_Horizontal_00_06            :
      constant Unicode_Char := 16#1F037#;
   Domino_Tile_Horizontal_01_00            :
      constant Unicode_Char := 16#1F038#;
   Domino_Tile_Horizontal_01_01            :
      constant Unicode_Char := 16#1F039#;
   Domino_Tile_Horizontal_01_02            :
      constant Unicode_Char := 16#1F03A#;
   Domino_Tile_Horizontal_01_03            :
      constant Unicode_Char := 16#1F03B#;
   Domino_Tile_Horizontal_01_04            :
      constant Unicode_Char := 16#1F03C#;
   Domino_Tile_Horizontal_01_05            :
      constant Unicode_Char := 16#1F03D#;
   Domino_Tile_Horizontal_01_06            :
      constant Unicode_Char := 16#1F03E#;
   Domino_Tile_Horizontal_02_00            :
      constant Unicode_Char := 16#1F03F#;
   Domino_Tile_Horizontal_02_01            :
      constant Unicode_Char := 16#1F040#;
   Domino_Tile_Horizontal_02_02            :
      constant Unicode_Char := 16#1F041#;
   Domino_Tile_Horizontal_02_03            :
      constant Unicode_Char := 16#1F042#;
   Domino_Tile_Horizontal_02_04            :
      constant Unicode_Char := 16#1F043#;
   Domino_Tile_Horizontal_02_05            :
      constant Unicode_Char := 16#1F044#;
   Domino_Tile_Horizontal_02_06            :
      constant Unicode_Char := 16#1F045#;
   Domino_Tile_Horizontal_03_00            :
      constant Unicode_Char := 16#1F046#;
   Domino_Tile_Horizontal_03_01            :
      constant Unicode_Char := 16#1F047#;
   Domino_Tile_Horizontal_03_02            :
      constant Unicode_Char := 16#1F048#;
   Domino_Tile_Horizontal_03_03            :
      constant Unicode_Char := 16#1F049#;
   Domino_Tile_Horizontal_03_04            :
      constant Unicode_Char := 16#1F04A#;
   Domino_Tile_Horizontal_03_05            :
      constant Unicode_Char := 16#1F04B#;
   Domino_Tile_Horizontal_03_06            :
      constant Unicode_Char := 16#1F04C#;
   Domino_Tile_Horizontal_04_00            :
      constant Unicode_Char := 16#1F04D#;
   Domino_Tile_Horizontal_04_01            :
      constant Unicode_Char := 16#1F04E#;
   Domino_Tile_Horizontal_04_02            :
      constant Unicode_Char := 16#1F04F#;
   Domino_Tile_Horizontal_04_03            :
      constant Unicode_Char := 16#1F050#;
   Domino_Tile_Horizontal_04_04            :
      constant Unicode_Char := 16#1F051#;
   Domino_Tile_Horizontal_04_05            :
      constant Unicode_Char := 16#1F052#;
   Domino_Tile_Horizontal_04_06            :
      constant Unicode_Char := 16#1F053#;
   Domino_Tile_Horizontal_05_00            :
      constant Unicode_Char := 16#1F054#;
   Domino_Tile_Horizontal_05_01            :
      constant Unicode_Char := 16#1F055#;
   Domino_Tile_Horizontal_05_02            :
      constant Unicode_Char := 16#1F056#;
   Domino_Tile_Horizontal_05_03            :
      constant Unicode_Char := 16#1F057#;
   Domino_Tile_Horizontal_05_04            :
      constant Unicode_Char := 16#1F058#;
   Domino_Tile_Horizontal_05_05            :
      constant Unicode_Char := 16#1F059#;
   Domino_Tile_Horizontal_05_06            :
      constant Unicode_Char := 16#1F05A#;
   Domino_Tile_Horizontal_06_00            :
      constant Unicode_Char := 16#1F05B#;
   Domino_Tile_Horizontal_06_01            :
      constant Unicode_Char := 16#1F05C#;
   Domino_Tile_Horizontal_06_02            :
      constant Unicode_Char := 16#1F05D#;
   Domino_Tile_Horizontal_06_03            :
      constant Unicode_Char := 16#1F05E#;
   Domino_Tile_Horizontal_06_04            :
      constant Unicode_Char := 16#1F05F#;
   Domino_Tile_Horizontal_06_05            :
      constant Unicode_Char := 16#1F060#;
   Domino_Tile_Horizontal_06_06            :
      constant Unicode_Char := 16#1F061#;
   Domino_Tile_Vertical_Back               :
      constant Unicode_Char := 16#1F062#;
   Domino_Tile_Vertical_00_00              :
      constant Unicode_Char := 16#1F063#;
   Domino_Tile_Vertical_00_01              :
      constant Unicode_Char := 16#1F064#;
   Domino_Tile_Vertical_00_02              :
      constant Unicode_Char := 16#1F065#;
   Domino_Tile_Vertical_00_03              :
      constant Unicode_Char := 16#1F066#;
   Domino_Tile_Vertical_00_04              :
      constant Unicode_Char := 16#1F067#;
   Domino_Tile_Vertical_00_05              :
      constant Unicode_Char := 16#1F068#;
   Domino_Tile_Vertical_00_06              :
      constant Unicode_Char := 16#1F069#;
   Domino_Tile_Vertical_01_00              :
      constant Unicode_Char := 16#1F06A#;
   Domino_Tile_Vertical_01_01              :
      constant Unicode_Char := 16#1F06B#;
   Domino_Tile_Vertical_01_02              :
      constant Unicode_Char := 16#1F06C#;
   Domino_Tile_Vertical_01_03              :
      constant Unicode_Char := 16#1F06D#;
   Domino_Tile_Vertical_01_04              :
      constant Unicode_Char := 16#1F06E#;
   Domino_Tile_Vertical_01_05              :
      constant Unicode_Char := 16#1F06F#;
   Domino_Tile_Vertical_01_06              :
      constant Unicode_Char := 16#1F070#;
   Domino_Tile_Vertical_02_00              :
      constant Unicode_Char := 16#1F071#;
   Domino_Tile_Vertical_02_01              :
      constant Unicode_Char := 16#1F072#;
   Domino_Tile_Vertical_02_02              :
      constant Unicode_Char := 16#1F073#;
   Domino_Tile_Vertical_02_03              :
      constant Unicode_Char := 16#1F074#;
   Domino_Tile_Vertical_02_04              :
      constant Unicode_Char := 16#1F075#;
   Domino_Tile_Vertical_02_05              :
      constant Unicode_Char := 16#1F076#;
   Domino_Tile_Vertical_02_06              :
      constant Unicode_Char := 16#1F077#;
   Domino_Tile_Vertical_03_00              :
      constant Unicode_Char := 16#1F078#;
   Domino_Tile_Vertical_03_01              :
      constant Unicode_Char := 16#1F079#;
   Domino_Tile_Vertical_03_02              :
      constant Unicode_Char := 16#1F07A#;
   Domino_Tile_Vertical_03_03              :
      constant Unicode_Char := 16#1F07B#;
   Domino_Tile_Vertical_03_04              :
      constant Unicode_Char := 16#1F07C#;
   Domino_Tile_Vertical_03_05              :
      constant Unicode_Char := 16#1F07D#;
   Domino_Tile_Vertical_03_06              :
      constant Unicode_Char := 16#1F07E#;
   Domino_Tile_Vertical_04_00              :
      constant Unicode_Char := 16#1F07F#;
   Domino_Tile_Vertical_04_01              :
      constant Unicode_Char := 16#1F080#;
   Domino_Tile_Vertical_04_02              :
      constant Unicode_Char := 16#1F081#;
   Domino_Tile_Vertical_04_03              :
      constant Unicode_Char := 16#1F082#;
   Domino_Tile_Vertical_04_04              :
      constant Unicode_Char := 16#1F083#;
   Domino_Tile_Vertical_04_05              :
      constant Unicode_Char := 16#1F084#;
   Domino_Tile_Vertical_04_06              :
      constant Unicode_Char := 16#1F085#;
   Domino_Tile_Vertical_05_00              :
      constant Unicode_Char := 16#1F086#;
   Domino_Tile_Vertical_05_01              :
      constant Unicode_Char := 16#1F087#;
   Domino_Tile_Vertical_05_02              :
      constant Unicode_Char := 16#1F088#;
   Domino_Tile_Vertical_05_03              :
      constant Unicode_Char := 16#1F089#;
   Domino_Tile_Vertical_05_04              :
      constant Unicode_Char := 16#1F08A#;
   Domino_Tile_Vertical_05_05              :
      constant Unicode_Char := 16#1F08B#;
   Domino_Tile_Vertical_05_06              :
      constant Unicode_Char := 16#1F08C#;
   Domino_Tile_Vertical_06_00              :
      constant Unicode_Char := 16#1F08D#;
   Domino_Tile_Vertical_06_01              :
      constant Unicode_Char := 16#1F08E#;
   Domino_Tile_Vertical_06_02              :
      constant Unicode_Char := 16#1F08F#;
   Domino_Tile_Vertical_06_03              :
      constant Unicode_Char := 16#1F090#;
   Domino_Tile_Vertical_06_04              :
      constant Unicode_Char := 16#1F091#;
   Domino_Tile_Vertical_06_05              :
      constant Unicode_Char := 16#1F092#;
   Domino_Tile_Vertical_06_06              :
      constant Unicode_Char := 16#1F093#;
end Unicode.Names.Domino_Tiles;
