--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Bopomofo is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Bopomofo_Letter_B                       : constant Unicode_Char := 16#3105#;
   Bopomofo_Letter_P                       : constant Unicode_Char := 16#3106#;
   Bopomofo_Letter_M                       : constant Unicode_Char := 16#3107#;
   Bopomofo_Letter_F                       : constant Unicode_Char := 16#3108#;
   Bopomofo_Letter_D                       : constant Unicode_Char := 16#3109#;
   Bopomofo_Letter_T                       : constant Unicode_Char := 16#310A#;
   Bopomofo_Letter_N                       : constant Unicode_Char := 16#310B#;
   Bopomofo_Letter_L                       : constant Unicode_Char := 16#310C#;
   Bopomofo_Letter_G                       : constant Unicode_Char := 16#310D#;
   Bopomofo_Letter_K                       : constant Unicode_Char := 16#310E#;
   Bopomofo_Letter_H                       : constant Unicode_Char := 16#310F#;
   Bopomofo_Letter_J                       : constant Unicode_Char := 16#3110#;
   Bopomofo_Letter_Q                       : constant Unicode_Char := 16#3111#;
   Bopomofo_Letter_X                       : constant Unicode_Char := 16#3112#;
   Bopomofo_Letter_Zh                      : constant Unicode_Char := 16#3113#;
   Bopomofo_Letter_Ch                      : constant Unicode_Char := 16#3114#;
   Bopomofo_Letter_Sh                      : constant Unicode_Char := 16#3115#;
   Bopomofo_Letter_R                       : constant Unicode_Char := 16#3116#;
   Bopomofo_Letter_Z                       : constant Unicode_Char := 16#3117#;
   Bopomofo_Letter_C                       : constant Unicode_Char := 16#3118#;
   Bopomofo_Letter_S                       : constant Unicode_Char := 16#3119#;
   Bopomofo_Letter_A                       : constant Unicode_Char := 16#311A#;
   Bopomofo_Letter_O                       : constant Unicode_Char := 16#311B#;
   Bopomofo_Letter_E                       : constant Unicode_Char := 16#311C#;
   Bopomofo_Letter_Eh                      : constant Unicode_Char := 16#311D#;
   Bopomofo_Letter_Ai                      : constant Unicode_Char := 16#311E#;
   Bopomofo_Letter_Ei                      : constant Unicode_Char := 16#311F#;
   Bopomofo_Letter_Au                      : constant Unicode_Char := 16#3120#;
   Bopomofo_Letter_Ou                      : constant Unicode_Char := 16#3121#;
   Bopomofo_Letter_An                      : constant Unicode_Char := 16#3122#;
   Bopomofo_Letter_En                      : constant Unicode_Char := 16#3123#;
   Bopomofo_Letter_Ang                     : constant Unicode_Char := 16#3124#;
   Bopomofo_Letter_Eng                     : constant Unicode_Char := 16#3125#;
   Bopomofo_Letter_Er                      : constant Unicode_Char := 16#3126#;
   Bopomofo_Letter_I                       : constant Unicode_Char := 16#3127#;
   Bopomofo_Letter_U                       : constant Unicode_Char := 16#3128#;
   Bopomofo_Letter_Iu                      : constant Unicode_Char := 16#3129#;
   Bopomofo_Letter_V                       : constant Unicode_Char := 16#312A#;
   Bopomofo_Letter_Ng                      : constant Unicode_Char := 16#312B#;
   Bopomofo_Letter_Gn                      : constant Unicode_Char := 16#312C#;
   Bopomofo_Letter_Ih                      : constant Unicode_Char := 16#312D#;
end Unicode.Names.Bopomofo;
