--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Ogham is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Ogham_Space_Mark                        : constant Unicode_Char := 16#1680#;
   Ogham_Letter_Beith                      : constant Unicode_Char := 16#1681#;
   Ogham_Letter_Luis                       : constant Unicode_Char := 16#1682#;
   Ogham_Letter_Fearn                      : constant Unicode_Char := 16#1683#;
   Ogham_Letter_Sail                       : constant Unicode_Char := 16#1684#;
   Ogham_Letter_Nion                       : constant Unicode_Char := 16#1685#;
   Ogham_Letter_Uath                       : constant Unicode_Char := 16#1686#;
   Ogham_Letter_Dair                       : constant Unicode_Char := 16#1687#;
   Ogham_Letter_Tinne                      : constant Unicode_Char := 16#1688#;
   Ogham_Letter_Coll                       : constant Unicode_Char := 16#1689#;
   Ogham_Letter_Ceirt                      : constant Unicode_Char := 16#168A#;
   Ogham_Letter_Muin                       : constant Unicode_Char := 16#168B#;
   Ogham_Letter_Gort                       : constant Unicode_Char := 16#168C#;
   Ogham_Letter_Ngeadal                    : constant Unicode_Char := 16#168D#;
   Ogham_Letter_Straif                     : constant Unicode_Char := 16#168E#;
   Ogham_Letter_Ruis                       : constant Unicode_Char := 16#168F#;
   Ogham_Letter_Ailm                       : constant Unicode_Char := 16#1690#;
   Ogham_Letter_Onn                        : constant Unicode_Char := 16#1691#;
   Ogham_Letter_Ur                         : constant Unicode_Char := 16#1692#;
   Ogham_Letter_Eadhadh                    : constant Unicode_Char := 16#1693#;
   Ogham_Letter_Iodhadh                    : constant Unicode_Char := 16#1694#;
   Ogham_Letter_Eabhadh                    : constant Unicode_Char := 16#1695#;
   Ogham_Letter_Or                         : constant Unicode_Char := 16#1696#;
   Ogham_Letter_Uilleann                   : constant Unicode_Char := 16#1697#;
   Ogham_Letter_Ifin                       : constant Unicode_Char := 16#1698#;
   Ogham_Letter_Eamhancholl                : constant Unicode_Char := 16#1699#;
   Ogham_Letter_Peith                      : constant Unicode_Char := 16#169A#;
   Ogham_Feather_Mark                      : constant Unicode_Char := 16#169B#;
   Ogham_Reversed_Feather_Mark             : constant Unicode_Char := 16#169C#;
end Unicode.Names.Ogham;
