--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Manichaean is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Manichaean_Letter_Aleph                 :
      constant Unicode_Char := 16#10AC0#;
   Manichaean_Letter_Beth                  :
      constant Unicode_Char := 16#10AC1#;
   Manichaean_Letter_Bheth                 :
      constant Unicode_Char := 16#10AC2#;
   Manichaean_Letter_Gimel                 :
      constant Unicode_Char := 16#10AC3#;
   Manichaean_Letter_Ghimel                :
      constant Unicode_Char := 16#10AC4#;
   Manichaean_Letter_Daleth                :
      constant Unicode_Char := 16#10AC5#;
   Manichaean_Letter_He                    :
      constant Unicode_Char := 16#10AC6#;
   Manichaean_Letter_Waw                   :
      constant Unicode_Char := 16#10AC7#;
   Manichaean_Sign_Ud                      :
      constant Unicode_Char := 16#10AC8#;
   Manichaean_Letter_Zayin                 :
      constant Unicode_Char := 16#10AC9#;
   Manichaean_Letter_Zhayin                :
      constant Unicode_Char := 16#10ACA#;
   Manichaean_Letter_Jayin                 :
      constant Unicode_Char := 16#10ACB#;
   Manichaean_Letter_Jhayin                :
      constant Unicode_Char := 16#10ACC#;
   Manichaean_Letter_Heth                  :
      constant Unicode_Char := 16#10ACD#;
   Manichaean_Letter_Teth                  :
      constant Unicode_Char := 16#10ACE#;
   Manichaean_Letter_Yodh                  :
      constant Unicode_Char := 16#10ACF#;
   Manichaean_Letter_Kaph                  :
      constant Unicode_Char := 16#10AD0#;
   Manichaean_Letter_Xaph                  :
      constant Unicode_Char := 16#10AD1#;
   Manichaean_Letter_Khaph                 :
      constant Unicode_Char := 16#10AD2#;
   Manichaean_Letter_Lamedh                :
      constant Unicode_Char := 16#10AD3#;
   Manichaean_Letter_Dhamedh               :
      constant Unicode_Char := 16#10AD4#;
   Manichaean_Letter_Thamedh               :
      constant Unicode_Char := 16#10AD5#;
   Manichaean_Letter_Mem                   :
      constant Unicode_Char := 16#10AD6#;
   Manichaean_Letter_Nun                   :
      constant Unicode_Char := 16#10AD7#;
   Manichaean_Letter_Samekh                :
      constant Unicode_Char := 16#10AD8#;
   Manichaean_Letter_Ayin                  :
      constant Unicode_Char := 16#10AD9#;
   Manichaean_Letter_Aayin                 :
      constant Unicode_Char := 16#10ADA#;
   Manichaean_Letter_Pe                    :
      constant Unicode_Char := 16#10ADB#;
   Manichaean_Letter_Fe                    :
      constant Unicode_Char := 16#10ADC#;
   Manichaean_Letter_Sadhe                 :
      constant Unicode_Char := 16#10ADD#;
   Manichaean_Letter_Qoph                  :
      constant Unicode_Char := 16#10ADE#;
   Manichaean_Letter_Xoph                  :
      constant Unicode_Char := 16#10ADF#;
   Manichaean_Letter_Qhoph                 :
      constant Unicode_Char := 16#10AE0#;
   Manichaean_Letter_Resh                  :
      constant Unicode_Char := 16#10AE1#;
   Manichaean_Letter_Shin                  :
      constant Unicode_Char := 16#10AE2#;
   Manichaean_Letter_Sshin                 :
      constant Unicode_Char := 16#10AE3#;
   Manichaean_Letter_Taw                   :
      constant Unicode_Char := 16#10AE4#;
   Manichaean_Abbreviation_Mark_Above      :
      constant Unicode_Char := 16#10AE5#;
   Manichaean_Abbreviation_Mark_Below      :
      constant Unicode_Char := 16#10AE6#;
   Manichaean_Number_One                   :
      constant Unicode_Char := 16#10AEB#;
   Manichaean_Number_Five                  :
      constant Unicode_Char := 16#10AEC#;
   Manichaean_Number_Ten                   :
      constant Unicode_Char := 16#10AED#;
   Manichaean_Number_Twenty                :
      constant Unicode_Char := 16#10AEE#;
   Manichaean_Number_One_Hundred           :
      constant Unicode_Char := 16#10AEF#;
   Manichaean_Punctuation_Star             :
      constant Unicode_Char := 16#10AF0#;
   Manichaean_Punctuation_Fleuron          :
      constant Unicode_Char := 16#10AF1#;
   Manichaean_Punctuation_Double_Dot_Within_Dot :
      constant Unicode_Char := 16#10AF2#;
   Manichaean_Punctuation_Dot_Within_Dot   :
      constant Unicode_Char := 16#10AF3#;
   Manichaean_Punctuation_Dot              :
      constant Unicode_Char := 16#10AF4#;
   Manichaean_Punctuation_Two_Dots         :
      constant Unicode_Char := 16#10AF5#;
   Manichaean_Punctuation_Line_Filler      :
      constant Unicode_Char := 16#10AF6#;
end Unicode.Names.Manichaean;
