--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Khmer is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Khmer_Letter_Ka                         : constant Unicode_Char := 16#1780#;
   Khmer_Letter_Kha                        : constant Unicode_Char := 16#1781#;
   Khmer_Letter_Ko                         : constant Unicode_Char := 16#1782#;
   Khmer_Letter_Kho                        : constant Unicode_Char := 16#1783#;
   Khmer_Letter_Ngo                        : constant Unicode_Char := 16#1784#;
   Khmer_Letter_Ca                         : constant Unicode_Char := 16#1785#;
   Khmer_Letter_Cha                        : constant Unicode_Char := 16#1786#;
   Khmer_Letter_Co                         : constant Unicode_Char := 16#1787#;
   Khmer_Letter_Cho                        : constant Unicode_Char := 16#1788#;
   Khmer_Letter_Nyo                        : constant Unicode_Char := 16#1789#;
   Khmer_Letter_Da                         : constant Unicode_Char := 16#178A#;
   Khmer_Letter_Ttha                       : constant Unicode_Char := 16#178B#;
   Khmer_Letter_Do                         : constant Unicode_Char := 16#178C#;
   Khmer_Letter_Ttho                       : constant Unicode_Char := 16#178D#;
   Khmer_Letter_Nno                        : constant Unicode_Char := 16#178E#;
   Khmer_Letter_Ta                         : constant Unicode_Char := 16#178F#;
   Khmer_Letter_Tha                        : constant Unicode_Char := 16#1790#;
   Khmer_Letter_To                         : constant Unicode_Char := 16#1791#;
   Khmer_Letter_Tho                        : constant Unicode_Char := 16#1792#;
   Khmer_Letter_No                         : constant Unicode_Char := 16#1793#;
   Khmer_Letter_Ba                         : constant Unicode_Char := 16#1794#;
   Khmer_Letter_Pha                        : constant Unicode_Char := 16#1795#;
   Khmer_Letter_Po                         : constant Unicode_Char := 16#1796#;
   Khmer_Letter_Pho                        : constant Unicode_Char := 16#1797#;
   Khmer_Letter_Mo                         : constant Unicode_Char := 16#1798#;
   Khmer_Letter_Yo                         : constant Unicode_Char := 16#1799#;
   Khmer_Letter_Ro                         : constant Unicode_Char := 16#179A#;
   Khmer_Letter_Lo                         : constant Unicode_Char := 16#179B#;
   Khmer_Letter_Vo                         : constant Unicode_Char := 16#179C#;
   Khmer_Letter_Sha                        : constant Unicode_Char := 16#179D#;
   Khmer_Letter_Sso                        : constant Unicode_Char := 16#179E#;
   Khmer_Letter_Sa                         : constant Unicode_Char := 16#179F#;
   Khmer_Letter_Ha                         : constant Unicode_Char := 16#17A0#;
   Khmer_Letter_La                         : constant Unicode_Char := 16#17A1#;
   Khmer_Letter_Qa                         : constant Unicode_Char := 16#17A2#;
   Khmer_Independent_Vowel_Qaq             : constant Unicode_Char := 16#17A3#;
   Khmer_Independent_Vowel_Qaa             : constant Unicode_Char := 16#17A4#;
   Khmer_Independent_Vowel_Qi              : constant Unicode_Char := 16#17A5#;
   Khmer_Independent_Vowel_Qii             : constant Unicode_Char := 16#17A6#;
   Khmer_Independent_Vowel_Qu              : constant Unicode_Char := 16#17A7#;
   Khmer_Independent_Vowel_Quk             : constant Unicode_Char := 16#17A8#;
   Khmer_Independent_Vowel_Quu             : constant Unicode_Char := 16#17A9#;
   Khmer_Independent_Vowel_Quuv            : constant Unicode_Char := 16#17AA#;
   Khmer_Independent_Vowel_Ry              : constant Unicode_Char := 16#17AB#;
   Khmer_Independent_Vowel_Ryy             : constant Unicode_Char := 16#17AC#;
   Khmer_Independent_Vowel_Ly              : constant Unicode_Char := 16#17AD#;
   Khmer_Independent_Vowel_Lyy             : constant Unicode_Char := 16#17AE#;
   Khmer_Independent_Vowel_Qe              : constant Unicode_Char := 16#17AF#;
   Khmer_Independent_Vowel_Qai             : constant Unicode_Char := 16#17B0#;
   Khmer_Independent_Vowel_Qoo_Type_One    : constant Unicode_Char := 16#17B1#;
   Khmer_Independent_Vowel_Qoo_Type_Two    : constant Unicode_Char := 16#17B2#;
   Khmer_Independent_Vowel_Qau             : constant Unicode_Char := 16#17B3#;
   Khmer_Vowel_Inherent_Aq                 : constant Unicode_Char := 16#17B4#;
   Khmer_Vowel_Inherent_Aa                 : constant Unicode_Char := 16#17B5#;
   Khmer_Vowel_Sign_Aa                     : constant Unicode_Char := 16#17B6#;
   Khmer_Vowel_Sign_I                      : constant Unicode_Char := 16#17B7#;
   Khmer_Vowel_Sign_Ii                     : constant Unicode_Char := 16#17B8#;
   Khmer_Vowel_Sign_Y                      : constant Unicode_Char := 16#17B9#;
   Khmer_Vowel_Sign_Yy                     : constant Unicode_Char := 16#17BA#;
   Khmer_Vowel_Sign_U                      : constant Unicode_Char := 16#17BB#;
   Khmer_Vowel_Sign_Uu                     : constant Unicode_Char := 16#17BC#;
   Khmer_Vowel_Sign_Ua                     : constant Unicode_Char := 16#17BD#;
   Khmer_Vowel_Sign_Oe                     : constant Unicode_Char := 16#17BE#;
   Khmer_Vowel_Sign_Ya                     : constant Unicode_Char := 16#17BF#;
   Khmer_Vowel_Sign_Ie                     : constant Unicode_Char := 16#17C0#;
   Khmer_Vowel_Sign_E                      : constant Unicode_Char := 16#17C1#;
   Khmer_Vowel_Sign_Ae                     : constant Unicode_Char := 16#17C2#;
   Khmer_Vowel_Sign_Ai                     : constant Unicode_Char := 16#17C3#;
   Khmer_Vowel_Sign_Oo                     : constant Unicode_Char := 16#17C4#;
   Khmer_Vowel_Sign_Au                     : constant Unicode_Char := 16#17C5#;
   Khmer_Sign_Nikahit                      : constant Unicode_Char := 16#17C6#;
   Khmer_Sign_Reahmuk                      : constant Unicode_Char := 16#17C7#;
   Khmer_Sign_Yuukaleapintu                : constant Unicode_Char := 16#17C8#;
   Khmer_Sign_Muusikatoan                  : constant Unicode_Char := 16#17C9#;
   Khmer_Sign_Triisap                      : constant Unicode_Char := 16#17CA#;
   Khmer_Sign_Bantoc                       : constant Unicode_Char := 16#17CB#;
   Khmer_Sign_Robat                        : constant Unicode_Char := 16#17CC#;
   Khmer_Sign_Toandakhiat                  : constant Unicode_Char := 16#17CD#;
   Khmer_Sign_Kakabat                      : constant Unicode_Char := 16#17CE#;
   Khmer_Sign_Ahsda                        : constant Unicode_Char := 16#17CF#;
   Khmer_Sign_Samyok_Sannya                : constant Unicode_Char := 16#17D0#;
   Khmer_Sign_Viriam                       : constant Unicode_Char := 16#17D1#;
   Khmer_Sign_Coeng                        : constant Unicode_Char := 16#17D2#;
   Khmer_Sign_Bathamasat                   : constant Unicode_Char := 16#17D3#;
   Khmer_Sign_Khan                         : constant Unicode_Char := 16#17D4#;
   Khmer_Sign_Bariyoosan                   : constant Unicode_Char := 16#17D5#;
   Khmer_Sign_Camnuc_Pii_Kuuh              : constant Unicode_Char := 16#17D6#;
   Khmer_Sign_Lek_Too                      : constant Unicode_Char := 16#17D7#;
   Khmer_Sign_Beyyal                       : constant Unicode_Char := 16#17D8#;
   Khmer_Sign_Phnaek_Muan                  : constant Unicode_Char := 16#17D9#;
   Khmer_Sign_Koomuut                      : constant Unicode_Char := 16#17DA#;
   Khmer_Currency_Symbol_Riel              : constant Unicode_Char := 16#17DB#;
   Khmer_Sign_Avakrahasanya                : constant Unicode_Char := 16#17DC#;
   Khmer_Sign_Atthacan                     : constant Unicode_Char := 16#17DD#;
   Khmer_Digit_Zero                        : constant Unicode_Char := 16#17E0#;
   Khmer_Digit_One                         : constant Unicode_Char := 16#17E1#;
   Khmer_Digit_Two                         : constant Unicode_Char := 16#17E2#;
   Khmer_Digit_Three                       : constant Unicode_Char := 16#17E3#;
   Khmer_Digit_Four                        : constant Unicode_Char := 16#17E4#;
   Khmer_Digit_Five                        : constant Unicode_Char := 16#17E5#;
   Khmer_Digit_Six                         : constant Unicode_Char := 16#17E6#;
   Khmer_Digit_Seven                       : constant Unicode_Char := 16#17E7#;
   Khmer_Digit_Eight                       : constant Unicode_Char := 16#17E8#;
   Khmer_Digit_Nine                        : constant Unicode_Char := 16#17E9#;
   Khmer_Symbol_Lek_Attak_Son              : constant Unicode_Char := 16#17F0#;
   Khmer_Symbol_Lek_Attak_Muoy             : constant Unicode_Char := 16#17F1#;
   Khmer_Symbol_Lek_Attak_Pii              : constant Unicode_Char := 16#17F2#;
   Khmer_Symbol_Lek_Attak_Bei              : constant Unicode_Char := 16#17F3#;
   Khmer_Symbol_Lek_Attak_Buon             : constant Unicode_Char := 16#17F4#;
   Khmer_Symbol_Lek_Attak_Pram             : constant Unicode_Char := 16#17F5#;
   Khmer_Symbol_Lek_Attak_Pram_Muoy        : constant Unicode_Char := 16#17F6#;
   Khmer_Symbol_Lek_Attak_Pram_Pii         : constant Unicode_Char := 16#17F7#;
   Khmer_Symbol_Lek_Attak_Pram_Bei         : constant Unicode_Char := 16#17F8#;
   Khmer_Symbol_Lek_Attak_Pram_Buon        : constant Unicode_Char := 16#17F9#;
end Unicode.Names.Khmer;
