--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Egyptian_Hieroglyphs is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Egyptian_Hieroglyph_A001                :
      constant Unicode_Char := 16#13000#;
   Egyptian_Hieroglyph_A002                :
      constant Unicode_Char := 16#13001#;
   Egyptian_Hieroglyph_A003                :
      constant Unicode_Char := 16#13002#;
   Egyptian_Hieroglyph_A004                :
      constant Unicode_Char := 16#13003#;
   Egyptian_Hieroglyph_A005                :
      constant Unicode_Char := 16#13004#;
   Egyptian_Hieroglyph_A005a               :
      constant Unicode_Char := 16#13005#;
   Egyptian_Hieroglyph_A006                :
      constant Unicode_Char := 16#13006#;
   Egyptian_Hieroglyph_A006a               :
      constant Unicode_Char := 16#13007#;
   Egyptian_Hieroglyph_A006b               :
      constant Unicode_Char := 16#13008#;
   Egyptian_Hieroglyph_A007                :
      constant Unicode_Char := 16#13009#;
   Egyptian_Hieroglyph_A008                :
      constant Unicode_Char := 16#1300A#;
   Egyptian_Hieroglyph_A009                :
      constant Unicode_Char := 16#1300B#;
   Egyptian_Hieroglyph_A010                :
      constant Unicode_Char := 16#1300C#;
   Egyptian_Hieroglyph_A011                :
      constant Unicode_Char := 16#1300D#;
   Egyptian_Hieroglyph_A012                :
      constant Unicode_Char := 16#1300E#;
   Egyptian_Hieroglyph_A013                :
      constant Unicode_Char := 16#1300F#;
   Egyptian_Hieroglyph_A014                :
      constant Unicode_Char := 16#13010#;
   Egyptian_Hieroglyph_A014a               :
      constant Unicode_Char := 16#13011#;
   Egyptian_Hieroglyph_A015                :
      constant Unicode_Char := 16#13012#;
   Egyptian_Hieroglyph_A016                :
      constant Unicode_Char := 16#13013#;
   Egyptian_Hieroglyph_A017                :
      constant Unicode_Char := 16#13014#;
   Egyptian_Hieroglyph_A017a               :
      constant Unicode_Char := 16#13015#;
   Egyptian_Hieroglyph_A018                :
      constant Unicode_Char := 16#13016#;
   Egyptian_Hieroglyph_A019                :
      constant Unicode_Char := 16#13017#;
   Egyptian_Hieroglyph_A020                :
      constant Unicode_Char := 16#13018#;
   Egyptian_Hieroglyph_A021                :
      constant Unicode_Char := 16#13019#;
   Egyptian_Hieroglyph_A022                :
      constant Unicode_Char := 16#1301A#;
   Egyptian_Hieroglyph_A023                :
      constant Unicode_Char := 16#1301B#;
   Egyptian_Hieroglyph_A024                :
      constant Unicode_Char := 16#1301C#;
   Egyptian_Hieroglyph_A025                :
      constant Unicode_Char := 16#1301D#;
   Egyptian_Hieroglyph_A026                :
      constant Unicode_Char := 16#1301E#;
   Egyptian_Hieroglyph_A027                :
      constant Unicode_Char := 16#1301F#;
   Egyptian_Hieroglyph_A028                :
      constant Unicode_Char := 16#13020#;
   Egyptian_Hieroglyph_A029                :
      constant Unicode_Char := 16#13021#;
   Egyptian_Hieroglyph_A030                :
      constant Unicode_Char := 16#13022#;
   Egyptian_Hieroglyph_A031                :
      constant Unicode_Char := 16#13023#;
   Egyptian_Hieroglyph_A032                :
      constant Unicode_Char := 16#13024#;
   Egyptian_Hieroglyph_A032a               :
      constant Unicode_Char := 16#13025#;
   Egyptian_Hieroglyph_A033                :
      constant Unicode_Char := 16#13026#;
   Egyptian_Hieroglyph_A034                :
      constant Unicode_Char := 16#13027#;
   Egyptian_Hieroglyph_A035                :
      constant Unicode_Char := 16#13028#;
   Egyptian_Hieroglyph_A036                :
      constant Unicode_Char := 16#13029#;
   Egyptian_Hieroglyph_A037                :
      constant Unicode_Char := 16#1302A#;
   Egyptian_Hieroglyph_A038                :
      constant Unicode_Char := 16#1302B#;
   Egyptian_Hieroglyph_A039                :
      constant Unicode_Char := 16#1302C#;
   Egyptian_Hieroglyph_A040                :
      constant Unicode_Char := 16#1302D#;
   Egyptian_Hieroglyph_A040a               :
      constant Unicode_Char := 16#1302E#;
   Egyptian_Hieroglyph_A041                :
      constant Unicode_Char := 16#1302F#;
   Egyptian_Hieroglyph_A042                :
      constant Unicode_Char := 16#13030#;
   Egyptian_Hieroglyph_A042a               :
      constant Unicode_Char := 16#13031#;
   Egyptian_Hieroglyph_A043                :
      constant Unicode_Char := 16#13032#;
   Egyptian_Hieroglyph_A043a               :
      constant Unicode_Char := 16#13033#;
   Egyptian_Hieroglyph_A044                :
      constant Unicode_Char := 16#13034#;
   Egyptian_Hieroglyph_A045                :
      constant Unicode_Char := 16#13035#;
   Egyptian_Hieroglyph_A045a               :
      constant Unicode_Char := 16#13036#;
   Egyptian_Hieroglyph_A046                :
      constant Unicode_Char := 16#13037#;
   Egyptian_Hieroglyph_A047                :
      constant Unicode_Char := 16#13038#;
   Egyptian_Hieroglyph_A048                :
      constant Unicode_Char := 16#13039#;
   Egyptian_Hieroglyph_A049                :
      constant Unicode_Char := 16#1303A#;
   Egyptian_Hieroglyph_A050                :
      constant Unicode_Char := 16#1303B#;
   Egyptian_Hieroglyph_A051                :
      constant Unicode_Char := 16#1303C#;
   Egyptian_Hieroglyph_A052                :
      constant Unicode_Char := 16#1303D#;
   Egyptian_Hieroglyph_A053                :
      constant Unicode_Char := 16#1303E#;
   Egyptian_Hieroglyph_A054                :
      constant Unicode_Char := 16#1303F#;
   Egyptian_Hieroglyph_A055                :
      constant Unicode_Char := 16#13040#;
   Egyptian_Hieroglyph_A056                :
      constant Unicode_Char := 16#13041#;
   Egyptian_Hieroglyph_A057                :
      constant Unicode_Char := 16#13042#;
   Egyptian_Hieroglyph_A058                :
      constant Unicode_Char := 16#13043#;
   Egyptian_Hieroglyph_A059                :
      constant Unicode_Char := 16#13044#;
   Egyptian_Hieroglyph_A060                :
      constant Unicode_Char := 16#13045#;
   Egyptian_Hieroglyph_A061                :
      constant Unicode_Char := 16#13046#;
   Egyptian_Hieroglyph_A062                :
      constant Unicode_Char := 16#13047#;
   Egyptian_Hieroglyph_A063                :
      constant Unicode_Char := 16#13048#;
   Egyptian_Hieroglyph_A064                :
      constant Unicode_Char := 16#13049#;
   Egyptian_Hieroglyph_A065                :
      constant Unicode_Char := 16#1304A#;
   Egyptian_Hieroglyph_A066                :
      constant Unicode_Char := 16#1304B#;
   Egyptian_Hieroglyph_A067                :
      constant Unicode_Char := 16#1304C#;
   Egyptian_Hieroglyph_A068                :
      constant Unicode_Char := 16#1304D#;
   Egyptian_Hieroglyph_A069                :
      constant Unicode_Char := 16#1304E#;
   Egyptian_Hieroglyph_A070                :
      constant Unicode_Char := 16#1304F#;
   Egyptian_Hieroglyph_B001                :
      constant Unicode_Char := 16#13050#;
   Egyptian_Hieroglyph_B002                :
      constant Unicode_Char := 16#13051#;
   Egyptian_Hieroglyph_B003                :
      constant Unicode_Char := 16#13052#;
   Egyptian_Hieroglyph_B004                :
      constant Unicode_Char := 16#13053#;
   Egyptian_Hieroglyph_B005                :
      constant Unicode_Char := 16#13054#;
   Egyptian_Hieroglyph_B005a               :
      constant Unicode_Char := 16#13055#;
   Egyptian_Hieroglyph_B006                :
      constant Unicode_Char := 16#13056#;
   Egyptian_Hieroglyph_B007                :
      constant Unicode_Char := 16#13057#;
   Egyptian_Hieroglyph_B008                :
      constant Unicode_Char := 16#13058#;
   Egyptian_Hieroglyph_B009                :
      constant Unicode_Char := 16#13059#;
   Egyptian_Hieroglyph_C001                :
      constant Unicode_Char := 16#1305A#;
   Egyptian_Hieroglyph_C002                :
      constant Unicode_Char := 16#1305B#;
   Egyptian_Hieroglyph_C002a               :
      constant Unicode_Char := 16#1305C#;
   Egyptian_Hieroglyph_C002b               :
      constant Unicode_Char := 16#1305D#;
   Egyptian_Hieroglyph_C002c               :
      constant Unicode_Char := 16#1305E#;
   Egyptian_Hieroglyph_C003                :
      constant Unicode_Char := 16#1305F#;
   Egyptian_Hieroglyph_C004                :
      constant Unicode_Char := 16#13060#;
   Egyptian_Hieroglyph_C005                :
      constant Unicode_Char := 16#13061#;
   Egyptian_Hieroglyph_C006                :
      constant Unicode_Char := 16#13062#;
   Egyptian_Hieroglyph_C007                :
      constant Unicode_Char := 16#13063#;
   Egyptian_Hieroglyph_C008                :
      constant Unicode_Char := 16#13064#;
   Egyptian_Hieroglyph_C009                :
      constant Unicode_Char := 16#13065#;
   Egyptian_Hieroglyph_C010                :
      constant Unicode_Char := 16#13066#;
   Egyptian_Hieroglyph_C010a               :
      constant Unicode_Char := 16#13067#;
   Egyptian_Hieroglyph_C011                :
      constant Unicode_Char := 16#13068#;
   Egyptian_Hieroglyph_C012                :
      constant Unicode_Char := 16#13069#;
   Egyptian_Hieroglyph_C013                :
      constant Unicode_Char := 16#1306A#;
   Egyptian_Hieroglyph_C014                :
      constant Unicode_Char := 16#1306B#;
   Egyptian_Hieroglyph_C015                :
      constant Unicode_Char := 16#1306C#;
   Egyptian_Hieroglyph_C016                :
      constant Unicode_Char := 16#1306D#;
   Egyptian_Hieroglyph_C017                :
      constant Unicode_Char := 16#1306E#;
   Egyptian_Hieroglyph_C018                :
      constant Unicode_Char := 16#1306F#;
   Egyptian_Hieroglyph_C019                :
      constant Unicode_Char := 16#13070#;
   Egyptian_Hieroglyph_C020                :
      constant Unicode_Char := 16#13071#;
   Egyptian_Hieroglyph_C021                :
      constant Unicode_Char := 16#13072#;
   Egyptian_Hieroglyph_C022                :
      constant Unicode_Char := 16#13073#;
   Egyptian_Hieroglyph_C023                :
      constant Unicode_Char := 16#13074#;
   Egyptian_Hieroglyph_C024                :
      constant Unicode_Char := 16#13075#;
   Egyptian_Hieroglyph_D001                :
      constant Unicode_Char := 16#13076#;
   Egyptian_Hieroglyph_D002                :
      constant Unicode_Char := 16#13077#;
   Egyptian_Hieroglyph_D003                :
      constant Unicode_Char := 16#13078#;
   Egyptian_Hieroglyph_D004                :
      constant Unicode_Char := 16#13079#;
   Egyptian_Hieroglyph_D005                :
      constant Unicode_Char := 16#1307A#;
   Egyptian_Hieroglyph_D006                :
      constant Unicode_Char := 16#1307B#;
   Egyptian_Hieroglyph_D007                :
      constant Unicode_Char := 16#1307C#;
   Egyptian_Hieroglyph_D008                :
      constant Unicode_Char := 16#1307D#;
   Egyptian_Hieroglyph_D008a               :
      constant Unicode_Char := 16#1307E#;
   Egyptian_Hieroglyph_D009                :
      constant Unicode_Char := 16#1307F#;
   Egyptian_Hieroglyph_D010                :
      constant Unicode_Char := 16#13080#;
   Egyptian_Hieroglyph_D011                :
      constant Unicode_Char := 16#13081#;
   Egyptian_Hieroglyph_D012                :
      constant Unicode_Char := 16#13082#;
   Egyptian_Hieroglyph_D013                :
      constant Unicode_Char := 16#13083#;
   Egyptian_Hieroglyph_D014                :
      constant Unicode_Char := 16#13084#;
   Egyptian_Hieroglyph_D015                :
      constant Unicode_Char := 16#13085#;
   Egyptian_Hieroglyph_D016                :
      constant Unicode_Char := 16#13086#;
   Egyptian_Hieroglyph_D017                :
      constant Unicode_Char := 16#13087#;
   Egyptian_Hieroglyph_D018                :
      constant Unicode_Char := 16#13088#;
   Egyptian_Hieroglyph_D019                :
      constant Unicode_Char := 16#13089#;
   Egyptian_Hieroglyph_D020                :
      constant Unicode_Char := 16#1308A#;
   Egyptian_Hieroglyph_D021                :
      constant Unicode_Char := 16#1308B#;
   Egyptian_Hieroglyph_D022                :
      constant Unicode_Char := 16#1308C#;
   Egyptian_Hieroglyph_D023                :
      constant Unicode_Char := 16#1308D#;
   Egyptian_Hieroglyph_D024                :
      constant Unicode_Char := 16#1308E#;
   Egyptian_Hieroglyph_D025                :
      constant Unicode_Char := 16#1308F#;
   Egyptian_Hieroglyph_D026                :
      constant Unicode_Char := 16#13090#;
   Egyptian_Hieroglyph_D027                :
      constant Unicode_Char := 16#13091#;
   Egyptian_Hieroglyph_D027a               :
      constant Unicode_Char := 16#13092#;
   Egyptian_Hieroglyph_D028                :
      constant Unicode_Char := 16#13093#;
   Egyptian_Hieroglyph_D029                :
      constant Unicode_Char := 16#13094#;
   Egyptian_Hieroglyph_D030                :
      constant Unicode_Char := 16#13095#;
   Egyptian_Hieroglyph_D031                :
      constant Unicode_Char := 16#13096#;
   Egyptian_Hieroglyph_D031a               :
      constant Unicode_Char := 16#13097#;
   Egyptian_Hieroglyph_D032                :
      constant Unicode_Char := 16#13098#;
   Egyptian_Hieroglyph_D033                :
      constant Unicode_Char := 16#13099#;
   Egyptian_Hieroglyph_D034                :
      constant Unicode_Char := 16#1309A#;
   Egyptian_Hieroglyph_D034a               :
      constant Unicode_Char := 16#1309B#;
   Egyptian_Hieroglyph_D035                :
      constant Unicode_Char := 16#1309C#;
   Egyptian_Hieroglyph_D036                :
      constant Unicode_Char := 16#1309D#;
   Egyptian_Hieroglyph_D037                :
      constant Unicode_Char := 16#1309E#;
   Egyptian_Hieroglyph_D038                :
      constant Unicode_Char := 16#1309F#;
   Egyptian_Hieroglyph_D039                :
      constant Unicode_Char := 16#130A0#;
   Egyptian_Hieroglyph_D040                :
      constant Unicode_Char := 16#130A1#;
   Egyptian_Hieroglyph_D041                :
      constant Unicode_Char := 16#130A2#;
   Egyptian_Hieroglyph_D042                :
      constant Unicode_Char := 16#130A3#;
   Egyptian_Hieroglyph_D043                :
      constant Unicode_Char := 16#130A4#;
   Egyptian_Hieroglyph_D044                :
      constant Unicode_Char := 16#130A5#;
   Egyptian_Hieroglyph_D045                :
      constant Unicode_Char := 16#130A6#;
   Egyptian_Hieroglyph_D046                :
      constant Unicode_Char := 16#130A7#;
   Egyptian_Hieroglyph_D046a               :
      constant Unicode_Char := 16#130A8#;
   Egyptian_Hieroglyph_D047                :
      constant Unicode_Char := 16#130A9#;
   Egyptian_Hieroglyph_D048                :
      constant Unicode_Char := 16#130AA#;
   Egyptian_Hieroglyph_D048a               :
      constant Unicode_Char := 16#130AB#;
   Egyptian_Hieroglyph_D049                :
      constant Unicode_Char := 16#130AC#;
   Egyptian_Hieroglyph_D050                :
      constant Unicode_Char := 16#130AD#;
   Egyptian_Hieroglyph_D050a               :
      constant Unicode_Char := 16#130AE#;
   Egyptian_Hieroglyph_D050b               :
      constant Unicode_Char := 16#130AF#;
   Egyptian_Hieroglyph_D050c               :
      constant Unicode_Char := 16#130B0#;
   Egyptian_Hieroglyph_D050d               :
      constant Unicode_Char := 16#130B1#;
   Egyptian_Hieroglyph_D050e               :
      constant Unicode_Char := 16#130B2#;
   Egyptian_Hieroglyph_D050f               :
      constant Unicode_Char := 16#130B3#;
   Egyptian_Hieroglyph_D050g               :
      constant Unicode_Char := 16#130B4#;
   Egyptian_Hieroglyph_D050h               :
      constant Unicode_Char := 16#130B5#;
   Egyptian_Hieroglyph_D050i               :
      constant Unicode_Char := 16#130B6#;
   Egyptian_Hieroglyph_D051                :
      constant Unicode_Char := 16#130B7#;
   Egyptian_Hieroglyph_D052                :
      constant Unicode_Char := 16#130B8#;
   Egyptian_Hieroglyph_D052a               :
      constant Unicode_Char := 16#130B9#;
   Egyptian_Hieroglyph_D053                :
      constant Unicode_Char := 16#130BA#;
   Egyptian_Hieroglyph_D054                :
      constant Unicode_Char := 16#130BB#;
   Egyptian_Hieroglyph_D054a               :
      constant Unicode_Char := 16#130BC#;
   Egyptian_Hieroglyph_D055                :
      constant Unicode_Char := 16#130BD#;
   Egyptian_Hieroglyph_D056                :
      constant Unicode_Char := 16#130BE#;
   Egyptian_Hieroglyph_D057                :
      constant Unicode_Char := 16#130BF#;
   Egyptian_Hieroglyph_D058                :
      constant Unicode_Char := 16#130C0#;
   Egyptian_Hieroglyph_D059                :
      constant Unicode_Char := 16#130C1#;
   Egyptian_Hieroglyph_D060                :
      constant Unicode_Char := 16#130C2#;
   Egyptian_Hieroglyph_D061                :
      constant Unicode_Char := 16#130C3#;
   Egyptian_Hieroglyph_D062                :
      constant Unicode_Char := 16#130C4#;
   Egyptian_Hieroglyph_D063                :
      constant Unicode_Char := 16#130C5#;
   Egyptian_Hieroglyph_D064                :
      constant Unicode_Char := 16#130C6#;
   Egyptian_Hieroglyph_D065                :
      constant Unicode_Char := 16#130C7#;
   Egyptian_Hieroglyph_D066                :
      constant Unicode_Char := 16#130C8#;
   Egyptian_Hieroglyph_D067                :
      constant Unicode_Char := 16#130C9#;
   Egyptian_Hieroglyph_D067a               :
      constant Unicode_Char := 16#130CA#;
   Egyptian_Hieroglyph_D067b               :
      constant Unicode_Char := 16#130CB#;
   Egyptian_Hieroglyph_D067c               :
      constant Unicode_Char := 16#130CC#;
   Egyptian_Hieroglyph_D067d               :
      constant Unicode_Char := 16#130CD#;
   Egyptian_Hieroglyph_D067e               :
      constant Unicode_Char := 16#130CE#;
   Egyptian_Hieroglyph_D067f               :
      constant Unicode_Char := 16#130CF#;
   Egyptian_Hieroglyph_D067g               :
      constant Unicode_Char := 16#130D0#;
   Egyptian_Hieroglyph_D067h               :
      constant Unicode_Char := 16#130D1#;
   Egyptian_Hieroglyph_E001                :
      constant Unicode_Char := 16#130D2#;
   Egyptian_Hieroglyph_E002                :
      constant Unicode_Char := 16#130D3#;
   Egyptian_Hieroglyph_E003                :
      constant Unicode_Char := 16#130D4#;
   Egyptian_Hieroglyph_E004                :
      constant Unicode_Char := 16#130D5#;
   Egyptian_Hieroglyph_E005                :
      constant Unicode_Char := 16#130D6#;
   Egyptian_Hieroglyph_E006                :
      constant Unicode_Char := 16#130D7#;
   Egyptian_Hieroglyph_E007                :
      constant Unicode_Char := 16#130D8#;
   Egyptian_Hieroglyph_E008                :
      constant Unicode_Char := 16#130D9#;
   Egyptian_Hieroglyph_E008a               :
      constant Unicode_Char := 16#130DA#;
   Egyptian_Hieroglyph_E009                :
      constant Unicode_Char := 16#130DB#;
   Egyptian_Hieroglyph_E009a               :
      constant Unicode_Char := 16#130DC#;
   Egyptian_Hieroglyph_E010                :
      constant Unicode_Char := 16#130DD#;
   Egyptian_Hieroglyph_E011                :
      constant Unicode_Char := 16#130DE#;
   Egyptian_Hieroglyph_E012                :
      constant Unicode_Char := 16#130DF#;
   Egyptian_Hieroglyph_E013                :
      constant Unicode_Char := 16#130E0#;
   Egyptian_Hieroglyph_E014                :
      constant Unicode_Char := 16#130E1#;
   Egyptian_Hieroglyph_E015                :
      constant Unicode_Char := 16#130E2#;
   Egyptian_Hieroglyph_E016                :
      constant Unicode_Char := 16#130E3#;
   Egyptian_Hieroglyph_E016a               :
      constant Unicode_Char := 16#130E4#;
   Egyptian_Hieroglyph_E017                :
      constant Unicode_Char := 16#130E5#;
   Egyptian_Hieroglyph_E017a               :
      constant Unicode_Char := 16#130E6#;
   Egyptian_Hieroglyph_E018                :
      constant Unicode_Char := 16#130E7#;
   Egyptian_Hieroglyph_E019                :
      constant Unicode_Char := 16#130E8#;
   Egyptian_Hieroglyph_E020                :
      constant Unicode_Char := 16#130E9#;
   Egyptian_Hieroglyph_E020a               :
      constant Unicode_Char := 16#130EA#;
   Egyptian_Hieroglyph_E021                :
      constant Unicode_Char := 16#130EB#;
   Egyptian_Hieroglyph_E022                :
      constant Unicode_Char := 16#130EC#;
   Egyptian_Hieroglyph_E023                :
      constant Unicode_Char := 16#130ED#;
   Egyptian_Hieroglyph_E024                :
      constant Unicode_Char := 16#130EE#;
   Egyptian_Hieroglyph_E025                :
      constant Unicode_Char := 16#130EF#;
   Egyptian_Hieroglyph_E026                :
      constant Unicode_Char := 16#130F0#;
   Egyptian_Hieroglyph_E027                :
      constant Unicode_Char := 16#130F1#;
   Egyptian_Hieroglyph_E028                :
      constant Unicode_Char := 16#130F2#;
   Egyptian_Hieroglyph_E028a               :
      constant Unicode_Char := 16#130F3#;
   Egyptian_Hieroglyph_E029                :
      constant Unicode_Char := 16#130F4#;
   Egyptian_Hieroglyph_E030                :
      constant Unicode_Char := 16#130F5#;
   Egyptian_Hieroglyph_E031                :
      constant Unicode_Char := 16#130F6#;
   Egyptian_Hieroglyph_E032                :
      constant Unicode_Char := 16#130F7#;
   Egyptian_Hieroglyph_E033                :
      constant Unicode_Char := 16#130F8#;
   Egyptian_Hieroglyph_E034                :
      constant Unicode_Char := 16#130F9#;
   Egyptian_Hieroglyph_E034a               :
      constant Unicode_Char := 16#130FA#;
   Egyptian_Hieroglyph_E036                :
      constant Unicode_Char := 16#130FB#;
   Egyptian_Hieroglyph_E037                :
      constant Unicode_Char := 16#130FC#;
   Egyptian_Hieroglyph_E038                :
      constant Unicode_Char := 16#130FD#;
   Egyptian_Hieroglyph_F001                :
      constant Unicode_Char := 16#130FE#;
   Egyptian_Hieroglyph_F001a               :
      constant Unicode_Char := 16#130FF#;
   Egyptian_Hieroglyph_F002                :
      constant Unicode_Char := 16#13100#;
   Egyptian_Hieroglyph_F003                :
      constant Unicode_Char := 16#13101#;
   Egyptian_Hieroglyph_F004                :
      constant Unicode_Char := 16#13102#;
   Egyptian_Hieroglyph_F005                :
      constant Unicode_Char := 16#13103#;
   Egyptian_Hieroglyph_F006                :
      constant Unicode_Char := 16#13104#;
   Egyptian_Hieroglyph_F007                :
      constant Unicode_Char := 16#13105#;
   Egyptian_Hieroglyph_F008                :
      constant Unicode_Char := 16#13106#;
   Egyptian_Hieroglyph_F009                :
      constant Unicode_Char := 16#13107#;
   Egyptian_Hieroglyph_F010                :
      constant Unicode_Char := 16#13108#;
   Egyptian_Hieroglyph_F011                :
      constant Unicode_Char := 16#13109#;
   Egyptian_Hieroglyph_F012                :
      constant Unicode_Char := 16#1310A#;
   Egyptian_Hieroglyph_F013                :
      constant Unicode_Char := 16#1310B#;
   Egyptian_Hieroglyph_F013a               :
      constant Unicode_Char := 16#1310C#;
   Egyptian_Hieroglyph_F014                :
      constant Unicode_Char := 16#1310D#;
   Egyptian_Hieroglyph_F015                :
      constant Unicode_Char := 16#1310E#;
   Egyptian_Hieroglyph_F016                :
      constant Unicode_Char := 16#1310F#;
   Egyptian_Hieroglyph_F017                :
      constant Unicode_Char := 16#13110#;
   Egyptian_Hieroglyph_F018                :
      constant Unicode_Char := 16#13111#;
   Egyptian_Hieroglyph_F019                :
      constant Unicode_Char := 16#13112#;
   Egyptian_Hieroglyph_F020                :
      constant Unicode_Char := 16#13113#;
   Egyptian_Hieroglyph_F021                :
      constant Unicode_Char := 16#13114#;
   Egyptian_Hieroglyph_F021a               :
      constant Unicode_Char := 16#13115#;
   Egyptian_Hieroglyph_F022                :
      constant Unicode_Char := 16#13116#;
   Egyptian_Hieroglyph_F023                :
      constant Unicode_Char := 16#13117#;
   Egyptian_Hieroglyph_F024                :
      constant Unicode_Char := 16#13118#;
   Egyptian_Hieroglyph_F025                :
      constant Unicode_Char := 16#13119#;
   Egyptian_Hieroglyph_F026                :
      constant Unicode_Char := 16#1311A#;
   Egyptian_Hieroglyph_F027                :
      constant Unicode_Char := 16#1311B#;
   Egyptian_Hieroglyph_F028                :
      constant Unicode_Char := 16#1311C#;
   Egyptian_Hieroglyph_F029                :
      constant Unicode_Char := 16#1311D#;
   Egyptian_Hieroglyph_F030                :
      constant Unicode_Char := 16#1311E#;
   Egyptian_Hieroglyph_F031                :
      constant Unicode_Char := 16#1311F#;
   Egyptian_Hieroglyph_F031a               :
      constant Unicode_Char := 16#13120#;
   Egyptian_Hieroglyph_F032                :
      constant Unicode_Char := 16#13121#;
   Egyptian_Hieroglyph_F033                :
      constant Unicode_Char := 16#13122#;
   Egyptian_Hieroglyph_F034                :
      constant Unicode_Char := 16#13123#;
   Egyptian_Hieroglyph_F035                :
      constant Unicode_Char := 16#13124#;
   Egyptian_Hieroglyph_F036                :
      constant Unicode_Char := 16#13125#;
   Egyptian_Hieroglyph_F037                :
      constant Unicode_Char := 16#13126#;
   Egyptian_Hieroglyph_F037a               :
      constant Unicode_Char := 16#13127#;
   Egyptian_Hieroglyph_F038                :
      constant Unicode_Char := 16#13128#;
   Egyptian_Hieroglyph_F038a               :
      constant Unicode_Char := 16#13129#;
   Egyptian_Hieroglyph_F039                :
      constant Unicode_Char := 16#1312A#;
   Egyptian_Hieroglyph_F040                :
      constant Unicode_Char := 16#1312B#;
   Egyptian_Hieroglyph_F041                :
      constant Unicode_Char := 16#1312C#;
   Egyptian_Hieroglyph_F042                :
      constant Unicode_Char := 16#1312D#;
   Egyptian_Hieroglyph_F043                :
      constant Unicode_Char := 16#1312E#;
   Egyptian_Hieroglyph_F044                :
      constant Unicode_Char := 16#1312F#;
   Egyptian_Hieroglyph_F045                :
      constant Unicode_Char := 16#13130#;
   Egyptian_Hieroglyph_F045a               :
      constant Unicode_Char := 16#13131#;
   Egyptian_Hieroglyph_F046                :
      constant Unicode_Char := 16#13132#;
   Egyptian_Hieroglyph_F046a               :
      constant Unicode_Char := 16#13133#;
   Egyptian_Hieroglyph_F047                :
      constant Unicode_Char := 16#13134#;
   Egyptian_Hieroglyph_F047a               :
      constant Unicode_Char := 16#13135#;
   Egyptian_Hieroglyph_F048                :
      constant Unicode_Char := 16#13136#;
   Egyptian_Hieroglyph_F049                :
      constant Unicode_Char := 16#13137#;
   Egyptian_Hieroglyph_F050                :
      constant Unicode_Char := 16#13138#;
   Egyptian_Hieroglyph_F051                :
      constant Unicode_Char := 16#13139#;
   Egyptian_Hieroglyph_F051a               :
      constant Unicode_Char := 16#1313A#;
   Egyptian_Hieroglyph_F051b               :
      constant Unicode_Char := 16#1313B#;
   Egyptian_Hieroglyph_F051c               :
      constant Unicode_Char := 16#1313C#;
   Egyptian_Hieroglyph_F052                :
      constant Unicode_Char := 16#1313D#;
   Egyptian_Hieroglyph_F053                :
      constant Unicode_Char := 16#1313E#;
   Egyptian_Hieroglyph_G001                :
      constant Unicode_Char := 16#1313F#;
   Egyptian_Hieroglyph_G002                :
      constant Unicode_Char := 16#13140#;
   Egyptian_Hieroglyph_G003                :
      constant Unicode_Char := 16#13141#;
   Egyptian_Hieroglyph_G004                :
      constant Unicode_Char := 16#13142#;
   Egyptian_Hieroglyph_G005                :
      constant Unicode_Char := 16#13143#;
   Egyptian_Hieroglyph_G006                :
      constant Unicode_Char := 16#13144#;
   Egyptian_Hieroglyph_G006a               :
      constant Unicode_Char := 16#13145#;
   Egyptian_Hieroglyph_G007                :
      constant Unicode_Char := 16#13146#;
   Egyptian_Hieroglyph_G007a               :
      constant Unicode_Char := 16#13147#;
   Egyptian_Hieroglyph_G007b               :
      constant Unicode_Char := 16#13148#;
   Egyptian_Hieroglyph_G008                :
      constant Unicode_Char := 16#13149#;
   Egyptian_Hieroglyph_G009                :
      constant Unicode_Char := 16#1314A#;
   Egyptian_Hieroglyph_G010                :
      constant Unicode_Char := 16#1314B#;
   Egyptian_Hieroglyph_G011                :
      constant Unicode_Char := 16#1314C#;
   Egyptian_Hieroglyph_G011a               :
      constant Unicode_Char := 16#1314D#;
   Egyptian_Hieroglyph_G012                :
      constant Unicode_Char := 16#1314E#;
   Egyptian_Hieroglyph_G013                :
      constant Unicode_Char := 16#1314F#;
   Egyptian_Hieroglyph_G014                :
      constant Unicode_Char := 16#13150#;
   Egyptian_Hieroglyph_G015                :
      constant Unicode_Char := 16#13151#;
   Egyptian_Hieroglyph_G016                :
      constant Unicode_Char := 16#13152#;
   Egyptian_Hieroglyph_G017                :
      constant Unicode_Char := 16#13153#;
   Egyptian_Hieroglyph_G018                :
      constant Unicode_Char := 16#13154#;
   Egyptian_Hieroglyph_G019                :
      constant Unicode_Char := 16#13155#;
   Egyptian_Hieroglyph_G020                :
      constant Unicode_Char := 16#13156#;
   Egyptian_Hieroglyph_G020a               :
      constant Unicode_Char := 16#13157#;
   Egyptian_Hieroglyph_G021                :
      constant Unicode_Char := 16#13158#;
   Egyptian_Hieroglyph_G022                :
      constant Unicode_Char := 16#13159#;
   Egyptian_Hieroglyph_G023                :
      constant Unicode_Char := 16#1315A#;
   Egyptian_Hieroglyph_G024                :
      constant Unicode_Char := 16#1315B#;
   Egyptian_Hieroglyph_G025                :
      constant Unicode_Char := 16#1315C#;
   Egyptian_Hieroglyph_G026                :
      constant Unicode_Char := 16#1315D#;
   Egyptian_Hieroglyph_G026a               :
      constant Unicode_Char := 16#1315E#;
   Egyptian_Hieroglyph_G027                :
      constant Unicode_Char := 16#1315F#;
   Egyptian_Hieroglyph_G028                :
      constant Unicode_Char := 16#13160#;
   Egyptian_Hieroglyph_G029                :
      constant Unicode_Char := 16#13161#;
   Egyptian_Hieroglyph_G030                :
      constant Unicode_Char := 16#13162#;
   Egyptian_Hieroglyph_G031                :
      constant Unicode_Char := 16#13163#;
   Egyptian_Hieroglyph_G032                :
      constant Unicode_Char := 16#13164#;
   Egyptian_Hieroglyph_G033                :
      constant Unicode_Char := 16#13165#;
   Egyptian_Hieroglyph_G034                :
      constant Unicode_Char := 16#13166#;
   Egyptian_Hieroglyph_G035                :
      constant Unicode_Char := 16#13167#;
   Egyptian_Hieroglyph_G036                :
      constant Unicode_Char := 16#13168#;
   Egyptian_Hieroglyph_G036a               :
      constant Unicode_Char := 16#13169#;
   Egyptian_Hieroglyph_G037                :
      constant Unicode_Char := 16#1316A#;
   Egyptian_Hieroglyph_G037a               :
      constant Unicode_Char := 16#1316B#;
   Egyptian_Hieroglyph_G038                :
      constant Unicode_Char := 16#1316C#;
   Egyptian_Hieroglyph_G039                :
      constant Unicode_Char := 16#1316D#;
   Egyptian_Hieroglyph_G040                :
      constant Unicode_Char := 16#1316E#;
   Egyptian_Hieroglyph_G041                :
      constant Unicode_Char := 16#1316F#;
   Egyptian_Hieroglyph_G042                :
      constant Unicode_Char := 16#13170#;
   Egyptian_Hieroglyph_G043                :
      constant Unicode_Char := 16#13171#;
   Egyptian_Hieroglyph_G043a               :
      constant Unicode_Char := 16#13172#;
   Egyptian_Hieroglyph_G044                :
      constant Unicode_Char := 16#13173#;
   Egyptian_Hieroglyph_G045                :
      constant Unicode_Char := 16#13174#;
   Egyptian_Hieroglyph_G045a               :
      constant Unicode_Char := 16#13175#;
   Egyptian_Hieroglyph_G046                :
      constant Unicode_Char := 16#13176#;
   Egyptian_Hieroglyph_G047                :
      constant Unicode_Char := 16#13177#;
   Egyptian_Hieroglyph_G048                :
      constant Unicode_Char := 16#13178#;
   Egyptian_Hieroglyph_G049                :
      constant Unicode_Char := 16#13179#;
   Egyptian_Hieroglyph_G050                :
      constant Unicode_Char := 16#1317A#;
   Egyptian_Hieroglyph_G051                :
      constant Unicode_Char := 16#1317B#;
   Egyptian_Hieroglyph_G052                :
      constant Unicode_Char := 16#1317C#;
   Egyptian_Hieroglyph_G053                :
      constant Unicode_Char := 16#1317D#;
   Egyptian_Hieroglyph_G054                :
      constant Unicode_Char := 16#1317E#;
   Egyptian_Hieroglyph_H001                :
      constant Unicode_Char := 16#1317F#;
   Egyptian_Hieroglyph_H002                :
      constant Unicode_Char := 16#13180#;
   Egyptian_Hieroglyph_H003                :
      constant Unicode_Char := 16#13181#;
   Egyptian_Hieroglyph_H004                :
      constant Unicode_Char := 16#13182#;
   Egyptian_Hieroglyph_H005                :
      constant Unicode_Char := 16#13183#;
   Egyptian_Hieroglyph_H006                :
      constant Unicode_Char := 16#13184#;
   Egyptian_Hieroglyph_H006a               :
      constant Unicode_Char := 16#13185#;
   Egyptian_Hieroglyph_H007                :
      constant Unicode_Char := 16#13186#;
   Egyptian_Hieroglyph_H008                :
      constant Unicode_Char := 16#13187#;
   Egyptian_Hieroglyph_I001                :
      constant Unicode_Char := 16#13188#;
   Egyptian_Hieroglyph_I002                :
      constant Unicode_Char := 16#13189#;
   Egyptian_Hieroglyph_I003                :
      constant Unicode_Char := 16#1318A#;
   Egyptian_Hieroglyph_I004                :
      constant Unicode_Char := 16#1318B#;
   Egyptian_Hieroglyph_I005                :
      constant Unicode_Char := 16#1318C#;
   Egyptian_Hieroglyph_I005a               :
      constant Unicode_Char := 16#1318D#;
   Egyptian_Hieroglyph_I006                :
      constant Unicode_Char := 16#1318E#;
   Egyptian_Hieroglyph_I007                :
      constant Unicode_Char := 16#1318F#;
   Egyptian_Hieroglyph_I008                :
      constant Unicode_Char := 16#13190#;
   Egyptian_Hieroglyph_I009                :
      constant Unicode_Char := 16#13191#;
   Egyptian_Hieroglyph_I009a               :
      constant Unicode_Char := 16#13192#;
   Egyptian_Hieroglyph_I010                :
      constant Unicode_Char := 16#13193#;
   Egyptian_Hieroglyph_I010a               :
      constant Unicode_Char := 16#13194#;
   Egyptian_Hieroglyph_I011                :
      constant Unicode_Char := 16#13195#;
   Egyptian_Hieroglyph_I011a               :
      constant Unicode_Char := 16#13196#;
   Egyptian_Hieroglyph_I012                :
      constant Unicode_Char := 16#13197#;
   Egyptian_Hieroglyph_I013                :
      constant Unicode_Char := 16#13198#;
   Egyptian_Hieroglyph_I014                :
      constant Unicode_Char := 16#13199#;
   Egyptian_Hieroglyph_I015                :
      constant Unicode_Char := 16#1319A#;
   Egyptian_Hieroglyph_K001                :
      constant Unicode_Char := 16#1319B#;
   Egyptian_Hieroglyph_K002                :
      constant Unicode_Char := 16#1319C#;
   Egyptian_Hieroglyph_K003                :
      constant Unicode_Char := 16#1319D#;
   Egyptian_Hieroglyph_K004                :
      constant Unicode_Char := 16#1319E#;
   Egyptian_Hieroglyph_K005                :
      constant Unicode_Char := 16#1319F#;
   Egyptian_Hieroglyph_K006                :
      constant Unicode_Char := 16#131A0#;
   Egyptian_Hieroglyph_K007                :
      constant Unicode_Char := 16#131A1#;
   Egyptian_Hieroglyph_K008                :
      constant Unicode_Char := 16#131A2#;
   Egyptian_Hieroglyph_L001                :
      constant Unicode_Char := 16#131A3#;
   Egyptian_Hieroglyph_L002                :
      constant Unicode_Char := 16#131A4#;
   Egyptian_Hieroglyph_L002a               :
      constant Unicode_Char := 16#131A5#;
   Egyptian_Hieroglyph_L003                :
      constant Unicode_Char := 16#131A6#;
   Egyptian_Hieroglyph_L004                :
      constant Unicode_Char := 16#131A7#;
   Egyptian_Hieroglyph_L005                :
      constant Unicode_Char := 16#131A8#;
   Egyptian_Hieroglyph_L006                :
      constant Unicode_Char := 16#131A9#;
   Egyptian_Hieroglyph_L006a               :
      constant Unicode_Char := 16#131AA#;
   Egyptian_Hieroglyph_L007                :
      constant Unicode_Char := 16#131AB#;
   Egyptian_Hieroglyph_L008                :
      constant Unicode_Char := 16#131AC#;
   Egyptian_Hieroglyph_M001                :
      constant Unicode_Char := 16#131AD#;
   Egyptian_Hieroglyph_M001a               :
      constant Unicode_Char := 16#131AE#;
   Egyptian_Hieroglyph_M001b               :
      constant Unicode_Char := 16#131AF#;
   Egyptian_Hieroglyph_M002                :
      constant Unicode_Char := 16#131B0#;
   Egyptian_Hieroglyph_M003                :
      constant Unicode_Char := 16#131B1#;
   Egyptian_Hieroglyph_M003a               :
      constant Unicode_Char := 16#131B2#;
   Egyptian_Hieroglyph_M004                :
      constant Unicode_Char := 16#131B3#;
   Egyptian_Hieroglyph_M005                :
      constant Unicode_Char := 16#131B4#;
   Egyptian_Hieroglyph_M006                :
      constant Unicode_Char := 16#131B5#;
   Egyptian_Hieroglyph_M007                :
      constant Unicode_Char := 16#131B6#;
   Egyptian_Hieroglyph_M008                :
      constant Unicode_Char := 16#131B7#;
   Egyptian_Hieroglyph_M009                :
      constant Unicode_Char := 16#131B8#;
   Egyptian_Hieroglyph_M010                :
      constant Unicode_Char := 16#131B9#;
   Egyptian_Hieroglyph_M010a               :
      constant Unicode_Char := 16#131BA#;
   Egyptian_Hieroglyph_M011                :
      constant Unicode_Char := 16#131BB#;
   Egyptian_Hieroglyph_M012                :
      constant Unicode_Char := 16#131BC#;
   Egyptian_Hieroglyph_M012a               :
      constant Unicode_Char := 16#131BD#;
   Egyptian_Hieroglyph_M012b               :
      constant Unicode_Char := 16#131BE#;
   Egyptian_Hieroglyph_M012c               :
      constant Unicode_Char := 16#131BF#;
   Egyptian_Hieroglyph_M012d               :
      constant Unicode_Char := 16#131C0#;
   Egyptian_Hieroglyph_M012e               :
      constant Unicode_Char := 16#131C1#;
   Egyptian_Hieroglyph_M012f               :
      constant Unicode_Char := 16#131C2#;
   Egyptian_Hieroglyph_M012g               :
      constant Unicode_Char := 16#131C3#;
   Egyptian_Hieroglyph_M012h               :
      constant Unicode_Char := 16#131C4#;
   Egyptian_Hieroglyph_M013                :
      constant Unicode_Char := 16#131C5#;
   Egyptian_Hieroglyph_M014                :
      constant Unicode_Char := 16#131C6#;
   Egyptian_Hieroglyph_M015                :
      constant Unicode_Char := 16#131C7#;
   Egyptian_Hieroglyph_M015a               :
      constant Unicode_Char := 16#131C8#;
   Egyptian_Hieroglyph_M016                :
      constant Unicode_Char := 16#131C9#;
   Egyptian_Hieroglyph_M016a               :
      constant Unicode_Char := 16#131CA#;
   Egyptian_Hieroglyph_M017                :
      constant Unicode_Char := 16#131CB#;
   Egyptian_Hieroglyph_M017a               :
      constant Unicode_Char := 16#131CC#;
   Egyptian_Hieroglyph_M018                :
      constant Unicode_Char := 16#131CD#;
   Egyptian_Hieroglyph_M019                :
      constant Unicode_Char := 16#131CE#;
   Egyptian_Hieroglyph_M020                :
      constant Unicode_Char := 16#131CF#;
   Egyptian_Hieroglyph_M021                :
      constant Unicode_Char := 16#131D0#;
   Egyptian_Hieroglyph_M022                :
      constant Unicode_Char := 16#131D1#;
   Egyptian_Hieroglyph_M022a               :
      constant Unicode_Char := 16#131D2#;
   Egyptian_Hieroglyph_M023                :
      constant Unicode_Char := 16#131D3#;
   Egyptian_Hieroglyph_M024                :
      constant Unicode_Char := 16#131D4#;
   Egyptian_Hieroglyph_M024a               :
      constant Unicode_Char := 16#131D5#;
   Egyptian_Hieroglyph_M025                :
      constant Unicode_Char := 16#131D6#;
   Egyptian_Hieroglyph_M026                :
      constant Unicode_Char := 16#131D7#;
   Egyptian_Hieroglyph_M027                :
      constant Unicode_Char := 16#131D8#;
   Egyptian_Hieroglyph_M028                :
      constant Unicode_Char := 16#131D9#;
   Egyptian_Hieroglyph_M028a               :
      constant Unicode_Char := 16#131DA#;
   Egyptian_Hieroglyph_M029                :
      constant Unicode_Char := 16#131DB#;
   Egyptian_Hieroglyph_M030                :
      constant Unicode_Char := 16#131DC#;
   Egyptian_Hieroglyph_M031                :
      constant Unicode_Char := 16#131DD#;
   Egyptian_Hieroglyph_M031a               :
      constant Unicode_Char := 16#131DE#;
   Egyptian_Hieroglyph_M032                :
      constant Unicode_Char := 16#131DF#;
   Egyptian_Hieroglyph_M033                :
      constant Unicode_Char := 16#131E0#;
   Egyptian_Hieroglyph_M033a               :
      constant Unicode_Char := 16#131E1#;
   Egyptian_Hieroglyph_M033b               :
      constant Unicode_Char := 16#131E2#;
   Egyptian_Hieroglyph_M034                :
      constant Unicode_Char := 16#131E3#;
   Egyptian_Hieroglyph_M035                :
      constant Unicode_Char := 16#131E4#;
   Egyptian_Hieroglyph_M036                :
      constant Unicode_Char := 16#131E5#;
   Egyptian_Hieroglyph_M037                :
      constant Unicode_Char := 16#131E6#;
   Egyptian_Hieroglyph_M038                :
      constant Unicode_Char := 16#131E7#;
   Egyptian_Hieroglyph_M039                :
      constant Unicode_Char := 16#131E8#;
   Egyptian_Hieroglyph_M040                :
      constant Unicode_Char := 16#131E9#;
   Egyptian_Hieroglyph_M040a               :
      constant Unicode_Char := 16#131EA#;
   Egyptian_Hieroglyph_M041                :
      constant Unicode_Char := 16#131EB#;
   Egyptian_Hieroglyph_M042                :
      constant Unicode_Char := 16#131EC#;
   Egyptian_Hieroglyph_M043                :
      constant Unicode_Char := 16#131ED#;
   Egyptian_Hieroglyph_M044                :
      constant Unicode_Char := 16#131EE#;
   Egyptian_Hieroglyph_N001                :
      constant Unicode_Char := 16#131EF#;
   Egyptian_Hieroglyph_N002                :
      constant Unicode_Char := 16#131F0#;
   Egyptian_Hieroglyph_N003                :
      constant Unicode_Char := 16#131F1#;
   Egyptian_Hieroglyph_N004                :
      constant Unicode_Char := 16#131F2#;
   Egyptian_Hieroglyph_N005                :
      constant Unicode_Char := 16#131F3#;
   Egyptian_Hieroglyph_N006                :
      constant Unicode_Char := 16#131F4#;
   Egyptian_Hieroglyph_N007                :
      constant Unicode_Char := 16#131F5#;
   Egyptian_Hieroglyph_N008                :
      constant Unicode_Char := 16#131F6#;
   Egyptian_Hieroglyph_N009                :
      constant Unicode_Char := 16#131F7#;
   Egyptian_Hieroglyph_N010                :
      constant Unicode_Char := 16#131F8#;
   Egyptian_Hieroglyph_N011                :
      constant Unicode_Char := 16#131F9#;
   Egyptian_Hieroglyph_N012                :
      constant Unicode_Char := 16#131FA#;
   Egyptian_Hieroglyph_N013                :
      constant Unicode_Char := 16#131FB#;
   Egyptian_Hieroglyph_N014                :
      constant Unicode_Char := 16#131FC#;
   Egyptian_Hieroglyph_N015                :
      constant Unicode_Char := 16#131FD#;
   Egyptian_Hieroglyph_N016                :
      constant Unicode_Char := 16#131FE#;
   Egyptian_Hieroglyph_N017                :
      constant Unicode_Char := 16#131FF#;
   Egyptian_Hieroglyph_N018                :
      constant Unicode_Char := 16#13200#;
   Egyptian_Hieroglyph_N018a               :
      constant Unicode_Char := 16#13201#;
   Egyptian_Hieroglyph_N018b               :
      constant Unicode_Char := 16#13202#;
   Egyptian_Hieroglyph_N019                :
      constant Unicode_Char := 16#13203#;
   Egyptian_Hieroglyph_N020                :
      constant Unicode_Char := 16#13204#;
   Egyptian_Hieroglyph_N021                :
      constant Unicode_Char := 16#13205#;
   Egyptian_Hieroglyph_N022                :
      constant Unicode_Char := 16#13206#;
   Egyptian_Hieroglyph_N023                :
      constant Unicode_Char := 16#13207#;
   Egyptian_Hieroglyph_N024                :
      constant Unicode_Char := 16#13208#;
   Egyptian_Hieroglyph_N025                :
      constant Unicode_Char := 16#13209#;
   Egyptian_Hieroglyph_N025a               :
      constant Unicode_Char := 16#1320A#;
   Egyptian_Hieroglyph_N026                :
      constant Unicode_Char := 16#1320B#;
   Egyptian_Hieroglyph_N027                :
      constant Unicode_Char := 16#1320C#;
   Egyptian_Hieroglyph_N028                :
      constant Unicode_Char := 16#1320D#;
   Egyptian_Hieroglyph_N029                :
      constant Unicode_Char := 16#1320E#;
   Egyptian_Hieroglyph_N030                :
      constant Unicode_Char := 16#1320F#;
   Egyptian_Hieroglyph_N031                :
      constant Unicode_Char := 16#13210#;
   Egyptian_Hieroglyph_N032                :
      constant Unicode_Char := 16#13211#;
   Egyptian_Hieroglyph_N033                :
      constant Unicode_Char := 16#13212#;
   Egyptian_Hieroglyph_N033a               :
      constant Unicode_Char := 16#13213#;
   Egyptian_Hieroglyph_N034                :
      constant Unicode_Char := 16#13214#;
   Egyptian_Hieroglyph_N034a               :
      constant Unicode_Char := 16#13215#;
   Egyptian_Hieroglyph_N035                :
      constant Unicode_Char := 16#13216#;
   Egyptian_Hieroglyph_N035a               :
      constant Unicode_Char := 16#13217#;
   Egyptian_Hieroglyph_N036                :
      constant Unicode_Char := 16#13218#;
   Egyptian_Hieroglyph_N037                :
      constant Unicode_Char := 16#13219#;
   Egyptian_Hieroglyph_N037a               :
      constant Unicode_Char := 16#1321A#;
   Egyptian_Hieroglyph_N038                :
      constant Unicode_Char := 16#1321B#;
   Egyptian_Hieroglyph_N039                :
      constant Unicode_Char := 16#1321C#;
   Egyptian_Hieroglyph_N040                :
      constant Unicode_Char := 16#1321D#;
   Egyptian_Hieroglyph_N041                :
      constant Unicode_Char := 16#1321E#;
   Egyptian_Hieroglyph_N042                :
      constant Unicode_Char := 16#1321F#;
   Egyptian_Hieroglyph_Nl001               :
      constant Unicode_Char := 16#13220#;
   Egyptian_Hieroglyph_Nl002               :
      constant Unicode_Char := 16#13221#;
   Egyptian_Hieroglyph_Nl003               :
      constant Unicode_Char := 16#13222#;
   Egyptian_Hieroglyph_Nl004               :
      constant Unicode_Char := 16#13223#;
   Egyptian_Hieroglyph_Nl005               :
      constant Unicode_Char := 16#13224#;
   Egyptian_Hieroglyph_Nl005a              :
      constant Unicode_Char := 16#13225#;
   Egyptian_Hieroglyph_Nl006               :
      constant Unicode_Char := 16#13226#;
   Egyptian_Hieroglyph_Nl007               :
      constant Unicode_Char := 16#13227#;
   Egyptian_Hieroglyph_Nl008               :
      constant Unicode_Char := 16#13228#;
   Egyptian_Hieroglyph_Nl009               :
      constant Unicode_Char := 16#13229#;
   Egyptian_Hieroglyph_Nl010               :
      constant Unicode_Char := 16#1322A#;
   Egyptian_Hieroglyph_Nl011               :
      constant Unicode_Char := 16#1322B#;
   Egyptian_Hieroglyph_Nl012               :
      constant Unicode_Char := 16#1322C#;
   Egyptian_Hieroglyph_Nl013               :
      constant Unicode_Char := 16#1322D#;
   Egyptian_Hieroglyph_Nl014               :
      constant Unicode_Char := 16#1322E#;
   Egyptian_Hieroglyph_Nl015               :
      constant Unicode_Char := 16#1322F#;
   Egyptian_Hieroglyph_Nl016               :
      constant Unicode_Char := 16#13230#;
   Egyptian_Hieroglyph_Nl017               :
      constant Unicode_Char := 16#13231#;
   Egyptian_Hieroglyph_Nl017a              :
      constant Unicode_Char := 16#13232#;
   Egyptian_Hieroglyph_Nl018               :
      constant Unicode_Char := 16#13233#;
   Egyptian_Hieroglyph_Nl019               :
      constant Unicode_Char := 16#13234#;
   Egyptian_Hieroglyph_Nl020               :
      constant Unicode_Char := 16#13235#;
   Egyptian_Hieroglyph_Nu001               :
      constant Unicode_Char := 16#13236#;
   Egyptian_Hieroglyph_Nu002               :
      constant Unicode_Char := 16#13237#;
   Egyptian_Hieroglyph_Nu003               :
      constant Unicode_Char := 16#13238#;
   Egyptian_Hieroglyph_Nu004               :
      constant Unicode_Char := 16#13239#;
   Egyptian_Hieroglyph_Nu005               :
      constant Unicode_Char := 16#1323A#;
   Egyptian_Hieroglyph_Nu006               :
      constant Unicode_Char := 16#1323B#;
   Egyptian_Hieroglyph_Nu007               :
      constant Unicode_Char := 16#1323C#;
   Egyptian_Hieroglyph_Nu008               :
      constant Unicode_Char := 16#1323D#;
   Egyptian_Hieroglyph_Nu009               :
      constant Unicode_Char := 16#1323E#;
   Egyptian_Hieroglyph_Nu010               :
      constant Unicode_Char := 16#1323F#;
   Egyptian_Hieroglyph_Nu010a              :
      constant Unicode_Char := 16#13240#;
   Egyptian_Hieroglyph_Nu011               :
      constant Unicode_Char := 16#13241#;
   Egyptian_Hieroglyph_Nu011a              :
      constant Unicode_Char := 16#13242#;
   Egyptian_Hieroglyph_Nu012               :
      constant Unicode_Char := 16#13243#;
   Egyptian_Hieroglyph_Nu013               :
      constant Unicode_Char := 16#13244#;
   Egyptian_Hieroglyph_Nu014               :
      constant Unicode_Char := 16#13245#;
   Egyptian_Hieroglyph_Nu015               :
      constant Unicode_Char := 16#13246#;
   Egyptian_Hieroglyph_Nu016               :
      constant Unicode_Char := 16#13247#;
   Egyptian_Hieroglyph_Nu017               :
      constant Unicode_Char := 16#13248#;
   Egyptian_Hieroglyph_Nu018               :
      constant Unicode_Char := 16#13249#;
   Egyptian_Hieroglyph_Nu018a              :
      constant Unicode_Char := 16#1324A#;
   Egyptian_Hieroglyph_Nu019               :
      constant Unicode_Char := 16#1324B#;
   Egyptian_Hieroglyph_Nu020               :
      constant Unicode_Char := 16#1324C#;
   Egyptian_Hieroglyph_Nu021               :
      constant Unicode_Char := 16#1324D#;
   Egyptian_Hieroglyph_Nu022               :
      constant Unicode_Char := 16#1324E#;
   Egyptian_Hieroglyph_Nu022a              :
      constant Unicode_Char := 16#1324F#;
   Egyptian_Hieroglyph_O001                :
      constant Unicode_Char := 16#13250#;
   Egyptian_Hieroglyph_O001a               :
      constant Unicode_Char := 16#13251#;
   Egyptian_Hieroglyph_O002                :
      constant Unicode_Char := 16#13252#;
   Egyptian_Hieroglyph_O003                :
      constant Unicode_Char := 16#13253#;
   Egyptian_Hieroglyph_O004                :
      constant Unicode_Char := 16#13254#;
   Egyptian_Hieroglyph_O005                :
      constant Unicode_Char := 16#13255#;
   Egyptian_Hieroglyph_O005a               :
      constant Unicode_Char := 16#13256#;
   Egyptian_Hieroglyph_O006                :
      constant Unicode_Char := 16#13257#;
   Egyptian_Hieroglyph_O006a               :
      constant Unicode_Char := 16#13258#;
   Egyptian_Hieroglyph_O006b               :
      constant Unicode_Char := 16#13259#;
   Egyptian_Hieroglyph_O006c               :
      constant Unicode_Char := 16#1325A#;
   Egyptian_Hieroglyph_O006d               :
      constant Unicode_Char := 16#1325B#;
   Egyptian_Hieroglyph_O006e               :
      constant Unicode_Char := 16#1325C#;
   Egyptian_Hieroglyph_O006f               :
      constant Unicode_Char := 16#1325D#;
   Egyptian_Hieroglyph_O007                :
      constant Unicode_Char := 16#1325E#;
   Egyptian_Hieroglyph_O008                :
      constant Unicode_Char := 16#1325F#;
   Egyptian_Hieroglyph_O009                :
      constant Unicode_Char := 16#13260#;
   Egyptian_Hieroglyph_O010                :
      constant Unicode_Char := 16#13261#;
   Egyptian_Hieroglyph_O010a               :
      constant Unicode_Char := 16#13262#;
   Egyptian_Hieroglyph_O010b               :
      constant Unicode_Char := 16#13263#;
   Egyptian_Hieroglyph_O010c               :
      constant Unicode_Char := 16#13264#;
   Egyptian_Hieroglyph_O011                :
      constant Unicode_Char := 16#13265#;
   Egyptian_Hieroglyph_O012                :
      constant Unicode_Char := 16#13266#;
   Egyptian_Hieroglyph_O013                :
      constant Unicode_Char := 16#13267#;
   Egyptian_Hieroglyph_O014                :
      constant Unicode_Char := 16#13268#;
   Egyptian_Hieroglyph_O015                :
      constant Unicode_Char := 16#13269#;
   Egyptian_Hieroglyph_O016                :
      constant Unicode_Char := 16#1326A#;
   Egyptian_Hieroglyph_O017                :
      constant Unicode_Char := 16#1326B#;
   Egyptian_Hieroglyph_O018                :
      constant Unicode_Char := 16#1326C#;
   Egyptian_Hieroglyph_O019                :
      constant Unicode_Char := 16#1326D#;
   Egyptian_Hieroglyph_O019a               :
      constant Unicode_Char := 16#1326E#;
   Egyptian_Hieroglyph_O020                :
      constant Unicode_Char := 16#1326F#;
   Egyptian_Hieroglyph_O020a               :
      constant Unicode_Char := 16#13270#;
   Egyptian_Hieroglyph_O021                :
      constant Unicode_Char := 16#13271#;
   Egyptian_Hieroglyph_O022                :
      constant Unicode_Char := 16#13272#;
   Egyptian_Hieroglyph_O023                :
      constant Unicode_Char := 16#13273#;
   Egyptian_Hieroglyph_O024                :
      constant Unicode_Char := 16#13274#;
   Egyptian_Hieroglyph_O024a               :
      constant Unicode_Char := 16#13275#;
   Egyptian_Hieroglyph_O025                :
      constant Unicode_Char := 16#13276#;
   Egyptian_Hieroglyph_O025a               :
      constant Unicode_Char := 16#13277#;
   Egyptian_Hieroglyph_O026                :
      constant Unicode_Char := 16#13278#;
   Egyptian_Hieroglyph_O027                :
      constant Unicode_Char := 16#13279#;
   Egyptian_Hieroglyph_O028                :
      constant Unicode_Char := 16#1327A#;
   Egyptian_Hieroglyph_O029                :
      constant Unicode_Char := 16#1327B#;
   Egyptian_Hieroglyph_O029a               :
      constant Unicode_Char := 16#1327C#;
   Egyptian_Hieroglyph_O030                :
      constant Unicode_Char := 16#1327D#;
   Egyptian_Hieroglyph_O030a               :
      constant Unicode_Char := 16#1327E#;
   Egyptian_Hieroglyph_O031                :
      constant Unicode_Char := 16#1327F#;
   Egyptian_Hieroglyph_O032                :
      constant Unicode_Char := 16#13280#;
   Egyptian_Hieroglyph_O033                :
      constant Unicode_Char := 16#13281#;
   Egyptian_Hieroglyph_O033a               :
      constant Unicode_Char := 16#13282#;
   Egyptian_Hieroglyph_O034                :
      constant Unicode_Char := 16#13283#;
   Egyptian_Hieroglyph_O035                :
      constant Unicode_Char := 16#13284#;
   Egyptian_Hieroglyph_O036                :
      constant Unicode_Char := 16#13285#;
   Egyptian_Hieroglyph_O036a               :
      constant Unicode_Char := 16#13286#;
   Egyptian_Hieroglyph_O036b               :
      constant Unicode_Char := 16#13287#;
   Egyptian_Hieroglyph_O036c               :
      constant Unicode_Char := 16#13288#;
   Egyptian_Hieroglyph_O036d               :
      constant Unicode_Char := 16#13289#;
   Egyptian_Hieroglyph_O037                :
      constant Unicode_Char := 16#1328A#;
   Egyptian_Hieroglyph_O038                :
      constant Unicode_Char := 16#1328B#;
   Egyptian_Hieroglyph_O039                :
      constant Unicode_Char := 16#1328C#;
   Egyptian_Hieroglyph_O040                :
      constant Unicode_Char := 16#1328D#;
   Egyptian_Hieroglyph_O041                :
      constant Unicode_Char := 16#1328E#;
   Egyptian_Hieroglyph_O042                :
      constant Unicode_Char := 16#1328F#;
   Egyptian_Hieroglyph_O043                :
      constant Unicode_Char := 16#13290#;
   Egyptian_Hieroglyph_O044                :
      constant Unicode_Char := 16#13291#;
   Egyptian_Hieroglyph_O045                :
      constant Unicode_Char := 16#13292#;
   Egyptian_Hieroglyph_O046                :
      constant Unicode_Char := 16#13293#;
   Egyptian_Hieroglyph_O047                :
      constant Unicode_Char := 16#13294#;
   Egyptian_Hieroglyph_O048                :
      constant Unicode_Char := 16#13295#;
   Egyptian_Hieroglyph_O049                :
      constant Unicode_Char := 16#13296#;
   Egyptian_Hieroglyph_O050                :
      constant Unicode_Char := 16#13297#;
   Egyptian_Hieroglyph_O050a               :
      constant Unicode_Char := 16#13298#;
   Egyptian_Hieroglyph_O050b               :
      constant Unicode_Char := 16#13299#;
   Egyptian_Hieroglyph_O051                :
      constant Unicode_Char := 16#1329A#;
   Egyptian_Hieroglyph_P001                :
      constant Unicode_Char := 16#1329B#;
   Egyptian_Hieroglyph_P001a               :
      constant Unicode_Char := 16#1329C#;
   Egyptian_Hieroglyph_P002                :
      constant Unicode_Char := 16#1329D#;
   Egyptian_Hieroglyph_P003                :
      constant Unicode_Char := 16#1329E#;
   Egyptian_Hieroglyph_P003a               :
      constant Unicode_Char := 16#1329F#;
   Egyptian_Hieroglyph_P004                :
      constant Unicode_Char := 16#132A0#;
   Egyptian_Hieroglyph_P005                :
      constant Unicode_Char := 16#132A1#;
   Egyptian_Hieroglyph_P006                :
      constant Unicode_Char := 16#132A2#;
   Egyptian_Hieroglyph_P007                :
      constant Unicode_Char := 16#132A3#;
   Egyptian_Hieroglyph_P008                :
      constant Unicode_Char := 16#132A4#;
   Egyptian_Hieroglyph_P009                :
      constant Unicode_Char := 16#132A5#;
   Egyptian_Hieroglyph_P010                :
      constant Unicode_Char := 16#132A6#;
   Egyptian_Hieroglyph_P011                :
      constant Unicode_Char := 16#132A7#;
   Egyptian_Hieroglyph_Q001                :
      constant Unicode_Char := 16#132A8#;
   Egyptian_Hieroglyph_Q002                :
      constant Unicode_Char := 16#132A9#;
   Egyptian_Hieroglyph_Q003                :
      constant Unicode_Char := 16#132AA#;
   Egyptian_Hieroglyph_Q004                :
      constant Unicode_Char := 16#132AB#;
   Egyptian_Hieroglyph_Q005                :
      constant Unicode_Char := 16#132AC#;
   Egyptian_Hieroglyph_Q006                :
      constant Unicode_Char := 16#132AD#;
   Egyptian_Hieroglyph_Q007                :
      constant Unicode_Char := 16#132AE#;
   Egyptian_Hieroglyph_R001                :
      constant Unicode_Char := 16#132AF#;
   Egyptian_Hieroglyph_R002                :
      constant Unicode_Char := 16#132B0#;
   Egyptian_Hieroglyph_R002a               :
      constant Unicode_Char := 16#132B1#;
   Egyptian_Hieroglyph_R003                :
      constant Unicode_Char := 16#132B2#;
   Egyptian_Hieroglyph_R003a               :
      constant Unicode_Char := 16#132B3#;
   Egyptian_Hieroglyph_R003b               :
      constant Unicode_Char := 16#132B4#;
   Egyptian_Hieroglyph_R004                :
      constant Unicode_Char := 16#132B5#;
   Egyptian_Hieroglyph_R005                :
      constant Unicode_Char := 16#132B6#;
   Egyptian_Hieroglyph_R006                :
      constant Unicode_Char := 16#132B7#;
   Egyptian_Hieroglyph_R007                :
      constant Unicode_Char := 16#132B8#;
   Egyptian_Hieroglyph_R008                :
      constant Unicode_Char := 16#132B9#;
   Egyptian_Hieroglyph_R009                :
      constant Unicode_Char := 16#132BA#;
   Egyptian_Hieroglyph_R010                :
      constant Unicode_Char := 16#132BB#;
   Egyptian_Hieroglyph_R010a               :
      constant Unicode_Char := 16#132BC#;
   Egyptian_Hieroglyph_R011                :
      constant Unicode_Char := 16#132BD#;
   Egyptian_Hieroglyph_R012                :
      constant Unicode_Char := 16#132BE#;
   Egyptian_Hieroglyph_R013                :
      constant Unicode_Char := 16#132BF#;
   Egyptian_Hieroglyph_R014                :
      constant Unicode_Char := 16#132C0#;
   Egyptian_Hieroglyph_R015                :
      constant Unicode_Char := 16#132C1#;
   Egyptian_Hieroglyph_R016                :
      constant Unicode_Char := 16#132C2#;
   Egyptian_Hieroglyph_R016a               :
      constant Unicode_Char := 16#132C3#;
   Egyptian_Hieroglyph_R017                :
      constant Unicode_Char := 16#132C4#;
   Egyptian_Hieroglyph_R018                :
      constant Unicode_Char := 16#132C5#;
   Egyptian_Hieroglyph_R019                :
      constant Unicode_Char := 16#132C6#;
   Egyptian_Hieroglyph_R020                :
      constant Unicode_Char := 16#132C7#;
   Egyptian_Hieroglyph_R021                :
      constant Unicode_Char := 16#132C8#;
   Egyptian_Hieroglyph_R022                :
      constant Unicode_Char := 16#132C9#;
   Egyptian_Hieroglyph_R023                :
      constant Unicode_Char := 16#132CA#;
   Egyptian_Hieroglyph_R024                :
      constant Unicode_Char := 16#132CB#;
   Egyptian_Hieroglyph_R025                :
      constant Unicode_Char := 16#132CC#;
   Egyptian_Hieroglyph_R026                :
      constant Unicode_Char := 16#132CD#;
   Egyptian_Hieroglyph_R027                :
      constant Unicode_Char := 16#132CE#;
   Egyptian_Hieroglyph_R028                :
      constant Unicode_Char := 16#132CF#;
   Egyptian_Hieroglyph_R029                :
      constant Unicode_Char := 16#132D0#;
   Egyptian_Hieroglyph_S001                :
      constant Unicode_Char := 16#132D1#;
   Egyptian_Hieroglyph_S002                :
      constant Unicode_Char := 16#132D2#;
   Egyptian_Hieroglyph_S002a               :
      constant Unicode_Char := 16#132D3#;
   Egyptian_Hieroglyph_S003                :
      constant Unicode_Char := 16#132D4#;
   Egyptian_Hieroglyph_S004                :
      constant Unicode_Char := 16#132D5#;
   Egyptian_Hieroglyph_S005                :
      constant Unicode_Char := 16#132D6#;
   Egyptian_Hieroglyph_S006                :
      constant Unicode_Char := 16#132D7#;
   Egyptian_Hieroglyph_S006a               :
      constant Unicode_Char := 16#132D8#;
   Egyptian_Hieroglyph_S007                :
      constant Unicode_Char := 16#132D9#;
   Egyptian_Hieroglyph_S008                :
      constant Unicode_Char := 16#132DA#;
   Egyptian_Hieroglyph_S009                :
      constant Unicode_Char := 16#132DB#;
   Egyptian_Hieroglyph_S010                :
      constant Unicode_Char := 16#132DC#;
   Egyptian_Hieroglyph_S011                :
      constant Unicode_Char := 16#132DD#;
   Egyptian_Hieroglyph_S012                :
      constant Unicode_Char := 16#132DE#;
   Egyptian_Hieroglyph_S013                :
      constant Unicode_Char := 16#132DF#;
   Egyptian_Hieroglyph_S014                :
      constant Unicode_Char := 16#132E0#;
   Egyptian_Hieroglyph_S014a               :
      constant Unicode_Char := 16#132E1#;
   Egyptian_Hieroglyph_S014b               :
      constant Unicode_Char := 16#132E2#;
   Egyptian_Hieroglyph_S015                :
      constant Unicode_Char := 16#132E3#;
   Egyptian_Hieroglyph_S016                :
      constant Unicode_Char := 16#132E4#;
   Egyptian_Hieroglyph_S017                :
      constant Unicode_Char := 16#132E5#;
   Egyptian_Hieroglyph_S017a               :
      constant Unicode_Char := 16#132E6#;
   Egyptian_Hieroglyph_S018                :
      constant Unicode_Char := 16#132E7#;
   Egyptian_Hieroglyph_S019                :
      constant Unicode_Char := 16#132E8#;
   Egyptian_Hieroglyph_S020                :
      constant Unicode_Char := 16#132E9#;
   Egyptian_Hieroglyph_S021                :
      constant Unicode_Char := 16#132EA#;
   Egyptian_Hieroglyph_S022                :
      constant Unicode_Char := 16#132EB#;
   Egyptian_Hieroglyph_S023                :
      constant Unicode_Char := 16#132EC#;
   Egyptian_Hieroglyph_S024                :
      constant Unicode_Char := 16#132ED#;
   Egyptian_Hieroglyph_S025                :
      constant Unicode_Char := 16#132EE#;
   Egyptian_Hieroglyph_S026                :
      constant Unicode_Char := 16#132EF#;
   Egyptian_Hieroglyph_S026a               :
      constant Unicode_Char := 16#132F0#;
   Egyptian_Hieroglyph_S026b               :
      constant Unicode_Char := 16#132F1#;
   Egyptian_Hieroglyph_S027                :
      constant Unicode_Char := 16#132F2#;
   Egyptian_Hieroglyph_S028                :
      constant Unicode_Char := 16#132F3#;
   Egyptian_Hieroglyph_S029                :
      constant Unicode_Char := 16#132F4#;
   Egyptian_Hieroglyph_S030                :
      constant Unicode_Char := 16#132F5#;
   Egyptian_Hieroglyph_S031                :
      constant Unicode_Char := 16#132F6#;
   Egyptian_Hieroglyph_S032                :
      constant Unicode_Char := 16#132F7#;
   Egyptian_Hieroglyph_S033                :
      constant Unicode_Char := 16#132F8#;
   Egyptian_Hieroglyph_S034                :
      constant Unicode_Char := 16#132F9#;
   Egyptian_Hieroglyph_S035                :
      constant Unicode_Char := 16#132FA#;
   Egyptian_Hieroglyph_S035a               :
      constant Unicode_Char := 16#132FB#;
   Egyptian_Hieroglyph_S036                :
      constant Unicode_Char := 16#132FC#;
   Egyptian_Hieroglyph_S037                :
      constant Unicode_Char := 16#132FD#;
   Egyptian_Hieroglyph_S038                :
      constant Unicode_Char := 16#132FE#;
   Egyptian_Hieroglyph_S039                :
      constant Unicode_Char := 16#132FF#;
   Egyptian_Hieroglyph_S040                :
      constant Unicode_Char := 16#13300#;
   Egyptian_Hieroglyph_S041                :
      constant Unicode_Char := 16#13301#;
   Egyptian_Hieroglyph_S042                :
      constant Unicode_Char := 16#13302#;
   Egyptian_Hieroglyph_S043                :
      constant Unicode_Char := 16#13303#;
   Egyptian_Hieroglyph_S044                :
      constant Unicode_Char := 16#13304#;
   Egyptian_Hieroglyph_S045                :
      constant Unicode_Char := 16#13305#;
   Egyptian_Hieroglyph_S046                :
      constant Unicode_Char := 16#13306#;
   Egyptian_Hieroglyph_T001                :
      constant Unicode_Char := 16#13307#;
   Egyptian_Hieroglyph_T002                :
      constant Unicode_Char := 16#13308#;
   Egyptian_Hieroglyph_T003                :
      constant Unicode_Char := 16#13309#;
   Egyptian_Hieroglyph_T003a               :
      constant Unicode_Char := 16#1330A#;
   Egyptian_Hieroglyph_T004                :
      constant Unicode_Char := 16#1330B#;
   Egyptian_Hieroglyph_T005                :
      constant Unicode_Char := 16#1330C#;
   Egyptian_Hieroglyph_T006                :
      constant Unicode_Char := 16#1330D#;
   Egyptian_Hieroglyph_T007                :
      constant Unicode_Char := 16#1330E#;
   Egyptian_Hieroglyph_T007a               :
      constant Unicode_Char := 16#1330F#;
   Egyptian_Hieroglyph_T008                :
      constant Unicode_Char := 16#13310#;
   Egyptian_Hieroglyph_T008a               :
      constant Unicode_Char := 16#13311#;
   Egyptian_Hieroglyph_T009                :
      constant Unicode_Char := 16#13312#;
   Egyptian_Hieroglyph_T009a               :
      constant Unicode_Char := 16#13313#;
   Egyptian_Hieroglyph_T010                :
      constant Unicode_Char := 16#13314#;
   Egyptian_Hieroglyph_T011                :
      constant Unicode_Char := 16#13315#;
   Egyptian_Hieroglyph_T011a               :
      constant Unicode_Char := 16#13316#;
   Egyptian_Hieroglyph_T012                :
      constant Unicode_Char := 16#13317#;
   Egyptian_Hieroglyph_T013                :
      constant Unicode_Char := 16#13318#;
   Egyptian_Hieroglyph_T014                :
      constant Unicode_Char := 16#13319#;
   Egyptian_Hieroglyph_T015                :
      constant Unicode_Char := 16#1331A#;
   Egyptian_Hieroglyph_T016                :
      constant Unicode_Char := 16#1331B#;
   Egyptian_Hieroglyph_T016a               :
      constant Unicode_Char := 16#1331C#;
   Egyptian_Hieroglyph_T017                :
      constant Unicode_Char := 16#1331D#;
   Egyptian_Hieroglyph_T018                :
      constant Unicode_Char := 16#1331E#;
   Egyptian_Hieroglyph_T019                :
      constant Unicode_Char := 16#1331F#;
   Egyptian_Hieroglyph_T020                :
      constant Unicode_Char := 16#13320#;
   Egyptian_Hieroglyph_T021                :
      constant Unicode_Char := 16#13321#;
   Egyptian_Hieroglyph_T022                :
      constant Unicode_Char := 16#13322#;
   Egyptian_Hieroglyph_T023                :
      constant Unicode_Char := 16#13323#;
   Egyptian_Hieroglyph_T024                :
      constant Unicode_Char := 16#13324#;
   Egyptian_Hieroglyph_T025                :
      constant Unicode_Char := 16#13325#;
   Egyptian_Hieroglyph_T026                :
      constant Unicode_Char := 16#13326#;
   Egyptian_Hieroglyph_T027                :
      constant Unicode_Char := 16#13327#;
   Egyptian_Hieroglyph_T028                :
      constant Unicode_Char := 16#13328#;
   Egyptian_Hieroglyph_T029                :
      constant Unicode_Char := 16#13329#;
   Egyptian_Hieroglyph_T030                :
      constant Unicode_Char := 16#1332A#;
   Egyptian_Hieroglyph_T031                :
      constant Unicode_Char := 16#1332B#;
   Egyptian_Hieroglyph_T032                :
      constant Unicode_Char := 16#1332C#;
   Egyptian_Hieroglyph_T032a               :
      constant Unicode_Char := 16#1332D#;
   Egyptian_Hieroglyph_T033                :
      constant Unicode_Char := 16#1332E#;
   Egyptian_Hieroglyph_T033a               :
      constant Unicode_Char := 16#1332F#;
   Egyptian_Hieroglyph_T034                :
      constant Unicode_Char := 16#13330#;
   Egyptian_Hieroglyph_T035                :
      constant Unicode_Char := 16#13331#;
   Egyptian_Hieroglyph_T036                :
      constant Unicode_Char := 16#13332#;
   Egyptian_Hieroglyph_U001                :
      constant Unicode_Char := 16#13333#;
   Egyptian_Hieroglyph_U002                :
      constant Unicode_Char := 16#13334#;
   Egyptian_Hieroglyph_U003                :
      constant Unicode_Char := 16#13335#;
   Egyptian_Hieroglyph_U004                :
      constant Unicode_Char := 16#13336#;
   Egyptian_Hieroglyph_U005                :
      constant Unicode_Char := 16#13337#;
   Egyptian_Hieroglyph_U006                :
      constant Unicode_Char := 16#13338#;
   Egyptian_Hieroglyph_U006a               :
      constant Unicode_Char := 16#13339#;
   Egyptian_Hieroglyph_U006b               :
      constant Unicode_Char := 16#1333A#;
   Egyptian_Hieroglyph_U007                :
      constant Unicode_Char := 16#1333B#;
   Egyptian_Hieroglyph_U008                :
      constant Unicode_Char := 16#1333C#;
   Egyptian_Hieroglyph_U009                :
      constant Unicode_Char := 16#1333D#;
   Egyptian_Hieroglyph_U010                :
      constant Unicode_Char := 16#1333E#;
   Egyptian_Hieroglyph_U011                :
      constant Unicode_Char := 16#1333F#;
   Egyptian_Hieroglyph_U012                :
      constant Unicode_Char := 16#13340#;
   Egyptian_Hieroglyph_U013                :
      constant Unicode_Char := 16#13341#;
   Egyptian_Hieroglyph_U014                :
      constant Unicode_Char := 16#13342#;
   Egyptian_Hieroglyph_U015                :
      constant Unicode_Char := 16#13343#;
   Egyptian_Hieroglyph_U016                :
      constant Unicode_Char := 16#13344#;
   Egyptian_Hieroglyph_U017                :
      constant Unicode_Char := 16#13345#;
   Egyptian_Hieroglyph_U018                :
      constant Unicode_Char := 16#13346#;
   Egyptian_Hieroglyph_U019                :
      constant Unicode_Char := 16#13347#;
   Egyptian_Hieroglyph_U020                :
      constant Unicode_Char := 16#13348#;
   Egyptian_Hieroglyph_U021                :
      constant Unicode_Char := 16#13349#;
   Egyptian_Hieroglyph_U022                :
      constant Unicode_Char := 16#1334A#;
   Egyptian_Hieroglyph_U023                :
      constant Unicode_Char := 16#1334B#;
   Egyptian_Hieroglyph_U023a               :
      constant Unicode_Char := 16#1334C#;
   Egyptian_Hieroglyph_U024                :
      constant Unicode_Char := 16#1334D#;
   Egyptian_Hieroglyph_U025                :
      constant Unicode_Char := 16#1334E#;
   Egyptian_Hieroglyph_U026                :
      constant Unicode_Char := 16#1334F#;
   Egyptian_Hieroglyph_U027                :
      constant Unicode_Char := 16#13350#;
   Egyptian_Hieroglyph_U028                :
      constant Unicode_Char := 16#13351#;
   Egyptian_Hieroglyph_U029                :
      constant Unicode_Char := 16#13352#;
   Egyptian_Hieroglyph_U029a               :
      constant Unicode_Char := 16#13353#;
   Egyptian_Hieroglyph_U030                :
      constant Unicode_Char := 16#13354#;
   Egyptian_Hieroglyph_U031                :
      constant Unicode_Char := 16#13355#;
   Egyptian_Hieroglyph_U032                :
      constant Unicode_Char := 16#13356#;
   Egyptian_Hieroglyph_U032a               :
      constant Unicode_Char := 16#13357#;
   Egyptian_Hieroglyph_U033                :
      constant Unicode_Char := 16#13358#;
   Egyptian_Hieroglyph_U034                :
      constant Unicode_Char := 16#13359#;
   Egyptian_Hieroglyph_U035                :
      constant Unicode_Char := 16#1335A#;
   Egyptian_Hieroglyph_U036                :
      constant Unicode_Char := 16#1335B#;
   Egyptian_Hieroglyph_U037                :
      constant Unicode_Char := 16#1335C#;
   Egyptian_Hieroglyph_U038                :
      constant Unicode_Char := 16#1335D#;
   Egyptian_Hieroglyph_U039                :
      constant Unicode_Char := 16#1335E#;
   Egyptian_Hieroglyph_U040                :
      constant Unicode_Char := 16#1335F#;
   Egyptian_Hieroglyph_U041                :
      constant Unicode_Char := 16#13360#;
   Egyptian_Hieroglyph_U042                :
      constant Unicode_Char := 16#13361#;
   Egyptian_Hieroglyph_V001                :
      constant Unicode_Char := 16#13362#;
   Egyptian_Hieroglyph_V001a               :
      constant Unicode_Char := 16#13363#;
   Egyptian_Hieroglyph_V001b               :
      constant Unicode_Char := 16#13364#;
   Egyptian_Hieroglyph_V001c               :
      constant Unicode_Char := 16#13365#;
   Egyptian_Hieroglyph_V001d               :
      constant Unicode_Char := 16#13366#;
   Egyptian_Hieroglyph_V001e               :
      constant Unicode_Char := 16#13367#;
   Egyptian_Hieroglyph_V001f               :
      constant Unicode_Char := 16#13368#;
   Egyptian_Hieroglyph_V001g               :
      constant Unicode_Char := 16#13369#;
   Egyptian_Hieroglyph_V001h               :
      constant Unicode_Char := 16#1336A#;
   Egyptian_Hieroglyph_V001i               :
      constant Unicode_Char := 16#1336B#;
   Egyptian_Hieroglyph_V002                :
      constant Unicode_Char := 16#1336C#;
   Egyptian_Hieroglyph_V002a               :
      constant Unicode_Char := 16#1336D#;
   Egyptian_Hieroglyph_V003                :
      constant Unicode_Char := 16#1336E#;
   Egyptian_Hieroglyph_V004                :
      constant Unicode_Char := 16#1336F#;
   Egyptian_Hieroglyph_V005                :
      constant Unicode_Char := 16#13370#;
   Egyptian_Hieroglyph_V006                :
      constant Unicode_Char := 16#13371#;
   Egyptian_Hieroglyph_V007                :
      constant Unicode_Char := 16#13372#;
   Egyptian_Hieroglyph_V007a               :
      constant Unicode_Char := 16#13373#;
   Egyptian_Hieroglyph_V007b               :
      constant Unicode_Char := 16#13374#;
   Egyptian_Hieroglyph_V008                :
      constant Unicode_Char := 16#13375#;
   Egyptian_Hieroglyph_V009                :
      constant Unicode_Char := 16#13376#;
   Egyptian_Hieroglyph_V010                :
      constant Unicode_Char := 16#13377#;
   Egyptian_Hieroglyph_V011                :
      constant Unicode_Char := 16#13378#;
   Egyptian_Hieroglyph_V011a               :
      constant Unicode_Char := 16#13379#;
   Egyptian_Hieroglyph_V011b               :
      constant Unicode_Char := 16#1337A#;
   Egyptian_Hieroglyph_V011c               :
      constant Unicode_Char := 16#1337B#;
   Egyptian_Hieroglyph_V012                :
      constant Unicode_Char := 16#1337C#;
   Egyptian_Hieroglyph_V012a               :
      constant Unicode_Char := 16#1337D#;
   Egyptian_Hieroglyph_V012b               :
      constant Unicode_Char := 16#1337E#;
   Egyptian_Hieroglyph_V013                :
      constant Unicode_Char := 16#1337F#;
   Egyptian_Hieroglyph_V014                :
      constant Unicode_Char := 16#13380#;
   Egyptian_Hieroglyph_V015                :
      constant Unicode_Char := 16#13381#;
   Egyptian_Hieroglyph_V016                :
      constant Unicode_Char := 16#13382#;
   Egyptian_Hieroglyph_V017                :
      constant Unicode_Char := 16#13383#;
   Egyptian_Hieroglyph_V018                :
      constant Unicode_Char := 16#13384#;
   Egyptian_Hieroglyph_V019                :
      constant Unicode_Char := 16#13385#;
   Egyptian_Hieroglyph_V020                :
      constant Unicode_Char := 16#13386#;
   Egyptian_Hieroglyph_V020a               :
      constant Unicode_Char := 16#13387#;
   Egyptian_Hieroglyph_V020b               :
      constant Unicode_Char := 16#13388#;
   Egyptian_Hieroglyph_V020c               :
      constant Unicode_Char := 16#13389#;
   Egyptian_Hieroglyph_V020d               :
      constant Unicode_Char := 16#1338A#;
   Egyptian_Hieroglyph_V020e               :
      constant Unicode_Char := 16#1338B#;
   Egyptian_Hieroglyph_V020f               :
      constant Unicode_Char := 16#1338C#;
   Egyptian_Hieroglyph_V020g               :
      constant Unicode_Char := 16#1338D#;
   Egyptian_Hieroglyph_V020h               :
      constant Unicode_Char := 16#1338E#;
   Egyptian_Hieroglyph_V020i               :
      constant Unicode_Char := 16#1338F#;
   Egyptian_Hieroglyph_V020j               :
      constant Unicode_Char := 16#13390#;
   Egyptian_Hieroglyph_V020k               :
      constant Unicode_Char := 16#13391#;
   Egyptian_Hieroglyph_V020l               :
      constant Unicode_Char := 16#13392#;
   Egyptian_Hieroglyph_V021                :
      constant Unicode_Char := 16#13393#;
   Egyptian_Hieroglyph_V022                :
      constant Unicode_Char := 16#13394#;
   Egyptian_Hieroglyph_V023                :
      constant Unicode_Char := 16#13395#;
   Egyptian_Hieroglyph_V023a               :
      constant Unicode_Char := 16#13396#;
   Egyptian_Hieroglyph_V024                :
      constant Unicode_Char := 16#13397#;
   Egyptian_Hieroglyph_V025                :
      constant Unicode_Char := 16#13398#;
   Egyptian_Hieroglyph_V026                :
      constant Unicode_Char := 16#13399#;
   Egyptian_Hieroglyph_V027                :
      constant Unicode_Char := 16#1339A#;
   Egyptian_Hieroglyph_V028                :
      constant Unicode_Char := 16#1339B#;
   Egyptian_Hieroglyph_V028a               :
      constant Unicode_Char := 16#1339C#;
   Egyptian_Hieroglyph_V029                :
      constant Unicode_Char := 16#1339D#;
   Egyptian_Hieroglyph_V029a               :
      constant Unicode_Char := 16#1339E#;
   Egyptian_Hieroglyph_V030                :
      constant Unicode_Char := 16#1339F#;
   Egyptian_Hieroglyph_V030a               :
      constant Unicode_Char := 16#133A0#;
   Egyptian_Hieroglyph_V031                :
      constant Unicode_Char := 16#133A1#;
   Egyptian_Hieroglyph_V031a               :
      constant Unicode_Char := 16#133A2#;
   Egyptian_Hieroglyph_V032                :
      constant Unicode_Char := 16#133A3#;
   Egyptian_Hieroglyph_V033                :
      constant Unicode_Char := 16#133A4#;
   Egyptian_Hieroglyph_V033a               :
      constant Unicode_Char := 16#133A5#;
   Egyptian_Hieroglyph_V034                :
      constant Unicode_Char := 16#133A6#;
   Egyptian_Hieroglyph_V035                :
      constant Unicode_Char := 16#133A7#;
   Egyptian_Hieroglyph_V036                :
      constant Unicode_Char := 16#133A8#;
   Egyptian_Hieroglyph_V037                :
      constant Unicode_Char := 16#133A9#;
   Egyptian_Hieroglyph_V037a               :
      constant Unicode_Char := 16#133AA#;
   Egyptian_Hieroglyph_V038                :
      constant Unicode_Char := 16#133AB#;
   Egyptian_Hieroglyph_V039                :
      constant Unicode_Char := 16#133AC#;
   Egyptian_Hieroglyph_V040                :
      constant Unicode_Char := 16#133AD#;
   Egyptian_Hieroglyph_V040a               :
      constant Unicode_Char := 16#133AE#;
   Egyptian_Hieroglyph_W001                :
      constant Unicode_Char := 16#133AF#;
   Egyptian_Hieroglyph_W002                :
      constant Unicode_Char := 16#133B0#;
   Egyptian_Hieroglyph_W003                :
      constant Unicode_Char := 16#133B1#;
   Egyptian_Hieroglyph_W003a               :
      constant Unicode_Char := 16#133B2#;
   Egyptian_Hieroglyph_W004                :
      constant Unicode_Char := 16#133B3#;
   Egyptian_Hieroglyph_W005                :
      constant Unicode_Char := 16#133B4#;
   Egyptian_Hieroglyph_W006                :
      constant Unicode_Char := 16#133B5#;
   Egyptian_Hieroglyph_W007                :
      constant Unicode_Char := 16#133B6#;
   Egyptian_Hieroglyph_W008                :
      constant Unicode_Char := 16#133B7#;
   Egyptian_Hieroglyph_W009                :
      constant Unicode_Char := 16#133B8#;
   Egyptian_Hieroglyph_W009a               :
      constant Unicode_Char := 16#133B9#;
   Egyptian_Hieroglyph_W010                :
      constant Unicode_Char := 16#133BA#;
   Egyptian_Hieroglyph_W010a               :
      constant Unicode_Char := 16#133BB#;
   Egyptian_Hieroglyph_W011                :
      constant Unicode_Char := 16#133BC#;
   Egyptian_Hieroglyph_W012                :
      constant Unicode_Char := 16#133BD#;
   Egyptian_Hieroglyph_W013                :
      constant Unicode_Char := 16#133BE#;
   Egyptian_Hieroglyph_W014                :
      constant Unicode_Char := 16#133BF#;
   Egyptian_Hieroglyph_W014a               :
      constant Unicode_Char := 16#133C0#;
   Egyptian_Hieroglyph_W015                :
      constant Unicode_Char := 16#133C1#;
   Egyptian_Hieroglyph_W016                :
      constant Unicode_Char := 16#133C2#;
   Egyptian_Hieroglyph_W017                :
      constant Unicode_Char := 16#133C3#;
   Egyptian_Hieroglyph_W017a               :
      constant Unicode_Char := 16#133C4#;
   Egyptian_Hieroglyph_W018                :
      constant Unicode_Char := 16#133C5#;
   Egyptian_Hieroglyph_W018a               :
      constant Unicode_Char := 16#133C6#;
   Egyptian_Hieroglyph_W019                :
      constant Unicode_Char := 16#133C7#;
   Egyptian_Hieroglyph_W020                :
      constant Unicode_Char := 16#133C8#;
   Egyptian_Hieroglyph_W021                :
      constant Unicode_Char := 16#133C9#;
   Egyptian_Hieroglyph_W022                :
      constant Unicode_Char := 16#133CA#;
   Egyptian_Hieroglyph_W023                :
      constant Unicode_Char := 16#133CB#;
   Egyptian_Hieroglyph_W024                :
      constant Unicode_Char := 16#133CC#;
   Egyptian_Hieroglyph_W024a               :
      constant Unicode_Char := 16#133CD#;
   Egyptian_Hieroglyph_W025                :
      constant Unicode_Char := 16#133CE#;
   Egyptian_Hieroglyph_X001                :
      constant Unicode_Char := 16#133CF#;
   Egyptian_Hieroglyph_X002                :
      constant Unicode_Char := 16#133D0#;
   Egyptian_Hieroglyph_X003                :
      constant Unicode_Char := 16#133D1#;
   Egyptian_Hieroglyph_X004                :
      constant Unicode_Char := 16#133D2#;
   Egyptian_Hieroglyph_X004a               :
      constant Unicode_Char := 16#133D3#;
   Egyptian_Hieroglyph_X004b               :
      constant Unicode_Char := 16#133D4#;
   Egyptian_Hieroglyph_X005                :
      constant Unicode_Char := 16#133D5#;
   Egyptian_Hieroglyph_X006                :
      constant Unicode_Char := 16#133D6#;
   Egyptian_Hieroglyph_X006a               :
      constant Unicode_Char := 16#133D7#;
   Egyptian_Hieroglyph_X007                :
      constant Unicode_Char := 16#133D8#;
   Egyptian_Hieroglyph_X008                :
      constant Unicode_Char := 16#133D9#;
   Egyptian_Hieroglyph_X008a               :
      constant Unicode_Char := 16#133DA#;
   Egyptian_Hieroglyph_Y001                :
      constant Unicode_Char := 16#133DB#;
   Egyptian_Hieroglyph_Y001a               :
      constant Unicode_Char := 16#133DC#;
   Egyptian_Hieroglyph_Y002                :
      constant Unicode_Char := 16#133DD#;
   Egyptian_Hieroglyph_Y003                :
      constant Unicode_Char := 16#133DE#;
   Egyptian_Hieroglyph_Y004                :
      constant Unicode_Char := 16#133DF#;
   Egyptian_Hieroglyph_Y005                :
      constant Unicode_Char := 16#133E0#;
   Egyptian_Hieroglyph_Y006                :
      constant Unicode_Char := 16#133E1#;
   Egyptian_Hieroglyph_Y007                :
      constant Unicode_Char := 16#133E2#;
   Egyptian_Hieroglyph_Y008                :
      constant Unicode_Char := 16#133E3#;
   Egyptian_Hieroglyph_Z001                :
      constant Unicode_Char := 16#133E4#;
   Egyptian_Hieroglyph_Z002                :
      constant Unicode_Char := 16#133E5#;
   Egyptian_Hieroglyph_Z002a               :
      constant Unicode_Char := 16#133E6#;
   Egyptian_Hieroglyph_Z002b               :
      constant Unicode_Char := 16#133E7#;
   Egyptian_Hieroglyph_Z002c               :
      constant Unicode_Char := 16#133E8#;
   Egyptian_Hieroglyph_Z002d               :
      constant Unicode_Char := 16#133E9#;
   Egyptian_Hieroglyph_Z003                :
      constant Unicode_Char := 16#133EA#;
   Egyptian_Hieroglyph_Z003a               :
      constant Unicode_Char := 16#133EB#;
   Egyptian_Hieroglyph_Z003b               :
      constant Unicode_Char := 16#133EC#;
   Egyptian_Hieroglyph_Z004                :
      constant Unicode_Char := 16#133ED#;
   Egyptian_Hieroglyph_Z004a               :
      constant Unicode_Char := 16#133EE#;
   Egyptian_Hieroglyph_Z005                :
      constant Unicode_Char := 16#133EF#;
   Egyptian_Hieroglyph_Z005a               :
      constant Unicode_Char := 16#133F0#;
   Egyptian_Hieroglyph_Z006                :
      constant Unicode_Char := 16#133F1#;
   Egyptian_Hieroglyph_Z007                :
      constant Unicode_Char := 16#133F2#;
   Egyptian_Hieroglyph_Z008                :
      constant Unicode_Char := 16#133F3#;
   Egyptian_Hieroglyph_Z009                :
      constant Unicode_Char := 16#133F4#;
   Egyptian_Hieroglyph_Z010                :
      constant Unicode_Char := 16#133F5#;
   Egyptian_Hieroglyph_Z011                :
      constant Unicode_Char := 16#133F6#;
   Egyptian_Hieroglyph_Z012                :
      constant Unicode_Char := 16#133F7#;
   Egyptian_Hieroglyph_Z013                :
      constant Unicode_Char := 16#133F8#;
   Egyptian_Hieroglyph_Z014                :
      constant Unicode_Char := 16#133F9#;
   Egyptian_Hieroglyph_Z015                :
      constant Unicode_Char := 16#133FA#;
   Egyptian_Hieroglyph_Z015a               :
      constant Unicode_Char := 16#133FB#;
   Egyptian_Hieroglyph_Z015b               :
      constant Unicode_Char := 16#133FC#;
   Egyptian_Hieroglyph_Z015c               :
      constant Unicode_Char := 16#133FD#;
   Egyptian_Hieroglyph_Z015d               :
      constant Unicode_Char := 16#133FE#;
   Egyptian_Hieroglyph_Z015e               :
      constant Unicode_Char := 16#133FF#;
   Egyptian_Hieroglyph_Z015f               :
      constant Unicode_Char := 16#13400#;
   Egyptian_Hieroglyph_Z015g               :
      constant Unicode_Char := 16#13401#;
   Egyptian_Hieroglyph_Z015h               :
      constant Unicode_Char := 16#13402#;
   Egyptian_Hieroglyph_Z015i               :
      constant Unicode_Char := 16#13403#;
   Egyptian_Hieroglyph_Z016                :
      constant Unicode_Char := 16#13404#;
   Egyptian_Hieroglyph_Z016a               :
      constant Unicode_Char := 16#13405#;
   Egyptian_Hieroglyph_Z016b               :
      constant Unicode_Char := 16#13406#;
   Egyptian_Hieroglyph_Z016c               :
      constant Unicode_Char := 16#13407#;
   Egyptian_Hieroglyph_Z016d               :
      constant Unicode_Char := 16#13408#;
   Egyptian_Hieroglyph_Z016e               :
      constant Unicode_Char := 16#13409#;
   Egyptian_Hieroglyph_Z016f               :
      constant Unicode_Char := 16#1340A#;
   Egyptian_Hieroglyph_Z016g               :
      constant Unicode_Char := 16#1340B#;
   Egyptian_Hieroglyph_Z016h               :
      constant Unicode_Char := 16#1340C#;
   Egyptian_Hieroglyph_Aa001               :
      constant Unicode_Char := 16#1340D#;
   Egyptian_Hieroglyph_Aa002               :
      constant Unicode_Char := 16#1340E#;
   Egyptian_Hieroglyph_Aa003               :
      constant Unicode_Char := 16#1340F#;
   Egyptian_Hieroglyph_Aa004               :
      constant Unicode_Char := 16#13410#;
   Egyptian_Hieroglyph_Aa005               :
      constant Unicode_Char := 16#13411#;
   Egyptian_Hieroglyph_Aa006               :
      constant Unicode_Char := 16#13412#;
   Egyptian_Hieroglyph_Aa007               :
      constant Unicode_Char := 16#13413#;
   Egyptian_Hieroglyph_Aa007a              :
      constant Unicode_Char := 16#13414#;
   Egyptian_Hieroglyph_Aa007b              :
      constant Unicode_Char := 16#13415#;
   Egyptian_Hieroglyph_Aa008               :
      constant Unicode_Char := 16#13416#;
   Egyptian_Hieroglyph_Aa009               :
      constant Unicode_Char := 16#13417#;
   Egyptian_Hieroglyph_Aa010               :
      constant Unicode_Char := 16#13418#;
   Egyptian_Hieroglyph_Aa011               :
      constant Unicode_Char := 16#13419#;
   Egyptian_Hieroglyph_Aa012               :
      constant Unicode_Char := 16#1341A#;
   Egyptian_Hieroglyph_Aa013               :
      constant Unicode_Char := 16#1341B#;
   Egyptian_Hieroglyph_Aa014               :
      constant Unicode_Char := 16#1341C#;
   Egyptian_Hieroglyph_Aa015               :
      constant Unicode_Char := 16#1341D#;
   Egyptian_Hieroglyph_Aa016               :
      constant Unicode_Char := 16#1341E#;
   Egyptian_Hieroglyph_Aa017               :
      constant Unicode_Char := 16#1341F#;
   Egyptian_Hieroglyph_Aa018               :
      constant Unicode_Char := 16#13420#;
   Egyptian_Hieroglyph_Aa019               :
      constant Unicode_Char := 16#13421#;
   Egyptian_Hieroglyph_Aa020               :
      constant Unicode_Char := 16#13422#;
   Egyptian_Hieroglyph_Aa021               :
      constant Unicode_Char := 16#13423#;
   Egyptian_Hieroglyph_Aa022               :
      constant Unicode_Char := 16#13424#;
   Egyptian_Hieroglyph_Aa023               :
      constant Unicode_Char := 16#13425#;
   Egyptian_Hieroglyph_Aa024               :
      constant Unicode_Char := 16#13426#;
   Egyptian_Hieroglyph_Aa025               :
      constant Unicode_Char := 16#13427#;
   Egyptian_Hieroglyph_Aa026               :
      constant Unicode_Char := 16#13428#;
   Egyptian_Hieroglyph_Aa027               :
      constant Unicode_Char := 16#13429#;
   Egyptian_Hieroglyph_Aa028               :
      constant Unicode_Char := 16#1342A#;
   Egyptian_Hieroglyph_Aa029               :
      constant Unicode_Char := 16#1342B#;
   Egyptian_Hieroglyph_Aa030               :
      constant Unicode_Char := 16#1342C#;
   Egyptian_Hieroglyph_Aa031               :
      constant Unicode_Char := 16#1342D#;
   Egyptian_Hieroglyph_Aa032               :
      constant Unicode_Char := 16#1342E#;
end Unicode.Names.Egyptian_Hieroglyphs;
