--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Kayah_Li is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Kayah_Li_Digit_Zero                     : constant Unicode_Char := 16#A900#;
   Kayah_Li_Digit_One                      : constant Unicode_Char := 16#A901#;
   Kayah_Li_Digit_Two                      : constant Unicode_Char := 16#A902#;
   Kayah_Li_Digit_Three                    : constant Unicode_Char := 16#A903#;
   Kayah_Li_Digit_Four                     : constant Unicode_Char := 16#A904#;
   Kayah_Li_Digit_Five                     : constant Unicode_Char := 16#A905#;
   Kayah_Li_Digit_Six                      : constant Unicode_Char := 16#A906#;
   Kayah_Li_Digit_Seven                    : constant Unicode_Char := 16#A907#;
   Kayah_Li_Digit_Eight                    : constant Unicode_Char := 16#A908#;
   Kayah_Li_Digit_Nine                     : constant Unicode_Char := 16#A909#;
   Kayah_Li_Letter_Ka                      : constant Unicode_Char := 16#A90A#;
   Kayah_Li_Letter_Kha                     : constant Unicode_Char := 16#A90B#;
   Kayah_Li_Letter_Ga                      : constant Unicode_Char := 16#A90C#;
   Kayah_Li_Letter_Nga                     : constant Unicode_Char := 16#A90D#;
   Kayah_Li_Letter_Sa                      : constant Unicode_Char := 16#A90E#;
   Kayah_Li_Letter_Sha                     : constant Unicode_Char := 16#A90F#;
   Kayah_Li_Letter_Za                      : constant Unicode_Char := 16#A910#;
   Kayah_Li_Letter_Nya                     : constant Unicode_Char := 16#A911#;
   Kayah_Li_Letter_Ta                      : constant Unicode_Char := 16#A912#;
   Kayah_Li_Letter_Hta                     : constant Unicode_Char := 16#A913#;
   Kayah_Li_Letter_Na                      : constant Unicode_Char := 16#A914#;
   Kayah_Li_Letter_Pa                      : constant Unicode_Char := 16#A915#;
   Kayah_Li_Letter_Pha                     : constant Unicode_Char := 16#A916#;
   Kayah_Li_Letter_Ma                      : constant Unicode_Char := 16#A917#;
   Kayah_Li_Letter_Da                      : constant Unicode_Char := 16#A918#;
   Kayah_Li_Letter_Ba                      : constant Unicode_Char := 16#A919#;
   Kayah_Li_Letter_Ra                      : constant Unicode_Char := 16#A91A#;
   Kayah_Li_Letter_Ya                      : constant Unicode_Char := 16#A91B#;
   Kayah_Li_Letter_La                      : constant Unicode_Char := 16#A91C#;
   Kayah_Li_Letter_Wa                      : constant Unicode_Char := 16#A91D#;
   Kayah_Li_Letter_Tha                     : constant Unicode_Char := 16#A91E#;
   Kayah_Li_Letter_Ha                      : constant Unicode_Char := 16#A91F#;
   Kayah_Li_Letter_Va                      : constant Unicode_Char := 16#A920#;
   Kayah_Li_Letter_Ca                      : constant Unicode_Char := 16#A921#;
   Kayah_Li_Letter_A                       : constant Unicode_Char := 16#A922#;
   Kayah_Li_Letter_Oe                      : constant Unicode_Char := 16#A923#;
   Kayah_Li_Letter_I                       : constant Unicode_Char := 16#A924#;
   Kayah_Li_Letter_Oo                      : constant Unicode_Char := 16#A925#;
   Kayah_Li_Vowel_Ue                       : constant Unicode_Char := 16#A926#;
   Kayah_Li_Vowel_E                        : constant Unicode_Char := 16#A927#;
   Kayah_Li_Vowel_U                        : constant Unicode_Char := 16#A928#;
   Kayah_Li_Vowel_Ee                       : constant Unicode_Char := 16#A929#;
   Kayah_Li_Vowel_O                        : constant Unicode_Char := 16#A92A#;
   Kayah_Li_Tone_Plophu                    : constant Unicode_Char := 16#A92B#;
   Kayah_Li_Tone_Calya                     : constant Unicode_Char := 16#A92C#;
   Kayah_Li_Tone_Calya_Plophu              : constant Unicode_Char := 16#A92D#;
   Kayah_Li_Sign_Cwi                       : constant Unicode_Char := 16#A92E#;
   Kayah_Li_Sign_Shya                      : constant Unicode_Char := 16#A92F#;
end Unicode.Names.Kayah_Li;
