--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Saurashtra is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Saurashtra_Sign_Anusvara                : constant Unicode_Char := 16#A880#;
   Saurashtra_Sign_Visarga                 : constant Unicode_Char := 16#A881#;
   Saurashtra_Letter_A                     : constant Unicode_Char := 16#A882#;
   Saurashtra_Letter_Aa                    : constant Unicode_Char := 16#A883#;
   Saurashtra_Letter_I                     : constant Unicode_Char := 16#A884#;
   Saurashtra_Letter_Ii                    : constant Unicode_Char := 16#A885#;
   Saurashtra_Letter_U                     : constant Unicode_Char := 16#A886#;
   Saurashtra_Letter_Uu                    : constant Unicode_Char := 16#A887#;
   Saurashtra_Letter_Vocalic_R             : constant Unicode_Char := 16#A888#;
   Saurashtra_Letter_Vocalic_Rr            : constant Unicode_Char := 16#A889#;
   Saurashtra_Letter_Vocalic_L             : constant Unicode_Char := 16#A88A#;
   Saurashtra_Letter_Vocalic_Ll            : constant Unicode_Char := 16#A88B#;
   Saurashtra_Letter_E                     : constant Unicode_Char := 16#A88C#;
   Saurashtra_Letter_Ee                    : constant Unicode_Char := 16#A88D#;
   Saurashtra_Letter_Ai                    : constant Unicode_Char := 16#A88E#;
   Saurashtra_Letter_O                     : constant Unicode_Char := 16#A88F#;
   Saurashtra_Letter_Oo                    : constant Unicode_Char := 16#A890#;
   Saurashtra_Letter_Au                    : constant Unicode_Char := 16#A891#;
   Saurashtra_Letter_Ka                    : constant Unicode_Char := 16#A892#;
   Saurashtra_Letter_Kha                   : constant Unicode_Char := 16#A893#;
   Saurashtra_Letter_Ga                    : constant Unicode_Char := 16#A894#;
   Saurashtra_Letter_Gha                   : constant Unicode_Char := 16#A895#;
   Saurashtra_Letter_Nga                   : constant Unicode_Char := 16#A896#;
   Saurashtra_Letter_Ca                    : constant Unicode_Char := 16#A897#;
   Saurashtra_Letter_Cha                   : constant Unicode_Char := 16#A898#;
   Saurashtra_Letter_Ja                    : constant Unicode_Char := 16#A899#;
   Saurashtra_Letter_Jha                   : constant Unicode_Char := 16#A89A#;
   Saurashtra_Letter_Nya                   : constant Unicode_Char := 16#A89B#;
   Saurashtra_Letter_Tta                   : constant Unicode_Char := 16#A89C#;
   Saurashtra_Letter_Ttha                  : constant Unicode_Char := 16#A89D#;
   Saurashtra_Letter_Dda                   : constant Unicode_Char := 16#A89E#;
   Saurashtra_Letter_Ddha                  : constant Unicode_Char := 16#A89F#;
   Saurashtra_Letter_Nna                   : constant Unicode_Char := 16#A8A0#;
   Saurashtra_Letter_Ta                    : constant Unicode_Char := 16#A8A1#;
   Saurashtra_Letter_Tha                   : constant Unicode_Char := 16#A8A2#;
   Saurashtra_Letter_Da                    : constant Unicode_Char := 16#A8A3#;
   Saurashtra_Letter_Dha                   : constant Unicode_Char := 16#A8A4#;
   Saurashtra_Letter_Na                    : constant Unicode_Char := 16#A8A5#;
   Saurashtra_Letter_Pa                    : constant Unicode_Char := 16#A8A6#;
   Saurashtra_Letter_Pha                   : constant Unicode_Char := 16#A8A7#;
   Saurashtra_Letter_Ba                    : constant Unicode_Char := 16#A8A8#;
   Saurashtra_Letter_Bha                   : constant Unicode_Char := 16#A8A9#;
   Saurashtra_Letter_Ma                    : constant Unicode_Char := 16#A8AA#;
   Saurashtra_Letter_Ya                    : constant Unicode_Char := 16#A8AB#;
   Saurashtra_Letter_Ra                    : constant Unicode_Char := 16#A8AC#;
   Saurashtra_Letter_La                    : constant Unicode_Char := 16#A8AD#;
   Saurashtra_Letter_Va                    : constant Unicode_Char := 16#A8AE#;
   Saurashtra_Letter_Sha                   : constant Unicode_Char := 16#A8AF#;
   Saurashtra_Letter_Ssa                   : constant Unicode_Char := 16#A8B0#;
   Saurashtra_Letter_Sa                    : constant Unicode_Char := 16#A8B1#;
   Saurashtra_Letter_Ha                    : constant Unicode_Char := 16#A8B2#;
   Saurashtra_Letter_Lla                   : constant Unicode_Char := 16#A8B3#;
   Saurashtra_Consonant_Sign_Haaru         : constant Unicode_Char := 16#A8B4#;
   Saurashtra_Vowel_Sign_Aa                : constant Unicode_Char := 16#A8B5#;
   Saurashtra_Vowel_Sign_I                 : constant Unicode_Char := 16#A8B6#;
   Saurashtra_Vowel_Sign_Ii                : constant Unicode_Char := 16#A8B7#;
   Saurashtra_Vowel_Sign_U                 : constant Unicode_Char := 16#A8B8#;
   Saurashtra_Vowel_Sign_Uu                : constant Unicode_Char := 16#A8B9#;
   Saurashtra_Vowel_Sign_Vocalic_R         : constant Unicode_Char := 16#A8BA#;
   Saurashtra_Vowel_Sign_Vocalic_Rr        : constant Unicode_Char := 16#A8BB#;
   Saurashtra_Vowel_Sign_Vocalic_L         : constant Unicode_Char := 16#A8BC#;
   Saurashtra_Vowel_Sign_Vocalic_Ll        : constant Unicode_Char := 16#A8BD#;
   Saurashtra_Vowel_Sign_E                 : constant Unicode_Char := 16#A8BE#;
   Saurashtra_Vowel_Sign_Ee                : constant Unicode_Char := 16#A8BF#;
   Saurashtra_Vowel_Sign_Ai                : constant Unicode_Char := 16#A8C0#;
   Saurashtra_Vowel_Sign_O                 : constant Unicode_Char := 16#A8C1#;
   Saurashtra_Vowel_Sign_Oo                : constant Unicode_Char := 16#A8C2#;
   Saurashtra_Vowel_Sign_Au                : constant Unicode_Char := 16#A8C3#;
   Saurashtra_Sign_Virama                  : constant Unicode_Char := 16#A8C4#;
   Saurashtra_Danda                        : constant Unicode_Char := 16#A8CE#;
   Saurashtra_Double_Danda                 : constant Unicode_Char := 16#A8CF#;
   Saurashtra_Digit_Zero                   : constant Unicode_Char := 16#A8D0#;
   Saurashtra_Digit_One                    : constant Unicode_Char := 16#A8D1#;
   Saurashtra_Digit_Two                    : constant Unicode_Char := 16#A8D2#;
   Saurashtra_Digit_Three                  : constant Unicode_Char := 16#A8D3#;
   Saurashtra_Digit_Four                   : constant Unicode_Char := 16#A8D4#;
   Saurashtra_Digit_Five                   : constant Unicode_Char := 16#A8D5#;
   Saurashtra_Digit_Six                    : constant Unicode_Char := 16#A8D6#;
   Saurashtra_Digit_Seven                  : constant Unicode_Char := 16#A8D7#;
   Saurashtra_Digit_Eight                  : constant Unicode_Char := 16#A8D8#;
   Saurashtra_Digit_Nine                   : constant Unicode_Char := 16#A8D9#;
end Unicode.Names.Saurashtra;
