--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Arrows is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Leftwards_Arrow                         : constant Unicode_Char := 16#2190#;
   Upwards_Arrow                           : constant Unicode_Char := 16#2191#;
   Rightwards_Arrow                        : constant Unicode_Char := 16#2192#;
   Downwards_Arrow                         : constant Unicode_Char := 16#2193#;
   Left_Right_Arrow                        : constant Unicode_Char := 16#2194#;
   Up_Down_Arrow                           : constant Unicode_Char := 16#2195#;
   North_West_Arrow                        : constant Unicode_Char := 16#2196#;
   North_East_Arrow                        : constant Unicode_Char := 16#2197#;
   South_East_Arrow                        : constant Unicode_Char := 16#2198#;
   South_West_Arrow                        : constant Unicode_Char := 16#2199#;
   Leftwards_Arrow_With_Stroke             : constant Unicode_Char := 16#219A#;
   Rightwards_Arrow_With_Stroke            : constant Unicode_Char := 16#219B#;
   Leftwards_Wave_Arrow                    : constant Unicode_Char := 16#219C#;
   Rightwards_Wave_Arrow                   : constant Unicode_Char := 16#219D#;
   Leftwards_Two_Headed_Arrow              : constant Unicode_Char := 16#219E#;
   Upwards_Two_Headed_Arrow                : constant Unicode_Char := 16#219F#;
   Rightwards_Two_Headed_Arrow             : constant Unicode_Char := 16#21A0#;
   Downwards_Two_Headed_Arrow              : constant Unicode_Char := 16#21A1#;
   Leftwards_Arrow_With_Tail               : constant Unicode_Char := 16#21A2#;
   Rightwards_Arrow_With_Tail              : constant Unicode_Char := 16#21A3#;
   Leftwards_Arrow_From_Bar                : constant Unicode_Char := 16#21A4#;
   Upwards_Arrow_From_Bar                  : constant Unicode_Char := 16#21A5#;
   Rightwards_Arrow_From_Bar               : constant Unicode_Char := 16#21A6#;
   Downwards_Arrow_From_Bar                : constant Unicode_Char := 16#21A7#;
   Up_Down_Arrow_With_Base                 : constant Unicode_Char := 16#21A8#;
   Leftwards_Arrow_With_Hook               : constant Unicode_Char := 16#21A9#;
   Rightwards_Arrow_With_Hook              : constant Unicode_Char := 16#21AA#;
   Leftwards_Arrow_With_Loop               : constant Unicode_Char := 16#21AB#;
   Rightwards_Arrow_With_Loop              : constant Unicode_Char := 16#21AC#;
   Left_Right_Wave_Arrow                   : constant Unicode_Char := 16#21AD#;
   Left_Right_Arrow_With_Stroke            : constant Unicode_Char := 16#21AE#;
   Downwards_Zigzag_Arrow                  : constant Unicode_Char := 16#21AF#;
   Upwards_Arrow_With_Tip_Leftwards        : constant Unicode_Char := 16#21B0#;
   Upwards_Arrow_With_Tip_Rightwards       : constant Unicode_Char := 16#21B1#;
   Downwards_Arrow_With_Tip_Leftwards      : constant Unicode_Char := 16#21B2#;
   Downwards_Arrow_With_Tip_Rightwards     : constant Unicode_Char := 16#21B3#;
   Rightwards_Arrow_With_Corner_Downwards  : constant Unicode_Char := 16#21B4#;
   Downwards_Arrow_With_Corner_Leftwards   : constant Unicode_Char := 16#21B5#;
   Anticlockwise_Top_Semicircle_Arrow      : constant Unicode_Char := 16#21B6#;
   Clockwise_Top_Semicircle_Arrow          : constant Unicode_Char := 16#21B7#;
   North_West_Arrow_To_Long_Bar            : constant Unicode_Char := 16#21B8#;
   Leftwards_Arrow_To_Bar_Over_Rightwards_Arrow_To_Bar :
      constant Unicode_Char := 16#21B9#;
   Anticlockwise_Open_Circle_Arrow         : constant Unicode_Char := 16#21BA#;
   Clockwise_Open_Circle_Arrow             : constant Unicode_Char := 16#21BB#;
   Leftwards_Harpoon_With_Barb_Upwards     : constant Unicode_Char := 16#21BC#;
   Leftwards_Harpoon_With_Barb_Downwards   : constant Unicode_Char := 16#21BD#;
   Upwards_Harpoon_With_Barb_Rightwards    : constant Unicode_Char := 16#21BE#;
   Upwards_Harpoon_With_Barb_Leftwards     : constant Unicode_Char := 16#21BF#;
   Rightwards_Harpoon_With_Barb_Upwards    : constant Unicode_Char := 16#21C0#;
   Rightwards_Harpoon_With_Barb_Downwards  : constant Unicode_Char := 16#21C1#;
   Downwards_Harpoon_With_Barb_Rightwards  : constant Unicode_Char := 16#21C2#;
   Downwards_Harpoon_With_Barb_Leftwards   : constant Unicode_Char := 16#21C3#;
   Rightwards_Arrow_Over_Leftwards_Arrow   : constant Unicode_Char := 16#21C4#;
   Upwards_Arrow_Leftwards_Of_Downwards_Arrow :
      constant Unicode_Char := 16#21C5#;
   Leftwards_Arrow_Over_Rightwards_Arrow   : constant Unicode_Char := 16#21C6#;
   Leftwards_Paired_Arrows                 : constant Unicode_Char := 16#21C7#;
   Upwards_Paired_Arrows                   : constant Unicode_Char := 16#21C8#;
   Rightwards_Paired_Arrows                : constant Unicode_Char := 16#21C9#;
   Downwards_Paired_Arrows                 : constant Unicode_Char := 16#21CA#;
   Leftwards_Harpoon_Over_Rightwards_Harpoon :
      constant Unicode_Char := 16#21CB#;
   Rightwards_Harpoon_Over_Leftwards_Harpoon :
      constant Unicode_Char := 16#21CC#;
   Leftwards_Double_Arrow_With_Stroke      : constant Unicode_Char := 16#21CD#;
   Left_Right_Double_Arrow_With_Stroke     : constant Unicode_Char := 16#21CE#;
   Rightwards_Double_Arrow_With_Stroke     : constant Unicode_Char := 16#21CF#;
   Leftwards_Double_Arrow                  : constant Unicode_Char := 16#21D0#;
   Upwards_Double_Arrow                    : constant Unicode_Char := 16#21D1#;
   Rightwards_Double_Arrow                 : constant Unicode_Char := 16#21D2#;
   Downwards_Double_Arrow                  : constant Unicode_Char := 16#21D3#;
   Left_Right_Double_Arrow                 : constant Unicode_Char := 16#21D4#;
   Up_Down_Double_Arrow                    : constant Unicode_Char := 16#21D5#;
   North_West_Double_Arrow                 : constant Unicode_Char := 16#21D6#;
   North_East_Double_Arrow                 : constant Unicode_Char := 16#21D7#;
   South_East_Double_Arrow                 : constant Unicode_Char := 16#21D8#;
   South_West_Double_Arrow                 : constant Unicode_Char := 16#21D9#;
   Leftwards_Triple_Arrow                  : constant Unicode_Char := 16#21DA#;
   Rightwards_Triple_Arrow                 : constant Unicode_Char := 16#21DB#;
   Leftwards_Squiggle_Arrow                : constant Unicode_Char := 16#21DC#;
   Rightwards_Squiggle_Arrow               : constant Unicode_Char := 16#21DD#;
   Upwards_Arrow_With_Double_Stroke        : constant Unicode_Char := 16#21DE#;
   Downwards_Arrow_With_Double_Stroke      : constant Unicode_Char := 16#21DF#;
   Leftwards_Dashed_Arrow                  : constant Unicode_Char := 16#21E0#;
   Upwards_Dashed_Arrow                    : constant Unicode_Char := 16#21E1#;
   Rightwards_Dashed_Arrow                 : constant Unicode_Char := 16#21E2#;
   Downwards_Dashed_Arrow                  : constant Unicode_Char := 16#21E3#;
   Leftwards_Arrow_To_Bar                  : constant Unicode_Char := 16#21E4#;
   Rightwards_Arrow_To_Bar                 : constant Unicode_Char := 16#21E5#;
   Leftwards_White_Arrow                   : constant Unicode_Char := 16#21E6#;
   Upwards_White_Arrow                     : constant Unicode_Char := 16#21E7#;
   Rightwards_White_Arrow                  : constant Unicode_Char := 16#21E8#;
   Downwards_White_Arrow                   : constant Unicode_Char := 16#21E9#;
   Upwards_White_Arrow_From_Bar            : constant Unicode_Char := 16#21EA#;
   Upwards_White_Arrow_On_Pedestal         : constant Unicode_Char := 16#21EB#;
   Upwards_White_Arrow_On_Pedestal_With_Horizontal_Bar :
      constant Unicode_Char := 16#21EC#;
   Upwards_White_Arrow_On_Pedestal_With_Vertical_Bar :
      constant Unicode_Char := 16#21ED#;
   Upwards_White_Double_Arrow              : constant Unicode_Char := 16#21EE#;
   Upwards_White_Double_Arrow_On_Pedestal  : constant Unicode_Char := 16#21EF#;
   Rightwards_White_Arrow_From_Wall        : constant Unicode_Char := 16#21F0#;
   North_West_Arrow_To_Corner              : constant Unicode_Char := 16#21F1#;
   South_East_Arrow_To_Corner              : constant Unicode_Char := 16#21F2#;
   Up_Down_White_Arrow                     : constant Unicode_Char := 16#21F3#;
   Right_Arrow_With_Small_Circle           : constant Unicode_Char := 16#21F4#;
   Downwards_Arrow_Leftwards_Of_Upwards_Arrow :
      constant Unicode_Char := 16#21F5#;
   Three_Rightwards_Arrows                 : constant Unicode_Char := 16#21F6#;
   Leftwards_Arrow_With_Vertical_Stroke    : constant Unicode_Char := 16#21F7#;
   Rightwards_Arrow_With_Vertical_Stroke   : constant Unicode_Char := 16#21F8#;
   Left_Right_Arrow_With_Vertical_Stroke   : constant Unicode_Char := 16#21F9#;
   Leftwards_Arrow_With_Double_Vertical_Stroke :
      constant Unicode_Char := 16#21FA#;
   Rightwards_Arrow_With_Double_Vertical_Stroke :
      constant Unicode_Char := 16#21FB#;
   Left_Right_Arrow_With_Double_Vertical_Stroke :
      constant Unicode_Char := 16#21FC#;
   Leftwards_Open_Headed_Arrow             : constant Unicode_Char := 16#21FD#;
   Rightwards_Open_Headed_Arrow            : constant Unicode_Char := 16#21FE#;
   Left_Right_Open_Headed_Arrow            : constant Unicode_Char := 16#21FF#;
end Unicode.Names.Arrows;
