--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Tai_Viet is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Tai_Viet_Letter_Low_Ko                  : constant Unicode_Char := 16#AA80#;
   Tai_Viet_Letter_High_Ko                 : constant Unicode_Char := 16#AA81#;
   Tai_Viet_Letter_Low_Kho                 : constant Unicode_Char := 16#AA82#;
   Tai_Viet_Letter_High_Kho                : constant Unicode_Char := 16#AA83#;
   Tai_Viet_Letter_Low_Khho                : constant Unicode_Char := 16#AA84#;
   Tai_Viet_Letter_High_Khho               : constant Unicode_Char := 16#AA85#;
   Tai_Viet_Letter_Low_Go                  : constant Unicode_Char := 16#AA86#;
   Tai_Viet_Letter_High_Go                 : constant Unicode_Char := 16#AA87#;
   Tai_Viet_Letter_Low_Ngo                 : constant Unicode_Char := 16#AA88#;
   Tai_Viet_Letter_High_Ngo                : constant Unicode_Char := 16#AA89#;
   Tai_Viet_Letter_Low_Co                  : constant Unicode_Char := 16#AA8A#;
   Tai_Viet_Letter_High_Co                 : constant Unicode_Char := 16#AA8B#;
   Tai_Viet_Letter_Low_Cho                 : constant Unicode_Char := 16#AA8C#;
   Tai_Viet_Letter_High_Cho                : constant Unicode_Char := 16#AA8D#;
   Tai_Viet_Letter_Low_So                  : constant Unicode_Char := 16#AA8E#;
   Tai_Viet_Letter_High_So                 : constant Unicode_Char := 16#AA8F#;
   Tai_Viet_Letter_Low_Nyo                 : constant Unicode_Char := 16#AA90#;
   Tai_Viet_Letter_High_Nyo                : constant Unicode_Char := 16#AA91#;
   Tai_Viet_Letter_Low_Do                  : constant Unicode_Char := 16#AA92#;
   Tai_Viet_Letter_High_Do                 : constant Unicode_Char := 16#AA93#;
   Tai_Viet_Letter_Low_To                  : constant Unicode_Char := 16#AA94#;
   Tai_Viet_Letter_High_To                 : constant Unicode_Char := 16#AA95#;
   Tai_Viet_Letter_Low_Tho                 : constant Unicode_Char := 16#AA96#;
   Tai_Viet_Letter_High_Tho                : constant Unicode_Char := 16#AA97#;
   Tai_Viet_Letter_Low_No                  : constant Unicode_Char := 16#AA98#;
   Tai_Viet_Letter_High_No                 : constant Unicode_Char := 16#AA99#;
   Tai_Viet_Letter_Low_Bo                  : constant Unicode_Char := 16#AA9A#;
   Tai_Viet_Letter_High_Bo                 : constant Unicode_Char := 16#AA9B#;
   Tai_Viet_Letter_Low_Po                  : constant Unicode_Char := 16#AA9C#;
   Tai_Viet_Letter_High_Po                 : constant Unicode_Char := 16#AA9D#;
   Tai_Viet_Letter_Low_Pho                 : constant Unicode_Char := 16#AA9E#;
   Tai_Viet_Letter_High_Pho                : constant Unicode_Char := 16#AA9F#;
   Tai_Viet_Letter_Low_Fo                  : constant Unicode_Char := 16#AAA0#;
   Tai_Viet_Letter_High_Fo                 : constant Unicode_Char := 16#AAA1#;
   Tai_Viet_Letter_Low_Mo                  : constant Unicode_Char := 16#AAA2#;
   Tai_Viet_Letter_High_Mo                 : constant Unicode_Char := 16#AAA3#;
   Tai_Viet_Letter_Low_Yo                  : constant Unicode_Char := 16#AAA4#;
   Tai_Viet_Letter_High_Yo                 : constant Unicode_Char := 16#AAA5#;
   Tai_Viet_Letter_Low_Ro                  : constant Unicode_Char := 16#AAA6#;
   Tai_Viet_Letter_High_Ro                 : constant Unicode_Char := 16#AAA7#;
   Tai_Viet_Letter_Low_Lo                  : constant Unicode_Char := 16#AAA8#;
   Tai_Viet_Letter_High_Lo                 : constant Unicode_Char := 16#AAA9#;
   Tai_Viet_Letter_Low_Vo                  : constant Unicode_Char := 16#AAAA#;
   Tai_Viet_Letter_High_Vo                 : constant Unicode_Char := 16#AAAB#;
   Tai_Viet_Letter_Low_Ho                  : constant Unicode_Char := 16#AAAC#;
   Tai_Viet_Letter_High_Ho                 : constant Unicode_Char := 16#AAAD#;
   Tai_Viet_Letter_Low_O                   : constant Unicode_Char := 16#AAAE#;
   Tai_Viet_Letter_High_O                  : constant Unicode_Char := 16#AAAF#;
   Tai_Viet_Mai_Kang                       : constant Unicode_Char := 16#AAB0#;
   Tai_Viet_Vowel_Aa                       : constant Unicode_Char := 16#AAB1#;
   Tai_Viet_Vowel_I                        : constant Unicode_Char := 16#AAB2#;
   Tai_Viet_Vowel_Ue                       : constant Unicode_Char := 16#AAB3#;
   Tai_Viet_Vowel_U                        : constant Unicode_Char := 16#AAB4#;
   Tai_Viet_Vowel_E                        : constant Unicode_Char := 16#AAB5#;
   Tai_Viet_Vowel_O                        : constant Unicode_Char := 16#AAB6#;
   Tai_Viet_Mai_Khit                       : constant Unicode_Char := 16#AAB7#;
   Tai_Viet_Vowel_Ia                       : constant Unicode_Char := 16#AAB8#;
   Tai_Viet_Vowel_Uea                      : constant Unicode_Char := 16#AAB9#;
   Tai_Viet_Vowel_Ua                       : constant Unicode_Char := 16#AABA#;
   Tai_Viet_Vowel_Aue                      : constant Unicode_Char := 16#AABB#;
   Tai_Viet_Vowel_Ay                       : constant Unicode_Char := 16#AABC#;
   Tai_Viet_Vowel_An                       : constant Unicode_Char := 16#AABD#;
   Tai_Viet_Vowel_Am                       : constant Unicode_Char := 16#AABE#;
   Tai_Viet_Tone_Mai_Ek                    : constant Unicode_Char := 16#AABF#;
   Tai_Viet_Tone_Mai_Nueng                 : constant Unicode_Char := 16#AAC0#;
   Tai_Viet_Tone_Mai_Tho                   : constant Unicode_Char := 16#AAC1#;
   Tai_Viet_Tone_Mai_Song                  : constant Unicode_Char := 16#AAC2#;
   Tai_Viet_Symbol_Kon                     : constant Unicode_Char := 16#AADB#;
   Tai_Viet_Symbol_Nueng                   : constant Unicode_Char := 16#AADC#;
   Tai_Viet_Symbol_Sam                     : constant Unicode_Char := 16#AADD#;
   Tai_Viet_Symbol_Ho_Hoi                  : constant Unicode_Char := 16#AADE#;
   Tai_Viet_Symbol_Koi_Koi                 : constant Unicode_Char := 16#AADF#;
end Unicode.Names.Tai_Viet;
