--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Armenian is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Armenian_Capital_Letter_Ayb             : constant Unicode_Char := 16#0531#;
   Armenian_Capital_Letter_Ben             : constant Unicode_Char := 16#0532#;
   Armenian_Capital_Letter_Gim             : constant Unicode_Char := 16#0533#;
   Armenian_Capital_Letter_Da              : constant Unicode_Char := 16#0534#;
   Armenian_Capital_Letter_Ech             : constant Unicode_Char := 16#0535#;
   Armenian_Capital_Letter_Za              : constant Unicode_Char := 16#0536#;
   Armenian_Capital_Letter_Eh              : constant Unicode_Char := 16#0537#;
   Armenian_Capital_Letter_Et              : constant Unicode_Char := 16#0538#;
   Armenian_Capital_Letter_To              : constant Unicode_Char := 16#0539#;
   Armenian_Capital_Letter_Zhe             : constant Unicode_Char := 16#053A#;
   Armenian_Capital_Letter_Ini             : constant Unicode_Char := 16#053B#;
   Armenian_Capital_Letter_Liwn            : constant Unicode_Char := 16#053C#;
   Armenian_Capital_Letter_Xeh             : constant Unicode_Char := 16#053D#;
   Armenian_Capital_Letter_Ca              : constant Unicode_Char := 16#053E#;
   Armenian_Capital_Letter_Ken             : constant Unicode_Char := 16#053F#;
   Armenian_Capital_Letter_Ho              : constant Unicode_Char := 16#0540#;
   Armenian_Capital_Letter_Ja              : constant Unicode_Char := 16#0541#;
   Armenian_Capital_Letter_Ghad            : constant Unicode_Char := 16#0542#;
   Armenian_Capital_Letter_Cheh            : constant Unicode_Char := 16#0543#;
   Armenian_Capital_Letter_Men             : constant Unicode_Char := 16#0544#;
   Armenian_Capital_Letter_Yi              : constant Unicode_Char := 16#0545#;
   Armenian_Capital_Letter_Now             : constant Unicode_Char := 16#0546#;
   Armenian_Capital_Letter_Sha             : constant Unicode_Char := 16#0547#;
   Armenian_Capital_Letter_Vo              : constant Unicode_Char := 16#0548#;
   Armenian_Capital_Letter_Cha             : constant Unicode_Char := 16#0549#;
   Armenian_Capital_Letter_Peh             : constant Unicode_Char := 16#054A#;
   Armenian_Capital_Letter_Jheh            : constant Unicode_Char := 16#054B#;
   Armenian_Capital_Letter_Ra              : constant Unicode_Char := 16#054C#;
   Armenian_Capital_Letter_Seh             : constant Unicode_Char := 16#054D#;
   Armenian_Capital_Letter_Vew             : constant Unicode_Char := 16#054E#;
   Armenian_Capital_Letter_Tiwn            : constant Unicode_Char := 16#054F#;
   Armenian_Capital_Letter_Reh             : constant Unicode_Char := 16#0550#;
   Armenian_Capital_Letter_Co              : constant Unicode_Char := 16#0551#;
   Armenian_Capital_Letter_Yiwn            : constant Unicode_Char := 16#0552#;
   Armenian_Capital_Letter_Piwr            : constant Unicode_Char := 16#0553#;
   Armenian_Capital_Letter_Keh             : constant Unicode_Char := 16#0554#;
   Armenian_Capital_Letter_Oh              : constant Unicode_Char := 16#0555#;
   Armenian_Capital_Letter_Feh             : constant Unicode_Char := 16#0556#;
   Armenian_Modifier_Letter_Left_Half_Ring : constant Unicode_Char := 16#0559#;
   Armenian_Apostrophe                     : constant Unicode_Char := 16#055A#;
   Armenian_Emphasis_Mark                  : constant Unicode_Char := 16#055B#;
   Armenian_Exclamation_Mark               : constant Unicode_Char := 16#055C#;
   Armenian_Comma                          : constant Unicode_Char := 16#055D#;
   Armenian_Question_Mark                  : constant Unicode_Char := 16#055E#;
   Armenian_Abbreviation_Mark              : constant Unicode_Char := 16#055F#;
   Armenian_Small_Letter_Ayb               : constant Unicode_Char := 16#0561#;
   Armenian_Small_Letter_Ben               : constant Unicode_Char := 16#0562#;
   Armenian_Small_Letter_Gim               : constant Unicode_Char := 16#0563#;
   Armenian_Small_Letter_Da                : constant Unicode_Char := 16#0564#;
   Armenian_Small_Letter_Ech               : constant Unicode_Char := 16#0565#;
   Armenian_Small_Letter_Za                : constant Unicode_Char := 16#0566#;
   Armenian_Small_Letter_Eh                : constant Unicode_Char := 16#0567#;
   Armenian_Small_Letter_Et                : constant Unicode_Char := 16#0568#;
   Armenian_Small_Letter_To                : constant Unicode_Char := 16#0569#;
   Armenian_Small_Letter_Zhe               : constant Unicode_Char := 16#056A#;
   Armenian_Small_Letter_Ini               : constant Unicode_Char := 16#056B#;
   Armenian_Small_Letter_Liwn              : constant Unicode_Char := 16#056C#;
   Armenian_Small_Letter_Xeh               : constant Unicode_Char := 16#056D#;
   Armenian_Small_Letter_Ca                : constant Unicode_Char := 16#056E#;
   Armenian_Small_Letter_Ken               : constant Unicode_Char := 16#056F#;
   Armenian_Small_Letter_Ho                : constant Unicode_Char := 16#0570#;
   Armenian_Small_Letter_Ja                : constant Unicode_Char := 16#0571#;
   Armenian_Small_Letter_Ghad              : constant Unicode_Char := 16#0572#;
   Armenian_Small_Letter_Cheh              : constant Unicode_Char := 16#0573#;
   Armenian_Small_Letter_Men               : constant Unicode_Char := 16#0574#;
   Armenian_Small_Letter_Yi                : constant Unicode_Char := 16#0575#;
   Armenian_Small_Letter_Now               : constant Unicode_Char := 16#0576#;
   Armenian_Small_Letter_Sha               : constant Unicode_Char := 16#0577#;
   Armenian_Small_Letter_Vo                : constant Unicode_Char := 16#0578#;
   Armenian_Small_Letter_Cha               : constant Unicode_Char := 16#0579#;
   Armenian_Small_Letter_Peh               : constant Unicode_Char := 16#057A#;
   Armenian_Small_Letter_Jheh              : constant Unicode_Char := 16#057B#;
   Armenian_Small_Letter_Ra                : constant Unicode_Char := 16#057C#;
   Armenian_Small_Letter_Seh               : constant Unicode_Char := 16#057D#;
   Armenian_Small_Letter_Vew               : constant Unicode_Char := 16#057E#;
   Armenian_Small_Letter_Tiwn              : constant Unicode_Char := 16#057F#;
   Armenian_Small_Letter_Reh               : constant Unicode_Char := 16#0580#;
   Armenian_Small_Letter_Co                : constant Unicode_Char := 16#0581#;
   Armenian_Small_Letter_Yiwn              : constant Unicode_Char := 16#0582#;
   Armenian_Small_Letter_Piwr              : constant Unicode_Char := 16#0583#;
   Armenian_Small_Letter_Keh               : constant Unicode_Char := 16#0584#;
   Armenian_Small_Letter_Oh                : constant Unicode_Char := 16#0585#;
   Armenian_Small_Letter_Feh               : constant Unicode_Char := 16#0586#;
   Armenian_Small_Ligature_Ech_Yiwn        : constant Unicode_Char := 16#0587#;
   Armenian_Full_Stop                      : constant Unicode_Char := 16#0589#;
   Armenian_Hyphen                         : constant Unicode_Char := 16#058A#;
   Right_Facing_Armenian_Eternity_Sign     : constant Unicode_Char := 16#058D#;
   Left_Facing_Armenian_Eternity_Sign      : constant Unicode_Char := 16#058E#;
   Armenian_Dram_Sign                      : constant Unicode_Char := 16#058F#;
end Unicode.Names.Armenian;
