--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Nabataean is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Nabataean_Letter_Final_Aleph            :
      constant Unicode_Char := 16#10880#;
   Nabataean_Letter_Aleph                  :
      constant Unicode_Char := 16#10881#;
   Nabataean_Letter_Final_Beth             :
      constant Unicode_Char := 16#10882#;
   Nabataean_Letter_Beth                   :
      constant Unicode_Char := 16#10883#;
   Nabataean_Letter_Gimel                  :
      constant Unicode_Char := 16#10884#;
   Nabataean_Letter_Daleth                 :
      constant Unicode_Char := 16#10885#;
   Nabataean_Letter_Final_He               :
      constant Unicode_Char := 16#10886#;
   Nabataean_Letter_He                     :
      constant Unicode_Char := 16#10887#;
   Nabataean_Letter_Waw                    :
      constant Unicode_Char := 16#10888#;
   Nabataean_Letter_Zayin                  :
      constant Unicode_Char := 16#10889#;
   Nabataean_Letter_Heth                   :
      constant Unicode_Char := 16#1088A#;
   Nabataean_Letter_Teth                   :
      constant Unicode_Char := 16#1088B#;
   Nabataean_Letter_Final_Yodh             :
      constant Unicode_Char := 16#1088C#;
   Nabataean_Letter_Yodh                   :
      constant Unicode_Char := 16#1088D#;
   Nabataean_Letter_Final_Kaph             :
      constant Unicode_Char := 16#1088E#;
   Nabataean_Letter_Kaph                   :
      constant Unicode_Char := 16#1088F#;
   Nabataean_Letter_Final_Lamedh           :
      constant Unicode_Char := 16#10890#;
   Nabataean_Letter_Lamedh                 :
      constant Unicode_Char := 16#10891#;
   Nabataean_Letter_Final_Mem              :
      constant Unicode_Char := 16#10892#;
   Nabataean_Letter_Mem                    :
      constant Unicode_Char := 16#10893#;
   Nabataean_Letter_Final_Nun              :
      constant Unicode_Char := 16#10894#;
   Nabataean_Letter_Nun                    :
      constant Unicode_Char := 16#10895#;
   Nabataean_Letter_Samekh                 :
      constant Unicode_Char := 16#10896#;
   Nabataean_Letter_Ayin                   :
      constant Unicode_Char := 16#10897#;
   Nabataean_Letter_Pe                     :
      constant Unicode_Char := 16#10898#;
   Nabataean_Letter_Sadhe                  :
      constant Unicode_Char := 16#10899#;
   Nabataean_Letter_Qoph                   :
      constant Unicode_Char := 16#1089A#;
   Nabataean_Letter_Resh                   :
      constant Unicode_Char := 16#1089B#;
   Nabataean_Letter_Final_Shin             :
      constant Unicode_Char := 16#1089C#;
   Nabataean_Letter_Shin                   :
      constant Unicode_Char := 16#1089D#;
   Nabataean_Letter_Taw                    :
      constant Unicode_Char := 16#1089E#;
   Nabataean_Number_One                    :
      constant Unicode_Char := 16#108A7#;
   Nabataean_Number_Two                    :
      constant Unicode_Char := 16#108A8#;
   Nabataean_Number_Three                  :
      constant Unicode_Char := 16#108A9#;
   Nabataean_Number_Four                   :
      constant Unicode_Char := 16#108AA#;
   Nabataean_Cruciform_Number_Four         :
      constant Unicode_Char := 16#108AB#;
   Nabataean_Number_Five                   :
      constant Unicode_Char := 16#108AC#;
   Nabataean_Number_Ten                    :
      constant Unicode_Char := 16#108AD#;
   Nabataean_Number_Twenty                 :
      constant Unicode_Char := 16#108AE#;
   Nabataean_Number_One_Hundred            :
      constant Unicode_Char := 16#108AF#;
end Unicode.Names.Nabataean;
