--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Myanmar_Extended_A is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Myanmar_Letter_Khamti_Ga                : constant Unicode_Char := 16#AA60#;
   Myanmar_Letter_Khamti_Ca                : constant Unicode_Char := 16#AA61#;
   Myanmar_Letter_Khamti_Cha               : constant Unicode_Char := 16#AA62#;
   Myanmar_Letter_Khamti_Ja                : constant Unicode_Char := 16#AA63#;
   Myanmar_Letter_Khamti_Jha               : constant Unicode_Char := 16#AA64#;
   Myanmar_Letter_Khamti_Nya               : constant Unicode_Char := 16#AA65#;
   Myanmar_Letter_Khamti_Tta               : constant Unicode_Char := 16#AA66#;
   Myanmar_Letter_Khamti_Ttha              : constant Unicode_Char := 16#AA67#;
   Myanmar_Letter_Khamti_Dda               : constant Unicode_Char := 16#AA68#;
   Myanmar_Letter_Khamti_Ddha              : constant Unicode_Char := 16#AA69#;
   Myanmar_Letter_Khamti_Dha               : constant Unicode_Char := 16#AA6A#;
   Myanmar_Letter_Khamti_Na                : constant Unicode_Char := 16#AA6B#;
   Myanmar_Letter_Khamti_Sa                : constant Unicode_Char := 16#AA6C#;
   Myanmar_Letter_Khamti_Ha                : constant Unicode_Char := 16#AA6D#;
   Myanmar_Letter_Khamti_Hha               : constant Unicode_Char := 16#AA6E#;
   Myanmar_Letter_Khamti_Fa                : constant Unicode_Char := 16#AA6F#;
   Myanmar_Modifier_Letter_Khamti_Reduplication :
      constant Unicode_Char := 16#AA70#;
   Myanmar_Letter_Khamti_Xa                : constant Unicode_Char := 16#AA71#;
   Myanmar_Letter_Khamti_Za                : constant Unicode_Char := 16#AA72#;
   Myanmar_Letter_Khamti_Ra                : constant Unicode_Char := 16#AA73#;
   Myanmar_Logogram_Khamti_Oay             : constant Unicode_Char := 16#AA74#;
   Myanmar_Logogram_Khamti_Qn              : constant Unicode_Char := 16#AA75#;
   Myanmar_Logogram_Khamti_Hm              : constant Unicode_Char := 16#AA76#;
   Myanmar_Symbol_Aiton_Exclamation        : constant Unicode_Char := 16#AA77#;
   Myanmar_Symbol_Aiton_One                : constant Unicode_Char := 16#AA78#;
   Myanmar_Symbol_Aiton_Two                : constant Unicode_Char := 16#AA79#;
   Myanmar_Letter_Aiton_Ra                 : constant Unicode_Char := 16#AA7A#;
   Myanmar_Sign_Pao_Karen_Tone             : constant Unicode_Char := 16#AA7B#;
   Myanmar_Sign_Tai_Laing_Tone_2           : constant Unicode_Char := 16#AA7C#;
   Myanmar_Sign_Tai_Laing_Tone_5           : constant Unicode_Char := 16#AA7D#;
   Myanmar_Letter_Shwe_Palaung_Cha         : constant Unicode_Char := 16#AA7E#;
   Myanmar_Letter_Shwe_Palaung_Sha         : constant Unicode_Char := 16#AA7F#;
end Unicode.Names.Myanmar_Extended_A;
