--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Latin_Extended_E is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Latin_Small_Letter_Barred_Alpha         : constant Unicode_Char := 16#AB30#;
   Latin_Small_Letter_A_Reversed_Schwa     : constant Unicode_Char := 16#AB31#;
   Latin_Small_Letter_Blackletter_E        : constant Unicode_Char := 16#AB32#;
   Latin_Small_Letter_Barred_E             : constant Unicode_Char := 16#AB33#;
   Latin_Small_Letter_E_With_Flourish      : constant Unicode_Char := 16#AB34#;
   Latin_Small_Letter_Lenis_F              : constant Unicode_Char := 16#AB35#;
   Latin_Small_Letter_Script_G_With_Crossed_Tail :
      constant Unicode_Char := 16#AB36#;
   Latin_Small_Letter_L_With_Inverted_Lazy_S :
      constant Unicode_Char := 16#AB37#;
   Latin_Small_Letter_L_With_Double_Middle_Tilde :
      constant Unicode_Char := 16#AB38#;
   Latin_Small_Letter_L_With_Middle_Ring   : constant Unicode_Char := 16#AB39#;
   Latin_Small_Letter_M_With_Crossed_Tail  : constant Unicode_Char := 16#AB3A#;
   Latin_Small_Letter_N_With_Crossed_Tail  : constant Unicode_Char := 16#AB3B#;
   Latin_Small_Letter_Eng_With_Crossed_Tail :
      constant Unicode_Char := 16#AB3C#;
   Latin_Small_Letter_Blackletter_O        : constant Unicode_Char := 16#AB3D#;
   Latin_Small_Letter_Blackletter_O_With_Stroke :
      constant Unicode_Char := 16#AB3E#;
   Latin_Small_Letter_Open_O_With_Stroke   : constant Unicode_Char := 16#AB3F#;
   Latin_Small_Letter_Inverted_Oe          : constant Unicode_Char := 16#AB40#;
   Latin_Small_Letter_Turned_Oe_With_Stroke :
      constant Unicode_Char := 16#AB41#;
   Latin_Small_Letter_Turned_Oe_With_Horizontal_Stroke :
      constant Unicode_Char := 16#AB42#;
   Latin_Small_Letter_Turned_O_Open_O      : constant Unicode_Char := 16#AB43#;
   Latin_Small_Letter_Turned_O_Open_O_With_Stroke :
      constant Unicode_Char := 16#AB44#;
   Latin_Small_Letter_Stirrup_R            : constant Unicode_Char := 16#AB45#;
   Latin_Letter_Small_Capital_R_With_Right_Leg :
      constant Unicode_Char := 16#AB46#;
   Latin_Small_Letter_R_Without_Handle     : constant Unicode_Char := 16#AB47#;
   Latin_Small_Letter_Double_R             : constant Unicode_Char := 16#AB48#;
   Latin_Small_Letter_R_With_Crossed_Tail  : constant Unicode_Char := 16#AB49#;
   Latin_Small_Letter_Double_R_With_Crossed_Tail :
      constant Unicode_Char := 16#AB4A#;
   Latin_Small_Letter_Script_R             : constant Unicode_Char := 16#AB4B#;
   Latin_Small_Letter_Script_R_With_Ring   : constant Unicode_Char := 16#AB4C#;
   Latin_Small_Letter_Baseline_Esh         : constant Unicode_Char := 16#AB4D#;
   Latin_Small_Letter_U_With_Short_Right_Leg :
      constant Unicode_Char := 16#AB4E#;
   Latin_Small_Letter_U_Bar_With_Short_Right_Leg :
      constant Unicode_Char := 16#AB4F#;
   Latin_Small_Letter_Ui                   : constant Unicode_Char := 16#AB50#;
   Latin_Small_Letter_Turned_Ui            : constant Unicode_Char := 16#AB51#;
   Latin_Small_Letter_U_With_Left_Hook     : constant Unicode_Char := 16#AB52#;
   Latin_Small_Letter_Chi                  : constant Unicode_Char := 16#AB53#;
   Latin_Small_Letter_Chi_With_Low_Right_Ring :
      constant Unicode_Char := 16#AB54#;
   Latin_Small_Letter_Chi_With_Low_Left_Serif :
      constant Unicode_Char := 16#AB55#;
   Latin_Small_Letter_X_With_Low_Right_Ring :
      constant Unicode_Char := 16#AB56#;
   Latin_Small_Letter_X_With_Long_Left_Leg : constant Unicode_Char := 16#AB57#;
   Latin_Small_Letter_X_With_Long_Left_Leg_And_Low_Right_Ring :
      constant Unicode_Char := 16#AB58#;
   Latin_Small_Letter_X_With_Long_Left_Leg_With_Serif :
      constant Unicode_Char := 16#AB59#;
   Latin_Small_Letter_Y_With_Short_Right_Leg :
      constant Unicode_Char := 16#AB5A#;
   Modifier_Breve_With_Inverted_Breve      : constant Unicode_Char := 16#AB5B#;
   Modifier_Letter_Small_Heng              : constant Unicode_Char := 16#AB5C#;
   Modifier_Letter_Small_L_With_Inverted_Lazy_S :
      constant Unicode_Char := 16#AB5D#;
   Modifier_Letter_Small_L_With_Middle_Tilde :
      constant Unicode_Char := 16#AB5E#;
   Modifier_Letter_Small_U_With_Left_Hook  : constant Unicode_Char := 16#AB5F#;
   Latin_Small_Letter_Sakha_Yat            : constant Unicode_Char := 16#AB60#;
   Latin_Small_Letter_Iotified_E           : constant Unicode_Char := 16#AB61#;
   Latin_Small_Letter_Open_Oe              : constant Unicode_Char := 16#AB62#;
   Latin_Small_Letter_Uo                   : constant Unicode_Char := 16#AB63#;
   Latin_Small_Letter_Inverted_Alpha       : constant Unicode_Char := 16#AB64#;
   Greek_Letter_Small_Capital_Omega        : constant Unicode_Char := 16#AB65#;
end Unicode.Names.Latin_Extended_E;
