--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Hangul_Compatibility_Jamo is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Hangul_Letter_Kiyeok                    : constant Unicode_Char := 16#3131#;
   Hangul_Letter_Ssangkiyeok               : constant Unicode_Char := 16#3132#;
   Hangul_Letter_Kiyeok_Sios               : constant Unicode_Char := 16#3133#;
   Hangul_Letter_Nieun                     : constant Unicode_Char := 16#3134#;
   Hangul_Letter_Nieun_Cieuc               : constant Unicode_Char := 16#3135#;
   Hangul_Letter_Nieun_Hieuh               : constant Unicode_Char := 16#3136#;
   Hangul_Letter_Tikeut                    : constant Unicode_Char := 16#3137#;
   Hangul_Letter_Ssangtikeut               : constant Unicode_Char := 16#3138#;
   Hangul_Letter_Rieul                     : constant Unicode_Char := 16#3139#;
   Hangul_Letter_Rieul_Kiyeok              : constant Unicode_Char := 16#313A#;
   Hangul_Letter_Rieul_Mieum               : constant Unicode_Char := 16#313B#;
   Hangul_Letter_Rieul_Pieup               : constant Unicode_Char := 16#313C#;
   Hangul_Letter_Rieul_Sios                : constant Unicode_Char := 16#313D#;
   Hangul_Letter_Rieul_Thieuth             : constant Unicode_Char := 16#313E#;
   Hangul_Letter_Rieul_Phieuph             : constant Unicode_Char := 16#313F#;
   Hangul_Letter_Rieul_Hieuh               : constant Unicode_Char := 16#3140#;
   Hangul_Letter_Mieum                     : constant Unicode_Char := 16#3141#;
   Hangul_Letter_Pieup                     : constant Unicode_Char := 16#3142#;
   Hangul_Letter_Ssangpieup                : constant Unicode_Char := 16#3143#;
   Hangul_Letter_Pieup_Sios                : constant Unicode_Char := 16#3144#;
   Hangul_Letter_Sios                      : constant Unicode_Char := 16#3145#;
   Hangul_Letter_Ssangsios                 : constant Unicode_Char := 16#3146#;
   Hangul_Letter_Ieung                     : constant Unicode_Char := 16#3147#;
   Hangul_Letter_Cieuc                     : constant Unicode_Char := 16#3148#;
   Hangul_Letter_Ssangcieuc                : constant Unicode_Char := 16#3149#;
   Hangul_Letter_Chieuch                   : constant Unicode_Char := 16#314A#;
   Hangul_Letter_Khieukh                   : constant Unicode_Char := 16#314B#;
   Hangul_Letter_Thieuth                   : constant Unicode_Char := 16#314C#;
   Hangul_Letter_Phieuph                   : constant Unicode_Char := 16#314D#;
   Hangul_Letter_Hieuh                     : constant Unicode_Char := 16#314E#;
   Hangul_Letter_A                         : constant Unicode_Char := 16#314F#;
   Hangul_Letter_Ae                        : constant Unicode_Char := 16#3150#;
   Hangul_Letter_Ya                        : constant Unicode_Char := 16#3151#;
   Hangul_Letter_Yae                       : constant Unicode_Char := 16#3152#;
   Hangul_Letter_Eo                        : constant Unicode_Char := 16#3153#;
   Hangul_Letter_E                         : constant Unicode_Char := 16#3154#;
   Hangul_Letter_Yeo                       : constant Unicode_Char := 16#3155#;
   Hangul_Letter_Ye                        : constant Unicode_Char := 16#3156#;
   Hangul_Letter_O                         : constant Unicode_Char := 16#3157#;
   Hangul_Letter_Wa                        : constant Unicode_Char := 16#3158#;
   Hangul_Letter_Wae                       : constant Unicode_Char := 16#3159#;
   Hangul_Letter_Oe                        : constant Unicode_Char := 16#315A#;
   Hangul_Letter_Yo                        : constant Unicode_Char := 16#315B#;
   Hangul_Letter_U                         : constant Unicode_Char := 16#315C#;
   Hangul_Letter_Weo                       : constant Unicode_Char := 16#315D#;
   Hangul_Letter_We                        : constant Unicode_Char := 16#315E#;
   Hangul_Letter_Wi                        : constant Unicode_Char := 16#315F#;
   Hangul_Letter_Yu                        : constant Unicode_Char := 16#3160#;
   Hangul_Letter_Eu                        : constant Unicode_Char := 16#3161#;
   Hangul_Letter_Yi                        : constant Unicode_Char := 16#3162#;
   Hangul_Letter_I                         : constant Unicode_Char := 16#3163#;
   Hangul_Filler                           : constant Unicode_Char := 16#3164#;
   Hangul_Letter_Ssangnieun                : constant Unicode_Char := 16#3165#;
   Hangul_Letter_Nieun_Tikeut              : constant Unicode_Char := 16#3166#;
   Hangul_Letter_Nieun_Sios                : constant Unicode_Char := 16#3167#;
   Hangul_Letter_Nieun_Pansios             : constant Unicode_Char := 16#3168#;
   Hangul_Letter_Rieul_Kiyeok_Sios         : constant Unicode_Char := 16#3169#;
   Hangul_Letter_Rieul_Tikeut              : constant Unicode_Char := 16#316A#;
   Hangul_Letter_Rieul_Pieup_Sios          : constant Unicode_Char := 16#316B#;
   Hangul_Letter_Rieul_Pansios             : constant Unicode_Char := 16#316C#;
   Hangul_Letter_Rieul_Yeorinhieuh         : constant Unicode_Char := 16#316D#;
   Hangul_Letter_Mieum_Pieup               : constant Unicode_Char := 16#316E#;
   Hangul_Letter_Mieum_Sios                : constant Unicode_Char := 16#316F#;
   Hangul_Letter_Mieum_Pansios             : constant Unicode_Char := 16#3170#;
   Hangul_Letter_Kapyeounmieum             : constant Unicode_Char := 16#3171#;
   Hangul_Letter_Pieup_Kiyeok              : constant Unicode_Char := 16#3172#;
   Hangul_Letter_Pieup_Tikeut              : constant Unicode_Char := 16#3173#;
   Hangul_Letter_Pieup_Sios_Kiyeok         : constant Unicode_Char := 16#3174#;
   Hangul_Letter_Pieup_Sios_Tikeut         : constant Unicode_Char := 16#3175#;
   Hangul_Letter_Pieup_Cieuc               : constant Unicode_Char := 16#3176#;
   Hangul_Letter_Pieup_Thieuth             : constant Unicode_Char := 16#3177#;
   Hangul_Letter_Kapyeounpieup             : constant Unicode_Char := 16#3178#;
   Hangul_Letter_Kapyeounssangpieup        : constant Unicode_Char := 16#3179#;
   Hangul_Letter_Sios_Kiyeok               : constant Unicode_Char := 16#317A#;
   Hangul_Letter_Sios_Nieun                : constant Unicode_Char := 16#317B#;
   Hangul_Letter_Sios_Tikeut               : constant Unicode_Char := 16#317C#;
   Hangul_Letter_Sios_Pieup                : constant Unicode_Char := 16#317D#;
   Hangul_Letter_Sios_Cieuc                : constant Unicode_Char := 16#317E#;
   Hangul_Letter_Pansios                   : constant Unicode_Char := 16#317F#;
   Hangul_Letter_Ssangieung                : constant Unicode_Char := 16#3180#;
   Hangul_Letter_Yesieung                  : constant Unicode_Char := 16#3181#;
   Hangul_Letter_Yesieung_Sios             : constant Unicode_Char := 16#3182#;
   Hangul_Letter_Yesieung_Pansios          : constant Unicode_Char := 16#3183#;
   Hangul_Letter_Kapyeounphieuph           : constant Unicode_Char := 16#3184#;
   Hangul_Letter_Ssanghieuh                : constant Unicode_Char := 16#3185#;
   Hangul_Letter_Yeorinhieuh               : constant Unicode_Char := 16#3186#;
   Hangul_Letter_Yo_Ya                     : constant Unicode_Char := 16#3187#;
   Hangul_Letter_Yo_Yae                    : constant Unicode_Char := 16#3188#;
   Hangul_Letter_Yo_I                      : constant Unicode_Char := 16#3189#;
   Hangul_Letter_Yu_Yeo                    : constant Unicode_Char := 16#318A#;
   Hangul_Letter_Yu_Ye                     : constant Unicode_Char := 16#318B#;
   Hangul_Letter_Yu_I                      : constant Unicode_Char := 16#318C#;
   Hangul_Letter_Araea                     : constant Unicode_Char := 16#318D#;
   Hangul_Letter_Araeae                    : constant Unicode_Char := 16#318E#;
end Unicode.Names.Hangul_Compatibility_Jamo;
