--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Brahmi is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Brahmi_Sign_Candrabindu                 :
      constant Unicode_Char := 16#11000#;
   Brahmi_Sign_Anusvara                    :
      constant Unicode_Char := 16#11001#;
   Brahmi_Sign_Visarga                     :
      constant Unicode_Char := 16#11002#;
   Brahmi_Sign_Jihvamuliya                 :
      constant Unicode_Char := 16#11003#;
   Brahmi_Sign_Upadhmaniya                 :
      constant Unicode_Char := 16#11004#;
   Brahmi_Letter_A                         :
      constant Unicode_Char := 16#11005#;
   Brahmi_Letter_Aa                        :
      constant Unicode_Char := 16#11006#;
   Brahmi_Letter_I                         :
      constant Unicode_Char := 16#11007#;
   Brahmi_Letter_Ii                        :
      constant Unicode_Char := 16#11008#;
   Brahmi_Letter_U                         :
      constant Unicode_Char := 16#11009#;
   Brahmi_Letter_Uu                        :
      constant Unicode_Char := 16#1100A#;
   Brahmi_Letter_Vocalic_R                 :
      constant Unicode_Char := 16#1100B#;
   Brahmi_Letter_Vocalic_Rr                :
      constant Unicode_Char := 16#1100C#;
   Brahmi_Letter_Vocalic_L                 :
      constant Unicode_Char := 16#1100D#;
   Brahmi_Letter_Vocalic_Ll                :
      constant Unicode_Char := 16#1100E#;
   Brahmi_Letter_E                         :
      constant Unicode_Char := 16#1100F#;
   Brahmi_Letter_Ai                        :
      constant Unicode_Char := 16#11010#;
   Brahmi_Letter_O                         :
      constant Unicode_Char := 16#11011#;
   Brahmi_Letter_Au                        :
      constant Unicode_Char := 16#11012#;
   Brahmi_Letter_Ka                        :
      constant Unicode_Char := 16#11013#;
   Brahmi_Letter_Kha                       :
      constant Unicode_Char := 16#11014#;
   Brahmi_Letter_Ga                        :
      constant Unicode_Char := 16#11015#;
   Brahmi_Letter_Gha                       :
      constant Unicode_Char := 16#11016#;
   Brahmi_Letter_Nga                       :
      constant Unicode_Char := 16#11017#;
   Brahmi_Letter_Ca                        :
      constant Unicode_Char := 16#11018#;
   Brahmi_Letter_Cha                       :
      constant Unicode_Char := 16#11019#;
   Brahmi_Letter_Ja                        :
      constant Unicode_Char := 16#1101A#;
   Brahmi_Letter_Jha                       :
      constant Unicode_Char := 16#1101B#;
   Brahmi_Letter_Nya                       :
      constant Unicode_Char := 16#1101C#;
   Brahmi_Letter_Tta                       :
      constant Unicode_Char := 16#1101D#;
   Brahmi_Letter_Ttha                      :
      constant Unicode_Char := 16#1101E#;
   Brahmi_Letter_Dda                       :
      constant Unicode_Char := 16#1101F#;
   Brahmi_Letter_Ddha                      :
      constant Unicode_Char := 16#11020#;
   Brahmi_Letter_Nna                       :
      constant Unicode_Char := 16#11021#;
   Brahmi_Letter_Ta                        :
      constant Unicode_Char := 16#11022#;
   Brahmi_Letter_Tha                       :
      constant Unicode_Char := 16#11023#;
   Brahmi_Letter_Da                        :
      constant Unicode_Char := 16#11024#;
   Brahmi_Letter_Dha                       :
      constant Unicode_Char := 16#11025#;
   Brahmi_Letter_Na                        :
      constant Unicode_Char := 16#11026#;
   Brahmi_Letter_Pa                        :
      constant Unicode_Char := 16#11027#;
   Brahmi_Letter_Pha                       :
      constant Unicode_Char := 16#11028#;
   Brahmi_Letter_Ba                        :
      constant Unicode_Char := 16#11029#;
   Brahmi_Letter_Bha                       :
      constant Unicode_Char := 16#1102A#;
   Brahmi_Letter_Ma                        :
      constant Unicode_Char := 16#1102B#;
   Brahmi_Letter_Ya                        :
      constant Unicode_Char := 16#1102C#;
   Brahmi_Letter_Ra                        :
      constant Unicode_Char := 16#1102D#;
   Brahmi_Letter_La                        :
      constant Unicode_Char := 16#1102E#;
   Brahmi_Letter_Va                        :
      constant Unicode_Char := 16#1102F#;
   Brahmi_Letter_Sha                       :
      constant Unicode_Char := 16#11030#;
   Brahmi_Letter_Ssa                       :
      constant Unicode_Char := 16#11031#;
   Brahmi_Letter_Sa                        :
      constant Unicode_Char := 16#11032#;
   Brahmi_Letter_Ha                        :
      constant Unicode_Char := 16#11033#;
   Brahmi_Letter_Lla                       :
      constant Unicode_Char := 16#11034#;
   Brahmi_Letter_Old_Tamil_Llla            :
      constant Unicode_Char := 16#11035#;
   Brahmi_Letter_Old_Tamil_Rra             :
      constant Unicode_Char := 16#11036#;
   Brahmi_Letter_Old_Tamil_Nnna            :
      constant Unicode_Char := 16#11037#;
   Brahmi_Vowel_Sign_Aa                    :
      constant Unicode_Char := 16#11038#;
   Brahmi_Vowel_Sign_Bhattiprolu_Aa        :
      constant Unicode_Char := 16#11039#;
   Brahmi_Vowel_Sign_I                     :
      constant Unicode_Char := 16#1103A#;
   Brahmi_Vowel_Sign_Ii                    :
      constant Unicode_Char := 16#1103B#;
   Brahmi_Vowel_Sign_U                     :
      constant Unicode_Char := 16#1103C#;
   Brahmi_Vowel_Sign_Uu                    :
      constant Unicode_Char := 16#1103D#;
   Brahmi_Vowel_Sign_Vocalic_R             :
      constant Unicode_Char := 16#1103E#;
   Brahmi_Vowel_Sign_Vocalic_Rr            :
      constant Unicode_Char := 16#1103F#;
   Brahmi_Vowel_Sign_Vocalic_L             :
      constant Unicode_Char := 16#11040#;
   Brahmi_Vowel_Sign_Vocalic_Ll            :
      constant Unicode_Char := 16#11041#;
   Brahmi_Vowel_Sign_E                     :
      constant Unicode_Char := 16#11042#;
   Brahmi_Vowel_Sign_Ai                    :
      constant Unicode_Char := 16#11043#;
   Brahmi_Vowel_Sign_O                     :
      constant Unicode_Char := 16#11044#;
   Brahmi_Vowel_Sign_Au                    :
      constant Unicode_Char := 16#11045#;
   Brahmi_Virama                           :
      constant Unicode_Char := 16#11046#;
   Brahmi_Danda                            :
      constant Unicode_Char := 16#11047#;
   Brahmi_Double_Danda                     :
      constant Unicode_Char := 16#11048#;
   Brahmi_Punctuation_Dot                  :
      constant Unicode_Char := 16#11049#;
   Brahmi_Punctuation_Double_Dot           :
      constant Unicode_Char := 16#1104A#;
   Brahmi_Punctuation_Line                 :
      constant Unicode_Char := 16#1104B#;
   Brahmi_Punctuation_Crescent_Bar         :
      constant Unicode_Char := 16#1104C#;
   Brahmi_Punctuation_Lotus                :
      constant Unicode_Char := 16#1104D#;
   Brahmi_Number_One                       :
      constant Unicode_Char := 16#11052#;
   Brahmi_Number_Two                       :
      constant Unicode_Char := 16#11053#;
   Brahmi_Number_Three                     :
      constant Unicode_Char := 16#11054#;
   Brahmi_Number_Four                      :
      constant Unicode_Char := 16#11055#;
   Brahmi_Number_Five                      :
      constant Unicode_Char := 16#11056#;
   Brahmi_Number_Six                       :
      constant Unicode_Char := 16#11057#;
   Brahmi_Number_Seven                     :
      constant Unicode_Char := 16#11058#;
   Brahmi_Number_Eight                     :
      constant Unicode_Char := 16#11059#;
   Brahmi_Number_Nine                      :
      constant Unicode_Char := 16#1105A#;
   Brahmi_Number_Ten                       :
      constant Unicode_Char := 16#1105B#;
   Brahmi_Number_Twenty                    :
      constant Unicode_Char := 16#1105C#;
   Brahmi_Number_Thirty                    :
      constant Unicode_Char := 16#1105D#;
   Brahmi_Number_Forty                     :
      constant Unicode_Char := 16#1105E#;
   Brahmi_Number_Fifty                     :
      constant Unicode_Char := 16#1105F#;
   Brahmi_Number_Sixty                     :
      constant Unicode_Char := 16#11060#;
   Brahmi_Number_Seventy                   :
      constant Unicode_Char := 16#11061#;
   Brahmi_Number_Eighty                    :
      constant Unicode_Char := 16#11062#;
   Brahmi_Number_Ninety                    :
      constant Unicode_Char := 16#11063#;
   Brahmi_Number_One_Hundred               :
      constant Unicode_Char := 16#11064#;
   Brahmi_Number_One_Thousand              :
      constant Unicode_Char := 16#11065#;
   Brahmi_Digit_Zero                       :
      constant Unicode_Char := 16#11066#;
   Brahmi_Digit_One                        :
      constant Unicode_Char := 16#11067#;
   Brahmi_Digit_Two                        :
      constant Unicode_Char := 16#11068#;
   Brahmi_Digit_Three                      :
      constant Unicode_Char := 16#11069#;
   Brahmi_Digit_Four                       :
      constant Unicode_Char := 16#1106A#;
   Brahmi_Digit_Five                       :
      constant Unicode_Char := 16#1106B#;
   Brahmi_Digit_Six                        :
      constant Unicode_Char := 16#1106C#;
   Brahmi_Digit_Seven                      :
      constant Unicode_Char := 16#1106D#;
   Brahmi_Digit_Eight                      :
      constant Unicode_Char := 16#1106E#;
   Brahmi_Digit_Nine                       :
      constant Unicode_Char := 16#1106F#;
   Brahmi_Number_Joiner                    :
      constant Unicode_Char := 16#1107F#;
end Unicode.Names.Brahmi;
