--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Dingbats is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Black_Safety_Scissors                   : constant Unicode_Char := 16#2700#;
   Upper_Blade_Scissors                    : constant Unicode_Char := 16#2701#;
   Black_Scissors                          : constant Unicode_Char := 16#2702#;
   Lower_Blade_Scissors                    : constant Unicode_Char := 16#2703#;
   White_Scissors                          : constant Unicode_Char := 16#2704#;
   White_Heavy_Check_Mark                  : constant Unicode_Char := 16#2705#;
   Telephone_Location_Sign                 : constant Unicode_Char := 16#2706#;
   Tape_Drive                              : constant Unicode_Char := 16#2707#;
   Airplane                                : constant Unicode_Char := 16#2708#;
   Envelope                                : constant Unicode_Char := 16#2709#;
   Raised_Fist                             : constant Unicode_Char := 16#270A#;
   Raised_Hand                             : constant Unicode_Char := 16#270B#;
   Victory_Hand                            : constant Unicode_Char := 16#270C#;
   Writing_Hand                            : constant Unicode_Char := 16#270D#;
   Lower_Right_Pencil                      : constant Unicode_Char := 16#270E#;
   Pencil                                  : constant Unicode_Char := 16#270F#;
   Upper_Right_Pencil                      : constant Unicode_Char := 16#2710#;
   White_Nib                               : constant Unicode_Char := 16#2711#;
   Black_Nib                               : constant Unicode_Char := 16#2712#;
   Check_Mark                              : constant Unicode_Char := 16#2713#;
   Heavy_Check_Mark                        : constant Unicode_Char := 16#2714#;
   Multiplication_X                        : constant Unicode_Char := 16#2715#;
   Heavy_Multiplication_X                  : constant Unicode_Char := 16#2716#;
   Ballot_X                                : constant Unicode_Char := 16#2717#;
   Heavy_Ballot_X                          : constant Unicode_Char := 16#2718#;
   Outlined_Greek_Cross                    : constant Unicode_Char := 16#2719#;
   Heavy_Greek_Cross                       : constant Unicode_Char := 16#271A#;
   Open_Centre_Cross                       : constant Unicode_Char := 16#271B#;
   Heavy_Open_Centre_Cross                 : constant Unicode_Char := 16#271C#;
   Latin_Cross                             : constant Unicode_Char := 16#271D#;
   Shadowed_White_Latin_Cross              : constant Unicode_Char := 16#271E#;
   Outlined_Latin_Cross                    : constant Unicode_Char := 16#271F#;
   Maltese_Cross                           : constant Unicode_Char := 16#2720#;
   Star_Of_David                           : constant Unicode_Char := 16#2721#;
   Four_Teardrop_Spoked_Asterisk           : constant Unicode_Char := 16#2722#;
   Four_Balloon_Spoked_Asterisk            : constant Unicode_Char := 16#2723#;
   Heavy_Four_Balloon_Spoked_Asterisk      : constant Unicode_Char := 16#2724#;
   Four_Club_Spoked_Asterisk               : constant Unicode_Char := 16#2725#;
   Black_Four_Pointed_Star                 : constant Unicode_Char := 16#2726#;
   White_Four_Pointed_Star                 : constant Unicode_Char := 16#2727#;
   Sparkles                                : constant Unicode_Char := 16#2728#;
   Stress_Outlined_White_Star              : constant Unicode_Char := 16#2729#;
   Circled_White_Star                      : constant Unicode_Char := 16#272A#;
   Open_Centre_Black_Star                  : constant Unicode_Char := 16#272B#;
   Black_Centre_White_Star                 : constant Unicode_Char := 16#272C#;
   Outlined_Black_Star                     : constant Unicode_Char := 16#272D#;
   Heavy_Outlined_Black_Star               : constant Unicode_Char := 16#272E#;
   Pinwheel_Star                           : constant Unicode_Char := 16#272F#;
   Shadowed_White_Star                     : constant Unicode_Char := 16#2730#;
   Heavy_Asterisk                          : constant Unicode_Char := 16#2731#;
   Open_Centre_Asterisk                    : constant Unicode_Char := 16#2732#;
   Eight_Spoked_Asterisk                   : constant Unicode_Char := 16#2733#;
   Eight_Pointed_Black_Star                : constant Unicode_Char := 16#2734#;
   Eight_Pointed_Pinwheel_Star             : constant Unicode_Char := 16#2735#;
   Six_Pointed_Black_Star                  : constant Unicode_Char := 16#2736#;
   Eight_Pointed_Rectilinear_Black_Star    : constant Unicode_Char := 16#2737#;
   Heavy_Eight_Pointed_Rectilinear_Black_Star :
      constant Unicode_Char := 16#2738#;
   Twelve_Pointed_Black_Star               : constant Unicode_Char := 16#2739#;
   Sixteen_Pointed_Asterisk                : constant Unicode_Char := 16#273A#;
   Teardrop_Spoked_Asterisk                : constant Unicode_Char := 16#273B#;
   Open_Centre_Teardrop_Spoked_Asterisk    : constant Unicode_Char := 16#273C#;
   Heavy_Teardrop_Spoked_Asterisk          : constant Unicode_Char := 16#273D#;
   Six_Petalled_Black_And_White_Florette   : constant Unicode_Char := 16#273E#;
   Black_Florette                          : constant Unicode_Char := 16#273F#;
   White_Florette                          : constant Unicode_Char := 16#2740#;
   Eight_Petalled_Outlined_Black_Florette  : constant Unicode_Char := 16#2741#;
   Circled_Open_Centre_Eight_Pointed_Star  : constant Unicode_Char := 16#2742#;
   Heavy_Teardrop_Spoked_Pinwheel_Asterisk : constant Unicode_Char := 16#2743#;
   Snowflake                               : constant Unicode_Char := 16#2744#;
   Tight_Trifoliate_Snowflake              : constant Unicode_Char := 16#2745#;
   Heavy_Chevron_Snowflake                 : constant Unicode_Char := 16#2746#;
   Sparkle                                 : constant Unicode_Char := 16#2747#;
   Heavy_Sparkle                           : constant Unicode_Char := 16#2748#;
   Balloon_Spoked_Asterisk                 : constant Unicode_Char := 16#2749#;
   Eight_Teardrop_Spoked_Propeller_Asterisk :
      constant Unicode_Char := 16#274A#;
   Heavy_Eight_Teardrop_Spoked_Propeller_Asterisk :
      constant Unicode_Char := 16#274B#;
   Cross_Mark                              : constant Unicode_Char := 16#274C#;
   Shadowed_White_Circle                   : constant Unicode_Char := 16#274D#;
   Negative_Squared_Cross_Mark             : constant Unicode_Char := 16#274E#;
   Lower_Right_Drop_Shadowed_White_Square  : constant Unicode_Char := 16#274F#;
   Upper_Right_Drop_Shadowed_White_Square  : constant Unicode_Char := 16#2750#;
   Lower_Right_Shadowed_White_Square       : constant Unicode_Char := 16#2751#;
   Upper_Right_Shadowed_White_Square       : constant Unicode_Char := 16#2752#;
   Black_Question_Mark_Ornament            : constant Unicode_Char := 16#2753#;
   White_Question_Mark_Ornament            : constant Unicode_Char := 16#2754#;
   White_Exclamation_Mark_Ornament         : constant Unicode_Char := 16#2755#;
   Black_Diamond_Minus_White_X             : constant Unicode_Char := 16#2756#;
   Heavy_Exclamation_Mark_Symbol           : constant Unicode_Char := 16#2757#;
   Light_Vertical_Bar                      : constant Unicode_Char := 16#2758#;
   Medium_Vertical_Bar                     : constant Unicode_Char := 16#2759#;
   Heavy_Vertical_Bar                      : constant Unicode_Char := 16#275A#;
   Heavy_Single_Turned_Comma_Quotation_Mark_Ornament :
      constant Unicode_Char := 16#275B#;
   Heavy_Single_Comma_Quotation_Mark_Ornament :
      constant Unicode_Char := 16#275C#;
   Heavy_Double_Turned_Comma_Quotation_Mark_Ornament :
      constant Unicode_Char := 16#275D#;
   Heavy_Double_Comma_Quotation_Mark_Ornament :
      constant Unicode_Char := 16#275E#;
   Heavy_Low_Single_Comma_Quotation_Mark_Ornament :
      constant Unicode_Char := 16#275F#;
   Heavy_Low_Double_Comma_Quotation_Mark_Ornament :
      constant Unicode_Char := 16#2760#;
   Curved_Stem_Paragraph_Sign_Ornament     : constant Unicode_Char := 16#2761#;
   Heavy_Exclamation_Mark_Ornament         : constant Unicode_Char := 16#2762#;
   Heavy_Heart_Exclamation_Mark_Ornament   : constant Unicode_Char := 16#2763#;
   Heavy_Black_Heart                       : constant Unicode_Char := 16#2764#;
   Rotated_Heavy_Black_Heart_Bullet        : constant Unicode_Char := 16#2765#;
   Floral_Heart                            : constant Unicode_Char := 16#2766#;
   Rotated_Floral_Heart_Bullet             : constant Unicode_Char := 16#2767#;
   Medium_Left_Parenthesis_Ornament        : constant Unicode_Char := 16#2768#;
   Medium_Right_Parenthesis_Ornament       : constant Unicode_Char := 16#2769#;
   Medium_Flattened_Left_Parenthesis_Ornament :
      constant Unicode_Char := 16#276A#;
   Medium_Flattened_Right_Parenthesis_Ornament :
      constant Unicode_Char := 16#276B#;
   Medium_Left_Pointing_Angle_Bracket_Ornament :
      constant Unicode_Char := 16#276C#;
   Medium_Right_Pointing_Angle_Bracket_Ornament :
      constant Unicode_Char := 16#276D#;
   Heavy_Left_Pointing_Angle_Quotation_Mark_Ornament :
      constant Unicode_Char := 16#276E#;
   Heavy_Right_Pointing_Angle_Quotation_Mark_Ornament :
      constant Unicode_Char := 16#276F#;
   Heavy_Left_Pointing_Angle_Bracket_Ornament :
      constant Unicode_Char := 16#2770#;
   Heavy_Right_Pointing_Angle_Bracket_Ornament :
      constant Unicode_Char := 16#2771#;
   Light_Left_Tortoise_Shell_Bracket_Ornament :
      constant Unicode_Char := 16#2772#;
   Light_Right_Tortoise_Shell_Bracket_Ornament :
      constant Unicode_Char := 16#2773#;
   Medium_Left_Curly_Bracket_Ornament      : constant Unicode_Char := 16#2774#;
   Medium_Right_Curly_Bracket_Ornament     : constant Unicode_Char := 16#2775#;
   Dingbat_Negative_Circled_Digit_One      : constant Unicode_Char := 16#2776#;
   Dingbat_Negative_Circled_Digit_Two      : constant Unicode_Char := 16#2777#;
   Dingbat_Negative_Circled_Digit_Three    : constant Unicode_Char := 16#2778#;
   Dingbat_Negative_Circled_Digit_Four     : constant Unicode_Char := 16#2779#;
   Dingbat_Negative_Circled_Digit_Five     : constant Unicode_Char := 16#277A#;
   Dingbat_Negative_Circled_Digit_Six      : constant Unicode_Char := 16#277B#;
   Dingbat_Negative_Circled_Digit_Seven    : constant Unicode_Char := 16#277C#;
   Dingbat_Negative_Circled_Digit_Eight    : constant Unicode_Char := 16#277D#;
   Dingbat_Negative_Circled_Digit_Nine     : constant Unicode_Char := 16#277E#;
   Dingbat_Negative_Circled_Number_Ten     : constant Unicode_Char := 16#277F#;
   Dingbat_Circled_Sans_Serif_Digit_One    : constant Unicode_Char := 16#2780#;
   Dingbat_Circled_Sans_Serif_Digit_Two    : constant Unicode_Char := 16#2781#;
   Dingbat_Circled_Sans_Serif_Digit_Three  : constant Unicode_Char := 16#2782#;
   Dingbat_Circled_Sans_Serif_Digit_Four   : constant Unicode_Char := 16#2783#;
   Dingbat_Circled_Sans_Serif_Digit_Five   : constant Unicode_Char := 16#2784#;
   Dingbat_Circled_Sans_Serif_Digit_Six    : constant Unicode_Char := 16#2785#;
   Dingbat_Circled_Sans_Serif_Digit_Seven  : constant Unicode_Char := 16#2786#;
   Dingbat_Circled_Sans_Serif_Digit_Eight  : constant Unicode_Char := 16#2787#;
   Dingbat_Circled_Sans_Serif_Digit_Nine   : constant Unicode_Char := 16#2788#;
   Dingbat_Circled_Sans_Serif_Number_Ten   : constant Unicode_Char := 16#2789#;
   Dingbat_Negative_Circled_Sans_Serif_Digit_One :
      constant Unicode_Char := 16#278A#;
   Dingbat_Negative_Circled_Sans_Serif_Digit_Two :
      constant Unicode_Char := 16#278B#;
   Dingbat_Negative_Circled_Sans_Serif_Digit_Three :
      constant Unicode_Char := 16#278C#;
   Dingbat_Negative_Circled_Sans_Serif_Digit_Four :
      constant Unicode_Char := 16#278D#;
   Dingbat_Negative_Circled_Sans_Serif_Digit_Five :
      constant Unicode_Char := 16#278E#;
   Dingbat_Negative_Circled_Sans_Serif_Digit_Six :
      constant Unicode_Char := 16#278F#;
   Dingbat_Negative_Circled_Sans_Serif_Digit_Seven :
      constant Unicode_Char := 16#2790#;
   Dingbat_Negative_Circled_Sans_Serif_Digit_Eight :
      constant Unicode_Char := 16#2791#;
   Dingbat_Negative_Circled_Sans_Serif_Digit_Nine :
      constant Unicode_Char := 16#2792#;
   Dingbat_Negative_Circled_Sans_Serif_Number_Ten :
      constant Unicode_Char := 16#2793#;
   Heavy_Wide_Headed_Rightwards_Arrow      : constant Unicode_Char := 16#2794#;
   Heavy_Plus_Sign                         : constant Unicode_Char := 16#2795#;
   Heavy_Minus_Sign                        : constant Unicode_Char := 16#2796#;
   Heavy_Division_Sign                     : constant Unicode_Char := 16#2797#;
   Heavy_South_East_Arrow                  : constant Unicode_Char := 16#2798#;
   Heavy_Rightwards_Arrow                  : constant Unicode_Char := 16#2799#;
   Heavy_North_East_Arrow                  : constant Unicode_Char := 16#279A#;
   Drafting_Point_Rightwards_Arrow         : constant Unicode_Char := 16#279B#;
   Heavy_Round_Tipped_Rightwards_Arrow     : constant Unicode_Char := 16#279C#;
   Triangle_Headed_Rightwards_Arrow        : constant Unicode_Char := 16#279D#;
   Heavy_Triangle_Headed_Rightwards_Arrow  : constant Unicode_Char := 16#279E#;
   Dashed_Triangle_Headed_Rightwards_Arrow : constant Unicode_Char := 16#279F#;
   Heavy_Dashed_Triangle_Headed_Rightwards_Arrow :
      constant Unicode_Char := 16#27A0#;
   Black_Rightwards_Arrow                  : constant Unicode_Char := 16#27A1#;
   Three_D_Top_Lighted_Rightwards_Arrowhead :
      constant Unicode_Char := 16#27A2#;
   Three_D_Bottom_Lighted_Rightwards_Arrowhead :
      constant Unicode_Char := 16#27A3#;
   Black_Rightwards_Arrowhead              : constant Unicode_Char := 16#27A4#;
   Heavy_Black_Curved_Downwards_And_Rightwards_Arrow :
      constant Unicode_Char := 16#27A5#;
   Heavy_Black_Curved_Upwards_And_Rightwards_Arrow :
      constant Unicode_Char := 16#27A6#;
   Squat_Black_Rightwards_Arrow            : constant Unicode_Char := 16#27A7#;
   Heavy_Concave_Pointed_Black_Rightwards_Arrow :
      constant Unicode_Char := 16#27A8#;
   Right_Shaded_White_Rightwards_Arrow     : constant Unicode_Char := 16#27A9#;
   Left_Shaded_White_Rightwards_Arrow      : constant Unicode_Char := 16#27AA#;
   Back_Tilted_Shadowed_White_Rightwards_Arrow :
      constant Unicode_Char := 16#27AB#;
   Front_Tilted_Shadowed_White_Rightwards_Arrow :
      constant Unicode_Char := 16#27AC#;
   Heavy_Lower_Right_Shadowed_White_Rightwards_Arrow :
      constant Unicode_Char := 16#27AD#;
   Heavy_Upper_Right_Shadowed_White_Rightwards_Arrow :
      constant Unicode_Char := 16#27AE#;
   Notched_Lower_Right_Shadowed_White_Rightwards_Arrow :
      constant Unicode_Char := 16#27AF#;
   Curly_Loop                              : constant Unicode_Char := 16#27B0#;
   Notched_Upper_Right_Shadowed_White_Rightwards_Arrow :
      constant Unicode_Char := 16#27B1#;
   Circled_Heavy_White_Rightwards_Arrow    : constant Unicode_Char := 16#27B2#;
   White_Feathered_Rightwards_Arrow        : constant Unicode_Char := 16#27B3#;
   Black_Feathered_South_East_Arrow        : constant Unicode_Char := 16#27B4#;
   Black_Feathered_Rightwards_Arrow        : constant Unicode_Char := 16#27B5#;
   Black_Feathered_North_East_Arrow        : constant Unicode_Char := 16#27B6#;
   Heavy_Black_Feathered_South_East_Arrow  : constant Unicode_Char := 16#27B7#;
   Heavy_Black_Feathered_Rightwards_Arrow  : constant Unicode_Char := 16#27B8#;
   Heavy_Black_Feathered_North_East_Arrow  : constant Unicode_Char := 16#27B9#;
   Teardrop_Barbed_Rightwards_Arrow        : constant Unicode_Char := 16#27BA#;
   Heavy_Teardrop_Shanked_Rightwards_Arrow : constant Unicode_Char := 16#27BB#;
   Wedge_Tailed_Rightwards_Arrow           : constant Unicode_Char := 16#27BC#;
   Heavy_Wedge_Tailed_Rightwards_Arrow     : constant Unicode_Char := 16#27BD#;
   Open_Outlined_Rightwards_Arrow          : constant Unicode_Char := 16#27BE#;
   Double_Curly_Loop                       : constant Unicode_Char := 16#27BF#;
end Unicode.Names.Dingbats;
