--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Devanagari is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Devanagari_Sign_Inverted_Candrabindu    : constant Unicode_Char := 16#0900#;
   Devanagari_Sign_Candrabindu             : constant Unicode_Char := 16#0901#;
   Devanagari_Sign_Anusvara                : constant Unicode_Char := 16#0902#;
   Devanagari_Sign_Visarga                 : constant Unicode_Char := 16#0903#;
   Devanagari_Letter_Short_A               : constant Unicode_Char := 16#0904#;
   Devanagari_Letter_A                     : constant Unicode_Char := 16#0905#;
   Devanagari_Letter_Aa                    : constant Unicode_Char := 16#0906#;
   Devanagari_Letter_I                     : constant Unicode_Char := 16#0907#;
   Devanagari_Letter_Ii                    : constant Unicode_Char := 16#0908#;
   Devanagari_Letter_U                     : constant Unicode_Char := 16#0909#;
   Devanagari_Letter_Uu                    : constant Unicode_Char := 16#090A#;
   Devanagari_Letter_Vocalic_R             : constant Unicode_Char := 16#090B#;
   Devanagari_Letter_Vocalic_L             : constant Unicode_Char := 16#090C#;
   Devanagari_Letter_Candra_E              : constant Unicode_Char := 16#090D#;
   Devanagari_Letter_Short_E               : constant Unicode_Char := 16#090E#;
   Devanagari_Letter_E                     : constant Unicode_Char := 16#090F#;
   Devanagari_Letter_Ai                    : constant Unicode_Char := 16#0910#;
   Devanagari_Letter_Candra_O              : constant Unicode_Char := 16#0911#;
   Devanagari_Letter_Short_O               : constant Unicode_Char := 16#0912#;
   Devanagari_Letter_O                     : constant Unicode_Char := 16#0913#;
   Devanagari_Letter_Au                    : constant Unicode_Char := 16#0914#;
   Devanagari_Letter_Ka                    : constant Unicode_Char := 16#0915#;
   Devanagari_Letter_Kha                   : constant Unicode_Char := 16#0916#;
   Devanagari_Letter_Ga                    : constant Unicode_Char := 16#0917#;
   Devanagari_Letter_Gha                   : constant Unicode_Char := 16#0918#;
   Devanagari_Letter_Nga                   : constant Unicode_Char := 16#0919#;
   Devanagari_Letter_Ca                    : constant Unicode_Char := 16#091A#;
   Devanagari_Letter_Cha                   : constant Unicode_Char := 16#091B#;
   Devanagari_Letter_Ja                    : constant Unicode_Char := 16#091C#;
   Devanagari_Letter_Jha                   : constant Unicode_Char := 16#091D#;
   Devanagari_Letter_Nya                   : constant Unicode_Char := 16#091E#;
   Devanagari_Letter_Tta                   : constant Unicode_Char := 16#091F#;
   Devanagari_Letter_Ttha                  : constant Unicode_Char := 16#0920#;
   Devanagari_Letter_Dda                   : constant Unicode_Char := 16#0921#;
   Devanagari_Letter_Ddha                  : constant Unicode_Char := 16#0922#;
   Devanagari_Letter_Nna                   : constant Unicode_Char := 16#0923#;
   Devanagari_Letter_Ta                    : constant Unicode_Char := 16#0924#;
   Devanagari_Letter_Tha                   : constant Unicode_Char := 16#0925#;
   Devanagari_Letter_Da                    : constant Unicode_Char := 16#0926#;
   Devanagari_Letter_Dha                   : constant Unicode_Char := 16#0927#;
   Devanagari_Letter_Na                    : constant Unicode_Char := 16#0928#;
   Devanagari_Letter_Nnna                  : constant Unicode_Char := 16#0929#;
   Devanagari_Letter_Pa                    : constant Unicode_Char := 16#092A#;
   Devanagari_Letter_Pha                   : constant Unicode_Char := 16#092B#;
   Devanagari_Letter_Ba                    : constant Unicode_Char := 16#092C#;
   Devanagari_Letter_Bha                   : constant Unicode_Char := 16#092D#;
   Devanagari_Letter_Ma                    : constant Unicode_Char := 16#092E#;
   Devanagari_Letter_Ya                    : constant Unicode_Char := 16#092F#;
   Devanagari_Letter_Ra                    : constant Unicode_Char := 16#0930#;
   Devanagari_Letter_Rra                   : constant Unicode_Char := 16#0931#;
   Devanagari_Letter_La                    : constant Unicode_Char := 16#0932#;
   Devanagari_Letter_Lla                   : constant Unicode_Char := 16#0933#;
   Devanagari_Letter_Llla                  : constant Unicode_Char := 16#0934#;
   Devanagari_Letter_Va                    : constant Unicode_Char := 16#0935#;
   Devanagari_Letter_Sha                   : constant Unicode_Char := 16#0936#;
   Devanagari_Letter_Ssa                   : constant Unicode_Char := 16#0937#;
   Devanagari_Letter_Sa                    : constant Unicode_Char := 16#0938#;
   Devanagari_Letter_Ha                    : constant Unicode_Char := 16#0939#;
   Devanagari_Vowel_Sign_Oe                : constant Unicode_Char := 16#093A#;
   Devanagari_Vowel_Sign_Ooe               : constant Unicode_Char := 16#093B#;
   Devanagari_Sign_Nukta                   : constant Unicode_Char := 16#093C#;
   Devanagari_Sign_Avagraha                : constant Unicode_Char := 16#093D#;
   Devanagari_Vowel_Sign_Aa                : constant Unicode_Char := 16#093E#;
   Devanagari_Vowel_Sign_I                 : constant Unicode_Char := 16#093F#;
   Devanagari_Vowel_Sign_Ii                : constant Unicode_Char := 16#0940#;
   Devanagari_Vowel_Sign_U                 : constant Unicode_Char := 16#0941#;
   Devanagari_Vowel_Sign_Uu                : constant Unicode_Char := 16#0942#;
   Devanagari_Vowel_Sign_Vocalic_R         : constant Unicode_Char := 16#0943#;
   Devanagari_Vowel_Sign_Vocalic_Rr        : constant Unicode_Char := 16#0944#;
   Devanagari_Vowel_Sign_Candra_E          : constant Unicode_Char := 16#0945#;
   Devanagari_Vowel_Sign_Short_E           : constant Unicode_Char := 16#0946#;
   Devanagari_Vowel_Sign_E                 : constant Unicode_Char := 16#0947#;
   Devanagari_Vowel_Sign_Ai                : constant Unicode_Char := 16#0948#;
   Devanagari_Vowel_Sign_Candra_O          : constant Unicode_Char := 16#0949#;
   Devanagari_Vowel_Sign_Short_O           : constant Unicode_Char := 16#094A#;
   Devanagari_Vowel_Sign_O                 : constant Unicode_Char := 16#094B#;
   Devanagari_Vowel_Sign_Au                : constant Unicode_Char := 16#094C#;
   Devanagari_Sign_Virama                  : constant Unicode_Char := 16#094D#;
   Devanagari_Vowel_Sign_Prishthamatra_E   : constant Unicode_Char := 16#094E#;
   Devanagari_Vowel_Sign_Aw                : constant Unicode_Char := 16#094F#;
   Devanagari_Om                           : constant Unicode_Char := 16#0950#;
   Devanagari_Stress_Sign_Udatta           : constant Unicode_Char := 16#0951#;
   Devanagari_Stress_Sign_Anudatta         : constant Unicode_Char := 16#0952#;
   Devanagari_Grave_Accent                 : constant Unicode_Char := 16#0953#;
   Devanagari_Acute_Accent                 : constant Unicode_Char := 16#0954#;
   Devanagari_Vowel_Sign_Candra_Long_E     : constant Unicode_Char := 16#0955#;
   Devanagari_Vowel_Sign_Ue                : constant Unicode_Char := 16#0956#;
   Devanagari_Vowel_Sign_Uue               : constant Unicode_Char := 16#0957#;
   Devanagari_Letter_Qa                    : constant Unicode_Char := 16#0958#;
   Devanagari_Letter_Khha                  : constant Unicode_Char := 16#0959#;
   Devanagari_Letter_Ghha                  : constant Unicode_Char := 16#095A#;
   Devanagari_Letter_Za                    : constant Unicode_Char := 16#095B#;
   Devanagari_Letter_Dddha                 : constant Unicode_Char := 16#095C#;
   Devanagari_Letter_Rha                   : constant Unicode_Char := 16#095D#;
   Devanagari_Letter_Fa                    : constant Unicode_Char := 16#095E#;
   Devanagari_Letter_Yya                   : constant Unicode_Char := 16#095F#;
   Devanagari_Letter_Vocalic_Rr            : constant Unicode_Char := 16#0960#;
   Devanagari_Letter_Vocalic_Ll            : constant Unicode_Char := 16#0961#;
   Devanagari_Vowel_Sign_Vocalic_L         : constant Unicode_Char := 16#0962#;
   Devanagari_Vowel_Sign_Vocalic_Ll        : constant Unicode_Char := 16#0963#;
   Devanagari_Danda                        : constant Unicode_Char := 16#0964#;
   Devanagari_Double_Danda                 : constant Unicode_Char := 16#0965#;
   Devanagari_Digit_Zero                   : constant Unicode_Char := 16#0966#;
   Devanagari_Digit_One                    : constant Unicode_Char := 16#0967#;
   Devanagari_Digit_Two                    : constant Unicode_Char := 16#0968#;
   Devanagari_Digit_Three                  : constant Unicode_Char := 16#0969#;
   Devanagari_Digit_Four                   : constant Unicode_Char := 16#096A#;
   Devanagari_Digit_Five                   : constant Unicode_Char := 16#096B#;
   Devanagari_Digit_Six                    : constant Unicode_Char := 16#096C#;
   Devanagari_Digit_Seven                  : constant Unicode_Char := 16#096D#;
   Devanagari_Digit_Eight                  : constant Unicode_Char := 16#096E#;
   Devanagari_Digit_Nine                   : constant Unicode_Char := 16#096F#;
   Devanagari_Abbreviation_Sign            : constant Unicode_Char := 16#0970#;
   Devanagari_Sign_High_Spacing_Dot        : constant Unicode_Char := 16#0971#;
   Devanagari_Letter_Candra_A              : constant Unicode_Char := 16#0972#;
   Devanagari_Letter_Oe                    : constant Unicode_Char := 16#0973#;
   Devanagari_Letter_Ooe                   : constant Unicode_Char := 16#0974#;
   Devanagari_Letter_Aw                    : constant Unicode_Char := 16#0975#;
   Devanagari_Letter_Ue                    : constant Unicode_Char := 16#0976#;
   Devanagari_Letter_Uue                   : constant Unicode_Char := 16#0977#;
   Devanagari_Letter_Marwari_Dda           : constant Unicode_Char := 16#0978#;
   Devanagari_Letter_Zha                   : constant Unicode_Char := 16#0979#;
   Devanagari_Letter_Heavy_Ya              : constant Unicode_Char := 16#097A#;
   Devanagari_Letter_Gga                   : constant Unicode_Char := 16#097B#;
   Devanagari_Letter_Jja                   : constant Unicode_Char := 16#097C#;
   Devanagari_Letter_Glottal_Stop          : constant Unicode_Char := 16#097D#;
   Devanagari_Letter_Ddda                  : constant Unicode_Char := 16#097E#;
   Devanagari_Letter_Bba                   : constant Unicode_Char := 16#097F#;
end Unicode.Names.Devanagari;
