--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Tamil is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Tamil_Sign_Anusvara                     : constant Unicode_Char := 16#0B82#;
   Tamil_Sign_Visarga                      : constant Unicode_Char := 16#0B83#;
   Tamil_Letter_A                          : constant Unicode_Char := 16#0B85#;
   Tamil_Letter_Aa                         : constant Unicode_Char := 16#0B86#;
   Tamil_Letter_I                          : constant Unicode_Char := 16#0B87#;
   Tamil_Letter_Ii                         : constant Unicode_Char := 16#0B88#;
   Tamil_Letter_U                          : constant Unicode_Char := 16#0B89#;
   Tamil_Letter_Uu                         : constant Unicode_Char := 16#0B8A#;
   Tamil_Letter_E                          : constant Unicode_Char := 16#0B8E#;
   Tamil_Letter_Ee                         : constant Unicode_Char := 16#0B8F#;
   Tamil_Letter_Ai                         : constant Unicode_Char := 16#0B90#;
   Tamil_Letter_O                          : constant Unicode_Char := 16#0B92#;
   Tamil_Letter_Oo                         : constant Unicode_Char := 16#0B93#;
   Tamil_Letter_Au                         : constant Unicode_Char := 16#0B94#;
   Tamil_Letter_Ka                         : constant Unicode_Char := 16#0B95#;
   Tamil_Letter_Nga                        : constant Unicode_Char := 16#0B99#;
   Tamil_Letter_Ca                         : constant Unicode_Char := 16#0B9A#;
   Tamil_Letter_Ja                         : constant Unicode_Char := 16#0B9C#;
   Tamil_Letter_Nya                        : constant Unicode_Char := 16#0B9E#;
   Tamil_Letter_Tta                        : constant Unicode_Char := 16#0B9F#;
   Tamil_Letter_Nna                        : constant Unicode_Char := 16#0BA3#;
   Tamil_Letter_Ta                         : constant Unicode_Char := 16#0BA4#;
   Tamil_Letter_Na                         : constant Unicode_Char := 16#0BA8#;
   Tamil_Letter_Nnna                       : constant Unicode_Char := 16#0BA9#;
   Tamil_Letter_Pa                         : constant Unicode_Char := 16#0BAA#;
   Tamil_Letter_Ma                         : constant Unicode_Char := 16#0BAE#;
   Tamil_Letter_Ya                         : constant Unicode_Char := 16#0BAF#;
   Tamil_Letter_Ra                         : constant Unicode_Char := 16#0BB0#;
   Tamil_Letter_Rra                        : constant Unicode_Char := 16#0BB1#;
   Tamil_Letter_La                         : constant Unicode_Char := 16#0BB2#;
   Tamil_Letter_Lla                        : constant Unicode_Char := 16#0BB3#;
   Tamil_Letter_Llla                       : constant Unicode_Char := 16#0BB4#;
   Tamil_Letter_Va                         : constant Unicode_Char := 16#0BB5#;
   Tamil_Letter_Sha                        : constant Unicode_Char := 16#0BB6#;
   Tamil_Letter_Ssa                        : constant Unicode_Char := 16#0BB7#;
   Tamil_Letter_Sa                         : constant Unicode_Char := 16#0BB8#;
   Tamil_Letter_Ha                         : constant Unicode_Char := 16#0BB9#;
   Tamil_Vowel_Sign_Aa                     : constant Unicode_Char := 16#0BBE#;
   Tamil_Vowel_Sign_I                      : constant Unicode_Char := 16#0BBF#;
   Tamil_Vowel_Sign_Ii                     : constant Unicode_Char := 16#0BC0#;
   Tamil_Vowel_Sign_U                      : constant Unicode_Char := 16#0BC1#;
   Tamil_Vowel_Sign_Uu                     : constant Unicode_Char := 16#0BC2#;
   Tamil_Vowel_Sign_E                      : constant Unicode_Char := 16#0BC6#;
   Tamil_Vowel_Sign_Ee                     : constant Unicode_Char := 16#0BC7#;
   Tamil_Vowel_Sign_Ai                     : constant Unicode_Char := 16#0BC8#;
   Tamil_Vowel_Sign_O                      : constant Unicode_Char := 16#0BCA#;
   Tamil_Vowel_Sign_Oo                     : constant Unicode_Char := 16#0BCB#;
   Tamil_Vowel_Sign_Au                     : constant Unicode_Char := 16#0BCC#;
   Tamil_Sign_Virama                       : constant Unicode_Char := 16#0BCD#;
   Tamil_Om                                : constant Unicode_Char := 16#0BD0#;
   Tamil_Au_Length_Mark                    : constant Unicode_Char := 16#0BD7#;
   Tamil_Digit_Zero                        : constant Unicode_Char := 16#0BE6#;
   Tamil_Digit_One                         : constant Unicode_Char := 16#0BE7#;
   Tamil_Digit_Two                         : constant Unicode_Char := 16#0BE8#;
   Tamil_Digit_Three                       : constant Unicode_Char := 16#0BE9#;
   Tamil_Digit_Four                        : constant Unicode_Char := 16#0BEA#;
   Tamil_Digit_Five                        : constant Unicode_Char := 16#0BEB#;
   Tamil_Digit_Six                         : constant Unicode_Char := 16#0BEC#;
   Tamil_Digit_Seven                       : constant Unicode_Char := 16#0BED#;
   Tamil_Digit_Eight                       : constant Unicode_Char := 16#0BEE#;
   Tamil_Digit_Nine                        : constant Unicode_Char := 16#0BEF#;
   Tamil_Number_Ten                        : constant Unicode_Char := 16#0BF0#;
   Tamil_Number_One_Hundred                : constant Unicode_Char := 16#0BF1#;
   Tamil_Number_One_Thousand               : constant Unicode_Char := 16#0BF2#;
   Tamil_Day_Sign                          : constant Unicode_Char := 16#0BF3#;
   Tamil_Month_Sign                        : constant Unicode_Char := 16#0BF4#;
   Tamil_Year_Sign                         : constant Unicode_Char := 16#0BF5#;
   Tamil_Debit_Sign                        : constant Unicode_Char := 16#0BF6#;
   Tamil_Credit_Sign                       : constant Unicode_Char := 16#0BF7#;
   Tamil_As_Above_Sign                     : constant Unicode_Char := 16#0BF8#;
   Tamil_Rupee_Sign                        : constant Unicode_Char := 16#0BF9#;
   Tamil_Number_Sign                       : constant Unicode_Char := 16#0BFA#;
end Unicode.Names.Tamil;
