--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Transport_And_Map_Symbols is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Rocket                                  :
      constant Unicode_Char := 16#1F680#;
   Helicopter                              :
      constant Unicode_Char := 16#1F681#;
   Steam_Locomotive                        :
      constant Unicode_Char := 16#1F682#;
   Railway_Car                             :
      constant Unicode_Char := 16#1F683#;
   High_Speed_Train                        :
      constant Unicode_Char := 16#1F684#;
   High_Speed_Train_With_Bullet_Nose       :
      constant Unicode_Char := 16#1F685#;
   Train                                   :
      constant Unicode_Char := 16#1F686#;
   Metro                                   :
      constant Unicode_Char := 16#1F687#;
   Light_Rail                              :
      constant Unicode_Char := 16#1F688#;
   Station                                 :
      constant Unicode_Char := 16#1F689#;
   Tram                                    :
      constant Unicode_Char := 16#1F68A#;
   Tram_Car                                :
      constant Unicode_Char := 16#1F68B#;
   Bus                                     :
      constant Unicode_Char := 16#1F68C#;
   Oncoming_Bus                            :
      constant Unicode_Char := 16#1F68D#;
   Trolleybus                              :
      constant Unicode_Char := 16#1F68E#;
   Bus_Stop                                :
      constant Unicode_Char := 16#1F68F#;
   Minibus                                 :
      constant Unicode_Char := 16#1F690#;
   Ambulance                               :
      constant Unicode_Char := 16#1F691#;
   Fire_Engine                             :
      constant Unicode_Char := 16#1F692#;
   Police_Car                              :
      constant Unicode_Char := 16#1F693#;
   Oncoming_Police_Car                     :
      constant Unicode_Char := 16#1F694#;
   Taxi                                    :
      constant Unicode_Char := 16#1F695#;
   Oncoming_Taxi                           :
      constant Unicode_Char := 16#1F696#;
   Automobile                              :
      constant Unicode_Char := 16#1F697#;
   Oncoming_Automobile                     :
      constant Unicode_Char := 16#1F698#;
   Recreational_Vehicle                    :
      constant Unicode_Char := 16#1F699#;
   Delivery_Truck                          :
      constant Unicode_Char := 16#1F69A#;
   Articulated_Lorry                       :
      constant Unicode_Char := 16#1F69B#;
   Tractor                                 :
      constant Unicode_Char := 16#1F69C#;
   Monorail                                :
      constant Unicode_Char := 16#1F69D#;
   Mountain_Railway                        :
      constant Unicode_Char := 16#1F69E#;
   Suspension_Railway                      :
      constant Unicode_Char := 16#1F69F#;
   Mountain_Cableway                       :
      constant Unicode_Char := 16#1F6A0#;
   Aerial_Tramway                          :
      constant Unicode_Char := 16#1F6A1#;
   Ship                                    :
      constant Unicode_Char := 16#1F6A2#;
   Rowboat                                 :
      constant Unicode_Char := 16#1F6A3#;
   Speedboat                               :
      constant Unicode_Char := 16#1F6A4#;
   Horizontal_Traffic_Light                :
      constant Unicode_Char := 16#1F6A5#;
   Vertical_Traffic_Light                  :
      constant Unicode_Char := 16#1F6A6#;
   Construction_Sign                       :
      constant Unicode_Char := 16#1F6A7#;
   Police_Cars_Revolving_Light             :
      constant Unicode_Char := 16#1F6A8#;
   Triangular_Flag_On_Post                 :
      constant Unicode_Char := 16#1F6A9#;
   Door                                    :
      constant Unicode_Char := 16#1F6AA#;
   No_Entry_Sign                           :
      constant Unicode_Char := 16#1F6AB#;
   Smoking_Symbol                          :
      constant Unicode_Char := 16#1F6AC#;
   No_Smoking_Symbol                       :
      constant Unicode_Char := 16#1F6AD#;
   Put_Litter_In_Its_Place_Symbol          :
      constant Unicode_Char := 16#1F6AE#;
   Do_Not_Litter_Symbol                    :
      constant Unicode_Char := 16#1F6AF#;
   Potable_Water_Symbol                    :
      constant Unicode_Char := 16#1F6B0#;
   Non_Potable_Water_Symbol                :
      constant Unicode_Char := 16#1F6B1#;
   Bicycle                                 :
      constant Unicode_Char := 16#1F6B2#;
   No_Bicycles                             :
      constant Unicode_Char := 16#1F6B3#;
   Bicyclist                               :
      constant Unicode_Char := 16#1F6B4#;
   Mountain_Bicyclist                      :
      constant Unicode_Char := 16#1F6B5#;
   Pedestrian                              :
      constant Unicode_Char := 16#1F6B6#;
   No_Pedestrians                          :
      constant Unicode_Char := 16#1F6B7#;
   Children_Crossing                       :
      constant Unicode_Char := 16#1F6B8#;
   Mens_Symbol                             :
      constant Unicode_Char := 16#1F6B9#;
   Womens_Symbol                           :
      constant Unicode_Char := 16#1F6BA#;
   Restroom                                :
      constant Unicode_Char := 16#1F6BB#;
   Baby_Symbol                             :
      constant Unicode_Char := 16#1F6BC#;
   Toilet                                  :
      constant Unicode_Char := 16#1F6BD#;
   Water_Closet                            :
      constant Unicode_Char := 16#1F6BE#;
   Shower                                  :
      constant Unicode_Char := 16#1F6BF#;
   Bath                                    :
      constant Unicode_Char := 16#1F6C0#;
   Bathtub                                 :
      constant Unicode_Char := 16#1F6C1#;
   Passport_Control                        :
      constant Unicode_Char := 16#1F6C2#;
   Customs                                 :
      constant Unicode_Char := 16#1F6C3#;
   Baggage_Claim                           :
      constant Unicode_Char := 16#1F6C4#;
   Left_Luggage                            :
      constant Unicode_Char := 16#1F6C5#;
   Triangle_With_Rounded_Corners           :
      constant Unicode_Char := 16#1F6C6#;
   Prohibited_Sign                         :
      constant Unicode_Char := 16#1F6C7#;
   Circled_Information_Source              :
      constant Unicode_Char := 16#1F6C8#;
   Boys_Symbol                             :
      constant Unicode_Char := 16#1F6C9#;
   Girls_Symbol                            :
      constant Unicode_Char := 16#1F6CA#;
   Couch_And_Lamp                          :
      constant Unicode_Char := 16#1F6CB#;
   Sleeping_Accommodation                  :
      constant Unicode_Char := 16#1F6CC#;
   Shopping_Bags                           :
      constant Unicode_Char := 16#1F6CD#;
   Bellhop_Bell                            :
      constant Unicode_Char := 16#1F6CE#;
   Bed                                     :
      constant Unicode_Char := 16#1F6CF#;
   Place_Of_Worship                        :
      constant Unicode_Char := 16#1F6D0#;
   Hammer_And_Wrench                       :
      constant Unicode_Char := 16#1F6E0#;
   Shield                                  :
      constant Unicode_Char := 16#1F6E1#;
   Oil_Drum                                :
      constant Unicode_Char := 16#1F6E2#;
   Motorway                                :
      constant Unicode_Char := 16#1F6E3#;
   Railway_Track                           :
      constant Unicode_Char := 16#1F6E4#;
   Motor_Boat                              :
      constant Unicode_Char := 16#1F6E5#;
   Up_Pointing_Military_Airplane           :
      constant Unicode_Char := 16#1F6E6#;
   Up_Pointing_Airplane                    :
      constant Unicode_Char := 16#1F6E7#;
   Up_Pointing_Small_Airplane              :
      constant Unicode_Char := 16#1F6E8#;
   Small_Airplane                          :
      constant Unicode_Char := 16#1F6E9#;
   Northeast_Pointing_Airplane             :
      constant Unicode_Char := 16#1F6EA#;
   Airplane_Departure                      :
      constant Unicode_Char := 16#1F6EB#;
   Airplane_Arriving                       :
      constant Unicode_Char := 16#1F6EC#;
   Satellite                               :
      constant Unicode_Char := 16#1F6F0#;
   Oncoming_Fire_Engine                    :
      constant Unicode_Char := 16#1F6F1#;
   Diesel_Locomotive                       :
      constant Unicode_Char := 16#1F6F2#;
   Passenger_Ship                          :
      constant Unicode_Char := 16#1F6F3#;
end Unicode.Names.Transport_And_Map_Symbols;
