--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Old_Persian is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Old_Persian_Sign_A                      :
      constant Unicode_Char := 16#103A0#;
   Old_Persian_Sign_I                      :
      constant Unicode_Char := 16#103A1#;
   Old_Persian_Sign_U                      :
      constant Unicode_Char := 16#103A2#;
   Old_Persian_Sign_Ka                     :
      constant Unicode_Char := 16#103A3#;
   Old_Persian_Sign_Ku                     :
      constant Unicode_Char := 16#103A4#;
   Old_Persian_Sign_Ga                     :
      constant Unicode_Char := 16#103A5#;
   Old_Persian_Sign_Gu                     :
      constant Unicode_Char := 16#103A6#;
   Old_Persian_Sign_Xa                     :
      constant Unicode_Char := 16#103A7#;
   Old_Persian_Sign_Ca                     :
      constant Unicode_Char := 16#103A8#;
   Old_Persian_Sign_Ja                     :
      constant Unicode_Char := 16#103A9#;
   Old_Persian_Sign_Ji                     :
      constant Unicode_Char := 16#103AA#;
   Old_Persian_Sign_Ta                     :
      constant Unicode_Char := 16#103AB#;
   Old_Persian_Sign_Tu                     :
      constant Unicode_Char := 16#103AC#;
   Old_Persian_Sign_Da                     :
      constant Unicode_Char := 16#103AD#;
   Old_Persian_Sign_Di                     :
      constant Unicode_Char := 16#103AE#;
   Old_Persian_Sign_Du                     :
      constant Unicode_Char := 16#103AF#;
   Old_Persian_Sign_Tha                    :
      constant Unicode_Char := 16#103B0#;
   Old_Persian_Sign_Pa                     :
      constant Unicode_Char := 16#103B1#;
   Old_Persian_Sign_Ba                     :
      constant Unicode_Char := 16#103B2#;
   Old_Persian_Sign_Fa                     :
      constant Unicode_Char := 16#103B3#;
   Old_Persian_Sign_Na                     :
      constant Unicode_Char := 16#103B4#;
   Old_Persian_Sign_Nu                     :
      constant Unicode_Char := 16#103B5#;
   Old_Persian_Sign_Ma                     :
      constant Unicode_Char := 16#103B6#;
   Old_Persian_Sign_Mi                     :
      constant Unicode_Char := 16#103B7#;
   Old_Persian_Sign_Mu                     :
      constant Unicode_Char := 16#103B8#;
   Old_Persian_Sign_Ya                     :
      constant Unicode_Char := 16#103B9#;
   Old_Persian_Sign_Va                     :
      constant Unicode_Char := 16#103BA#;
   Old_Persian_Sign_Vi                     :
      constant Unicode_Char := 16#103BB#;
   Old_Persian_Sign_Ra                     :
      constant Unicode_Char := 16#103BC#;
   Old_Persian_Sign_Ru                     :
      constant Unicode_Char := 16#103BD#;
   Old_Persian_Sign_La                     :
      constant Unicode_Char := 16#103BE#;
   Old_Persian_Sign_Sa                     :
      constant Unicode_Char := 16#103BF#;
   Old_Persian_Sign_Za                     :
      constant Unicode_Char := 16#103C0#;
   Old_Persian_Sign_Sha                    :
      constant Unicode_Char := 16#103C1#;
   Old_Persian_Sign_Ssa                    :
      constant Unicode_Char := 16#103C2#;
   Old_Persian_Sign_Ha                     :
      constant Unicode_Char := 16#103C3#;
   Old_Persian_Sign_Auramazdaa             :
      constant Unicode_Char := 16#103C8#;
   Old_Persian_Sign_Auramazdaa_2           :
      constant Unicode_Char := 16#103C9#;
   Old_Persian_Sign_Auramazdaaha           :
      constant Unicode_Char := 16#103CA#;
   Old_Persian_Sign_Xshaayathiya           :
      constant Unicode_Char := 16#103CB#;
   Old_Persian_Sign_Dahyaaush              :
      constant Unicode_Char := 16#103CC#;
   Old_Persian_Sign_Dahyaaush_2            :
      constant Unicode_Char := 16#103CD#;
   Old_Persian_Sign_Baga                   :
      constant Unicode_Char := 16#103CE#;
   Old_Persian_Sign_Buumish                :
      constant Unicode_Char := 16#103CF#;
   Old_Persian_Word_Divider                :
      constant Unicode_Char := 16#103D0#;
   Old_Persian_Number_One                  :
      constant Unicode_Char := 16#103D1#;
   Old_Persian_Number_Two                  :
      constant Unicode_Char := 16#103D2#;
   Old_Persian_Number_Ten                  :
      constant Unicode_Char := 16#103D3#;
   Old_Persian_Number_Twenty               :
      constant Unicode_Char := 16#103D4#;
   Old_Persian_Number_Hundred              :
      constant Unicode_Char := 16#103D5#;
end Unicode.Names.Old_Persian;
